// PrecisionTimer.h : PreciseTimer declaration
//
// Note:
// - Under Windows, class PrecisionTimer requires multi-media timers.
//   With Microsoft Visual C++ this is achieved by adding "winmm.lib" to "Project Properties > Linker > Input > Additional Dependencies".
//   Alternatively, this may achieved using a suitable "pragma comment".



#ifndef precisionTimer_INCLUDED
#define precisionTimer_INCLUDED



#ifdef __cplusplus
extern "C" {
#endif



#if defined (VX_WORKS)
//#define INCLUDE_getTimeZone
#ifdef INCLUDE_getTimeZone
void getTimeZone (time_t t, int* ipMin, int* ipDst);
#endif // INCLUDE_getTimeZone
int gettimeofday (struct timeval *tv, struct timezone *tz);
#endif // VX_WORKS


	
class PrecisionTimer
{
	public:

	PrecisionTimer (void);
	~PrecisionTimer (void);

	int SetTimeUnit (unsigned int uiTimeUnitsPerSecond);
	void SetBaseTime (void);
	double GetBaseTime (void);
	void SetEndTime (void);
	double GetEndTime (void);
	double GetDuration (void);
	double GetTime (void);
	void AccuratelySleep (unsigned int uiMilliseconds);

	private:

#if defined(WIN32)

	LARGE_INTEGER liBaseTime;
	LARGE_INTEGER liEndTime;
	LARGE_INTEGER liFrequencyPerSecond; // the frequency of the multimedia timer.
	unsigned int uiTimeUnitsPerSecond; // see the description in method SetTimeUnit().
	unsigned int uiTimerResolution; // timer resolution to use with multimedia timers.
	HANDLE hSleepSyncObject; // a synchronization object used to signal end of sleeping periods.
	static VOID CALLBACK TimerRoutine (UINT uTimerID, UINT uMsg, DWORD_PTR dwUser, DWORD_PTR dw1, DWORD_PTR dw2);

#elif ( defined(__unix__) || defined (VX_WORKS) )

	struct timeval tvBaseTime;
	struct timeval tvEndTime;
	unsigned int uiTimeUnitsPerSecond; // see the description in method SetTimeUnit().

#endif // __unix__ || VX_WORKS
};



#ifdef __cplusplus
}
#endif



#endif // precisionTimer_INCLUDED
