// Description  : A console application that tests Sital's stld1553 library.
// Version      : 1.0.0.0
// Author       : Ofer I. Elboher
//
// Note:
// - All configuration functions must adhere the following rules in order to be used with Sital's TestPlanRunner app:
//   - have one of the following signatures:
//     - S16BIT _DECL <name-of-configuration-function> ()
//     - S16BIT _DECL <name-of-configuration-function> (int iIntegerParameter)
//     - S16BIT _DECL <name-of-configuration-function> (char* szNullTerminatedStringParameter)
//   - Return the following values:
//     - sitalReturnCode_SUCCESS if function successfully completed.
//     - Negative sitalReturnCode_* if an error condition encountered or function failed.
// - All test functions must adhere the following rules in order to be used with Sital's TestPlanRunner app:
//   - have the following signature: S16BIT _DECL <name-of-test-function> ()
//   - Return the following values:
//     - sitalReturnCode_SUCCESS if function successfully completed.
//     - Negative sitalReturnCode_* if an error condition encountered or function failed.
// - Sital supports the following architectures:
//   - Using BOTH Sital and DDC function, structure, and constant names over Sital's stld1553 library.
//     Such users must BOTH define macro ENABLE_USAGE_OF_DDC_NAMING *AND* undefine macro USE_DDC_LIBRARY.
//   - Using BOTH Sital and DDC function, structure, and constant names over Sital's DDC-like library.
//     Such users must define macro USE_DDC_LIBRARY.
//   (See both macro definitions below.)
// - With all below defined Acceptance Test Plan functions stldTester_Atp_DoTest*:
//   - A list of participant devices in the following form is specified for each such test function:
//     Participant[s]: <list of devices>.
//     Within this list, each device is specified in the pattern <device-type>[<device-logical-number>] (e.g., RT, BC, MT, 1, 2, 3, 4, RT1, BC2, MT3, RT4), where:
//     - <device-type> is either TEST, RT, BC, or MT.
//       In case the device-type isn't specified, it means that given device is used, but as a general device on its card, and not as a device of a specific device-type.
//     - <device-logical-number> is the index of a below defined s_swDevice* ATP variable that is used by this test function for the related device.
//       In case the device-logical-index isn't specified, it means that such a device is used, but its device-logical-number may not be dynamically configured by the caller.
//   - The addresses that are set for participating RTs arte as follows: s_wRtAddress1 for the first listed RT, s_wRtAddress2 for the second one, &c.
//
// Modification history:
//

#include "stdafx.h"
#include <stdio.h>
#include <stdlib.h>
#include "PrecisionTimer.h"
#include "InterProcessSemaphore.h"
//#define USE_DDC_LIBRARY
//#define ENABLE_USAGE_OF_DDC_NAMING
#include "OperatingSystemDependencies.h"
// Note:
// - In case the library that's actually used while running is:
//   - Sital's own stld1553 library:
//     - Un-define USE_DDC_LIBRARY for both Debug and Release versions in Project Properties > C/C++ > Preprocessor Definitions (may also be done below, uniquely within each file where required).
//     - If in below defined function BOTH Sital and DDC function, structure, and constant names are used: define ENABLE_USAGE_OF_DDC_NAMING for both Debug and Release versions in Project Properties > C/C++ > Preprocessor Definitions (may also be done below, uniquely within each file where required).
//     - Add "Debug\Stld1553.lib" for the debug version and "Release\Stld1553.lib" for the release version in Project Properties > Linker > Input > Additional Dependencies.
//   - Either DDC's original library over DDC cards *OR* Sital's DDC-like library over Sital card:
//     - Add "..\DdcRemakeOverSitalCards\stlemace\Include" for both Debug and Release versions in Project Properties > C/C++ > General > Additional Include Directories.
//     - Add the path to the library to use in Project Properties > Linker > Input > Additional Dependencies.
//       E.g., for Sital's DDC-like library over Sital card add "..\DdcRemakeOverSitalCards\emace_32.lib" for both Debug and Release versions.
#ifndef USE_DDC_LIBRARY
#include "stld1553_returnCodes.h"
#include "stld1553.h"
#ifdef ENABLE_USAGE_OF_DDC_NAMING
#include "ddc2stld1553.h"
#endif // ENABLE_USAGE_OF_DDC_NAMING
#else // USE_DDC_LIBRARY
#include "stdemace.h" // File located at directory "..\DdcRemakeOverSitalCards\stlemace\Include".
#include "UniqueStldDefs.h"
#include "stld2ddc.h"
#endif // USE_DDC_LIBRARY
#include "stld1553_driverInterface.h"
#include "TestsBySital.h"



// Compilation flag definitions.
// TEMP => mute logs...
//#define CREATE_DRIVER_LOG



// constant definitions.
// The following constants are defined in v=favor of operating systems that does not use version info resources (e.g., Linux).
// Note that #ifdef &c compiler directives may not be used in this file.
#ifdef __unix__
#define versionNumber_Major			1
#define versionNumber_Minor			0
#define versionNumber_Build			0
#define versionNumber_Revision		1
#endif // __unix__



// macro definitions.



// enumeration definitions.



// structure definitions.



// static variables.



// internal function declarations.
S16BIT GetVersion (WORD* wpMajorVersion, WORD* wpMinorVersion, WORD* wpBuildNumber, WORD* wpRevisionNumber);
S16BIT CheckVersion ();



// internal functions.

/// <summary>
/// Get the version numbers of this application.
///
/// @param wpMajorVersion (out)	A pointer to a variable within which the major version number is returned
/// @param wpMinorVersion (out)	A pointer to a variable within which the minor version number is returned
/// @param wpBuildNumber (out)	A pointer to a variable within which the build number is returned
/// @param wpRevisionNumber (out)	A pointer to a variable within which the revision number is returned
/// @return sitalReturnCode_SUCCESS	Function successfully completed
/// @return Negative sitalReturnCode_*	Error condition or function failed
/// </summary>
S16BIT GetVersion (WORD* wpMajorVersion, WORD* wpMinorVersion, WORD* wpBuildNumber, WORD* wpRevisionNumber)
{
	/// @pseudocode

	/// If any state irrelevancy or illegal input parameter or operation failure is identified:
	///		Return error.

	if ((((U16BIT*)NULL) == wpMajorVersion) || (((U16BIT*)NULL) == wpMinorVersion) || (((U16BIT*)NULL) == wpBuildNumber) || (((U16BIT*)NULL) == wpRevisionNumber))
	{
		return sitalReturnCode_INVALID_PARAMETER;
	}

#if defined(WIN32)
	char szLibName[] = "StldTesterConsoleApp.exe";
	DWORD dwHandle;
	DWORD dwLen;
	UINT uiBufLen;
	LPTSTR lpData;
	VS_FIXEDFILEINFO* pFileInfo;

	dwLen = GetFileVersionInfoSize (szLibName, &dwHandle);
	if (!dwLen)
	{
		return sitalReturnCode_UNKNOWN_ERROR;
	}

	lpData = (LPTSTR) malloc (dwLen);
	if (!lpData)
	{
		return sitalReturnCode_INVALID_ALLOCATION;
	}

	if ( ! GetFileVersionInfo (szLibName, dwHandle, dwLen, lpData) )
	{
		free (lpData);
		return sitalReturnCode_INVALID_ACCESS;
	}

	if ( ! VerQueryValue (lpData, "\\", (LPVOID*)&pFileInfo, (PUINT)&uiBufLen) )
	{
		free (lpData);
		return sitalReturnCode_VERSION_ERROR;
	}

	*wpMajorVersion = HIWORD(pFileInfo->dwFileVersionMS);
	*wpMinorVersion = LOWORD(pFileInfo->dwFileVersionMS);
	*wpBuildNumber = HIWORD(pFileInfo->dwFileVersionLS);
	*wpRevisionNumber = LOWORD(pFileInfo->dwFileVersionLS);

	free (lpData);

#elif defined(__unix__)
	/// Return built-in numbers.
	*wpMajorVersion = versionNumber_Major;
	*wpMinorVersion = versionNumber_Minor;
	*wpBuildNumber = versionNumber_Build;
	*wpRevisionNumber = versionNumber_Revision;
#endif // __unix__

	return sitalReturnCode_SUCCESS;
}


/// <summary>
/// Get the version numbers of this application and those of stld1553 DLL, and verify that these versions suit.
///
/// @return sitalReturnCode_SUCCESS	Function successfully completed
/// @return Negative sitalReturnCode_*	Error condition or function failed
/// </summary>
S16BIT CheckVersion ()
{
	/// @pseudocode

	/// If any state irrelevancy or illegal input parameter or operation failure is identified:
	///		Return error.

	// When using the DDC (or a DDC-like) library, un-include code that is unique to Sital and isn't supported by DDC.
#ifndef USE_DDC_LIBRARY
	U16BIT wMajorVersionDll, wMinorVersionDll, wBuildNumberDll, wRevisionNumberDll;
	U16BIT wMajorVersionApp, wMinorVersionApp, wBuildNumberApp, wRevisionNumberApp;

	/// Display version numbers for this app and used DLL.
	S16BIT swResult; // Result of operation or function call.
	swResult = GetVersion (&wMajorVersionApp, &wMinorVersionApp, &wBuildNumberApp, &wRevisionNumberApp);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#Error: Failed to get version info for StldTesterApp\n");
		return sitalReturnCode_VERSION_ERROR;
	}
	sitalProcess_Log_PrintLine ("#StldTesterApp version: %i.%i.%i.%i\n", wMajorVersionApp, wMinorVersionApp, wBuildNumberApp, wRevisionNumberApp);

	swResult = sitalStld1553_GetLibraryVersion (&wMajorVersionDll, &wMinorVersionDll, &wBuildNumberDll, &wRevisionNumberDll);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#Error: Failed to get version info for Stld1553 DLL\n");
		return swResult;
	}
	sitalProcess_Log_PrintLine ("#Stld1553.DLL version: %i.%i.%i.%i\n", wMajorVersionDll, wMinorVersionDll, wBuildNumberDll, wRevisionNumberDll);
	if ((wMajorVersionApp != wMajorVersionDll) || (wMinorVersionApp != wMinorVersionDll) || (wBuildNumberApp != wBuildNumberDll))
	{
		sitalProcess_Log_PrintLine ("#StldTester.Version.Error: This version of StldTesterApp does not suit that of existing Stld1553 DLL\n");
		return sitalReturnCode_VERSION_ERROR;
	}
#endif // USE_DDC_LIBRARY

	return sitalReturnCode_SUCCESS;
}



/// <summary>
/// Main application function.
/// Perform the desired tests, and log the results.
///
/// @param argc (in)	(Standard)
/// @param argv (in)	(Standard)
/// @return sitalReturnCode_SUCCESS	Function successfully completed
/// @return Negative sitalReturnCode_*	Error condition or function failed
/// </summary>
int main (int argc, char * argv[])
{
	//U16BIT wCommandWord;
	//sitalBc_Command_GetWord (sitalOpcode_CALL_SUBROUTINE, sitalOpcodeCondition_NEVER, &wCommandWord);
	//printf_s ("command=%04X", wCommandWord);
	//printf ("%s\n", __FUNCTION__);
	//return sitalReturnCode_SUCCESS;

	/// @pseudocode

	/// If any state irrelevancy or illegal input parameter or operation failure is identified:
	///		Return error.

	S16BIT swResult; // Result of operation or function call.
#ifdef CREATE_DRIVER_LOG
	/// Instruct the device driver interface library to report device i/o operations to a log file.
	// When working with any Windows operating-system the path of the log is taken from registry value "file" under [HKEY_CURRENT_USER\Software\sital\trace-profiles\default].
	// In case this registry value cannot be found, the log starter function will fail.
	swResult = sitalProcess_Log_Start (NULL);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		printf ("#StldTester.ProcessLog.Start.Error: err - %i\n", swResult);
		return 0;
	}
#endif /// CREATE_DRIVER_LOG

	/// Verify that the version numbers of this app and stld1553 DLL suit.
	swResult = CheckVersion ();
	if (sitalReturnCode_SUCCESS != swResult)
	{
		return 0;
	}

	/// Call a desired test function.
#ifdef DO_ALL_BASIC_ATP_TESTS
	unsigned long counter = 0;
	while (counter < 0xFFFFFFFFFFFF) {
		swResult = stldTester_Atp_DoTest461_11a();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11a %i", swResult);
		swResult = stldTester_Atp_DoTest461_11b();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11b %i", swResult);
		swResult = stldTester_Atp_DoTest461_11c();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11c %i", swResult);
		swResult = stldTester_Atp_DoTest461_11d();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11d %i", swResult);
		swResult = stldTester_Atp_DoTest461_11e_Isr1_Bit00();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11e_Isr1_Bit00 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11e_Isr1_Bit01();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11e_Isr1_Bit01 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11e_Isr1_Bit02();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11e_Isr1_Bit02 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11e_Isr1_Bit03();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11e_Isr1_Bit03 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11e_Isr1_Bit04();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11e_Isr1_Bit04 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11e_Isr1_Bit06();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11e_Isr1_Bit06 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11e_Isr1_Bit07();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11e_Isr1_Bit07 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11e_Isr1_Bit08();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11e_Isr1_Bit08 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11e_Isr2_Bit00();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11e_Isr2_Bit00 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11e_Isr2_Bit01();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11e_Isr2_Bit01 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11e_Isr2_Bits02To05();if(swResult < 0)  printf("\nstldTester_Atp_DoTest461_11e_Isr2_Bits02To05 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11e_Isr2_Bit10();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11e_Isr2_Bit10 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11e_Isr2_Bit11();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11e_Isr2_Bit11 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11e_Isr2_Bit12();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11e_Isr2_Bit12 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11e_Isr2_Bit14();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11e_Isr2_Bit14 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11e_Isr1_Bits10To11_And_Isr2_Bits06To07();if(swResult < 0)  printf("\nstldTester_Atp_DoTest461_11e_Isr1_Bits10To11_And_Isr2_Bits06To07 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11f();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11f %i", swResult);
		swResult = stldTester_Atp_DoTest461_11g();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11g %i", swResult);
		swResult = stldTester_Atp_DoTest461_11h();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11h %i", swResult);
		swResult = stldTester_Atp_DoTest461_11j();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11j %i", swResult);
		swResult = stldTester_Atp_DoTest461_11k_1();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11k_1 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11k_2();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11k_2 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11k_4();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11k_4 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11k_5();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11k_5 %i", swResult);
		swResult = stldTester_Atp_DoTest461_11l();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11l %i", swResult);
		swResult = stldTester_Atp_DoTest461_11m_Low();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11m_Low %i", swResult);
		swResult = stldTester_Atp_DoTest461_11m_High();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11m_High %i", swResult);
		swResult = stldTester_Atp_DoTest461_11n();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_11n %i", swResult);
		swResult = stldTester_Atp_DoTest461_13a();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_13a %i", swResult);
		swResult = stldTester_Atp_DoTest461_13b();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_13b %i", swResult);
		swResult = stldTester_Atp_DoTest461_13c();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_13c %i", swResult);
		swResult = stldTester_Atp_DoTest461_13e();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_13e %i", swResult);
		swResult = stldTester_Atp_DoTest461_13f();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_13f %i", swResult);
		swResult = stldTester_Atp_DoTest461_13g();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_13g %i", swResult);
		swResult = stldTester_Atp_DoTest461_13h();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_13h %i", swResult);
		swResult = stldTester_Atp_DoTest461_13i();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_13i %i", swResult);
		swResult = stldTester_Atp_DoTest461_13j();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_13j %i", swResult);
		swResult = stldTester_Atp_DoTest461_13k_1();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_13k_1 %i", swResult);
		swResult = stldTester_Atp_DoTest461_13k_2();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_13k_2 %i", swResult);
		swResult = stldTester_Atp_DoTest461_13l();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_13l %i", swResult);
		swResult = stldTester_Atp_DoTest461_13m(); if(swResult < 0) printf("\nstldTester_Atp_DoTest461_13m %i", swResult);// Fails: Sital RT returns status 0x0400 (ME bit on) in case it is the transmitter RT of a RT-to-RT message that is directed to one of its illegalized sub-addresses.
		swResult = stldTester_Atp_DoTest461_15b();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_15b %i", swResult);
		swResult = stldTester_Atp_DoTest461_15f();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_15f %i", swResult);
		swResult = stldTester_Atp_DoTest461_15g();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_15g %i", swResult);
		swResult = stldTester_Atp_DoTest461_15h();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_15h %i", swResult);
		swResult = stldTester_Atp_DoTest461_15i();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_15i %i", swResult);
		swResult = stldTester_Atp_DoTest461_16a();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_16a %i", swResult);
		swResult = stldTester_Atp_DoTest461_EmptyFrame();if(swResult < 0) printf("\nstldTester_Atp_DoTest461_EmptyFrame %i", swResult);
		swResult = stldTester_BcRt_RtPostSynchronizationBehavior();if(swResult < 0) printf("\nstldTester_BcRt_RtPostSynchronizationBehavior %i", swResult);
		swResult = stldTester_Bc_InternalTests();if(swResult < 0) printf("\nstldTester_Bc_InternalTests %i", swResult);

		printf("\niteration %lu", counter);
		counter++;
	}
#else // NOT DO_ALL_BASIC_ATP_TESTS
	//swResult = stldTester_Bc_Isr ();
	//swResult = stldTester_Bc_LowPriorityAsynchronousMessages ();
	//swResult = stldTester_Bc_HighPriorityAsynchronousMessages ();
	//swResult = stldTester_BcRt_DataRxTx ();
	//swResult = Bc_HostBuffer ();
	//swResult = stldTester_Bc_TimeTag ();
	//swResult = stldTester_Bc_OpenCloseDevice ();
	//swResult = stldTester_BcRtRtMt_FrameContainingAllMessageTypes ();
	//swResult = stldTester_BcMultiRt_DataRxTx ();
	//swResult = stldTester_Atp_DoTest461_11a ();
	//swResult = stldTester_Atp_DoTest461_11b ();
	//swResult = stldTester_Atp_DoTest461_11c ();
	//swResult = stldTester_Atp_DoTest461_11d ();
	//swResult = stldTester_Atp_DoTest461_11e_Isr1_Bit00 ();
	//swResult = stldTester_Atp_DoTest461_11e_Isr1_Bit01 ();
	//swResult = stldTester_Atp_DoTest461_11e_Isr1_Bit02 ();
	//swResult = stldTester_Atp_DoTest461_11e_Isr1_Bit03 ();
	//swResult = stldTester_Atp_DoTest461_11e_Isr1_Bit04 ();
	//swResult = stldTester_Atp_DoTest461_11e_Isr1_Bit06 ();
	//swResult = stldTester_Atp_DoTest461_11e_Isr1_Bit07 ();
	//swResult = stldTester_Atp_DoTest461_11e_Isr1_Bit08 ();
	//swResult = stldTester_Atp_DoTest461_11e_Isr2_Bit00 ()`;
	//swResult = stldTester_Atp_DoTest461_11e_Isr2_Bit01 ();
	//swResult = stldTester_Atp_DoTest461_11e_Isr2_Bits02To05 ();
	//swResult = stldTester_Atp_DoTest461_11e_Isr2_Bit10 ();
	//swResult = stldTester_Atp_DoTest461_11e_Isr2_Bit11 ();
	//swResult = stldTester_Atp_DoTest461_11e_Isr2_Bit12 ();
	//swResult = stldTester_Atp_DoTest461_11e_Isr2_Bit14 ();
	//swResult = stldTester_Atp_DoTest461_11e_Isr1_Bits10To11_And_Isr2_Bits06To07 ();
	//swResult = stldTester_Atp_DoTest461_11f ();
	//swResult = stldTester_Atp_DoTest461_11g ();
	//swResult = stldTester_Atp_DoTest461_11h ();
	//swResult = stldTester_Atp_DoTest461_11j ();
	//swResult = stldTester_Atp_DoTest461_11k_1 ();
	//swResult = stldTester_Atp_DoTest461_11k_2 ();
	//{
	//	stldTester_Atp_SetDevice4_005 (); // RT4.
	//	swResult = stldTester_Atp_DoTest461_11k_3 (); // REQUIRES A 2-HUB-CONNECTOR TO INSERT DELAY BETWEEN DEVICE-1 AND DEVICE-3.
	//}
	//swResult = stldTester_Atp_DoTest461_11k_4 ();
	//swResult = stldTester_Atp_DoTest461_11k_5 ();
	//{
	//	stldTester_Atp_SetDevice2_000 (); // BC2.
	//	stldTester_Atp_SetDevice3_001 (); // MT3.
	//	swResult = stldTester_Atp_DoTest461_11k_6 (); // REQUIRES A BC DEVICE THAT'S CONNECTED TO BOTH BUSSES, BUS-A AND BUS-B.
	//}
	//swResult = stldTester_Atp_DoTest461_11l ();
	//swResult = stldTester_Atp_DoTest461_11m_Low ();
	//swResult = stldTester_Atp_DoTest461_11m_High ();
	//swResult = stldTester_Atp_DoTest461_11n ();
	//swResult = stldTester_Atp_DoTest461_13a ();
	//swResult = stldTester_Atp_DoTest461_13b ();
	//swResult = stldTester_Atp_DoTest461_13c ();
	//swResult = stldTester_Atp_DoTest461_13e ();
	//swResult = stldTester_Atp_DoTest461_13f ();
	//swResult = stldTester_Atp_DoTest461_13g ();
	//swResult = stldTester_Atp_DoTest461_13h ();
	//swResult = stldTester_Atp_DoTest461_13i ();
	//swResult = stldTester_Atp_DoTest461_13j ();
	//swResult = stldTester_Atp_DoTest461_13k_1 ();
	//swResult = stldTester_Atp_DoTest461_13k_2 ();
	//swResult = stldTester_Atp_DoTest461_13l ();
	//swResult = stldTester_Atp_DoTest461_13m (); // Fails: Sital RT returns status 0x0400 (ME bit on) in case it is the transmitter RT of a RT-to-RT message that is directed to one of its illegalized sub-addresses.
	//swResult = stldTester_Atp_DoTest461_15b ();
	//swResult = stldTester_Atp_DoTest461_15e (); // See remark on stldTester_Atp_DoTest461_11k_3 above.
	//swResult = stldTester_Atp_DoTest461_15f ();
	//swResult = stldTester_Atp_DoTest461_15g ();
	//swResult = stldTester_Atp_DoTest461_15h ();
	//swResult = stldTester_Atp_DoTest461_15i ();
	//swResult = stldTester_Atp_DoTest461_16a ();
	//swResult = stldTester_Atp_DoTest461_EmptyFrame ();
	//swResult = stldTester_BcRt_RtPostSynchronizationBehavior ();
	//swResult = stldTester_Bc_InternalTests ();
	//swResult = temp ();
	for (int i=0; i<5; i++)
	{
		//swResult = stldTester_Atp_DoTest461_11b ();

		//S16BIT stldTester_Atp_SetDevice2_003 (); // pciE.
		//swResult = stldTester_Atp_DoTest461_11e_Isr1_Bit06 ();

		//swResult = stldTester_Atp_DoTest461_11e_Isr2_Bit00 ();

		//swResult = stldTester_Atp_DoTest461_11j ();

		//swResult = stldTester_Atp_DoTest461_11k_1 ();

		//swResult = stldTester_Atp_DoTest461_11k_2 ();

		//swResult = stldTester_Atp_DoTest461_11k_4 ();

		//swResult = stldTester_Atp_DoTest461_15g ();

		//swResult = stldTester_Atp_DoTest461_11m_Low ();

		swResult = stldTester_Atp_DoTest461_11m_High ();

		//swResult = stldTester_Atp_DoTest461_11l ();
		//if (sitalReturnCode_SUCCESS != swResult)	break;
		//swResult = stldTester_Atp_DoTest461_13e ();
		//if (sitalReturnCode_SUCCESS != swResult)	break;

		//swResult = stldTester_Atp_DoTest461_11k_5 ();
		//if (sitalReturnCode_SUCCESS != swResult)	break;
		//swResult = stldTester_Atp_DoTest461_11l ();
		//if (sitalReturnCode_SUCCESS != swResult)	break;

		//swResult = stldTester_Atp_DoTest461_13c ();
		//if (sitalReturnCode_SUCCESS != swResult)	break;
		//swResult = stldTester_Atp_DoTest461_13e ();
		//if (sitalReturnCode_SUCCESS != swResult)	break;

		//swResult = stldTester_Atp_DoTest461_13f ();
		//if (sitalReturnCode_SUCCESS != swResult)	break;
		//swResult = stldTester_Atp_DoTest461_13g ();
		//if (sitalReturnCode_SUCCESS != swResult)	break;
	}
#endif // DO_ALL_BASIC_ATP_TESTS

	/// Instruct the device driver interface library to close the log file.

	sitalProcess_Log_Stop (TRUE);
	//TEMP NB
	printf("\nDONE");
	getchar();
	return 0;
}
