// Description  : Sital's stld1553 library test functions that have been originally implemented by DDC and by its clients.
// Version      : 1.0.0.0
// Author       : Sital Technology R&D
//
// Note:
// - All configuration functions must adhere the following rules in order to be used with Sital's TestPlanRunner app:
//   - have one of the following signatures:
//     - S16BIT _DECL <name-of-configuration-function> ()
//     - S16BIT _DECL <name-of-configuration-function> (int iIntegerParameter)
//     - S16BIT _DECL <name-of-configuration-function> (char* szNullTerminatedStringParameter)
//   - Return the following values:
//     - sitalReturnCode_SUCCESS if function successfully completed.
//     - Negative sitalReturnCode_* if an error condition encountered or function failed.
// - All test functions must adhere the following rules in order to be used with Sital's TestPlanRunner app:
//   - have the following signature: S16BIT _DECL <name-of-test-function> ()
//   - Return the following values:
//     - sitalReturnCode_SUCCESS if function successfully completed.
//     - Negative sitalReturnCode_* if an error condition encountered or function failed.
// - Sital supports the following architectures:
//   - Using BOTH Sital and DDC function, structure, and constant names over Sital's stld1553 library.
//     Such users must BOTH define macro ENABLE_USAGE_OF_DDC_NAMING *AND* undefine macro USE_DDC_LIBRARY.
//   - Using BOTH Sital and DDC function, structure, and constant names over Sital's DDC-like library.
//     Such users must define macro USE_DDC_LIBRARY.
//   (See both macro definitions below.)
// - With all below defined Acceptance Test Plan functions stldTester_Atp_DoTest*:
//   - A list of participant devices in the following form is specified for each such test function:
//     Participant[s]: <list of devices>.
//     Within this list, each device is specified in the pattern <device-type>[<device-logical-number>] (e.g., RT, BC, MT, 1, 2, 3, 4, RT1, BC2, MT3, RT4), where:
//     - <device-type> is either TEST, RT, BC, or MT.
//       In case the device-type isn't specified, it means that given device is used, but as a general device on its card, and not as a device of a specific device-type.
//     - <device-logical-number> is the index of a below defined s_swDevice* ATP variable that is used by this test function for the related device.
//       In case the device-logical-index isn't specified, it means that such a device is used, but its device-logical-number may not be dynamically configured by the caller.
//   - The addresses that are set for participating RTs arte as follows: s_wRtAddress1 for the first listed RT, s_wRtAddress2 for the second one, &c.
//
// Modification history:
//

#include "stdafx.h"
#include <stdio.h>
#include <stdlib.h>
//#define USE_DDC_LIBRARY
//#define ENABLE_USAGE_OF_DDC_NAMING
#include "OperatingSystemDependencies.h"
// Note:
// - In case the library that's actually used while running is:
//   - Sital's own stld1553 library:
//     - Un-define USE_DDC_LIBRARY for both Debug and Release versions in Project Properties > C/C++ > Preprocessor Definitions (may also be done below, uniquely within each file where required).
//     - If in below defined function BOTH Sital and DDC function, structure, and constant names are used: define ENABLE_USAGE_OF_DDC_NAMING for both Debug and Release versions in Project Properties > C/C++ > Preprocessor Definitions (may also be done below, uniquely within each file where required).
//     - Add "Debug\Stld1553.lib" for the debug version and "Release\Stld1553.lib" for the release version in Project Properties > Linker > Input > Additional Dependencies.
//   - Either DDC's original library over DDC cards *OR* Sital's DDC-like library over Sital card:
//     - Add "..\DdcRemakeOverSitalCards\stlemace\Include" for both Debug and Release versions in Project Properties > C/C++ > General > Additional Include Directories.
//     - Add the path to the library to use in Project Properties > Linker > Input > Additional Dependencies.
//       E.g., for Sital's DDC-like library over Sital card add "..\DdcRemakeOverSitalCards\emace_32.lib" for both Debug and Release versions.
#include "PrecisionTimer.h"
#include "InterProcessSemaphore.h"
#ifndef USE_DDC_LIBRARY
#include "stld1553_returnCodes.h"
#include "stld1553.h"
//#define ENABLE_USAGE_OF_DDC_NAMING
#ifdef ENABLE_USAGE_OF_DDC_NAMING
#include "ddc2stld1553.h"
#endif // ENABLE_USAGE_OF_DDC_NAMING
#else // USE_DDC_LIBRARY
#include "stdemace.h" // File located at directory "..\DdcRemakeOverSitalCards\stlemace\Include".
#include "UniqueStldDefs.h"
#include "stld2ddc.h"
#endif // USE_DDC_LIBRARY
#include "stld1553_driverInterface.h"
#include "TestsByDdcClients.h"



// Compilation flag definitions.
#define CREATE_DRIVER_LOG



// Constant definitions.

// Data block numbers.
#define DataBlock11									1 // stldTester_Bc_HostBuffer
#define DataBlock12									2 // stldTester_Bc_HostBuffer
#define DataBlock21									3 // stldTester_Bc_HostBuffer
#define DataBlock22									4 // stldTester_Bc_HostBuffer
#define DataBlock31									5 // stldTester_Bc_HostBuffer
#define DataBlock32									6 // stldTester_Bc_HostBuffer

// Message numbers.
#define Message11									1 // stldTester_Bc_HostBuffer
#define Message12									2 // stldTester_Bc_HostBuffer
#define Message21									3 // stldTester_Bc_HostBuffer
#define Message22									4 // stldTester_Bc_HostBuffer
#define Message31									5 // stldTester_Bc_HostBuffer
#define Message32									6 // stldTester_Bc_HostBuffer

// Command numbers.
#define Command11									1 // stldTester_Bc_HostBuffer
#define Command12									2 // stldTester_Bc_HostBuffer
#define Command21									3 // stldTester_Bc_HostBuffer
#define Command22									4 // stldTester_Bc_HostBuffer
#define Command31									5 // stldTester_Bc_HostBuffer
#define Command32									6 // stldTester_Bc_HostBuffer
#define CommandCallMinor							7 // stldTester_Bc_HostBuffer

#define Command0									7 // stldTester_Bc_Demo
#define Command1									5 // stldTester_Bc_Demo

// Frame numbers.
#define FrameMinor1									1 // stldTester_Bc_HostBuffer
#define FrameMinor2									2 // stldTester_Bc_HostBuffer
#define FrameMajor1									3 // stldTester_Bc_HostBuffer

#define FrameMinor3									6 // stldTester_Bc_Demo
#define FrameMajor2									4 // stldTester_Bc_Demo

// Number of milliseconds to wait for the interrupt at the end of each External / Real Time minor frame.
#define WaitedPeriod								2 // stldTester_Bc_HostBuffer

// Error types.
#define errorTimeout								0x00000001 // stldTester_Bc_HostBuffer
#define errorMessage1Read							0x80000000 // stldTester_Bc_HostBuffer
#define errorMessage1Lost							0x40000000 // stldTester_Bc_HostBuffer
#define errorMessage1NotReceived					0x20000000 // stldTester_Bc_HostBuffer
#define errorMessage1Bsw							0x10000000 // stldTester_Bc_HostBuffer
#define errorMessage2Read							0x00008000 // stldTester_Bc_HostBuffer
#define errorMessage2Lost							0x00004000 // stldTester_Bc_HostBuffer
#define errorMessage2NotReceived					0x00002000 // stldTester_Bc_HostBuffer
#define errorMessage2Bsw							0x00001000 // stldTester_Bc_HostBuffer



// Macro definitions.



// Enumeration definitions.



// Structure definitions.



// Static variables.
static U32BIT s_dwIsrCallCounter = 0; // The overall number of times that the ISR has been called.
static U32BIT s_dwMinorFrameCounter = 0; // The overall number of transmitted minor frames.
static U16BIT s_waRxTx[32] = // stldTester_Bc_HostBuffer
								{
									0x1010, 0x2020, 0x3030, 0x4040, 0x5050, 0x6060, 0x7070, 0x8080,
									0x9090, 0xa0a0, 0xb0b0, 0xc0c0, 0xd0d0, 0xe0e0, 0xf0f0, 0x0f0f,
									0x0101, 0x0202, 0x0303, 0x0404, 0x0505, 0x0606, 0x0707, 0x0808,
									0x0909, 0x0a0a, 0x0b0b, 0x0c0c, 0x0d0d, 0x0e0e, 0x0f0f, 0xf1f1
								};
static U16BIT s_waTx[3][32] = // stldTester_Bc_HostBuffer
								{
									{
											0x1110, 0x1111, 0x1112, 0x1113, 0x1114, 0x1115, 0x1116, 0x1117,
											0x1118, 0x1119, 0x111a, 0x111b, 0x111c, 0x111d, 0x111e, 0x111f,
											0x1120, 0x1121, 0x1122, 0x1123, 0x1124, 0x1125, 0x1126, 0x1127,
											0x1128, 0x1129, 0x112a, 0x112b, 0x112c, 0x112d, 0x112e, 0x112f
									},
									{
											0x2210, 0x2211, 0x2212, 0x2213, 0x2214, 0x2215, 0x2216, 0x2217,
											0x2218, 0x2219, 0x221a, 0x221b, 0x221c, 0x221d, 0x221e, 0x221f,
											0x2220, 0x2221, 0x2222, 0x2223, 0x2224, 0x2225, 0x2226, 0x2227,
											0x2228, 0x2229, 0x222a, 0x222b, 0x222c, 0x222d, 0x222e, 0x222f
									},
									{
											0x3310, 0x3311, 0x3312, 0x3313, 0x3314, 0x3315, 0x3316, 0x3317,
											0x3318, 0x3319, 0x331a, 0x331b, 0x331c, 0x331d, 0x331e, 0x331f,
											0x3320, 0x3321, 0x3322, 0x3323, 0x3324, 0x3325, 0x3326, 0x3327,
											0x3328, 0x3329, 0x332a, 0x332b, 0x332c, 0x332d, 0x332e, 0x332f
									}
								};

static U16BIT s_waDataBlock[64] = // stldTester_Bc_Demo
								{
									0x1111,0x2222,0x3333,0x4444,0x1111,0x2222,0x3333,0x4444,
									0x1111,0x2222,0x3333,0x4444,0x1111,0x2222,0x3333,0x4444,
									0x1111,0x2222,0x3333,0x4444,0x1111,0x2222,0x3333,0x4444,
									0x1111,0x2222,0x3333,0x4444,0x1111,0x2222,0x3333,0x4444
								};



// Other modules' internal function declarations.
U32BIT _DECL stldTestDeviceNumber_Get (S16BIT swDevice);
U32BIT _DECL stldTestRtAddress_Get (S16BIT swRtAddress);



// Internal function declarations.
void _DECL userISR (S16BIT swDevice, U32BIT dwIrqStatus);



// Internal functions.

/// <summary>
/// User's ISR.
/// Count the overall number of interrupts and the overall number of transmitted minor frames into the dedicated global variables.
///
/// Parameters:
/// - swDevice (in)	Logical number of device (0-1)
/// - dwIrqStatus (in)	IRQ status
///
/// Returned values: None.
/// </summary>
void _DECL userISR (S16BIT swDevice, U32BIT dwIrqStatus)
{
	/// @pseudocode

	s_dwIsrCallCounter++;

	//if (0U != (ACE_IMR2_BC_UIRQ3 & dwIrqStatus))
	// Commenting DDC 2018
	if (0U != (0x00200000 & dwIrqStatus))
	{
		s_dwMinorFrameCounter++;

		// Notice: The following line should be better commented-out, as printings along callbacks may cause the loss of interrupts!
		//sitalProcess_Log_PrintLine ("#StldTester.ISR.Callback: device - %i, irq_status - %08X, isr_calls - %i\n", swDevice, dwIrqStatus, s_dwMinorFrameCounter);
	}
}



// Exported functions.

/// <summary>
/// Set up given device as BC.
/// Perform 1553 bus communications test by transmitting a frame on given bus of given device, using given frame time and frame count.
///
/// Note:
/// - Given frame time should be greater than 1400 by 300 �s at least in order for it to be effective.
/// - 1553 Communications Load percentage is (1360 / (wFrameTime * 100) * 100).
/// - This function is actually an edited version of a function that was originally devised by some DDC users.
///   Though edited, some coding aspects have been left to reflect the original function.
///
/// @return sitalReturnCode_SUCCESS	Function successfully completed
/// @return Negative sitalReturnCode_*	Error condition or function failed
/// </summary>
S16BIT stldTester_Bc_HostBuffer ()
{
	/// @pseudocode

	/// If any state irrelevancy or illegal input parameter or operation failure is identified:
	///		Return error.

	U16BIT wTemp = 0; // Just in order to prevent compilation warning.
	wTemp++; // Just in order to prevent compilation warning.

#ifdef ENABLE_USAGE_OF_DDC_NAMING
	S16BIT swDevice = 0; // Logical number of device (0-31).
	U32BIT dwBus = ACE_BCCTRL_CHL_A; // The bus to test (sitalBcControlWord_BUS_*).
	U16BIT wFrameTime = 500; // The time (in units of 100 us) that the frame will take to complete.
	S32BIT sdwFrameCount = 100; // The number of times the frame should be transmitted (zero also means single Tx), or sitalBcFrameIterations_RUN_FOREVER if the frame should be run forever (>=-1).
	U32BIT dwMessageErrorsOnBusA[4] = {0, 0, 0, 0}; // Errors recording for devices 0-3 on bus A.
	U32BIT dwMessageErrorsOnBusB[4] = {0, 0, 0, 0}; // Errors recording for devices 0-3 on bus B.
	S16BIT swResult; // Result of operation or function call.
	U16BIT wRegisterValue = 0; // The current value of a target register, or the value to set for a target register.
	U16BIT wCommandIdCount; // The number of command IDs in the frame (1-sitalBcCounter_FRAME_COMMANDS).
	char cBusLetter; // 'A' or 'B', according to given bus.
    U16BIT bEnable = TRUE; // A flag to designate that some target feature is enabled.
    U32BIT dwMessageCount = 0; // The number of messages retrieved using the host buffer.
    U32BIT dwLostMessagesCount = 0; // The number of lost messages.
	S16BIT swaCommandIds[sitalBcCounter_COMMANDS];
	MSGSTRUCT dmsDecodedMessage; // A decoded message.
    S8BIT* szpBlockStatusWordError; // A pointer to a null-terminated BSW error description string.

	/// Initialize the test.
    if (ACE_BCCTRL_CHL_A == dwBus)
    {
        cBusLetter = 'A';
        for (U16BIT i=0; i<4; i++)	dwMessageErrorsOnBusA[i] = 0;
    }
    else
    {
        cBusLetter = 'B';
		for (U16BIT i=0; i<4; i++)	dwMessageErrorsOnBusB[i] = 0;
    }

    s_dwMinorFrameCounter = 0;

	/// Initialize given device as a real BC.
	swResult = aceInitialize (swDevice, ACE_ACCESS_CARD, (ACE_MODE_BC | ACE_ADVANCED_MODE), 0, 0, (U32BIT)NULL);
	if (ACE_ERR_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Device.Init.Error: err - %i\n", swResult);
		return swResult;
	}

    wRegisterValue = aceRegRead(swDevice, 0x8);
    wRegisterValue |= 0x1000;
    swResult = aceRegWrite(swDevice, 0x8, wRegisterValue);
    if (sitalReturnCode_SUCCESS != swResult)
    {
		sitalProcess_Log_PrintLine ("#StldTester.Device.Reg.Write.Error: err - %i\n", swResult);
        goto commEnd_3;
    }

    /// Enable IRQ-3 interrupts to be signaled at the completion of minor frames.
    swResult = aceSetIrqConditions (swDevice, bEnable, ACE_IMR2_BC_UIRQ3, userISR);
    if (sitalReturnCode_SUCCESS != swResult)
    {
		sitalProcess_Log_PrintLine ("#StldTester.Device.Irq.Set.Error: err - %i\n", swResult);
        goto commEnd_3;
    }

    /// Create data blocks.
    swResult = aceBCDataBlkCreate (swDevice, DataBlock11, ACE_BC_DBLK_DOUBLE, &s_waTx[0][0], 32);
    if (sitalReturnCode_SUCCESS != swResult)
    {
		sitalProcess_Log_PrintLine ("#StldTester.Bc.DataBlock.Create.Error: err - %i\n", swResult);
        goto commEnd_3;
    }

	swResult = aceBCDataBlkCreate (swDevice, DataBlock12, ACE_BC_DBLK_DOUBLE, NULL, 0);
    if (sitalReturnCode_SUCCESS != swResult)
    {
		sitalProcess_Log_PrintLine ("#StldTester.Bc.DataBlock.Create.Error: err - %i\n", swResult);
        goto commEnd_3;
    }

	swResult = aceBCDataBlkCreate (swDevice, DataBlock21, ACE_BC_DBLK_DOUBLE, &s_waTx[1][0], 32);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.DataBlock.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

    swResult = aceBCDataBlkCreate (swDevice, DataBlock22, ACE_BC_DBLK_DOUBLE, NULL, 0);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.DataBlock.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

    swResult = aceBCDataBlkCreate (swDevice, DataBlock31, ACE_BC_DBLK_DOUBLE, &s_waTx[2][0], 32);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.DataBlock.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

    swResult = aceBCDataBlkCreate (swDevice, DataBlock32, ACE_BC_DBLK_DOUBLE, NULL, 0);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.DataBlock.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

    /// Create messages.
	// Note:
	// If the Gap Time parameter of aceBCMsgCreate is non-zero, then aceBCMsgGapTimerEnable must be used.
	// When the Gap Timer is not enabled, the gaps between consecutive messages are the minimum that the H/W supports, i.e., 696 us (from the beginning of one message to the beginning of the next).
	// This minimum gap value is not supported, so the value is slightly increased in following aceBCMsgCreate* calls to 700 us.
    swResult = aceBCMsgGapTimerEnable (swDevice, bEnable);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.MessageGapTimeField.Enable.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

    /// Create Tx message with 1st RT.
    swResult = aceBCMsgCreateBCtoRT (swDevice, Message11, DataBlock11, (U16BIT)((swDevice + 1) % 2), 30, 32, 700, (dwBus | ACE_BCCTRL_EOM_IRQ));
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Message.BcToRt.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

	/// Create Rx message with 1st RT.
	swResult = aceBCMsgCreateRTtoBC (swDevice, Message12, DataBlock12, (U16BIT)((swDevice + 1) % 2), 30, 32, 700, (dwBus | ACE_BCCTRL_EOM_IRQ));
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Message.RtToBc.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

	/// Create Tx message with 2nd RT.
	swResult = aceBCMsgCreateBCtoRT (swDevice, Message21, DataBlock21, (U16BIT)((swDevice + 2) % 4), 30, 32, 700, (dwBus | ACE_BCCTRL_EOM_IRQ));
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Message.BcToRt.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

	/// Create Rx message with 2nd RT.
	swResult = aceBCMsgCreateRTtoBC (swDevice, Message22, DataBlock22, (U16BIT)((swDevice + 2) % 4), 30, 32, 700, (dwBus | ACE_BCCTRL_EOM_IRQ));
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Message.RtToBc.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

	/// Create Tx message with 3rd RT.
	swResult = aceBCMsgCreateBCtoRT (swDevice, Message31, DataBlock31, (U16BIT)((swDevice + 3) % 4), 30, 32, 700, (dwBus | ACE_BCCTRL_EOM_IRQ));
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Message.BcToRt.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

	/// Create Rx message with 3rd RT.
	swResult = aceBCMsgCreateRTtoBC (swDevice, Message31, DataBlock31, (U16BIT)((swDevice + 3) % 4), 30, 32, 700, (dwBus | ACE_BCCTRL_EOM_IRQ));
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Message.RtToBc.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

    /* Create XEQ opcodes that will use the messages & data blocks */
    swResult = aceBCOpCodeCreate (swDevice, Command11, ACE_OPCODE_XEQ, ACE_CNDTST_ALWAYS, Message11, 0, 0);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Command.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

	/// Create commands.
    swResult = aceBCOpCodeCreate (swDevice, Command12, ACE_OPCODE_XEQ, ACE_CNDTST_ALWAYS, Message12, 0, 0);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Command.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

    swResult = aceBCOpCodeCreate (swDevice, Command21, ACE_OPCODE_XEQ, ACE_CNDTST_ALWAYS, Message21, 0, 0);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Command.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

    swResult = aceBCOpCodeCreate (swDevice, Command22, ACE_OPCODE_XEQ, ACE_CNDTST_ALWAYS, Message22, 0, 0);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Command.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

    swResult = aceBCOpCodeCreate (swDevice, Command31, ACE_OPCODE_XEQ, ACE_CNDTST_ALWAYS, Message31, 0, 0);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Command.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

    swResult = aceBCOpCodeCreate (swDevice, Command32, ACE_OPCODE_XEQ, ACE_CNDTST_ALWAYS, Message32, 0, 0);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Command.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

    /// Create a command to call the minor frame.
    swResult = aceBCOpCodeCreate (swDevice, CommandCallMinor, ACE_OPCODE_CAL, ACE_CNDTST_ALWAYS, FrameMinor1, 0, 0);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Command.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

    /// Create frames.
	swaCommandIds[0] = Command11;
	swaCommandIds[1] = Command12;
	wCommandIdCount = 2;
    swResult = aceBCFrameCreate(swDevice, FrameMinor1, ACE_FRAME_MINOR, swaCommandIds, (U16BIT)wCommandIdCount, (S16BIT)wFrameTime, 0);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Frame.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

    swaCommandIds[0] = CommandCallMinor;
    swResult = aceBCFrameCreate(swDevice, FrameMajor1, ACE_FRAME_MAJOR, swaCommandIds, 1, 0, 0);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Frame.Create.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

    /// Create BC host buffer.
    swResult = aceBCInstallHBuf (swDevice, (64*1024));
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.HostBuffer.Install.Error: err - %i\n", swResult);
		goto commEnd_3;
	}

    /// Set the frame number value.
    s_waTx[0][3] = (U16BIT)s_dwMinorFrameCounter;
    s_waTx[0][2] = (U16BIT)(s_dwMinorFrameCounter >> 16);

    /// Update the appropriate data block.
    swResult = aceBCDataBlkWrite (swDevice, DataBlock11, &s_waTx[0][0], 4, 0);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.DataBlock.Write.Error: err - %i\n", swResult);
	}

    /// Start the BC.
    swResult = aceBCStart (swDevice, FrameMajor1, sdwFrameCount);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Start.Error: err - %i\n", swResult);
		goto commEnd_2;
	}

    /// Perform pass/fail checks with each frame.
    for (U32BIT i=1; i<=(U32BIT)sdwFrameCount; i++)
    {
		/// Wait for s_dwMinorFrameCounter to signify that current minor frame has finished, but no more than a constant timeout period.
		PrecisionTimer pt;
		pt.SetBaseTime ();
		while ((s_dwMinorFrameCounter < i) && (pt.GetDuration () < WaitedPeriod))
		{
			pt.SetEndTime ();
		}

		/// Check if a timeout occurred. If indeed, it is registered as BC channel's problem.
		if (pt.GetDuration () >= WaitedPeriod)
		{
			if (ACE_BCCTRL_CHL_A == dwBus)
				dwMessageErrorsOnBusA[swDevice] |=  errorTimeout;
			else
				dwMessageErrorsOnBusB[swDevice] |=  errorTimeout;

			sitalProcess_Log_PrintLine ("#StldTester.Bc.ExternalOrRealTimeTestTimeout: major_frame - %i\n", i);
			goto commEnd_1;
		}

		/// Read next message into the BC host buffer (purge it from the device).
		/// In case an error in encountered, this error is recorded as a BC error.
		swResult = aceBCGetHBufMsgDecoded (swDevice, &dmsDecodedMessage, &dwMessageCount, &dwLostMessagesCount, ACE_BC_MSGLOC_NEXT_PURGE);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			if (ACE_BCCTRL_CHL_A == dwBus)
				dwMessageErrorsOnBusA[swDevice] |= errorMessage1Read;
			else
				dwMessageErrorsOnBusB[swDevice] |= errorMessage1Read;

			sitalProcess_Log_PrintLine ("#StldTester.Bc.HostBuffer.Message.GetDecoded.Error: frame - %i, msg - %i, err - %i\n", i, 11, swResult);
		}

		/// If there were lost messages, display their count, and record this error as a BC error.
		/// Note: When it happens, this error is about previous message(s), and does not affect last message's pass/fail reporting.
		if (0 < dwLostMessagesCount)
		{
			if (ACE_BCCTRL_CHL_A == dwBus)
				dwMessageErrorsOnBusA[swDevice] |= errorMessage1Lost;
			else
				dwMessageErrorsOnBusB[swDevice] |= errorMessage1Lost;

			sitalProcess_Log_PrintLine ("#StldTester.Bc.HostBuffer.Message.Lost: frame - %i, lost_msg_count - %i\n", i, dwLostMessagesCount);
		}

		/// If no message has been received, display a suitable notification, and record this error as a BC error.
		if (0U == dwMessageCount)
		{
			if (ACE_BCCTRL_CHL_A == dwBus)
				dwMessageErrorsOnBusA[(swDevice + 1) % 2] |= errorMessage1NotReceived;
			else
				dwMessageErrorsOnBusB[(swDevice + 1) % 2] |= errorMessage1NotReceived;

			sitalProcess_Log_PrintLine ("#StldTester.Bc.HostBuffer.Message.NoneReceived: frame - %i, expected_msg - %i\n", i, 11);
		}

		/// Check whether any errors were encountered by the device with the received message.
		/// If indeed, display a suitable notification, and record this error as a BC error.
		szpBlockStatusWordError = aceGetBSWErrString (ACE_MODE_BC, dmsDecodedMessage.wBlkSts);
		if (0U != (*szpBlockStatusWordError))
		{
			if (ACE_BCCTRL_CHL_A == dwBus)
				dwMessageErrorsOnBusA[(swDevice + 1) % 2] |= errorMessage1Bsw;
			else
				dwMessageErrorsOnBusB[(swDevice + 1) % 2] |= errorMessage1Bsw;

			sitalProcess_Log_PrintLine ("#StldTester.Bc.Frame.MessageTx.Fail: frame - %i (bc>rt), msg - %i, bus - %c, bsw_err_code - %s\n", i, 11, cBusLetter, szpBlockStatusWordError);
		}

		/// Read next message into the BC host buffer (purge it from the device).
		/// In case an error in encountered, this error is recorded as a BC error.
		swResult = aceBCGetHBufMsgDecoded (swDevice, &dmsDecodedMessage, &dwMessageCount, &dwLostMessagesCount, ACE_BC_MSGLOC_NEXT_PURGE);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			if (ACE_BCCTRL_CHL_A == dwBus)
				dwMessageErrorsOnBusA[swDevice] |= errorMessage2Read;
			else
				dwMessageErrorsOnBusB[swDevice] |= errorMessage2Read;

			sitalProcess_Log_PrintLine ("#StldTester.Bc.HostBuffer.Message.GetDecoded.Error: frame - %i, msg - %i, err - %i\n", i, 12, swResult);
		}

		/// If there were lost messages, display their count, and record this error as a BC error.
		/// Note: When it happens, this error is about previous message(s), and does not affect last message's pass/fail reporting.
		if (0 < dwLostMessagesCount)
		{
			if (ACE_BCCTRL_CHL_A == dwBus)
				dwMessageErrorsOnBusA[swDevice] |= errorMessage2Lost;
			else
				dwMessageErrorsOnBusB[swDevice] |= errorMessage2Lost;

			sitalProcess_Log_PrintLine ("#StldTester.Bc.HostBuffer.Message.Lost: frame - %i, lost_msg_count - %i\n", i, dwLostMessagesCount);
		}

		/// If no message has been received, display a suitable notification, and record this error as a BC error.
		if (0U == dwMessageCount)
		{
			if (ACE_BCCTRL_CHL_A == dwBus)
				dwMessageErrorsOnBusA[(swDevice + 1) % 2] |= errorMessage2NotReceived;
			else
				dwMessageErrorsOnBusB[(swDevice + 1) % 2] |= errorMessage2NotReceived;

			sitalProcess_Log_PrintLine ("#StldTester.Bc.HostBuffer.Message.NoneReceived: frame - %i, expected_msg - %i\n", i, 12);
		}

		/// Check whether any errors were encountered by the device with the received message.
		/// If indeed, display a suitable notification, and record this error as a BC error.
		szpBlockStatusWordError = aceGetBSWErrString (ACE_MODE_BC, dmsDecodedMessage.wBlkSts);
		if (0U != (*szpBlockStatusWordError))
		{
			if (ACE_BCCTRL_CHL_A == dwBus)
				dwMessageErrorsOnBusA[(swDevice + 1) % 2] |= errorMessage2Bsw;
			else
				dwMessageErrorsOnBusB[(swDevice + 1) % 2] |= errorMessage2Bsw;

			sitalProcess_Log_PrintLine ("#StldTester.Bc.Frame.MessageTx.Fail: frame - %i (rt>bc), msg - %i, bus - %c, bsw_err_code - %s\n", i, 11, cBusLetter, szpBlockStatusWordError);
		}
    }

    if (ACE_BCCTRL_CHL_A == dwBus)
        for (U16BIT i = 0; i < 2; i++)
        {
			sitalProcess_Log_PrintLine ("#StldTester.Bc.Channel.TestResult: channel - %i, result - %s\n", i, ((0U == dwMessageErrorsOnBusA[i]) ? "passed" : "failed"));
        }
    else
        for (U16BIT i = 0; i < 2; i++)
        {
			sitalProcess_Log_PrintLine ("#StldTester.Bc.Channel.TestResult: channel - %i, result - %s\n", i, ((0U == dwMessageErrorsOnBusB[i]) ? "passed" : "failed"));
        }

commEnd_1:
	/// Stop the BC.
    aceBCStop (swDevice);

commEnd_2:
	/// Uninstall the BC's host buffer.
    swResult = aceBCUninstallHBuf (swDevice);
	if (sitalReturnCode_SUCCESS != swResult)
	{
		sitalProcess_Log_PrintLine ("#StldTester.Bc.HostBuffer.Uninstall.Error: err - %i\n", swResult);
	}

commEnd_3:
	/// Free the BC.
    swResult = aceFree (swDevice);
    if (sitalReturnCode_SUCCESS != swResult)
    {
		sitalProcess_Log_PrintLine ("#StldTester.Device.Free.Error: err - %i\n", swResult);
    }

    return swResult;

#else // USE_SITAL_NAMING
	return sitalReturnCode_UNKNOWN_ERROR;
#endif // ENABLE_USAGE_OF_DDC_NAMING
}



S16BIT stldTester_Bc_Demo ()
{
	/// @pseudocode

	/// If any state irrelevancy or illegal input parameter or operation failure is identified:
	///		Return error.

	sitalProcess_Log_PrintLine ("#StldTester.BcDemo.Start\n");

	U16BIT wTemp = 0; // Just in order to prevent compilation warning.
	wTemp++; // Just in order to prevent compilation warning.

#ifdef ENABLE_USAGE_OF_DDC_NAMING
	/// Set test arguments.
	S16BIT swDevice; // Logical number of device (0-31).
	swDevice = stldTestDeviceNumber_Get(2);
	const U16BIT wMessageCount = // The number of messages in a frame.
								 100; // 207 fails immediately. 100 fails after a while.
	S16BIT swResult; // Result of operation or function call.
	swResult = sitalReturnCode_SUCCESS;

	try
	{
		/// Initialize device (BC) as a real BC.
		sitalProcess_Log_PrintLine ("#StldTester.Device.Init: unit - %i, access-card, mode-bc, alloc_mem-none\n", swDevice);
		swResult = aceInitialize (swDevice, ACE_ACCESS_CARD, (ACE_MODE_BC | ACE_ADVANCED_MODE), 0, 0, 0);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Device.Init.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Configure device (BC) to get IRQ-3 notifications using an ISR.
		sitalProcess_Log_PrintLine ("#StldTester.Device.Irq.Manipulate: unit - %i, enable - %i, irq - %08X, callback - %s\n", swDevice, TRUE, sitalInterruptRegister2_BC_IRQ3, "stldTester_Bc_UserIsr");
		swResult = aceSetIrqConditions (swDevice, TRUE, ACE_IMR2_BC_UIRQ3, userISR);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Device.Irq.Set.Error: error - %i\n", swResult);
		}

		S16BIT swDataBlockId; // A unique ID designating a data block (0-(sitalBcCounter_DATA_BLOCKS-1)).
		S16BIT swMessageId; // A unique ID designating a message (0-(sitalBcCounter_MESSAGES-1)).
		U16BIT wRtAddress; // A RT address (0-31).
		U16BIT wRtSubaddress; // A RT subaddress (sitalRtSubaddress_0-sitalRtSubaddress_31) that's set for a RT for Rx.
		U16BIT wWordCount; // Word count (1-32).
		U16BIT wBus; // The bus (sitalBcControlWord_BUS_*) to use.
		S16BIT swCommandId; // A unique ID designating a command (0-(sitalBcCounter_COMMANDS-1)).
		S16BIT swaCommandIds[wMessageCount]; // An array of command-IDs.
		for (int iIteration=0; iIteration<wMessageCount; iIteration++)
		{
			/// Create for device (BC) data-block-DataBlockId, a data block of 32 data words.
			swDataBlockId = (iIteration + 1);
			sitalProcess_Log_PrintLine ("#StldTester.Bc.DataBlock.Create: unit - %i, block - %i, size - %i, buf_size - %i\n", swDevice, swDataBlockId, 32, 0);
			aceBCDataBlkCreate (swDevice, swDataBlockId, 32, s_waDataBlock, 0);
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Bc.DataBlock.Create.Error: error - %i\n", swResult);
				throw 0;
			}

			/// Create for device (BC) message-MessageId, a BC-to-RT(RtAddress/RtSubAddressRx message that uses the just created data-block to transmit WordCount data words. Message bus: bus.
			swMessageId = (iIteration + 1);
			wRtAddress = ((iIteration % 30) + 1);
			wRtSubaddress = ((iIteration / 30) + 1);
			wWordCount = 1;
			wBus = ( (iIteration % 2) ? ACE_BCCTRL_CHL_A : ACE_BCCTRL_CHL_B );
			sitalProcess_Log_PrintLine ("#StldTester.Bc.Message.BcToRt.Create: unit - %i, message - %i, block - %i, rx_rt - %i, rx_rt_sa - %i, wc - %i, gap - %i, opts-x%X\n", swDevice, swMessageId, swDataBlockId, wRtAddress, wRtSubaddress, wWordCount, 0, wBus);
//			if (171==swDataBlockId)
//			{
//				__asm__ __volatile__ ( "int3" );
//			}
			swResult = sitalBc_Message_CreateBcToRt (swDevice, swMessageId, swDataBlockId, wRtAddress, wRtSubaddress, wWordCount, 0, wBus);
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Bc.Message.BcToRt.Create.Error: error - %i\n", swResult);
				throw 0;
			}

			/// Create for device (BC) command-CommandId, a subroutine call command that executes minor-frame-FrameId. 
			swCommandId = (Command0 + iIteration + 1);
			sitalProcess_Log_PrintLine ("#StldTester.Bc.Command.Create: unit - %i, cmd - %i, opcode - %i, cond - %i, prm1 - %i, prm2 - %i\n", swDevice, swCommandId, sitalOpcode_CALL_SUBROUTINE, sitalOpcodeCondition_ALWAYS, swMessageId, 0);
			aceBCOpCodeCreate (swDevice, swCommandId, ACE_OPCODE_XEQ, ACE_CNDTST_ALWAYS, swMessageId, 0, 0);
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Bc.Command.Create.Error: error - %i\n", swResult);
				throw 0;
			}

			swaCommandIds[iIteration] = (Command0 + iIteration + 1);
		}

		/// Create for device (BC) minor-frame-Id.
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Frame.Create: unit - %i, frame - %i, type - %s, time - %ims, flags - %i\n", swDevice, FrameMinor3, "minor", wMessageCount, 0, 0);
		aceBCFrameCreate (swDevice, FrameMinor3, ACE_FRAME_MINOR, swaCommandIds, wMessageCount, 0, 0);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Bc.Frame.Create.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Create for device (BC) command-Id, a subroutine call command that executes minor-frame-Id.
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Command.Create: unit - %i, cmd - %i, opcode - %i, cond - %i, prm1 - %i, prm2 - %i\n", swDevice, Command1, sitalOpcode_CALL_SUBROUTINE, sitalOpcodeCondition_ALWAYS, FrameMinor3, 0);
		aceBCOpCodeCreate (swDevice, Command1, ACE_OPCODE_CAL, ACE_CNDTST_ALWAYS, FrameMinor3, 0, 0);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Bc.Command.Create.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Create for device (BC) major-frame-Id.
		sitalProcess_Log_PrintLine ("#StldTester.Bc.Frame.Create: unit - %i, frame - %i, type - %s, commands - %i, time - %ims, flags - %i\n", swDevice, FrameMajor2, "major", 1, 83, 0);
		swaCommandIds[0] = Command1;
		aceBCFrameCreate (swDevice, FrameMajor2, ACE_FRAME_MAJOR, swaCommandIds, 1, 83, 0);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Bc.Frame.Create.Error: error - %i\n", swResult);
			throw 0;
		}

		S16BIT nResult = 0;
		for (int iIteration=0; TRUE; iIteration++)
		{
			/// Start device (BC) running major-frame-Id for 1-shot.
			sitalProcess_Log_PrintLine ("#StldTester.Bc.Start: unit - %i, frame - %i, count - %i\n", swDevice, FrameMajor2, 1);
			aceBCStart (swDevice, FrameMajor2, 1);
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Bc.Start.Error: error - %i\n", swResult);
				throw 0;
			}

			///	Sleep for ~8333 us.
			Sleep_NonOsDependent(8.333);

			///	Stop device (BC).
			sitalProcess_Log_PrintLine ("#StldTester.Bc.Stop: unit - %i\n", swDevice);
			aceBCStop(swDevice);
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Bc.Stop.Error: error - %i\n", swResult);
				throw 0;
			}

			S16BIT swTxDataBlockId; // A unique ID designating a data block (0-(sitalBcCounter_DATA_BLOCKS-1)).
			for (int i = 0; i<wMessageCount; i++)
			{
				///	Update for device-2 (BC) the data in the buffer of data-block-Tx.
				swTxDataBlockId = (i + 1);
				sitalProcess_Log_PrintLine ("#StldTester.Bc.DataBlock.Write: unit - %i, block - %i, offset - %i, buf_size - %i\n", swDevice,swTxDataBlockId, 0, 32);
				nResult = aceBCDataBlkWrite (swDevice, swTxDataBlockId, s_waDataBlock, 32, 0);
				if (sitalReturnCode_SUCCESS != swResult)
				{
					sitalProcess_Log_PrintLine ("#StldTester.Bc.DataBlock.Write.Error: error - %i\n", swResult);
					throw 0;
				}

				swaCommandIds[i] = (Command0 + i + 1);
			}
	
			/// Delete device (BC) frame-Id.
			sitalProcess_Log_PrintLine ("#StldTester.Bc.Frame.Delete: unit - %i, frame - %i\n", swDevice, FrameMinor3);
			aceBCFrameDelete (swDevice, FrameMinor3);	
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Bc.Frame.Delete.Error: error - %i\n", swResult);
				throw 0;
			}

			/// Delete device (BC) frame-Id.
			sitalProcess_Log_PrintLine ("#StldTester.Bc.Frame.Delete: unit - %i, frame - %i\n", swDevice, FrameMajor2);
			aceBCFrameDelete (swDevice, FrameMajor2);
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Bc.Frame.Delete.Error: error - %i\n", swResult);
				throw 0;
			}

			/// Create for device (BC) minor-frame-Id.
			sitalProcess_Log_PrintLine ("#StldTester.Bc.Frame.Create: unit - %i, frame - %i, type - %s, time - %ims, flags - %i\n", swDevice, FrameMinor3, "minor", wMessageCount, 0, 0);
			aceBCFrameCreate (swDevice, FrameMinor3, ACE_FRAME_MINOR, swaCommandIds, wMessageCount, 0, 0);
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Bc.Frame.Create.Error: error - %i\n", swResult);
				throw 0;
			}
	
			/// Delete device (BC) command-Id.
			sitalProcess_Log_PrintLine ("#StldTester.Bc.Command.Delete: unit - %i, command - %i\n", swDevice, Command1);
			aceBCOpCodeDelete (swDevice, Command1);
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Bc.Command.Delete.Error: error - %i\n", swResult);
				throw 0;
			}

			/// Create for device (BC) command-Id, a subroutine call command that executes minor-frame-Id.
			sitalProcess_Log_PrintLine ("#StldTester.Bc.Command.Create: unit - %i, cmd - %i, opcode - %i, cond - %i, prm1 - %i, prm2 - %i\n", swDevice, Command1, sitalOpcode_CALL_SUBROUTINE, sitalOpcodeCondition_ALWAYS, FrameMinor3, 0);
			aceBCOpCodeCreate (swDevice, Command1, ACE_OPCODE_CAL, ACE_CNDTST_ALWAYS, FrameMinor3, 0, 0);
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Bc.Command.Create.Error: error - %i\n", swResult);
				throw 0;
			}
	
			/// Create for device (BC) major-frame-Id.
			sitalProcess_Log_PrintLine ("#StldTester.Bc.Frame.Create: unit - %i, frame - %i, type - %s, commands - %i, time - %ims, flags - %i\n", swDevice, Command1, "major", 1, 83, 0);
			swaCommandIds[0] = Command1;
			aceBCFrameCreate (swDevice, FrameMajor2, ACE_FRAME_MAJOR, swaCommandIds, 1, 83, 0);      
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Bc.Frame.Create.Error: error - %i\n", swResult);
				throw 0;
			}
		}

		/// Free device (BC).
		sitalProcess_Log_PrintLine ("#StldTester.Device.Free: unit - %i\n", swDevice);
		swResult = aceFree (swDevice);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Device.Free.Error: error - %i\n", swResult);
			throw 0;
		}
	}
	catch (int)
	{
		sitalDevice_Free (swDevice);
	}

	sitalProcess_Log_PrintLine ("#StldTester.BcDemo.End: test_succeeded - %c\n", ((sitalReturnCode_SUCCESS == swResult) ? 'Y' : 'N'));
	return swResult;

#else // USE_SITAL_NAMING
	return sitalReturnCode_UNKNOWN_ERROR;
#endif // ENABLE_USAGE_OF_DDC_NAMING
}



S16BIT stldTester_Rt_LegalizationTest ()
// Initializes device-2 as RT, sets its RT address to RT-address-1, and then legalizes only some specific messages.
// The user is then expected to run an external BC, and verify that messages are properly responded (i.e., depending on whether they are legalized/illegalized).
// To stop the test the user should abort the test application (e.g., using a <CTRL-C>).
// The external BC may be run using Sital s/w (e.g., MuxSim or Luthier).
{
	/// @pseudocode

	/// If any state irrelevancy or illegal input parameter or operation failure is identified:
	///		Return error.

	sitalProcess_Log_PrintLine ("#StldTester.RtLegalizationTest.Start\n");

	U16BIT wTemp = 0; // Just in order to prevent compilation warning.
	wTemp++; // Just in order to prevent compilation warning.

#ifdef ENABLE_USAGE_OF_DDC_NAMING
	/// Set test arguments.
	S16BIT swDevice; // Logical number of device (0-31).
	swDevice = stldTestDeviceNumber_Get(2);
	U16BIT wRtAddress; // A RT address (0-31).
	wRtAddress = stldTestRtAddress_Get (1);
	S16BIT swResult; // Result of operation or function call.
	swResult = sitalReturnCode_SUCCESS;

	try
	{
		///	Initialize device (RT) as a real RT.
		sitalProcess_Log_PrintLine ("#StldTester.Device.Init: unit - %i, access-card, mode-rt, alloc_mem-none\n", swDevice);
		swResult = aceInitialize (swDevice, ACE_ACCESS_CARD, ACE_MODE_RT, 0, 0, 0);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Device.Init.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Set device (RT) address to RtAddress.
		sitalProcess_Log_PrintLine ("#StldTester.Rt.Address.Set: unit - %i, address - %i\n", swDevice, wRtAddress);
		swResult = aceRTSetAddress (swDevice, wRtAddress);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Rt.Address.Set.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Clear all the response status bits for device (RT).
		sitalProcess_Log_PrintLine ("#StldTester.Rt.ResponseStatusBits.Unset: unit - %i, status_bits - %04X\n", swDevice, 0xFFFF);
		swResult = aceRTStatusBitsClear (swDevice, sitalRtStatusWordBit_BUSY);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Rt.ResponseStatusBits.Unset.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Illegalize on device (RT) all address-types in all directions for all subaddresses and all word counts / mode codes.
		sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Disable: unit - %i, address_type - %04X, directions - %04X, subaddress - %04X, word_count - %08X\n", swDevice, sitalRtAddressType_BOTH, sitalMessageDirection_BOTH, sitalRtAddress_ALL, 0xFFFFFFFF);
		swResult = aceRTMsgLegalityDisable (swDevice, ACE_RT_MODIFY_ALL, ACE_RT_MODIFY_ALL, ACE_RT_MODIFY_ALL, 0xFFFFFFFF);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Disable.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Legalize on device (RT) own address in all directions for all subaddresses and all word counts / mode codes.
		sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Enable: unit - %i, address_type - %i, directions - %i, subaddress - %i, word_count - %08X\n", swDevice, sitalRtAddressType_OWN, sitalMessageDirection_BOTH, sitalRtSubaddress_ALL, 0xFFFFFFFF);
		swResult = aceRTMsgLegalityEnable (swDevice, ACE_RT_OWN_ADDRESS, ACE_RT_MODIFY_ALL, ACE_RT_MODIFY_ALL, 0xFFFFFFFF);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Enable.Error: error - %i\n", swResult);
			throw 0;
		}

		// The following is an addition of mine (not in the original test of the client).
		/// Illegalize on device (RT) own address in all directions for subaddress-1 and all word counts / mode codes.
		sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Disable: unit - %i, address_type - %04X, directions - %04X, subaddress - %04X, word_count - %08X\n", swDevice, sitalRtAddressType_OWN, sitalMessageDirection_BOTH, 1, 0xFFFFFFFF);
		swResult = aceRTMsgLegalityDisable (swDevice, ACE_RT_OWN_ADDRESS, ACE_RT_MODIFY_ALL, 1, 0xFFFFFFFF);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Disable.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Illegalize on device (RT) own address in all directions for subaddress-0 and all word counts / mode codes.
		sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Disable: unit - %i, address_type - %04X, directions - %04X, subaddress - %04X, word_count - %08X\n", swDevice, sitalRtAddressType_OWN, sitalMessageDirection_BOTH, 0, 0xFFFFFFFF);
		swResult = aceRTMsgLegalityDisable (swDevice, ACE_RT_OWN_ADDRESS, ACE_RT_MODIFY_ALL, 0, 0xFFFFFFFF);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Disable.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Illegalize on device (RT) own address in all directions for subaddress-31 and all word counts / mode codes.
		sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Disable: unit - %i, address_type - %04X, directions - %04X, subaddress - %04X, word_count - %08X\n", swDevice, sitalRtAddressType_OWN, sitalMessageDirection_BOTH, 31, 0xFFFFFFFF);
		swResult = aceRTMsgLegalityDisable (swDevice, ACE_RT_OWN_ADDRESS, ACE_RT_MODIFY_ALL, 31, 0xFFFFFFFF);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Disable.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Legalize on device (RT) own address in Tx direction for subaddress-0 and word counts / mode codes 0x000D013C.
		// In this case 0x000D013C refers to the following mode codes: 2, 3, 4, 5, 8, 16, 18, 19.
		sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Enable: unit - %i, address_type - %i, directions - %i, subaddress - %i, word_count - %08X\n", swDevice, sitalRtAddressType_OWN, sitalMessageDirection_TX, 0, 0x000D013C);
		swResult = aceRTMsgLegalityEnable (swDevice, ACE_RT_OWN_ADDRESS, sitalMessageDirection_TX, 0, 0x000D013C);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Enable.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Legalize on device (RT) own address in Tx direction for subaddress-31 and word counts / mode codes 0x000D013C.
		// In this case 0x000D013C refers to the following mode codes: 2, 3, 4, 5, 8, 16, 18, 19.
		sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Enable: unit - %i, address_type - %i, directions - %i, subaddress - %i, word_count - %08X\n", swDevice, sitalRtAddressType_OWN, sitalMessageDirection_TX, 31, 0x000D013C);
		swResult = aceRTMsgLegalityEnable (swDevice, ACE_RT_OWN_ADDRESS, sitalMessageDirection_TX, 31, 0x000D013C);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Enable.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Legalize on device (RT) broadcast address in Rx direction for all subaddresses and all word counts / mode codes.
		sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Enable: unit - %i, address_type - %i, directions - %i, subaddress - %i, word_count - %08X\n", swDevice, sitalRtAddressType_BROADCAST, sitalMessageDirection_RX, sitalRtSubaddress_ALL, 0xFFFFFFFF);
		swResult = aceRTMsgLegalityEnable (swDevice, ACE_RT_BCST_ADDRSS, sitalMessageDirection_RX, ACE_RT_MODIFY_ALL, 0xFFFFFFFF);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Enable.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Illegalize on device (RT) broadcast address in Rx direction for subaddress-0 and all word counts / mode codes.
		sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Disable: unit - %i, address_type - %04X, directions - %04X, subaddress - %04X, word_count - %08X\n", swDevice, sitalRtAddressType_BROADCAST, sitalMessageDirection_RX, 0, 0xFFFFFFFF);
		swResult = aceRTMsgLegalityDisable (swDevice, ACE_RT_BCST_ADDRSS, sitalMessageDirection_RX, 0, 0xFFFFFFFF);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Disable.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Illegalize on device (RT) broadcast address in Rx direction for subaddress-31 and all word counts / mode codes.
		sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Disable: unit - %i, address_type - %04X, directions - %04X, subaddress - %04X, word_count - %08X\n", swDevice, sitalRtAddressType_BROADCAST, sitalMessageDirection_RX, 31, 0xFFFFFFFF);
		swResult = aceRTMsgLegalityDisable (swDevice, ACE_RT_BCST_ADDRSS, sitalMessageDirection_RX, 31, 0xFFFFFFFF);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Disable.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Legalize on device (RT) broadcast address in Tx direction for subaddress-0 and word counts / mode codes 0x00000138.
		// In this case 0x000D013C refers to the following mode codes: 3, 4, 5, 8.
		sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Enable: unit - %i, address_type - %i, directions - %i, subaddress - %i, word_count - %08X\n", swDevice, sitalRtAddressType_BROADCAST, sitalMessageDirection_TX, 0, 0x00000138);
		swResult = aceRTMsgLegalityEnable (swDevice, ACE_RT_BCST_ADDRSS, sitalMessageDirection_TX, 0, 0x00000138);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Enable.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Legalize on device (RT) broadcast address in Tx direction for subaddress-31 and word counts / mode codes 0x00000138.
		// In this case 0x000D013C refers to the following mode codes: 3, 4, 5, 8.
		sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Enable: unit - %i, address_type - %i, directions - %i, subaddress - %i, word_count - %08X\n", swDevice, sitalRtAddressType_BROADCAST, sitalMessageDirection_TX, 31, 0x00000138);
		swResult = aceRTMsgLegalityEnable (swDevice, ACE_RT_BCST_ADDRSS, sitalMessageDirection_TX, 31, 0x00000138);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Rt.MessageLegality.Enable.Error: error - %i\n", swResult);
			throw 0;
		}

		// Create received data blocks.
		S16BIT swRtDataBlockId; // A unique ID designating a data block (0-(sitalRtCounter_DATA_BLOCKS-1)).
		U16BIT wRtSubaddress; // A RT subaddress (sitalRtSubaddress_0-sitalRtSubaddress_31).
		U16BIT waData[32];
		for (int iSA = 1; iSA < 30; iSA++)
		{
			// Initialize the transmitted data.
			for (int i = 0; i < 31; i++)
			{
				waData[i] = 0;
			}

			///		Create for device (RT) data-block-SA, a data block of 32 data words.
			swRtDataBlockId = iSA;
			sitalProcess_Log_PrintLine ("#StldTester.Rt.DataBlock.Create: unit - %i, block - %i, type - %i, buf_size - %i\n", swDevice, swRtDataBlockId, sitalRtDataBlockType_SINGLE_32, 31);
			swResult = aceRTDataBlkCreate (swDevice, swRtDataBlockId, ACE_RT_DBLK_SINGLE, waData, 31);
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Rt.DataBlock.Create.Error: error - %i\n", swResult);
				throw 0;
			}

			///		Create for device (RT) data-block-(SA+32), a data block of 32 data words.
			swRtDataBlockId = (iSA + 32);
			sitalProcess_Log_PrintLine ("#StldTester.Rt.DataBlock.Create: unit - %i, block - %i, type - %i, buf_size - %i\n", swDevice, swRtDataBlockId, sitalRtDataBlockType_SINGLE_32, 31);
			swResult = aceRTDataBlkCreate (swDevice, swRtDataBlockId, ACE_RT_DBLK_SINGLE, waData, 31);
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Rt.DataBlock.Create.Error: error - %i\n", swResult);
				throw 0;
			}

			///		Map for device (RT) data-block-SA with message-type-Rx for RtSubAddress-SA, and legalize this subaddress.
			swRtDataBlockId = iSA;
			wRtSubaddress = iSA;
			sitalProcess_Log_PrintLine ("#StldTester.Rt.DataBlock.MapToSa: unit - %i, block - %i, sa - %i, msg_types - x%X, irq_opts-x%X, legalize - %c\n", swDevice, swRtDataBlockId, wRtSubaddress, sitalRtMessageType_RX, sitalRtDataBlockIrq_NONE, 'Y');
			swResult = aceRTDataBlkMapToSA (swDevice, swRtDataBlockId, wRtSubaddress, ACE_RT_MSGTYPE_RX, sitalRtDataBlockIrq_NONE, FALSE);
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Rt.DataBlock.MapToSa.Error: error - %i\n", swResult);
				throw 0;
			}

			///		Map for device (RT) data-block-(SA+32) with message-type-Tx for RtSubAddress-SA, and legalize this subaddress.
			swRtDataBlockId = (iSA + 32);
			wRtSubaddress = iSA;
			sitalProcess_Log_PrintLine ("#StldTester.Rt.DataBlock.MapToSa: unit - %i, block - %i, sa - %i, msg_types - x%X, irq_opts-x%X, legalize - %c\n", swDevice, swRtDataBlockId, wRtSubaddress, sitalRtMessageType_TX, sitalRtDataBlockIrq_NONE, 'Y');
			swResult = aceRTDataBlkMapToSA (swDevice, swRtDataBlockId, wRtSubaddress, ACE_RT_MSGTYPE_TX, sitalRtDataBlockIrq_NONE, FALSE);
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Rt.DataBlock.MapToSa.Error: error - %i\n", swResult);
				throw 0;
			}
		}

		// To create a "wrap-around" SA, use the same data block for both the Rx and Tx:
		{
			/// Create for device (RT) data-block-30, a data block of 32 data words.
			S16BIT swRtDataBlockId; // A unique ID designating a data block (0-(sitalRtCounter_DATA_BLOCKS-1)).
			swRtDataBlockId = 30;
			sitalProcess_Log_PrintLine ("#StldTester.Rt.DataBlock.Create: unit - %i, block - %i, type - %i, buf_size - %i\n", swDevice, swRtDataBlockId, sitalRtDataBlockType_SINGLE_32, 0);
			swResult = aceRTDataBlkCreate (swDevice, swRtDataBlockId, ACE_RT_DBLK_SINGLE, NULL, 0);
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Rt.DataBlock.Create.Error: error - %i\n", swResult);
				throw 0;
			}

			/// Map for device (RT) data-block-30 with message-type-Rx for RtSubAddress-30, and legalize this subaddress.
			swRtDataBlockId = 30;
			wRtSubaddress = 30;
			sitalProcess_Log_PrintLine ("#StldTester.Rt.DataBlock.MapToSa: unit - %i, block - %i, sa - %i, msg_types - x%X, irq_opts-x%X, legalize - %c\n", swDevice, swRtDataBlockId, wRtSubaddress, sitalRtMessageType_RX, sitalRtDataBlockIrq_NONE, 'Y');
			swResult = aceRTDataBlkMapToSA (swDevice, swRtDataBlockId, wRtSubaddress, ACE_RT_MSGTYPE_RX, sitalRtDataBlockIrq_NONE, FALSE);
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Rt.DataBlock.MapToSa.Error: error - %i\n", swResult);
				throw 0;
			}

			/// Map for device (RT) data-block-30 with message-type-Tx for RtSubAddress-30, and legalize this subaddress.
			swRtDataBlockId = 30;
			wRtSubaddress = 30;
			sitalProcess_Log_PrintLine ("#StldTester.Rt.DataBlock.MapToSa: unit - %i, block - %i, sa - %i, msg_types - x%X, irq_opts-x%X, legalize - %c\n", swDevice, swRtDataBlockId, wRtSubaddress, sitalRtMessageType_TX, sitalRtDataBlockIrq_NONE, 'Y');
			swResult = aceRTDataBlkMapToSA (swDevice, swRtDataBlockId, wRtSubaddress, ACE_RT_MSGTYPE_TX, sitalRtDataBlockIrq_NONE, FALSE);
			if (sitalReturnCode_SUCCESS != swResult)
			{
				sitalProcess_Log_PrintLine ("#StldTester.Rt.DataBlock.MapToSa.Error: error - %i\n", swResult);
				throw 0;
			}
		}

		// Set up the mode code table with indefinite data.
		sitalProcess_Log_PrintLine ("#StldTester.Rt.ModeCode.Data.Write: unit - %i, mode_code_address - %04X, value - %04X\n", swDevice, ACE_RT_MCDATA_TX_TRNS_LAST_CMD, 0x0000);
		swResult = aceRTModeCodeWriteData (swDevice, ACE_RT_MCDATA_TX_TRNS_LAST_CMD, 0x0000);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Rt.ModeCode.Data.Write.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Start device (RT).
		sitalProcess_Log_PrintLine ("#StldTester.Rt.Start: unit - %i\n", swDevice);
		swResult = aceRTStart (swDevice);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Rt.Start.Error: error - %i\n", swResult);
			throw 0;
		}

		// Loop forever waiting for messages from an external BC.
		for (;;)
		{
			Sleep_NonOsDependent(1000);
		}

		/// Stop device (RT).
		sitalProcess_Log_PrintLine ("#StldTester.Rt.Stop: unit - %i\n", swDevice);
		swResult = aceRTStop (swDevice);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Rt.Stop.Error: error - %i\n", swResult);
			throw 0;
		}

		/// Free device (RT).
		sitalProcess_Log_PrintLine ("#StldTester.Device.Free: unit - %i\n", swDevice);
		swResult = aceFree (swDevice);
		if (sitalReturnCode_SUCCESS != swResult)
		{
			sitalProcess_Log_PrintLine ("#StldTester.Device.Free.Error: error - %i\n", swResult);
			throw 0;
		}
	}
	catch (int)
	{
		sitalDevice_Free (swDevice);
	}

	sitalProcess_Log_PrintLine ("#StldTester.RtLegalizationTest.End: test_succeeded - %c\n", ((sitalReturnCode_SUCCESS == swResult) ? 'Y' : 'N'));
	return swResult;

#else // USE_SITAL_NAMING
	return sitalReturnCode_UNKNOWN_ERROR;
#endif // ENABLE_USAGE_OF_DDC_NAMING
}
