/// @file
/// Library definitions and declarations.

// Description  : A header file that contains library definitions and declarations
// Version      : 1.0.0.0
// Author       : Sital Technology R&D
//
// Modification history:
//



#ifndef libraryOperatingSystemDependencies_INCLUDED
#define libraryOperatingSystemDependencies_INCLUDED



#ifdef __cplusplus
// C++ compilers mangle function names, unless the function definitions are protected with extern "C"{}.
extern "C" {
#endif



// Enumeration definitions.



// Constant definitions.



// Macro definitions.



// Type/structure declarations.



// Type/structure definitions.



// Internal-function declarations.

#ifdef __unix__

// Under Unix there's no automatic way to get version numbers.
#include "VersionNumbers.h"

// Under Unix one must use the GCC __attribute__((constructor)) and __attribute__((destructor)) keywords (double underscores before and after) to explicitly declare functions to be called on load and unload.
// These keywords cause the compiler/linker to add the specified functions to the __CTOR_LIST__ and __DTOR_LIST__ ("ConstrucTOR LIST" and "DestrucTOR LIST" respectively) in the object file.
// Functions on the __CTOR_LIST__ are called by the loader when the library is loaded (either implicitly or by dlopen()). The main purpose for this list is to call the constructors on global objects in the library.
// Conversely, functions on the __DTOR_LIST__ are called when the library is unloaded (either implicitly or by dlclose()).
void __attribute__ ((constructor)) sitalLibrary_Load(void);
void __attribute__ ((destructor)) sitalLibrary_Unload(void);

#define REGISTER_EXIT_FUNCTION(fpLibraryUnloadFunction) // An empty definition; the destructor function for this library is registered under Unix using __attribute__ ((destructor)) (see above).

#elif defined(VX_WORKS)

// Under VxWorks there's no automatic way to get version numbers.
#include "VersionNumbers.h"

#define REGISTER_EXIT_FUNCTION(fpLibraryUnloadFunction)			atexit (fpLibraryUnloadFunction) // Required under VxWorks, as this operating-system does not support __attribute__ ((destructor)) (used with Unix, see above).

#endif // VX_WORKS

S16BIT helperLibraries_Load (void);
S16BIT library_GetVersion (	U16BIT* wpMajorVersion,
							U16BIT* wpMinorVersion,
							U16BIT* wpBuildNumber,
							U16BIT* wpRevisionNumber);
void sitalLibrary_Load (void);
S16BIT initializeLibrary (void);
void sitalLibrary_Unload (void);
S16BIT uninitializeLibrary (void);



#ifdef __cplusplus
}
#endif



#endif // libraryOperatingSystemDependencies_INCLUDED
