/// @file
/// This file isn't part of the code of project stld1553 DLL.
/// A header file to be included by clients in projects where DDC naming (constants, structures, functions) is already used.
/// A header file to be included by clients that would like to use Sital's stld1553 library in projects where DDC naming (constants, structures, functions) is already used.
/// Such clients may want to keep using DDC naming, and keep their already existing code unchanged.
/// Still, they would like that this DDC-like code would result in actually calling Sital functions instead.
/// Moreover, as they would like a more efficient operation, they will prefer not to use the Sital-stub functions (what's required in case their linker does not support something like NSVC's "#pragma comment(linker, "/export:...)" to explicitly identify export names).
/// Therefore, this header file only includes conversion macros for DDC naming.

// Description  : A header file that contains conversion macros for DDC naming
// Version      : 1.0.0.0
// Author       : Sital Technology R&D
//
// Modification history:
//



#ifndef stld1553_DDC_TO_STLD1553_DEFINITIONS
#define stld1553_DDC_TO_STLD1553_DEFINITIONS



#ifdef __cplusplus
extern "C" {
#endif



// Enumeration definitions.



// Constant definitions.
//#define sitalReturnCode_UNKNOWN_ERROR										-1		///< An unknown error occurred.
//#define sitalReturnCode_TEST_FAIL											-1010	///< Test failed (though the test function succeeded in performing all its actions).
//#define sitalBcCounter_COMMANDS									512		///< Available number of user defined commands per BC.
//#define sitalIeee1553_MAXIMUM_COUNT_OF_MESSAGE_DATA_WORDS					32		///< The maximum number of message data words supported by protocol IEEE-1533.
//#define sitalBcFrameIterations_RUN_FOREVER					-1		///< Run a major frame forever.
//#define sitalRtDataBlockIrq_NONE				0x0000		///< No IRQs generated.



// Macro definitions.



// Type/structure definitions.



// Internal-function declarations.



// Exported-function declarations.

// Configuration functions.
#define aceGetCoreVersion				sitalStld1553_GetShortCoreVersion
#define aceGetLibVersion				sitalStld1553_GetShortLibraryVersion
#define aceRegRead						sitalDevice_Register_Read
#define aceRegWrite						sitalDevice_Register_Write
#define aceMemRead						sitalDevice_Memory_Read
#define aceMemWrite						sitalDevice_Memory_Write
#define aceGetBSWErrString				sitalStld1553_GetBlockStatusWordErrorString
#define aceGetMsgTypeString				sitalStld1553_GetMessageTypeString
#define aceInitialize					sitalDevice_Initialize
#define aceFree							sitalDevice_Free
#define aceSetTimeTagValue				sitalDevice_TimeTag_Set
#define aceGetTimeTagValue				sitalDevice_TimeTag_Get
#define aceResetTimeTag					sitalDevice_TimeTag_Reset
#define aceResetTimeTag					sitalDevice_TimeTag_Reset
#define aceSetTimeTagRes				sitalDevice_TimeTag_SetResolution
#define aceSetMetrics					sitalDevice_OperationalStatisticsCollection_Configure
#define aceSetIrqConfig					sitalDevice_Irq_Configure
#define aceSetIrqConditions				sitalDevice_Irq_Manipulate
#define aceSetAsyncIsr					sitalDevice_SetAsynchronousMessagesIsr
#define aceSetClockFreq					sitalDevice_Clock_SetFrequency
#define aceISQRead(swDevice, iespIsqEntry)	sitalDevice_Isq_ReadEntry((swDevice), (sitalIsqEntryStructure*)(iespIsqEntry))
#define aceISQClear						sitalDevice_Isq_Clear
#define aceISQEnable					sitalDevice_Isq_Configure
#define aceSetRespTimeOut				sitalDevice_SetResponseTimeout
#define	aceBCSetWatchDogTimer			sitalDevice_ConfigureWatchdogTimeout
#define aceSetDecoderConfig				sitalDevice_ConfigureDecoder
#define aceSetRamParityChecking			sitalDevice_ConfigureRamParityCheck
#define aceTestRegisters				sitalDevice_Test_Registers
#define aceTestMemory					sitalDevice_Test_Memory
#define aceTestProtocol					sitalDevice_Test_Protocol
#define aceTestIrqs						sitalDevice_Test_Interrupts
#define aceTestVectors					sitalDevice_Test_Vectors

// Service functions.
#define aceCmdWordCreate				sitalBcStld1553_Command_GetCode
#define aceCmdWordParse					sitalBcStld1553_Command_ParseCode

// BC functions.
#define aceBCConfigure					sitalBc_Initialize
#define aceBCSetMsgRetry				sitalBc_MessageRetryPolicy_Set
#define aceBCStart						sitalBc_Start
#define aceBCStop						sitalBc_Stop
#define aceBCGetStatus					sitalBc_GetActivationState
#define aceBCDataBlkCreate				sitalBc_DataBlock_Create
#define aceBCDataBlkDelete				sitalBc_DataBlock_Delete
#define aceBCDataBlkWrite				sitalBc_DataBlock_Write
#define aceBCDataBlkRead				sitalBc_DataBlock_Read
#define aceBCFrameCreate				sitalBc_Frame_Create
#define aceBCFrameDelete				sitalBc_Frame_Delete
#define aceBCOpCodeCreate				sitalBc_Command_Create
#define aceBCOpCodeDelete				sitalBc_Command_Delete
#define aceBCMsgCreateBCtoRT			sitalBc_Message_CreateBcToRt
#define aceBCMsgCreateRTtoBC			sitalBc_Message_CreateRtToBc
#define aceBCMsgCreateRTtoRT			sitalBc_Message_CreateRtToRt
#define aceBCMsgCreateMode				sitalBc_Message_CreateBcToOrFromRtMode
#define aceBCMsgCreateBcst				sitalBc_Message_CreateBcToBroadcast
#define aceBCMsgCreateBcstRTtoRT		sitalBc_Message_CreateRtToBroadcast
#define aceBCMsgCreateBcstMode			sitalBc_Message_CreateBcToOrFromBroadcastMode
#define aceBCMsgCreate					sitalBc_Message_Create
#define aceBCMsgModifyBCtoRT			sitalBc_Message_ModifyBcToRt
#define aceBCMsgModifyRTtoBC			sitalBc_Message_ModifyRtToBc
#define aceBCMsgModifyRTtoRT			sitalBc_Message_ModifyRtToRt
#define aceBCMsgModifyMode				sitalBc_Message_ModifyBcToOrFromRtMode
#define aceBCMsgModifyBcst				sitalBc_Message_ModifyBcToBroadcast
#define aceBCMsgModifyBcstRTtoRT		sitalBc_Message_ModifyRtToBraodcast
#define aceBCMsgModifyBcstMode			sitalBc_Message_ModifyBcToOrFromBroadcastMode
#define aceBCMsgModify					sitalBc_Message_Modify
#define aceBCMsgDelete					sitalBc_Message_Delete
#define aceBCGetMsgFromIDRaw			sitalBc_Message_GetByIdRaw
#define aceBCDecodeRawMsg(swDevice, wapBuffer, dmspDecodedMessage)	sitalBc_Message_DecodeRaw((swDevice), (wapBuffer), (sitalDecodedMessageStructure*)(dmspDecodedMessage))
#define aceBCGetMsgFromIDDecoded(swDevice, swMessageId, dmspDecodedMessage, wIsPurgeRequired)	sitalBc_Message_GetByIdDecoded((swDevice), (swMessageId), (sitalDecodedMessageStructure*)(dmspDecodedMessage), (wIsPurgeRequired))
#define	aceBCMsgGapTimerEnable			sitalBc_ConfigureMessageGapTimeFieldPolicy
#define aceBCSetGPFState				sitalBc_Gpf_SetState
#define aceBCGetConditionCode			sitalBc_GetConditionState
#define aceBCGPQRead(swDevice, gespGpqEntry)	sitalBc_Gpq_Read((swDevice), (sitalGpqEntryStructure*)(gespGpqEntry))
#define aceBCGPQGetCount				sitalBc_Gpq_GetEntriesCount
#define aceBCFrmToHBuf					sitalBc_Gpq_HandleNewEntries
#define aceBCGetGPQMetric				sitalBc_Gpq_GetOperationalStatistics
#define aceBCAsyncMsgCreateBCtoRT		sitalBc_AsynchronousMessage_CreateBcToRt
#define aceBCAsyncMsgCreateRTtoBC		sitalBc_AsynchronousMessage_CreateRtToBc
#define aceBCAsyncMsgCreateRTtoRT		sitalBc_AsynchronousMessage_CreateRtToRt
#define aceBCAsyncMsgCreateMode			sitalBc_AsynchronousMessage_CreateBcToOrFromRtMode
#define aceBCAsyncMsgCreateBcst			sitalBc_AsynchronousMessage_CreateBcToBroadcast
#define aceBCAsyncMsgCreateBcstRTtoRT	sitalBc_AsynchronousMessage_CreateRtToBraodcast
#define aceBCAsyncMsgCreateBcstMode		sitalBc_AsynchronousMessage_CreateBcToOrFromBroadcastMode
#define aceBCSendAsyncMsgLP				sitalBc_AsynchronousMessage_SendAtLowPriority
#define aceBCSendAsyncMsgHP				sitalBc_AsynchronousMessage_SendAtHighPriority
#define aceBCInstallHBuf				sitalBc_HostBuffer_Initialize
#define aceBCUninstallHBuf				sitalBc_HostBuffer_Free
#define aceBCGetHBufMsgCount			sitalBc_HostBuffer_Message_GetCount
#define aceBCGetHBufMsgDecoded(swDevice, dmspDecodedMessage, dwpMessageCount, dwpLostMessageCount, wMessageLocationAndRemoval)	sitalBc_HostBuffer_Message_GetDecoded((swDevice), (sitalDecodedMessageStructure*)(dmspDecodedMessage), (dwpMessageCount), (dwpLostMessageCount), (wMessageLocationAndRemoval))
#define aceBCGetHBufMsgsRaw				sitalBc_HostBuffer_Message_GetRaw
#define aceBCGetHBufMetric(swDevice, hbosspHostBufferOperationalStatistics, bIsResetOfHighestRecordedPercentageRequired)	sitalBc_HostBuffer_GetOperationalStatistics((swDevice), (sitalHostBufferOperationalStatisticsStructure*)(hbosspHostBufferOperationalStatistics), (bIsResetOfHighestRecordedPercentageRequired))

// RT functions.
#define aceRTConfigure					sitalRt_Initialize
#define aceRTSetAddrSource				sitalRt_AddressSource_Set
#define aceRTGetAddrSource				sitalRt_AddressSource_Get
#define aceRTRelatchAddress				sitalRt_Address_Relatch
#define aceRTSetAddress					sitalRt_Address_Set
#define aceRTGetAddress					sitalRt_Address_Get
#define aceRTStart						sitalRt_Start
#define aceRTStop						sitalRt_Stop
#define aceRTDataBlkCreate				sitalRt_DataBlock_Create
#define aceRTDataBlkDelete				sitalRt_DataBlock_Delete
#define aceRTDataBlkWrite				sitalRt_DataBlock_Write
#define aceRTDataBlkRead				sitalRt_DataBlock_Read
#define aceRTDataBlkMapToSA				sitalRt_DataBlock_MapToSubaddress
#define aceRTDataBlkUnmapFromSA			sitalRt_DataBlock_UnmapFromSubaddress
#define aceRTModeCodeIrqEnable			sitalRt_ModeCode_EnableIrq
#define aceRTModeCodeIrqDisable			sitalRt_ModeCode_DisableIrq
#define aceRTModeCodeIrqStatus			sitalRt_ModeCode_GetIrq
#define aceRTModeCodeReadData			sitalRt_ModeCode_ReadData
#define aceRTModeCodeWriteData			sitalRt_ModeCode_WriteData
#define aceRTMsgLegalityEnable			sitalRt_MessageLegality_Enable
#define aceRTMsgLegalityDisable			sitalRt_MessageLegality_Disable
#define aceRTMsgLegalityStatus			sitalRt_MessageLegality_GetStatus
#define aceRTBusyBitsTblSet				sitalRt_MessageBusyBit_Set
#define aceRTBusyBitsTblClear			sitalRt_MessageBusyBit_Clear
#define aceRTBusyBitsTblStatus			sitalRt_MessageBusyBit_GetStatus
#define aceRTStatusBitsSet				sitalRt_ResponseStatusBits_Set
#define aceRTStatusBitsClear			sitalRt_ResponseStatusBits_Unset
#define aceRTStatusBitsStatus			sitalRt_ResponseStatusBits_Get
#define aceRTGetStkMsgsRaw				sitalRt_Message_GetFromStackRaw
#define aceRTGetStkMsgDecoded(swDevice, dmspDecodedMessage, wMessageLocationAndRemoval)	sitalRt_Message_GetFromStackDecoded((swDevice), (sitalDecodedMessageStructure*)(dmspDecodedMessage), (wMessageLocationAndRemoval))
#define aceRTDecodeRawMsg(swDevice, wapBuffer, dmspDecodedMessage)	sitalRt_Message_DecodeRaw((swDevice), (wapBuffer), (sitalDecodedMessageStructure*)(dmspDecodedMessage))
#define aceRTBITWrdConfig				sitalRt_BuiltInTestWord_Configure
#define aceRTBITWrdRead					sitalRt_BuiltInTestWord_Read
#define aceRTBITWrdWrite				sitalRt_BuiltInTestWord_Write
#define aceRTInstallHBuf				sitalRt_HostBuffer_Initialize
#define aceRTUninstallHBuf				sitalRt_HostBuffer_Free
#define aceRTStkToHBuf					sitalRt_HostBuffer_Message_Record
#define aceRTGetHBufMsgCount			sitalRt_HostBuffer_Message_GetCount
#define aceRTGetHBufMsgDecoded(swDevice, dmspDecodedMessage, dwpMessageCount, dwpStackLostMessageCount, dwpHostBufferLostMessageCount, wMessageLocationAndRemoval)	sitalRt_HostBuffer_Message_GetDecoded((swDevice), (sitalDecodedMessageStructure*)(dmspDecodedMessage), (dwpMessageCount), (dwpStackLostMessageCount), (dwpHostBufferLostMessageCount), (wMessageLocationAndRemoval))
#define aceRTGetHBufMsgsRaw				sitalRt_HostBuffer_Message_GetRaw
#define aceRTGetHBufMetric(swDevice, hbosspHostBufferOperationalStatistics, bIsResetOfHighestRecordedPercentageRequired)	sitalRt_HostBuffer_GetOperationalStatistics((swDevice), (sitalHostBufferOperationalStatisticsStructure*)(hbosspHostBufferOperationalStatistics), (bIsResetOfHighestRecordedPercentageRequired))
#define aceRTGetStkMetric(swDevice, sosspStackOperationalStatistics, bIsResetOfHighestRecordedPercentageRequired)	 sitalRt_Stack_GetOperationalStatistics((swDevice), (sitalStackOperationalStatisticsStructure*)(sosspStackOperationalStatistics), (bIsResetOfHighestRecordedPercentageRequired))

// MT functions.
#define aceMTConfigure					sitalMt_Initialize
#define aceMTGetStkMetric(swDevice, sosspStackOperationalStatistics, wStackSelector, bIsResetOfHighestRecordedPercentageRequired)	sitalMt_Stack_GetOperationalStatistics((swDevice), (sitalStackOperationalStatisticsStructure*)(sosspStackOperationalStatistics), (wStackSelector), (bIsResetOfHighestRecordedPercentageRequired))
#define aceMTSwapStks					sitalMt_Stack_Swap
#define aceMTGetInfo(swDevice, mispMtInformation)	sitalMt_GetInformation((swDevice), (sitalMtInformationStructure*)(mispMtInformation))
#define aceMTStart						sitalMt_Start
#define aceMTStop						sitalMt_Stop
#define aceMTPause						sitalMt_Pause
#define aceMTContinue					sitalMt_Continue
#define aceMTEnableRTFilter				sitalMt_MessageMonitoring_Enable
#define aceMTDisableRTFilter			sitalMt_MessageMonitoring_Disable
#define aceMTGetRTFilter				sitalMt_MessageMonitoring_GetStatus
#define aceMTDecodeRawMsg(swDevice, wapBuffer, dmspDecodedMessage)	sitalMt_Message_DecodeRaw((swDevice), (wapBuffer), (sitalDecodedMessageStructure*)(dmspDecodedMessage))
#define aceMTGetStkMsgsRaw				sitalMt_Message_GetFromStackRaw
#define aceMTGetStkMsgDecoded(swDevice, dmspDecodedMessage, wMessageLocationAndRemoval, wStackSelector)	sitalMt_Message_GetFromStackDecoded((swDevice), (sitalDecodedMessageStructure*)(dmspDecodedMessage), (wMessageLocationAndRemoval), (wStackSelector))
#define aceMTInstallHBuf				sitalMt_HostBuffer_Initialize
#define aceMTUninstallHBuf				sitalMt_HostBuffer_Free
#define aceMTStkToHBuf					sitalMt_HostBuffer_Message_Record
#define aceMTGetHBufMsgCount			sitalMt_HostBuffer_Message_GetCount
#define aceMTGetHBufMsgDecoded(swDevice, dmspDecodedMessage, dwpMessageCount, dwpStackLostMessageCount, dwpHostBufferLostMessageCount, wMessageLocationAndRemoval)	sitalMt_HostBuffer_Message_GetDecoded((swDevice), (sitalDecodedMessageStructure*)(dmspDecodedMessage), (dwpMessageCount), (dwpStackLostMessageCount), (dwpHostBufferLostMessageCount), (wMessageLocationAndRemoval))
#define aceMTGetHBufMsgsRaw				sitalMt_HostBuffer_Message_GetRaw
#define aceMTGetHBufMetric(swDevice, hbosspHostBufferOperationalStatistics, bIsResetOfHighestRecordedPercentageRequired)	sitalMt_HostBuffer_GetOperationalStatistics((swDevice), (sitalHostBufferOperationalStatisticsStructure*)(hbosspHostBufferOperationalStatistics), (bIsResetOfHighestRecordedPercentageRequired))

// RT&MT functions.
#define aceRTMTConfigure				sitalRtMt_Initialize
#define aceRTMTStart					sitalRtMt_Start
#define aceRTMTStop						sitalRtMt_Stop
#define aceRTMTInstallHBuf				sitalRtMt_HostBuffer_Initialize
#define aceRTMTUninstallHBuf			sitalRtMt_HostBuffer_Free
#define aceRTMTStkToHBuf				sitalRtMt_HostBuffer_Message_Record
#define aceRTMTGetHBufMsgCount			sitalRtMt_HostBuffer_Message_GetCount
#define aceRTMTGetHBufMsgDecoded(swDevice, dmspDecodedMessage, dwpMessageCount, dwpRtStackLostMessageCount, dwpMtStackLostMessageCount, dwpHostBufferLostMessageCount, wMessageLocationAndRemoval)	sitalMt_HostBuffer_Message_GetDecoded((swDevice), (sitalDecodedMessageStructure*)(dmspDecodedMessage), (dwpMessageCount), (dwpRtStackLostMessageCount), (dwpMtStackLostMessageCount), (dwpHostBufferLostMessageCount), (wMessageLocationAndRemoval))
#define aceRTMTGetHBufMsgsRaw			sitalRtMt_HostBuffer_Message_GetRaw
#define aceRTMTGetHBufMetric(swDevice, hbosspHostBufferOperationalStatistics, bIsResetOfHighestRecordedPercentageRequired)	sitalRtMt_HostBuffer_GetOperationalStatistics((swDevice), (sitalHostBufferOperationalStatisticsStructure*)(hbosspHostBufferOperationalStatistics), (bIsResetOfHighestRecordedPercentageRequired))

// Maximums.
#define MAX_NUM_OF_DEVICES		sitalMaximum_DEVICES									
#define ACE_MSGSIZE_BC		sitalBcMaximum_MESSAGE_SIZE								
#define ACE_MSGSIZE_RT		sitalRtMaximum_MESSAGE_SIZE								
#define ACE_MSGSIZE_MT		sitalMtMaximum_MESSAGE_SIZE								
#define ACE_MSGSIZE_RTMT		sitalRtMtMaximum_MESSAGE_SIZE							

// Parameter values.
#define ACE_RX_CMD		sitalCommand_RX	
#define ACE_TX_CMD		sitalCommand_TX	
#define ACE_BROADCAST		sital1553_BROADCAST			
#define ACE_MODE_CODE1		sital1553_MODE_CODE1		
#define ACE_MODE_CODE2		sital1553_MODE_CODE2		
#define ACE_MSG_BCTORT		sitalMessageType_BC_TO_RT					 
#define ACE_MSG_RTTOBC		sitalMessageType_RT_TO_BC					 
#define ACE_MSG_RTTORT		sitalMessageType_RT_TO_RT					 
#define ACE_MSG_MODENODATA		sitalMessageType_MODE_NO_DATA				 
#define ACE_MSG_MODEDATARX		sitalMessageType_MODE_DATA_RX				 
#define ACE_MSG_MODEDATATX		sitalMessageType_MODE_DATA_TX				 
#define ACE_MSG_BRDCST		sitalMessageType_BROADCAST					 
#define ACE_MSG_BRDCSTRTTORT		sitalMessageType_BROADCAST_RT_TO_RT			
#define ACE_MSG_BRDCSTMODENODATA		sitalMessageType_BROADCAST_MODE_NO_DATA		
#define ACE_MSG_BRDCSTMODEDATA		sitalMessageType_BROADCAST_MODE_DATA		
#define ACE_MSG_INVALID		sitalMessageType_INVALID					
#define ACE_ACCESS_CARD		sitalAccess_CARD			
#define ACE_ACCESS_SIM		sitalAccess_SIMULATION		
#define ACE_ACCESS_USR		sitalAccess_USER			
#define ACE_MODE_TEST		sitalMode_TEST			
#define ACE_MODE_BC		sitalMode_BC			
#define ACE_MODE_RT		sitalMode_RT			
#define ACE_MODE_MT		sitalMode_MT			
#define ACE_MODE_RTMT		sitalMode_RT_AND_MT		
#define ACE_NO_TT_RESET		sitalModeVariant_NO_TIME_TAG_RESET		
#define ACE_ADVANCED_MODE		sitalModeVariant_ADVANCED				
#define ACE_RESPTIME_18US		sitalResponseTimeout_18US			
#define ACE_RESPTIME_22US		sitalResponseTimeout_22US			
#define ACE_RESPTIME_50US		sitalResponseTimeout_50US			
#define ACE_RESPTIME_130US		sitalResponseTimeout_130US			
#define ACE_STATE_RESET		sitalDeviceState_RESET		
#define ACE_STATE_READY		sitalDeviceState_READY		
#define ACE_STATE_RUN		sitalDeviceState_RUN		
#define ACE_CLOCK_16MHZ		sitalClockSetup_16MHZ		
#define ACE_CLOCK_12MHZ		sitalClockSetup_12MHZ		
#define ACE_CLOCK_20MHZ		sitalClockSetup_20MHZ		
#define ACE_CLOCK_10MHZ		sitalClockSetup_10MHZ		
#define ACE_SINGLE_ENDED		sitalInputDevice_SingleEnded		
#define ACE_DOUBLE_ENDED		sitalInputDevice_DoubleEnded		
#define ACE_DISABLE_EXPANDED_XING		sitalExpendedXing_Disable		
#define ACE_ENABLE_EXPANDED_XING		sitalExpendedXing_Enable		
#define ACE_DISABLE_PARITY_CHECK		sitalRamParityCheck_DISABLE		
#define ACE_ENABLE_PARITY_CHECK		sitalRamParityCheck_ENABLE		
#define ACE_TT_2US		sitalTimeTagResolution_2US					
#define ACE_TT_4US		sitalTimeTagResolution_4US					
#define ACE_TT_8US		sitalTimeTagResolution_8US					
#define ACE_TT_16US		sitalTimeTagResolution_16US					
#define ACE_TT_32US		sitalTimeTagResolution_32US					
#define ACE_TT_64US		sitalTimeTagResolution_64US					
#define ACE_TT_TEST		sitalTimeTagResolution_TEST					
#define ACE_TT_EXT		sitalTimeTagResolution_EXTERNAL_CLOCK		
#define ACE_IRQ_PULSE		sitalIrqMode_PULSE		
#define ACE_IRQ_LEVEL		sitalIrqMode_LEVEL		
#define ACE_IRQ_NO_AUTO_CLR		sitalIrqClear_NO_AUTO_CLEAR	
#define ACE_IRQ_AUTO_CLR		sitalIrqClear_AUTO_CLEAR		
#define ACE_ISQ_MSG_NONMSG		sitalInterrupt_NON_MESSAGE							
#define ACE_ISQ_TX_TIMEOUT		sitalInterrupt_TX_TIMEOUT							
#define ACE_ISQ_ILL_LKUP		sitalInterrupt_ILL_LOOKUP							
#define ACE_ISQ_MT_DSTK_50P_ROVR		sitalInterrupt_MT_DATA_STACK_HALF_ROLLOVER			
#define ACE_ISQ_MT_DSTK_ROVER		sitalInterrupt_MT_DATA_STACK_ROVER					
#define ACE_ISQ_RT_DSTK_50P_ROVR		sitalInterrupt_RT_DATA_STACK_HALF_ROLLOVER			
#define ACE_ISQ_RT_DSTK_ROVER		sitalInterrupt_RT_DATA_STACK_ROLLOVER				
#define ACE_ISQ_MT_CSTK_50P_ROVR		sitalInterrupt_MT_COMMAND_STACK_HALF_ROLLOVER		
#define ACE_ISQ_MT_CSTK_ROVR		sitalInterrupt_MT_COMMAND_STACK_ROLLOVER			
#define ACE_ISQ_RT_CSTK_50P_ROVR		sitalInterrupt_RT_COMMAND_STACK_HALF_ROLLOVER		
#define ACE_ISQ_RT_CSTK_ROVR		sitalInterrupt_RT_COMMAND_STACK_ROLLOVER			
#define ACE_ISQ_HNDSHK_FAIL		sitalInterrupt_HANDSHAKE_FAIL						
#define ACE_ISQ_FMT_ERR		sitalInterrupt_FORMAT_ERROR							
#define ACE_ISQ_MCODE		sitalInterrupt_MODE_CODE							
#define ACE_ISQ_SA_EOM		sitalInterrupt_SUBADDRESS_END_OF_MESSAGE			
#define ACE_ISQ_EOM		sitalInterrupt_END_OF_MESSAGE						
#define ACE_ISQ_TIME_TAG		sitalInterrupt_TIME_TAG								
#define ACE_ISQ_RT_ADDR_PAR		sitalInterrupt_RT_ADDRESS_PARITY					
#define ACE_ISQ_SELF_TEST		sitalInterrupt_SELF_TEST							
#define ACE_IMR1_EOM		sitalInterruptRegister1_END_OF_MESSAGE 							
#define ACE_IMR1_BC_STATUS_SET		sitalInterruptRegister1_BC_STATUS_SET							
#define ACE_IMR1_RT_MODE_CODE		sitalInterruptRegister1_RT_MODE_CODE							
#define ACE_IMR1_MT_PATTERN_TRIG		sitalInterruptRegister1_MT_PATTERN_TRIGGER						
#define ACE_IMR1_FORMAT_ERR		sitalInterruptRegister1_FORMAT_ERROR 							
#define ACE_IMR1_BC_END_OF_FRM		sitalInterruptRegister1_BC_END_OF_FRAME							
#define ACE_IMR1_BC_MSG_EOM		sitalInterruptRegister1_BC_END_OF_MESSAGE 						
#define ACE_IMR1_RT_SUBADDR_EOM		sitalInterruptRegister1_RT_SUBADDRESS_END_OF_MESSAGE 			
#define ACE_IMR1_RT_CIRCBUF_ROVER		sitalInterruptRegister1_RT_CIRCULAR_BUFFER_ROLLOVER				
#define ACE_IMR1_TT_ROVER		sitalInterruptRegister1_TIME_TAG_ROLLOVER						
#define ACE_IMR1_RT_ADDR_PAR_ERR		sitalInterruptRegister1_RT_ADDRESS_PARITY_ERROR					
#define ACE_IMR1_BC_RETRY		sitalInterruptRegister1_BC_RETRY								
#define ACE_IMR1_HSHAKE_FAIL		sitalInterruptRegister1_HANDSHAKE_FAILURE							
#define ACE_IMR1_MT_DATASTK_ROVER		sitalInterruptRegister1_MT_DATA_STACK_ROLLOVER					
#define ACE_IMR1_MT_CMDSTK_ROVER		sitalInterruptRegister1_MT_COMMAND_STACK_ROLLOVER				
#define ACE_IMR1_BCRT_CMDSTK_ROVER		sitalInterruptRegister1_BC_RT_COMMAND_STACK_ROLLOVER			
#define ACE_IMR1_BCRT_TX_TIMEOUT		sitalInterruptRegister1_BC_RT_TRANSMITTER_TIMEOUT						
#define ACE_IMR1_RAM_PAR_ERR		sitalInterruptRegister1_RAM_PARITY_ERROR						
#define ACE_IMR2_BIT_COMPLETE		sitalInterruptRegister2_BUILT_IN_TEST_COMPLETE						
#define ACE_IMR2_BC_UIRQ0		sitalInterruptRegister2_BC_IRQ0									
#define ACE_IMR2_BC_UIRQ1		sitalInterruptRegister2_BC_IRQ1									
#define ACE_IMR2_BC_UIRQ2		sitalInterruptRegister2_BC_IRQ2									
#define ACE_IMR2_BC_UIRQ3		sitalInterruptRegister2_BC_IRQ3									
#define ACE_IMR2_MT_DSTK_50P_ROVER		sitalInterruptRegister2_MT_DATA_STACK_HALF_ROLLOVER				
#define ACE_IMR2_MT_CSTK_50P_ROVER		sitalInterruptRegister2_MT_COMMAND_STACK_HALF_ROLLOVER			
#define ACE_IMR2_RT_CIRC_50P_ROVER		sitalInterruptRegister2_RT_CIRCULAR_BUFFER_HALF_ROLLOVER		
#define ACE_IMR2_RT_CSTK_50P_ROVER		sitalInterruptRegister2_RT_COMMAND_STACK_HALF_ROLLOVER			
#define ACE_IMR2_BC_TRAP		sitalInterruptRegister2_BC_TRAP									
#define ACE_IMR2_BC_CALLSTK_ERR		sitalInterruptRegister2_BC_CALL_STACK_ERROR 					
#define ACE_IMR2_GPQ_ISQ_ROVER		sitalInterruptRegister2_GPQ_ISQ_ROLLOVER						
#define ACE_IMR2_RT_ILL_CMD		sitalInterruptRegister2_RT_ILLEGAL_COMMAND 							
#define ACE_IMR2_BC_OPCODE_PARITY		sitalInterruptRegister2_BC_OPCODE_PARITY_ERROR						
#define ACE_BC_MOD_DBLK1		sitalBcMessageModifier_MESSAGE1_DATA_BLOCK			
#define ACE_BC_MOD_BCCTRL1		sitalBcMessageModifier_MESSAGE1_BC_CONTROL			
#define ACE_BC_MOD_CMDWRD1_1		sitalBcMessageModifier_MESSAGE1_COMMAND1			
#define ACE_BC_MOD_CMDWRD1_2		sitalBcMessageModifier_MESSAGE1_COMMAND2			
#define ACE_BC_MOD_GAPTIME1		sitalBcMessageModifier_MESSAGE1_GAPTIME				
#define ACE_BC_MOD_DBLK2		sitalBcMessageModifier_MESSAGE2_DATA_BLOCK			
#define ACE_BC_MOD_BCCTRL2		sitalBcMessageModifier_MESSAGE2_BC_CONTROL			
#define ACE_BC_MOD_CMDWRD2_1		sitalBcMessageModifier_MESSAGE2_COMMAND1			
#define ACE_BC_MOD_CMDWRD2_2		sitalBcMessageModifier_MESSAGE2_COMMAND2			
#define ACE_BC_MOD_GAPTIME2		sitalBcMessageModifier_MESSAGE2_GAPTIME				
#define ACE_BC_IDLE		sitalBcActivationState_IDLE
#define ACE_BC_BUSY		sitalBcActivationState_BUSY
#define ACE_BC_MNRFRM_IRQ_DISABLE		sitalBcFrameFlag_MINOR_FRAME_IRQ_DISABLE			
#define ACE_RETRY_NONE		sitalMessageRetryCount_NONE			
#define ACE_RETRY_ONCE		sitalMessageRetryCount_ONE			
#define ACE_RETRY_TWICE		sitalMessageRetryCount_TWO			
#define ACE_RETRY_SAME		sitalMessageRetryBus_SAME			
#define ACE_RETRY_ALT		sitalMessageRetryBus_OTHER			
#define ACE_BC_ASYNC_LMODE		sitalBcSetupOption_ASYNCHRONOUS_LOW_PRIORITY_MODE			
#define ACE_BC_ASYNC_HMODE		sitalBcSetupOption_ASYNCHRONOUS_HIGH_PRIORITY_MODE			
#define ACE_BC_ASYNC_BOTH		sitalBcSetupOption_ASYNCHRONOUS_BOTH_PRIORITY_MODES			
#define ACE_BC_DBLK_SINGLE		sitalBcDataBlockSizeOption_SINGLE		
#define ACE_BC_DBLK_DOUBLE		sitalBcDataBlockSizeOption_DOUBLE		
#define ACE_BCCTRL_RT_TO_RT		sitalBcControlWord_RT_TO_RT														
#define ACE_BCCTRL_BCST		sitalBcControlWord_BROADCAST													
#define ACE_BCCTRL_MODE		sitalBcControlWord_MODE															
#define ACE_BCCTRL_1553A		sitalBcControlWord_1553A														
#define ACE_BCCTRL_CHL_B		sitalBcControlWord_BUS_B														
#define ACE_BCCTRL_1553B		sitalBcControlWord_1553B														
#define ACE_BCCTRL_EOM_IRQ		sitalBcControlWord_END_OF_MESSAGE_INTERRUPT_ENABLED								
#define ACE_BCCTRL_BCST_MSK		sitalBcControlWord_BROADCAST_CHECK_MASKED										
#define ACE_BCCTRL_SELFTST		sitalBcControlWord_LOOPBACK_TEST_PERFORMED										
#define ACE_BCCTRL_CHL_A		sitalBcControlWord_BUS_A														
#define ACE_BCCTRL_RETRY_ENA		sitalBcControlWord_RETRY_ENABLED												
#define ACE_BCCTRL_RES_MSK		sitalBcControlWord_RESERVE_STATUS_BITS_MASKED									
#define ACE_BCCTRL_TFLG_MSK		sitalBcControlWord_TERMINAL_STATUS_FLAG_MASKED									
#define ACE_BCCTRL_SSFLG_MSK		sitalBcControlWord_SUBSYSTEM_STATUS_FLAG_MASKED									
#define ACE_BCCTRL_SSBSY_MSK		sitalBcControlWord_BUSY_STATUS_BIT_MASKED										
#define ACE_BCCTRL_SREQ_MSK		sitalBcControlWord_SERVICE_REQUEST_STATUS_BIT_MASKED							
#define ACE_BCCTRL_ME_MSK		sitalBcControlWord_MESSAGE_ERROR_STATUS_BIT_MASKED								
#define ACE_MSGOPT_DOUBLE_BUFFER		sitalBcMessageOption_DUAL_MESSAGE												
#define ACE_MSGOPT_STAY_ON_ALT		sitalBcMessageOption_STAY_ON_ALTERNATE_BUS										
#define ACE_OPCODE_TRP		sitalOpcode_TRAP							
#define ACE_OPCODE_XEQ		sitalOpcode_EXECUTE_MESSAGE					
#define ACE_OPCODE_JMP		sitalOpcode_JUMP							
#define ACE_OPCODE_CAL		sitalOpcode_CALL_SUBROUTINE					
#define ACE_OPCODE_RTN		sitalOpcode_RETURN_FROM_SUBROUTINE			
#define ACE_OPCODE_IRQ		sitalOpcode_INTERRUPT_REQUEST				
#define ACE_OPCODE_HLT		sitalOpcode_HALT							
#define ACE_OPCODE_DLY		sitalOpcode_DELAY							
#define ACE_OPCODE_WFT		sitalOpcode_WAIT_END_OF_FRAME				
#define ACE_OPCODE_CFT		sitalOpcode_COMPARE_TO_FRAME_TIMER			
#define ACE_OPCODE_FLG		sitalOpcode_UPDATE_GENERAL_PURPOSE_FLAG		
#define ACE_OPCODE_LTT		sitalOpcode_LOAD_TIME_TAG_COUNTER			
#define ACE_OPCODE_LFT		sitalOpcode_LOAD_FRAME_TIMER				
#define ACE_OPCODE_SFT		sitalOpcode_START_FRAME_TIMER				
#define ACE_OPCODE_PTT		sitalOpcode_PUSH_TIME_TAG_COUNTER			
#define ACE_OPCODE_PBS		sitalOpcode_PUSH_BLOCK_STATUS_WORD			
#define ACE_OPCODE_PSI		sitalOpcode_PUSH_VALUE						
#define ACE_OPCODE_PSM		sitalOpcode_PUSH_INDERCT_VALUE				
#define ACE_OPCODE_WTG		sitalOpcode_WAIT_FOR_TRIGGER				
#define ACE_OPCODE_XQF		sitalOpcode_EXECUTE_AND_FLIP				
#define ACE_S_OPCODE_AMSG		sitalOpcode_TIME_CONDITIONED_MESSAGE_TX		
#define ACE_CNDTST_LT		sitalOpcodeCondition_LESS_THAN				
#define ACE_CNDTST_GT		sitalOpcodeCondition_GREATER_THAN			
#define ACE_CNDTST_EQ		sitalOpcodeCondition_EQUAL					
#define ACE_CNDTST_NEQ		sitalOpcodeCondition_NOT_EQUAL				
#define ACE_CNDTST_GP1_1		sitalOpcodeCondition_GP1_1					
#define ACE_CNDTST_GP1_0		sitalOpcodeCondition_GP1_0					
#define ACE_CNDTST_GP2_1		sitalOpcodeCondition_GP2_1					
#define ACE_CNDTST_GP2_0		sitalOpcodeCondition_GP2_0					
#define ACE_CNDTST_GP3_1		sitalOpcodeCondition_GP3_1					
#define ACE_CNDTST_GP3_0		sitalOpcodeCondition_GP3_0					
#define ACE_CNDTST_GP4_1		sitalOpcodeCondition_GP4_1					
#define ACE_CNDTST_GP4_0		sitalOpcodeCondition_GP4_0					
#define ACE_CNDTST_GP5_1		sitalOpcodeCondition_GP5_1					
#define ACE_CNDTST_GP5_0		sitalOpcodeCondition_GP5_0					
#define ACE_CNDTST_GP6_1		sitalOpcodeCondition_GP6_1					
#define ACE_CNDTST_GP6_0		sitalOpcodeCondition_GP6_0					
#define ACE_CNDTST_GP7_1		sitalOpcodeCondition_GP7_1					
#define ACE_CNDTST_GP7_0		sitalOpcodeCondition_GP7_0					
#define ACE_CNDTST_NO_RES		sitalOpcodeCondition_NO_RESPONSE			
#define ACE_CNDTST_RES		sitalOpcodeCondition_RESPONSE				
#define ACE_CNDTST_FMT_ERR		sitalOpcodeCondition_FORMAT_ERROR			
#define ACE_CNDTST_NO_FMT_ERR		sitalOpcodeCondition_NO_FORMAT_ERROR		
#define ACE_CNDTST_GD_XFER		sitalOpcodeCondition_GOOD_TRANSFER			
#define ACE_CNDTST_BAD_XFER		sitalOpcodeCondition_BAD_TRANFER			
#define ACE_CNDTST_MSK_STS_SET		sitalOpcodeCondition_MASKED_STATUS_SET			
#define ACE_CNDTST_MSK_STS_CLR		sitalOpcodeCondition_MASKED_STATUS_CLEAR		
#define ACE_CNDTST_BAD_MSG		sitalOpcodeCondition_BAD_MESSAGE			
#define ACE_CNDTST_GOOD_MSG		sitalOpcodeCondition_GOOD_MESSAGE			
#define ACE_CNDTST_0RETRY		sitalOpcodeCondition_NO_RETRY				
#define ACE_CNDTST_1RETRY		sitalOpcodeCondition_1_RETRY				
#define ACE_CNDTST_2RETRY		sitalOpcodeCondition_2_RETRIES				
#define ACE_CNDTST_ALWAYS		sitalOpcodeCondition_ALWAYS					
#define ACE_CNDTST_NEVER		sitalOpcodeCondition_NEVER					
#define ACE_GPQ_MJR_EOF		sitalGeneralPurposeQueueFlag_END_OF_MAJOR_FRAME					
#define ACE_GPQ_MNR_EOF		sitalGeneralPurposeQueueFlag_END_OF_MINOR_FRAME					
#define ACE_GPQ_MRR_TIME_EXP		sitalGeneralPurposeQueueFlag_WATCHDOG_TIMEOUT					
#define ACE_CND_LT_GT		sitalBcConditionCode_GPF_EQUAL_FLAG					
#define ACE_CND_EQ_NE		sitalBcConditionCode_GPF_LESS_THAN_FLAG				
#define ACE_CND_GPF0		sitalBcConditionCode_GPF0							
#define ACE_CND_GPF1		sitalBcConditionCode_GPF1							
#define ACE_CND_GPF2		sitalBcConditionCode_GPF2							
#define ACE_CND_GPF3		sitalBcConditionCode_GPF3							
#define ACE_CND_GPF4		sitalBcConditionCode_GPF4							
#define ACE_CND_GPF5		sitalBcConditionCode_GPF5							
#define ACE_CND_GPF6		sitalBcConditionCode_GPF6							
#define ACE_CND_GPF7		sitalBcConditionCode_GPF7							
#define ACE_CND_NORES		sitalBcConditionCode_NO_RESPONSE					
#define ACE_CND_FMT_ERR		sitalBcConditionCode_FORMAT_ERROR					
#define ACE_CND_GD_DATA		sitalBcConditionCode_GOOD_DATA_BLOCK_TRANSFER		
#define ACE_CND_MSKED_STS		sitalBcConditionCode_MASKED_STATUS					
#define ACE_CND_BAD_MSG		sitalBcConditionCode_BAD_MESSAGE					
#define ACE_CND_RETRY		sitalBcConditionCode_RETRY_COUNT					
#define ACE_CND_ALWAYS		sitalBcConditionCode_ALWAYS							
#define ACE_FRAME_MAJOR		sitalBcFrameType_MAJOR		
#define ACE_FRAME_MINOR		sitalBcFrameType_MINOR		
#define ACE_GPF0		sitalBcGpf_GPF0				
#define ACE_GPF1		sitalBcGpf_GPF1				
#define ACE_GPF2		sitalBcGpf_GPF2				
#define ACE_GPF3		sitalBcGpf_GPF3				
#define ACE_GPF4		sitalBcGpf_GPF4				
#define ACE_GPF5		sitalBcGpf_GPF5				
#define ACE_GPF6		sitalBcGpf_GPF6				
#define ACE_GPF7		sitalBcGpf_GPF7				
#define ACE_GPF_LEAVE		sitalBcGpfEffect_LEAVE		
#define ACE_GPF_SET		sitalBcGpfEffect_SET		
#define ACE_GPF_CLEAR		sitalBcGpfEffect_CLEAR		
#define ACE_GPF_TOGGLE		sitalBcGpfEffect_TOGGLE		
#define ACE_RT_CMDSTK_256		sitalRtCommandStackSize_256		
#define ACE_RT_CMDSTK_512		sitalRtCommandStackSize_512		
#define ACE_RT_CMDSTK_1K		sitalRtCommandStackSize_1024	
#define ACE_RT_CMDSTK_2K		sitalRtCommandStackSize_2048	
#define ACE_RT_EXTERNAL_ADDR		sitalRtAddressSource_EXTERNAL	
#define ACE_RT_INTERNAL_ADDR		sitalRtAddressSource_INTERNAL	
#define ACE_RT_OPT_CLR_SREQ		sitalRtSetupOption_CLEAR_SERVICE_REQUEST		
#define ACE_RT_OPT_LOAD_TT		sitalRtSetupOption_LOAD_TIME_TAG				
#define ACE_RT_OPT_CLEAR_TT		sitalRtSetupOption_CLEAR_TIME_TAG				
#define ACE_RT_OPT_OVR_DATA		sitalRtSetupOption_OVERWRITE_DATA				
#define ACE_RT_OPT_OVR_MBIT		sitalRtSetupOption_OVERRIDE_MODE_BIT			
#define ACE_RT_OPT_ALT_STS		sitalRtSetupOption_ALTERNATE_STATUS				
#define ACE_RT_OPT_IL_RX_D		sitalRtSetupOption_ILL_RX_DISABLE				
#define ACE_RT_OPT_BSY_RX_D		sitalRtSetupOption_BUSY_RX_DISABLE				
#define ACE_RT_OPT_SET_RTFG		sitalRtSetupOption_SET_RT_FLAG					
#define ACE_RT_OPT_1553A_MC		sitalRtSetupOption_1553A_MODE_CODES				
#define ACE_RT_OPT_MC_O_BSY		sitalRtSetupOption_MODE_COMMAND_OVERRIDE_BUSY	
#define ACE_RT_OPT_BCST_DIS		sitalRtSetupOption_BROADCAST_DISABLE			
#define ACE_RT_DBLK_SINGLE		sitalRtDataBlockType_SINGLE_32				
#define ACE_RT_DBLK_DOUBLE		sitalRtDataBlockType_DOUBLE					
#define ACE_RT_DBLK_C_128		sitalRtDataBlockType_CIRCULAR_128			
#define ACE_RT_DBLK_C_256		sitalRtDataBlockType_CIRCULAR_256			
#define ACE_RT_DBLK_C_512		sitalRtDataBlockType_CIRCULAR_512			
#define ACE_RT_DBLK_C_1K		sitalRtDataBlockType_CIRCULAR_1024			
#define ACE_RT_DBLK_C_2K		sitalRtDataBlockType_CIRCULAR_2048			
#define ACE_RT_DBLK_C_4K		sitalRtDataBlockType_CIRCULAR_4096			
#define ACE_RT_DBLK_C_8K		sitalRtDataBlockType_CIRCULAR_8192			
#define ACE_RT_DBLK_GBL_C_128		sitalRtDataBlockType_COMMON_CIRCULAR_128	
#define ACE_RT_DBLK_GBL_C_256		sitalRtDataBlockType_COMMON_CIRCULAR_256	
#define ACE_RT_DBLK_GBL_C_512		sitalRtDataBlockType_COMMON_CIRCULAR_512	
#define ACE_RT_DBLK_GBL_C_1K		sitalRtDataBlockType_COMMON_CIRCULAR_1024	
#define ACE_RT_DBLK_GBL_C_2K		sitalRtDataBlockType_COMMON_CIRCULAR_2048	
#define ACE_RT_DBLK_GBL_C_4K		sitalRtDataBlockType_COMMON_CIRCULAR_4096	
#define ACE_RT_DBLK_GBL_C_8K		sitalRtDataBlockType_COMMON_CIRCULAR_8192	
#define ACE_RT_MCTYPE_RX_NO_DATA		sitalRtModeCodeType_RX_NO_DATA				
#define ACE_RT_MCTYPE_RX_DATA		sitalRtModeCodeType_RX_DATA					
#define ACE_RT_MCTYPE_TX_NO_DATA		sitalRtModeCodeType_TX_NO_DATA				
#define ACE_RT_MCTYPE_TX_DATA		sitalRtModeCodeType_TX_DATA					
#define ACE_RT_MCTYPE_BCST_RX_NO_DATA		sitalRtModeCodeType_BROADCAST_RX_NO_DATA	
#define ACE_RT_MCTYPE_BCST_RX_DATA		sitalRtModeCodeType_BROADCAST_RX_DATA		
#define ACE_RT_MCTYPE_BCST_TX_NO_DATA		sitalRtModeCodeType_BROADCAST_TX_NO_DATA	
#define ACE_RT_MCTYPE_BCST_TX_DATA		sitalRtModeCodeType_BROADCAST_TX_DATA		
#define ACE_RT_MCIRQ_DYN_BUS_CTRL		sitalRtModeCodeIrq_DYNAMIC_BUS_CONTROL					
#define ACE_RT_MCIRQ_SYNCHRONIZE		sitalRtModeCodeIrq_SYNCHRONIZE							
#define ACE_RT_MCIRQ_TRNS_STATUS		sitalRtModeCodeIrq_TRANSMIT_STATUS						
#define ACE_RT_MCIRQ_INIT_SELF_TEST		sitalRtModeCodeIrq_INITIALIZE_SELF_TEST					
#define ACE_RT_MCIRQ_TRNS_SHUTDOWN		sitalRtModeCodeIrq_TRANSMITTER_SHUTDOWN					
#define ACE_RT_MCIRQ_OVR_TRNS_SHUTDWN		sitalRtModeCodeIrq_OVERRIDE_TRANSMITTER_SHUTDOWN			
#define ACE_RT_MCIRQ_INH_TERM_FLAG		sitalRtModeCodeIrq_INHIBIT_TERMINAL_FLAG				
#define ACE_RT_MCIRQ_OVR_INH_TERM_FLG		sitalRtModeCodeIrq_OVERRIDE_INHIBIT_TERMINAL_FLAG		
#define ACE_RT_MCIRQ_RESET_REMOTE_TERM		sitalRtModeCodeIrq_RESET_REMOTE_TERMINAL				
#define ACE_RT_MCIRQ_TRNS_VECTOR		sitalRtModeCodeIrq_TRANSMIT_VECTOR						
#define ACE_RT_MCIRQ_TRNS_LAST_CMD		sitalRtModeCodeIrq_TRANSMIT_LAST_COMMAND				
#define ACE_RT_MCIRQ_TRNS_BIT		sitalRtModeCodeIrq_TRANSMIT_BUILT_IN_TEST							
#define ACE_RT_MCIRQ_SEL_TRNS_SHUTDWN		sitalRtModeCodeIrq_SELECTED_TRANSMITTER_SHUTDOWN				
#define ACE_RT_MCIRQ_OVR_SEL_TRNS_SHUTDWN		sitalRtModeCodeIrq_OVERRIDE_SELECTED_TRANSMITTER_SHUTDOWN		
#define ACE_RT_MCIRQ_RESERVED_BIT6		sitalRtModeCodeIrq_RESERVED_BIT6						
#define ACE_RT_MCIRQ_RESERVED_BIT7		sitalRtModeCodeIrq_RESERVED_BIT7						
#define ACE_RT_MCIRQ_RESERVED_BIT7		sitalRtModeCodeIrq_RESERVED_BIT7						
#define ACE_RT_MCIRQ_RESERVED_BIT7		sitalRtModeCodeIrq_RESERVED_BIT7						
#define ACE_RT_MCIRQ_RESERVED_BIT8		sitalRtModeCodeIrq_RESERVED_BIT8						
#define ACE_RT_MCIRQ_RESERVED_BIT9		sitalRtModeCodeIrq_RESERVED_BIT9						
#define ACE_RT_MCIRQ_RESERVED_BIT10		sitalRtModeCodeIrq_RESERVED_BIT10						
#define ACE_RT_MCIRQ_RESERVED_BIT11		sitalRtModeCodeIrq_RESERVED_BIT11						
#define ACE_RT_MCIRQ_RESERVED_BIT12		sitalRtModeCodeIrq_RESERVED_BIT12						
#define ACE_RT_MCIRQ_RESERVED_BIT13		sitalRtModeCodeIrq_RESERVED_BIT13						
#define ACE_RT_MCIRQ_RESERVED_BIT14		sitalRtModeCodeIrq_RESERVED_BIT14						
#define ACE_RT_MCIRQ_RESERVED_BIT15		sitalRtModeCodeIrq_RESERVED_BIT15						
#define ACE_RT_MCDATA_RX_SYNCHRONIZE		sitalRtDataContainerModeCode_RX_SYNCHRONIZE								
#define ACE_RT_MCDATA_RX_SEL_T_SHUTDWN		sitalRtDataContainerModeCode_RX_TRANSMITTER_SHUTDOWN						
#define ACE_RT_MCDATA_RX_OVR_SEL_T_SHUTDWN		sitalRtDataContainerModeCode_RX_OVERRIDE_TRANSMITTER_SHUTDOWN					
#define ACE_RT_MCDATA_TX_TRNS_VECTOR		sitalRtDataContainerModeCode_TX_TRANSMIT_VECTOR_WORD							
#define ACE_RT_MCDATA_TX_TRNS_LAST_CMD		sitalRtDataContainerModeCode_TX_TRANSMIT_LAST_COMMAND_WORD					
#define ACE_RT_MCDATA_TX_TRNS_BIT		sitalRtDataContainerModeCode_TX_TRANSMIT_BUILT_IN_TEST_WORD							
#define ACE_RT_MCDATA_BCST_SYNCHRONIZE		sitalRtDataContainerModeCode_BROADCAST_SYNCHRONIZE						
#define ACE_RT_MCDATA_BCST_SEL_T_SHUTDWN		sitalRtDataContainerModeCode_BROADCAST_SELECTED_TRANSMITTER_SHUTDOWN				
#define ACE_RT_MCDATA_BCST_OVR_SEL_T_SHUTDWN		sitalRtDataContainerModeCode_BROADCAST_OVERRIDE_SELECTED_TRANSMITTER_SHUTDOWN		
#define ACE_RT_BCST_ADDRSS		sitalRtAddressType_BROADCAST		
#define ACE_RT_OWN_ADDRESS		sitalRtAddressType_OWN				
#define ACE_RT_MODIFY_ALL		sitalRtAddressType_BOTH
#define ACE_RT_SA_ALL		sitalRtSubaddress_ALL			
#define ACE_RT_SA0		sitalRtSubaddressMask_0				
#define ACE_RT_SA1		sitalRtSubaddressMask_1				
#define ACE_RT_SA2		sitalRtSubaddressMask_2				
#define ACE_RT_SA3		sitalRtSubaddressMask_3				
#define ACE_RT_SA4		sitalRtSubaddressMask_4				
#define ACE_RT_SA5		sitalRtSubaddressMask_5				
#define ACE_RT_SA6		sitalRtSubaddressMask_6				
#define ACE_RT_SA7		sitalRtSubaddressMask_7				
#define ACE_RT_SA8		sitalRtSubaddressMask_8				
#define ACE_RT_SA9		sitalRtSubaddressMask_9				
#define ACE_RT_SA10		sitalRtSubaddressMask_10			
#define ACE_RT_SA11		sitalRtSubaddressMask_11			
#define ACE_RT_SA12		sitalRtSubaddressMask_12			
#define ACE_RT_SA13		sitalRtSubaddressMask_13			
#define ACE_RT_SA14		sitalRtSubaddressMask_14			
#define ACE_RT_SA15		sitalRtSubaddressMask_15			
#define ACE_RT_SA16		sitalRtSubaddressMask_16			
#define ACE_RT_SA17		sitalRtSubaddressMask_17			
#define ACE_RT_SA18		sitalRtSubaddressMask_18			
#define ACE_RT_SA19		sitalRtSubaddressMask_19			
#define ACE_RT_SA20		sitalRtSubaddressMask_20			
#define ACE_RT_SA21		sitalRtSubaddressMask_21			
#define ACE_RT_SA22		sitalRtSubaddressMask_22			
#define ACE_RT_SA23		sitalRtSubaddressMask_23			
#define ACE_RT_SA24		sitalRtSubaddressMask_24			
#define ACE_RT_SA25		sitalRtSubaddressMask_25			
#define ACE_RT_SA26		sitalRtSubaddressMask_26			
#define ACE_RT_SA27		sitalRtSubaddressMask_27			
#define ACE_RT_SA28		sitalRtSubaddressMask_28			
#define ACE_RT_SA29		sitalRtSubaddressMask_29			
#define ACE_RT_SA30		sitalRtSubaddressMask_30			
#define ACE_RT_SA31		sitalRtSubaddressMask_31			
#define ACE_RT_STSBIT_DBCA		sitalRtStatusWordBit_DBCA				
#define ACE_RT_STSBIT_BUSY		sitalRtStatusWordBit_BUSY				
#define ACE_RT_STSBIT_SREQ		sitalRtStatusWordBit_SERVICE_REQUSET	
#define ACE_RT_STSBIT_SSFLAG		sitalRtStatusWordBit_SUBSYSTEM_FLAG		
#define ACE_RT_STSBIT_RTFLAG		sitalRtStatusWordBit_RT_FLAG			
#define ACE_RT_STSBIT_S10		sitalRtStatusWordBit_S10				
#define ACE_RT_STSBIT_S09		sitalRtStatusWordBit_S09				
#define ACE_RT_STSBIT_S08		sitalRtStatusWordBit_S08				
#define ACE_RT_STSBIT_S07		sitalRtStatusWordBit_S07				
#define ACE_RT_STSBIT_S06		sitalRtStatusWordBit_S06				
#define ACE_RT_STSBIT_S05		sitalRtStatusWordBit_S05				
#define ACE_RT_STSBIT_S04		sitalRtStatusWordBit_S04				
#define ACE_RT_STSBIT_S03		sitalRtStatusWordBit_S03				
#define ACE_RT_STSBIT_S02		sitalRtStatusWordBit_S02				
#define ACE_RT_STSBIT_S01		sitalRtStatusWordBit_S01				
#define ACE_RT_STSBIT_S00		sitalRtStatusWordBit_S00				
#define ACE_RT_MSGTYPE_RX		sitalRtMessageType_RX			
#define ACE_RT_MSGTYPE_TX		sitalRtMessageType_TX			
#define ACE_RT_MSGTYPE_BCST		sitalRtMessageType_BROADCAST	
#define ACE_RT_MSGTYPE_ALL		sitalRtMessageType_ALL			
#define ACE_BC_MSGLOC_NEXT_PURGE		sitalMessageLocationAndRemoval_NEXT_PURGE
#define ACE_BC_MSGLOC_NEXT_NPURGE		sitalMessageLocationAndRemoval_NEXT_NO_PURGE
#define ACE_BC_MSGLOC_LATEST_PURGE		sitalMessageLocationAndRemoval_LATEST_PURGE
#define ACE_BC_MSGLOC_LATEST_NPURGE		sitalMessageLocationAndRemoval_LATEST_NO_PURGE
#define ACE_RT_MSGLOC_NEXT_PURGE		sitalMessageLocationAndRemoval_NEXT_PURGE
#define ACE_RT_MSGLOC_NEXT_NPURGE		sitalMessageLocationAndRemoval_NEXT_NO_PURGE
#define ACE_RT_MSGLOC_LATEST_PURGE		sitalMessageLocationAndRemoval_LATEST_PURGE
#define ACE_RT_MSGLOC_LATEST_NPURGE		sitalMessageLocationAndRemoval_LATEST_NO_PURGE
#define ACE_MT_MSGLOC_NEXT_PURGE		sitalMessageLocationAndRemoval_NEXT_PURGE
#define ACE_MT_MSGLOC_NEXT_NPURGE		sitalMessageLocationAndRemoval_NEXT_NO_PURGE
#define ACE_MT_MSGLOC_LATEST_PURGE		sitalMessageLocationAndRemoval_LATEST_PURGE
#define ACE_MT_MSGLOC_LATEST_NPURGE		sitalMessageLocationAndRemoval_LATEST_NO_PURGE
#define ACE_RT_DBLK_CIRC_IRQ		sitalRtDataBlockIrq_CIRCULAR_BUFFER		
#define ACE_RT_DBLK_EOM_IRQ		sitalRtDataBlockIrq_END_OF_MESSAGE		
#define ACE_BC_BSW_INVWRD		sitalBcBlockStatusWord_INVALID_WORD
#define ACE_BC_BSW_BADSYNC		sitalBcBlockStatusWord_BAD_SYNCHRONIZATION
#define ACE_BC_BSW_WCERR		sitalBcBlockStatusWord_WORD_COUNT_ERROR
#define ACE_BC_BSW_WRGADDR_NGAP		sitalBcBlockStatusWord_WRONG_RT_ADDRESS
#define ACE_BC_BSW_GDATA		sitalBcBlockStatusWord_GOOD_DATA_BLOCK_RECEIVED
#define ACE_BC_BSW_RETRY		sitalBcBlockStatusWord_RETRIES_COUNT
#define ACE_BC_BSW_MSKED_STS		sitalBcBlockStatusWord_MASKED_STATUS
#define ACE_BC_BSW_LPFAIL		sitalBcBlockStatusWord_LOOPBACK_FAIL
#define ACE_BC_BSW_NORES		sitalBcBlockStatusWord_NO_RESPONSE
#define ACE_BC_BSW_FMTERR		sitalBcBlockStatusWord_FORMAT_ERROR
#define ACE_BC_BSW_STS_SET		sitalBcBlockStatusWord_STATUS_SET
#define ACE_BC_BSW_ERRFLG		sitalBcBlockStatusWord_ERROR_FLAG
#define ACE_BC_BSW_CHNL		sitalBcBlockStatusWord_BUS_B
#define ACE_BC_BSW_SOM		sitalBcBlockStatusWord_START_OF_MESSAGE
#define ACE_BC_BSW_EOM		sitalBcBlockStatusWord_END_OF_MESSAGE
#define ACE_RT_BSW_CMDERR		sitalRtBlockStatusWord_COMMAND_ERROR
#define ACE_RT_BSW_RTRTERR_2CMD		sitalRtBlockStatusWord_RT_TO_RT_COMMAND_ERROR
#define ACE_RT_BSW_RTRTERR_GSA		sitalRtBlockStatusWord_RT_TO_RT_GSA_ERROR
#define ACE_RT_BSW_INVWRD		sitalRtBlockStatusWord_INVALID_WORD
#define ACE_RT_BSW_BADSYNC		sitalRtBlockStatusWord_BAD_SYNCHRONIZATION
#define ACE_RT_BSW_WCERR		sitalRtBlockStatusWord_WORD_COUNT_ERROR
#define ACE_RT_BSW_ILLCMD		sitalRtBlockStatusWord_ILLEGAL_COMMAND
#define ACE_RT_BSW_CIRCOVR		sitalRtBlockStatusWord_CIRCULAR_ROLLOVER
#define ACE_RT_BSW_LPFAIL		sitalRtBlockStatusWord_LOOPBACK_FAIL
#define ACE_RT_BSW_NORES		sitalRtBlockStatusWord_NO_RESPONSE
#define ACE_RT_BSW_FMTERR		sitalRtBlockStatusWord_FORMAT_ERROR
#define ACE_RT_BSW_RTRT		sitalRtBlockStatusWord_RT_TO_RT
#define ACE_RT_BSW_ERRFLG		sitalRtBlockStatusWord_ERROR_FLAG
#define ACE_RT_BSW_CHNL		sitalRtBlockStatusWord_BUS_B
#define ACE_RT_BSW_SOM		sitalRtBlockStatusWord_START_OF_MESSAGE
#define ACE_RT_BSW_EOM		sitalRtBlockStatusWord_END_OF_MESSAGE
#define ACE_MT_BSW_CMDERR		sitalMtBlockStatusWord_COMMAND_ERROR					
#define ACE_MT_BSW_RTRTERR_2CMD		sitalMtBlockStatusWord_RT_TO_RT_MESSAGE_COMMAND_ERROR			
#define ACE_MT_BSW_RTRTERR_GSA		sitalMtBlockStatusWord_RT_TO_RT_MESSAGE_RESPOND_ERROR				
#define ACE_MT_BSW_INVWRD		sitalMtBlockStatusWord_INVALID_WORD						
#define ACE_MT_BSW_BADSYNC		sitalMtBlockStatusWord_BAD_SYNCHRONIZATION				
#define ACE_MT_BSW_WCERR		sitalMtBlockStatusWord_WORD_COUNT_ERROR					
#define ACE_MT_BSW_DSTK_ROVER		sitalMtBlockStatusWord_ROLLOVER				
#define ACE_MT_BSW_GDATA		sitalMtBlockStatusWord_GOOD_DATA						
#define ACE_MT_BSW_NORES		sitalMtBlockStatusWord_NO_RESPONSE						
#define ACE_MT_BSW_FMTERR		sitalMtBlockStatusWord_PROTOCOL_VIOLATION						
#define ACE_MT_BSW_RTRT		sitalMtBlockStatusWord_RT_TO_RT_MESSAGE							
#define ACE_MT_BSW_ERRFLG		sitalMtBlockStatusWord_ERROR_FLAG						
#define ACE_MT_BSW_CHNL		sitalMtBlockStatusWord_BUS_B							
#define ACE_MT_BSW_SOM		sitalMtBlockStatusWord_START_OF_MESSAGE					
#define ACE_MT_BSW_EOM		sitalMtBlockStatusWord_END_OF_MESSAGE					
#define ACE_MT_OPT_1553A_MC		sitalMtSetupOption_1553A_MODE_CODES_ENABLED		
#define ACE_RTMT_COMBO_HBUF		sitalRtMtSetupOption_COMBINED_HOST_BUFFER
#define ACE_MT_STKLOC_ACTIVE		sitalMtStack_ACTIVE				
#define ACE_MT_STKLOC_INACTIVE		sitalMtStack_INACTIVE			
#define ACE_MT_STKLOC_STKA		sitalMtStack_STACK_A			
#define ACE_MT_STKLOC_STKB		sitalMtStack_STACK_B			
#define ACE_MT_STKA		sitalMtStackSelector_STACK_A			
#define ACE_MT_STKB		sitalMtStackSelector_STACK_B			
#define ACE_MT_STK_CMB		sitalMtStackSelector_STACK_COMBINED			
#define ACE_MT_SINGLESTK		sitalMtStackOption_SINGLE		
#define ACE_MT_DOUBLESTK		sitalMtStackOption_DOUBLE		
#define ACE_MT_CMDSTK_256		sitalMtCommandStackSize_256		
#define ACE_MT_CMDSTK_1K		sitalMtCommandStackSize_1024	
#define ACE_MT_CMDSTK_4K		sitalMtCommandStackSize_4096	
#define ACE_MT_CMDSTK_16K		sitalMtCommandStackSize_16384	
#define ACE_MT_DATASTK_512		sitalMtDataStackSize_512		
#define ACE_MT_DATASTK_1K		sitalMtDataStackSize_1024		
#define ACE_MT_DATASTK_2K		sitalMtDataStackSize_2048		
#define ACE_MT_DATASTK_4K		sitalMtDataStackSize_4096		
#define ACE_MT_DATASTK_8K		sitalMtDataStackSize_8192		
#define ACE_MT_DATASTK_16K		sitalMtDataStackSize_16384		
#define ACE_MT_DATASTK_32K		sitalMtDataStackSize_32768		
#define ACE_MT_FILTER_ALL		sitalMessageDirection_BOTH	
#define ACE_MT_FILTER_RX		sitalMessageDirection_RX    
#define ACE_MT_FILTER_TX		sitalMessageDirection_TX    
#define ACE_MT_FILTER_SA_ALL		sitalRtSubaddress_ALL		
#define ACE_MT_FILTER_SA0		sitalRtSubaddressMask_0		
#define ACE_MT_FILTER_SA1		sitalRtSubaddressMask_1		
#define ACE_MT_FILTER_SA2		sitalRtSubaddressMask_2		
#define ACE_MT_FILTER_SA3		sitalRtSubaddressMask_3		
#define ACE_MT_FILTER_SA4		sitalRtSubaddressMask_4		
#define ACE_MT_FILTER_SA5		sitalRtSubaddressMask_5		
#define ACE_MT_FILTER_SA6		sitalRtSubaddressMask_6		
#define ACE_MT_FILTER_SA7		sitalRtSubaddressMask_7		
#define ACE_MT_FILTER_SA8		sitalRtSubaddressMask_8		
#define ACE_MT_FILTER_SA9		sitalRtSubaddressMask_9		
#define ACE_MT_FILTER_SA10		sitalRtSubaddressMask_10		
#define ACE_MT_FILTER_SA11		sitalRtSubaddressMask_11		
#define ACE_MT_FILTER_SA12		sitalRtSubaddressMask_12		
#define ACE_MT_FILTER_SA13		sitalRtSubaddressMask_13		
#define ACE_MT_FILTER_SA14		sitalRtSubaddressMask_14		
#define ACE_MT_FILTER_SA15		sitalRtSubaddressMask_15		
#define ACE_MT_FILTER_SA16		sitalRtSubaddressMask_16		
#define ACE_MT_FILTER_SA17		sitalRtSubaddressMask_17		
#define ACE_MT_FILTER_SA18		sitalRtSubaddressMask_18		
#define ACE_MT_FILTER_SA19		sitalRtSubaddressMask_19		
#define ACE_MT_FILTER_SA20		sitalRtSubaddressMask_20		
#define ACE_MT_FILTER_SA21		sitalRtSubaddressMask_21		
#define ACE_MT_FILTER_SA22		sitalRtSubaddressMask_22		
#define ACE_MT_FILTER_SA23		sitalRtSubaddressMask_23		
#define ACE_MT_FILTER_SA24		sitalRtSubaddressMask_24		
#define ACE_MT_FILTER_SA25		sitalRtSubaddressMask_25		
#define ACE_MT_FILTER_SA26		sitalRtSubaddressMask_26		
#define ACE_MT_FILTER_SA27		sitalRtSubaddressMask_27		
#define ACE_MT_FILTER_SA28		sitalRtSubaddressMask_28		
#define ACE_MT_FILTER_SA29		sitalRtSubaddressMask_29		
#define ACE_MT_FILTER_SA30		sitalRtSubaddressMask_30		
#define ACE_MT_FILTER_SA31		sitalRtSubaddressMask_31		
#define ACE_TEST_PASSED			sitalDeviceTestResult_PASS
#define ACE_TEST_NOT_PERFORMED	sitalDeviceTestResult_NON_UNPERFORMANCE
#define ACE_TEST_FAILED_RAM		sitalDeviceTestResult_RAM_FAIL
#define ACE_TEST_FAILED_REGISTER	sitalDeviceTestResult_REGISTER_FAIL
#define ACE_TEST_FAILED_PROTOCOL	sitalDeviceTestResult_PROTOCOL_FAIL
#define ACE_TEST_FAILED_INTERRUPT	sitalDeviceTestResult_INTERRUPT_FAIL
#define ACE_TEST_FAILED_MVECTOR	sitalDeviceTestResult_MEMORY_READ_VECTOR_FAIL
#define ACE_TEST_FAILED_RVECTOR	sitalDeviceTestResult_REGISTER_READ_VECTOR_FAIL

// Return codes.
#define ACE_ERR_SUCCESS		sitalReturnCode_SUCCESS												
#define ACE_WRN_RT_CFG_INVALID		sitalReturnCode_POSSIBLY_DETRIMENTAL_CONFIGURATION					
#define ACE_ERR_INVALID_DEVNUM		sitalReturnCode_INVALID_DEVICE_NUMBER								
#define ACE_ERR_INVALID_ACCESS		sitalReturnCode_INVALID_ACCESS										
#define ACE_ERR_INVALID_MODE		sitalReturnCode_INVALID_MODE										
#define ACE_ERR_INVALID_STATE		sitalReturnCode_INVALID_STATE										
#define ACE_ERR_INVALID_MEMSIZE		sitalReturnCode_INVALID_MEMORY_SIZE									
#define ACE_ERR_INVALID_ADDRESS		sitalReturnCode_INVALID_ADDRESS										
#define ACE_ERR_INVALID_OS		sitalReturnCode_INVALID_OPERATING_SYSTEM							
#define ACE_ERR_INVALID_MALLOC		sitalReturnCode_INVALID_ALLOCATION									
#define ACE_ERR_INVALID_BUF		sitalReturnCode_INVALID_BUFFER										
#define ACE_ERR_INVALID_ADMODE		sitalReturnCode_INVALID_ADDRESS_MODE								
#define ACE_ERR_SIMWRITEREG		sitalReturnCode_INVALID_REGISTER_ADDRESS								
#define ACE_ERR_TIMETAG_RES		sitalReturnCode_INVALID_TIME_TAG_RESOLUTION									
#define ACE_ERR_RESPTIME		sitalReturnCode_INVALID_RESPONSE_TIMEOUT								
#define ACE_ERR_CLOCKIN		sitalReturnCode_INVALID_CLOCK_FREQUENCY										
#define ACE_ERR_MSGSTRUCT		sitalReturnCode_INVALID_MESSAGE_STRUCTURE								
#define ACE_ERR_PARAMETER		sitalReturnCode_INVALID_PARAMETER										
#define ACE_ERR_INVALID_MODE_OP		sitalReturnCode_INVALID_MODE_OPTIONS								
#define ACE_ERR_METRICS_NOT_ENA		sitalReturnCode_OPERATIONAL_STATISTICS_NOT_ENABLED									
#define ACE_ERR_NOT_SUPPORTED		sitalReturnCode_NOT_SUPPORTED										
#define ACE_ERR_ISQ_DISABLED		sitalReturnCode_ISQ_DISABLED										
#define ACE_ERR_TASK_FAIL		sitalReturnCode_OPERATION_FAIL									
#define ACE_ERR_CANADDR		sitalReturnCode_INVALID_CAN_ADDRESS									
#define ACE_ERR_DIO		sitalReturnCode_INVALID_DIO_PORT												
#define ACE_ERR_REG_ACCESS		sitalReturnCode_REGISTERS_ACCESS_FAIL								
#define ACE_ERR_INVALID_CARD		sitalReturnCode_INVALID_CARD										
#define ACE_ERR_DRIVER_OPEN		sitalReturnCode_DRIVER_OPEN_FAIL									
#define ACE_ERR_MAPMEM_ACC		sitalReturnCode_MAPPED_MEMORY_ACCESS_FAIL							
#define ACE_ERR_INVALID_CARDNUM		sitalReturnCode_INVALID_CARD_NUMBER									
#define ACE_ERR_NODE_NOT_FOUND		sitalReturnCode_UNDEFINED_NODE										
#define ACE_ERR_NODE_MEMBLOCK		sitalReturnCode_NODE_NOT_MEMORY_BLOCK								
#define ACE_ERR_NODE_EXISTS		sitalReturnCode_NODE_EXISTS											
#define ACE_ERR_MEMMGR_FAIL		sitalReturnCode_ALLOCATION_FAIL										
#define ACE_ERR_TEST_BADSTRUCT		sitalReturnCode_INVALID_TEST_STRUCTURE									
#define ACE_ERR_TEST_FILE		sitalReturnCode_INVALID_FILE										
#define ACE_ERR_MT_BUFTYPE		sitalReturnCode_MT_INVALID_STACK_OPTION								
#define ACE_ERR_MT_CMDSTK		sitalReturnCode_MT_INVALID_COMMAND_STACK_SIZE							
#define ACE_ERR_MT_DATASTK		sitalReturnCode_MT_INVALID_DATA_STACK_SIZE								
#define ACE_ERR_MT_FILTER_RT		sitalReturnCode_MT_INVALID_RT_ADDRESS								
#define ACE_ERR_MT_FILTER_TR		sitalReturnCode_MT_INVALID_DIRECTION_BIT									
#define ACE_ERR_MT_FILTER_SA		sitalReturnCode_MT_INVALID_SUBADDRESS_BUFFER								
#define ACE_ERR_MT_STKLOC		sitalReturnCode_MT_INVALID_STACK_SELECTOR								
#define ACE_ERR_MT_MSGLOC		sitalReturnCode_MT_INVALID_MESSAGE_LOCATION								
#define ACE_ERR_MT_HOST_BUFFERSIZE		sitalReturnCode_MT_INVALID_HOST_BUFFER_SIZE								
#define ACE_ERR_MT_HOST_BUFFER		sitalReturnCode_MT_HOST_BUFFER_NOT_INSTALLED						
#define ACE_ERR_RTMT_COMBO_HOST_BUFFER		sitalReturnCode_RT_AND_MT_NON_COMBINED_HOST_BUFFER_MODE								
#define ACE_ERR_RTMT_HOST_BUFFERSIZE		sitalReturnCode_RT_AND_MT_INVALID_HOST_BUFFER_SIZE							
#define ACE_ERR_RTMT_HOST_BUFFER		sitalReturnCode_RT_AND_MT_HOST_BUFFER_NOT_INSTALLED						
#define ACE_ERR_RTMT_MSGLOC		sitalReturnCode_RT_AND_MT_INVALID_MESSAGE_LOCATION						
#define ACE_ERR_RT_DBLK_EXISTS		sitalReturnCode_RT_DATA_BLOCK_EXISTS								
#define ACE_ERR_RT_DBLK_ALLOC		sitalReturnCode_RT_DATA_BLOCK_ALLOCATION_FAIL						
#define ACE_ERR_RT_DBLK_MAPPED		sitalReturnCode_RT_DATA_BLOCK_MAPPED								
#define ACE_ERR_RT_DBLK_NOT_CB		sitalReturnCode_RT_DATA_BLOCK_NOT_CIRCULAR							
#define ACE_ERR_RT_HOST_BUFFER		sitalReturnCode_RT_HOST_BUFFER_NOT_INSTALLED						
#define ACE_ERR_BC_DBLK_EXISTS		sitalReturnCode_BC_OBJECT_ALREADY_EXISTS							
#define ACE_ERR_BC_DBLK_ALLOC		sitalReturnCode_BC_DATA_BLOCK_ALLOCATION_FAIL						
#define ACE_ERR_BC_DBLK_SIZE		sitalReturnCode_BC_INVALID_DATA_BLOCK_SIZE								
#define ACE_ERR_UNRES_DATABLK		sitalReturnCode_UNDEFINED_DATA_BLOCK								
#define ACE_ERR_UNRES_MSGBLK		sitalReturnCode_UNDEFINED_MESSAGE_BLOCK							
#define ACE_ERR_UNRES_FRAME		sitalReturnCode_ILLEGAL_FRAME									
#define ACE_ERR_UNRES_OPCODE		sitalReturnCode_UNDEFINED_COMMAND									
#define ACE_ERR_UNRES_JUMP		sitalReturnCode_UNRESOLVED_JUMP										
#define ACE_ERR_FRAME_NOT_MAJOR		sitalReturnCode_NOT_MAJOR_FRAME										
#define ACE_ERR_NOT_ASYNC_MODE		sitalReturnCode_SUITABLE_ASYNCHRONOUS_MODE_UNDEFINED				
#define ACE_ERR_UNRES_ASYNC_OP		sitalReturnCode_UNRESOLVED_ASYNCHRONOUS_COMMAND						
#define ACE_ERR_UNRES_ASYNC_ID		sitalReturnCode_ASYNCHRONOUS_LIST_IS_EMPTY							
#define ACE_ERR_ASYNC_NOT_EMPTY		sitalReturnCode_ASYNCHRONOUS_LIST_NOT_EMPTY							
#define ACE_ERR_ASYNC_MSG		sitalReturnCode_ASYNCHRONOUS_MESSAGE_ERROR							
#define ACE_WRN_BC_OPCODE_INVALID		sitalReturnCode_BC_POSSIBLY_DETRIMENTAL_OPCODE									
#define ACE_ERR_HBUFSIZE		sitalReturnCode_INVALID_HOST_BUFFER_SIZE								
#define ACE_ERR_HOST_BUFFER		sitalReturnCode_HOST_BUFFER_NOT_INSTALLED							
#define ACE_ERR_TOO_MANY_DEVS		sitalReturnCode_TOO_MANY_DEVICES									
#define ACE_RESOURCE_REQ_ERR		sitalReturnCode_DEVICE_CONNECTION_FAIL										
#define ACE_IOWRITE_ERR		sitalReturnCode_WRITE_ERROR											
#define ACE_IOREAD_ERR		sitalReturnCode_READ_ERROR											
#define ACE_MEM_MAP_ERR		sitalReturnCode_MEMORY_MAP_FAIL									
#define ACE_TASK_SPAWN_ERR		sitalReturnCode_TASK_SPAWN_FAIL									

// Structures.
typedef struct ISQENTRY
{
	U16BIT wISQHeader;
	U16BIT wISQData;
} ISQENTRY;

typedef struct GPQENTRY
{
	U16BIT wGPQHeader;
	U16BIT wGPQData;
} GPQENTRY;

typedef struct GPQMETRIC
{
	U32BIT dwLost;
	U16BIT wPctFull;
	U16BIT wHighPct;
} GPQMETRIC;

typedef struct OPCODESTRUCT
{
	S16BIT nOpCodeID;
	U16BIT wOpCodeType;
	U16BIT wParameter;
	U16BIT wCondition;
} OPCODESTRUCT;

typedef struct MSGSTRUCT
{
	U16BIT wType;
	U16BIT wBlkSts;
	U16BIT wTimeTag3;
	U16BIT wTimeTag2;
	U16BIT wTimeTag;
	U16BIT wCmdWrd1;
	U16BIT wCmdWrd2;
	U16BIT wCmdWrd1Flg;
	U16BIT wCmdWrd2Flg;
	U16BIT wStsWrd1;
	U16BIT wStsWrd2;
	U16BIT wStsWrd1Flg;
	U16BIT wStsWrd2Flg;
	U16BIT wWordCount;
	U16BIT aDataWrds[32];
	U16BIT wBCCtrlWrd;
	U16BIT wBCGapTime;
	U16BIT wBCLoopBack1;
	U16BIT wBCLoopBack2;
	U16BIT wBCLoopBack1Flg;
	U16BIT wBCLoopBack2Flg;
}	MSGSTRUCT;

typedef struct MTINFO
{
	U16BIT wStkMode;
	U16BIT wCmdStkSize;
	U16BIT wDataStkSize;
	U16BIT b1553aMCodes;
	U32BIT dwHBufSize;
} MTINFO;

typedef struct STKMETRIC
{
	U32BIT dwLost;
	U32BIT dwPctFull;
	U32BIT dwHighPct;
} STKMETRIC;

typedef struct HBUFMETRIC
{
	U32BIT dwCount;
	U32BIT dwLost;
	U32BIT dwPctFull;
	U32BIT dwHighPct;
} HBUFMETRIC;

typedef struct TESTRESULT
{
	U16BIT wResult;
	U16BIT wExpData;
	U16BIT wActData;
	U32BIT dwExpData;
	U32BIT dwActData;
	BOOLEAN PciMode32;
	U16BIT wAceAddr;
	U16BIT wCount;
} TESTRESULT;



#ifdef __cplusplus
}
#endif



#endif // stld1553_DDC_TO_STLD1553_DEFINITIONS
