/// @file
/// stld1553 library's internal definitions and declarations.

// Description  : A header file that contains stld1553 library's internal definitions and declarations
// Version      : 1.0.0.0
// Author       : Sital Technology R&D
//
// Modification history:
//



#ifndef stld1553_internal_INCLUDED
#define stld1553_internal_INCLUDED



#ifdef __cplusplus
// C++ compilers mangle function names, unless the function definitions are protected with extern "C"{}.
extern "C" {
#endif



// Type definitions.

///< A pointer to either function sitalMt_MessageMonitoring_Enable or function sitalMt_MessageMonitoring_Disable.
typedef S16BIT(_DECL *MT_MESSAGE_MONITORING_CONFIGURATION_FUNCTION)(S16BIT swDevice, U16BIT wRtAddress, U16BIT wMessageDirection, U32BIT dwSubaddressMask);



// Enumeration definitions.


/*
	Multi RT Constants and Definitions
*/
#define MAX_ELEMENTS	1024
#define MAX_DATABLOCKS	1024
#define MAX_BUSLISTS	32
#define MAX_BLOCKSIZE	1024*16 // 16K of Data per Element
// MRT Error Injection 
#define mrt_MSG_NUMBER_MIN 0
#define mrt_MSG_NUMBER_MAX 15
#define mrt_WORD_NUMBER_MIN 0
#define mrt_WORD_NUMBER_MAX 32
#define mrt_SYNC_ERR_MIN 0
#define mrt_SYNC_ERR_MAX 7
#define mrt_SYNC_INVERT 0x000F
#define mrt_ZX_DISTORTION_MIN -32
#define mrt_ZX_DISTORTION_MAX 31

//***********************************************************************************************************

// Constant definitions.

// Register helper masks and constants.
#define registerMask_ALL_BITS_ON											0xFFFFU
#define registerMask_ALL_BITS_OFF											0x0000U

#define configurationRegister1_RT_STATUS_ENABLER_BITS						(sitalConfigurationRegister1_RT_S00 | sitalConfigurationRegister1_RT_S01 | sitalConfigurationRegister1_RT_S02 | sitalConfigurationRegister1_RT_S03 | sitalConfigurationRegister1_RT_S04 | sitalConfigurationRegister1_RT_S05 | sitalConfigurationRegister1_RT_S06 |  sitalConfigurationRegister1_RT_SUBSYSTEM_FLAG | sitalConfigurationRegister1_RT_SERVICE_REQUEST | sitalConfigurationRegister1_RT_BUSY | sitalConfigurationRegister1_RT_DYNAMIC_BUS_CONTROL_ACCEPTANCE)	///< A mask of the status enabler bits within configuration register #1 that are used with RT alternate status.
#define configurationRegister1_RT_PARTIAL_STATUS_ENABLER_BITS				(sitalConfigurationRegister1_RT_FLAG |  sitalConfigurationRegister1_RT_SUBSYSTEM_FLAG | sitalConfigurationRegister1_RT_SERVICE_REQUEST | sitalConfigurationRegister1_RT_BUSY | sitalConfigurationRegister1_RT_DYNAMIC_BUS_CONTROL_ACCEPTANCE)	///< A mask of the status enabler bits within configuration register #1 that are used even without RT alternate status.

#define configurationRegister5_OFFSET_OF_RT_ADDRESS							1U ///< The index of the lowest of the bits of the RT address field.

#define configurationRegister6_OFFSET_OF_RT_ADDRESS_SOURCE					5U ///< The index of the lowest of the bits of the RT address source field.

#define configurationRegister7_MEMORY_MANAGEMENT_BASE_ADDRESS_MASK			0xFC00U

#define sitalInterruptStatusRegister2_OFFSET_OF_INTERRUPTS					2U		///< The index of the lowest of the interrupt bits field.

// BC condition code masks.
#define bcConditionCode_GFP_EQUAL_FLAG					0x0001U		///< Condition code: Equal.
#define bcConditionCode_GPF_LESS_THAN_FLAG				0x0002U		///< Condition code: Less than.
#define bcConditionCode_GPF0							0x0001U		///< Condition code: GPF-0.
#define bcConditionCode_GPF1							0x0002U		///< Condition code: GPF-1.
#define bcConditionCode_GPF2							0x0004U		///< Condition code: GPF-2.
#define bcConditionCode_GPF3							0x0008U		///< Condition code: GPF-3.
#define bcConditionCode_GPF4							0x0010U		///< Condition code: GPF-4.
#define bcConditionCode_GPF5							0x0020U		///< Condition code: GPF-5.
#define bcConditionCode_GPF6							0x0040U		///< Condition code: GPF-6.
#define bcConditionCode_GPF7							0x0080U		///< Condition code: GPF-7.
#define bcConditionCode_NO_RESPONSE						0x0100U		///< Condition code: No response.
#define bcConditionCode_FORMAT_ERROR					0x0200U		///< Condition code: Format error.
#define bcConditionCode_GOOD_DATA_BLOCK_TRANSFER		0x0400U		///< Condition code: Good data block transfer.
#define bcConditionCode_MASKED_STATUS					0x0800U		///< Condition code: Masked status.
#define bcConditionCode_BAD_MESSAGE						0x1000U		///< Condition code: Bad message.
#define bcConditionCode_RETRY_COUNT						0x6000U		///< Condition code: Retry count.
#define bcConditionCode_ALWAYS							0x8000U		///< Condition code: Always.

// BC general purpose flag register masks.
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_0_MASK			0x0101U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_0_LEAVE		0x0000U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_0_SET			0x0001U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_0_CLEAR		0x0100U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_0_TOGGLE		0x0101U

#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_1_MASK			0x0202U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_1_LEAVE		0x0000U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_1_SET			0x0002U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_1_CLEAR		0x0200U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_1_TOGGLE		0x0202U

#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_2_MASK			0x0404U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_2_LEAVE		0x0000U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_2_SET			0x0004U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_2_CLEAR		0x0400U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_2_TOGGLE		0x0404U

#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_3_MASK			0x0808U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_3_LEAVE		0x0000U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_3_SET			0x0008U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_3_CLEAR		0x0800U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_3_TOGGLE		0x0808U

#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_4_MASK			0x1010U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_4_LEAVE		0x0000U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_4_SET			0x0010U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_4_CLEAR		0x1000U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_4_TOGGLE		0x1010U

#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_5_MASK			0x2020U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_5_LEAVE		0x0000U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_5_SET			0x0020U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_5_CLEAR		0x2000U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_5_TOGGLE		0x2020U

#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_6_MASK			0x4040U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_6_LEAVE		0x0000U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_6_SET			0x0040U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_6_CLEAR		0x4000U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_6_TOGGLE		0x4040U

#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_7_MASK			0x8080U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_7_LEAVE		0x0000U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_7_SET			0x0080U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_7_CLEAR		0x8000U
#define bcGeneralPurposeFlagRegister_BC_GENERAL_PURPOSE_FLAG_7_TOGGLE		0x8080U

// IEEE-1553 command word masks and offsets.
#define commandWord_OFFSET_OF_RT_ADDRESS															11U		///< The index of the lowest of the bits of the RT address field.
#define commandWord_RT_ADDRESS																		0xF800U	///< The RT address field mask (all these bit are on in case of broadcast).
#define commandWord_BROADCAST																		0xF800U	///< The value of the RT address field mask in case of broadcast command.
#define commandWord_OFFSET_OF_RX_OR_TX																10U		///< The index of the bit of the Rx/Tx field.
#define commandWord_RX_OR_TX																		0x0400U	///< The Rx/Tx field mask (bit on in case of TX).
#define commandWord_TX																				0x0400U	///< The value of the Rx/Tx field in case of TX command.
#define commandWord_OFFSET_OF_SUBADDRESS_OR_MODE													5U		///< The index of the lowest of the bits of the subaddress/mode field.
#define commandWord_SUBADDRESS_OR_MODE																0x03E0U	///< The subaddress/mode field mask (all bits are either on or off in case of a mode command).
#define commandWord_MODE																			0x0000U	///< The value of the subaddress/mode field in case of mode command.
#define commandWord_OFFSET_OF_WORD_COUNT_OR_MODE_CODE												0U		///< The index of the lowest of the bits of the word-count/mode-code field.
#define commandWord_WORD_COUNT_OR_MODE_CODE															0x001FU	///< The word-count/mode-code field mask.
#define commandWord_MODE_WITH_OR_WITHOUT_DATA														0x0010U	///< The mode with data field mask (bit on in case of a mode with data command).
#define commandWord_MODE_WITH_DATA																	0x0010U	///< The value of the mode with data field mask in case of a mode with data command.

// sitalMessageType_* constants' component masks.
#define messageTypeComponent_TX																		0x1U		///< The component of sitalMessageType_* constants that designates a transmitted message.
#define messageTypeComponent_DATA																	0x2U		///< The component of sitalMessageType_* constants that designates a data containing message.
#define messageTypeComponent_MODE																	0x4U		///< The component of sitalMessageType_* constants that designates a mode message.
#define messageTypeComponent_BROADCAST																0x8U		///< The component of sitalMessageType_* constants that designates a broadcast message.

// Asynchronous message handling/subroutine constants.
#define asynchronousMessaging_HIGH_PRIORITY_MESSAGE_TX_CALL_COMMAND_COUNT		1U	///< The number of commands added after each message-transmitter-command in order to [re]try sending the possibly requested high priority asynchronous message.
//#define asynchronousMessaging_HIGH_PRIORITY_MESSAGE_TX_COMMAND_COUNT			2U	///< The number of commands that compose the high priority asynchronous message Tx subroutine (this subroutine contains the following series of commands: XQF, RTN).
//NB - 9.1.2017 - added clear GPF6 in order to send high async mesage once
#define asynchronousMessaging_HIGH_PRIORITY_MESSAGE_TX_COMMAND_COUNT			3U	///< The number of commands that compose the high priority asynchronous message Tx subroutine (this subroutine contains the following series of commands: XQF, RTN).
#define asynchronousMessaging_LOW_PRIORITY_MESSAGES_TX_CALL_COMMAND_COUNT		1U	///< The number of commands added at the end of each major frame in order to [re]try sending the possibly requested low priority asynchronous messages.
#define asynchronousMessaging_STUB_LOW_PRIORITY_MESSAGE_TX_COMMAND_COUNT		1U	///< The number of commands that compose the initial stub of the low priority asynchronous message Tx subroutine (in its degenerated state this subroutine merely contains a single RTN command).
#define asynchronousMessaging_COMMAND_COUNT_PER_LOW_PRIORITY_MESSAGE			4U	///< The number of commands added in the low priority asynchronous message Tx subroutine for each low priority asynchronous message.

// The number of hardware opcodes into which the different software opcode are parsed.
// The exact series into which each software opcode is parsed and the role of this software opcode are described in its documentation.
#define parsedOpcodeCount_MAXIMUM										5U	///< The maximum number of hardware opcodes for any specific software opcode.
#define parsedOpcodeCount_TIME_CONDITIONED_MESSAGE_TX					5U	///< Hardware opcodes for the time conditioned message Tx software opcode, not taking in account a potential call to the high asynchronous messages Tx subroutine (see the documentation for function sitalBc_Command_Create).

// The number of framing commands added to the different types of frames.
// See full description of below mentioned command groups in the documentation for function sitalBc_Start.
#define addedFramingCommandsCount_MajorFrame_MAXIMUM_TOTAL				17U	///< The maximum possible total number of framing commands included in major frame - groups A-C.
#define addedFramingCommandsCount_MajorFrame_GROUP_A					14U	///< The number of framing commands included in major frame - group A.
#define addedFramingCommandsCount_MajorFrame_GROUP_B					2U	///< The number of framing commands included in major frame - group B.
#define addedFramingCommandsCount_MajorFrame_GROUP_C					1U	///< The number of framing commands included in major frame - group C.
#define addedFramingCommandsCount_MinorFrame_MAXIMUM_TOTAL				14U	///< The maximum possible total number of framing commands included in major frame - groups A-H.
#define addedFramingCommandsCount_MinorFrame_GROUP_A					4U	///< The number of framing commands included in minor frame - group A.
#define addedFramingCommandsCount_MinorFrame_GROUP_B					2U	///< The number of framing commands included in minor frame - group B.
#define addedFramingCommandsCount_MinorFrame_GROUP_C					1U	///< The number of framing commands included in minor frame - group C.
#define addedFramingCommandsCount_MinorFrame_GROUP_D					1U	///< The number of framing commands included in minor frame - group D.
#define addedFramingCommandsCount_MinorFrame_GROUP_E					1U	///< The number of framing commands included in minor frame - group E.
#define addedFramingCommandsCount_MinorFrame_GROUP_F					3U	///< The number of framing commands included in minor frame - group F.
#define addedFramingCommandsCount_MinorFrame_GROUP_G					1U	///< The number of framing commands included in minor frame - group G.
#define addedFramingCommandsCount_MinorFrame_GROUP_H					1U	///< The number of framing commands included in minor frame - group H.

// The number of commands contained by a frame command writing helper buffer.
#define frameCommandWritingHelperBuffer_COMMAND_COUNT					(parsedOpcodeCount_MAXIMUM * sitalBcCounter_FRAME_COMMANDS) ///< The number of commands contained by a frame command writing helper buffer in order to deal with the largest possible frame).

// Checker values (base, border, offsets, masks, maximums) for the different constant groups and functional operations.
// Note: The border values aren't included in the group of legal values with all constant groups.
#define access_BORDER										0x0003U		///< Border value for Device initialization: wAccess values. (Equivalent DDC definition: ACE_ACCESS_MAXNUM)
#define mode_BASE											0x0FFFU		///< Base value for Device initialization: wMode values.
#define mode_BORDER											0x0009U		///< Border value for Device initialization: wMode values. // NB Oct 17 - changed to support RS485 and descrets and Arinc429
#define modeVariant_BORDER									0x3000U		///< Border value for Device initialization: wMode diversification values.
#define mode_VARIANT										0xF000U		///< Mode variants mask for Device initialization: wMode diversification values.
#define rtAddressSource_BORDER								0x0002U		///< Border value for RT address sources: wRtAddressSource values.
#define bcFrameType_BORDER									0x0003U		///< Border value for BC frame creation: wFrameType values.
#define bcFrameFlag_BORDER									0x0002U		///< Border value for BC frame creation: wFlags values.
#define timeTagResolution_BORDER							8U			///< Border value for Time tag resolution: wTimeTagResolution values.
#define irqSetupSignalType_BORDER							2U			///< Border value for Device IRQ configuration: wInterruptMode values.
#define irqSetupAutoClear_BORDER							2U			///< Border value for Device IRQ configuration: wAutoClear values.
#define clockSetup_BORDER									4U			///< Border value for Device clock frequency configuration: wClockFrequency values.
#define responseTimeout_BORDER								4U			///< Border value for Response timeout: wResponseTimeout values.
#define messageRetryCount_BORDER							3U			///< Border value for BC message retries: wNumberOfRetries values.
#define messageRetryBus_BORDER								2U			///< Border value for BC message retries: wFirstRetryBus/wSecondRetryBus values.
#define bcStopTrialsCount_MAXIMUM							10000U		///< Maximum value for BC stop: Number of retries.
#define opcodeCondition_GPF_NUMBER							0x000FU		///< GPF numbers mask for BC opcode creation: wCondition values.
#define opcodeCondition_GPF_NUMBER_BORDER					0x0008U		///< Border value for legal values of GPF numbers for BC opcode creation: wCondition values.
#define opcodeGpf_GPF_NUMBER_BORDER							0x0008U		///< Border value for BC GPF manipulation: wGpfNumber values.
#define opcodeCondition_GET_STATE_BORDER					0x0010U		///< Border value for BC get current condition state: wCondition values.
#define opcodeCondition_BORDER								0x0020U		///< Border value for BC opcode creation: wCondition values.
#define opcode_SITAL_HARDWARE_BASE							0x0016U		///< Base value for Sital's unique hardware opcodes.
#define opcode_HARDWARE_BORDER								0x001BU		///< Hardware border value for BC frame creation: wOpcode values.
#define opcode_SOFTWARE_FLAG								0x8000U		///< Software opcode flag mask for BC frame creation: wOpcode values.
#define commandDistortion_BORDER							0x0003U		///< Border value for BC command distortion: wDistortionManner values.
#define bcGpfEffect_BORDER									4U			///< Border value for General purpose flag state manipulation: wEffect values.
#define sitalRegisterAddress_BORDER							0x0020U		///< Border value for Register addresses.
#define rtAddress_BORDER									32U			///< Border value for RT addresses.
#define rtSubaddress_BORDER									32U			///< Border value for RT subaddresses.
#define rtDataBlockType_SINGLE_BORDER						33U			///< Border value for values of RT single data block creation: wDataBlockType values.
#define rtDataBlockType_NON_COMMON_BORDER					41U			///< Border value for values of RT non-common data block creation: wDataBlockType values.
#define rtDataBlockType_BORDER								48U			///< Border value for RT data block creation: wDataBlockType values.
#define rtMessageType_BORDER								0x0008U		///< Border value for RT data block to subaddress mapping manipulation: wMessageTypes values.
#define rtDataBlockIrq_BORDER								0x0004U		///< Border value for RT data block to subaddress mapping manipulation: wIrqOptions values.
#define ieee1553_SUBADDRESS_BORDER							32U			///< Border value for IEEE-1553 subaddress.
#define ieee1553_WORD_COUNT_OR_MODE_BORDER					32U			///< Border value for IEEE-1553 word-count or mode.
#define rtModeCodeType_BORDER								0x0008U		///< Border value for RT mode code manipulation: wModeCodeType values.
#define rtAddressType_BORDER								0x0002U		///< Border value for RT manipulation: wOwnAddressOrBroadcast values.
#define messageDirection_BORDER								0x0002U		///< Border value for RT manipulation: wMessageDirection values.
#define rtBuiltInTestWordSource_BORDER						2U			///< Border value for RT built-in test word sources: wWordLocation values.
#define rtBuiltInTestPermitOnBusy_BORDER					2U			///< Border value for RT built-in test permission options: wPermitOrInihibitIfRtBusy values.
#define messageLocationAndRemoval_BORDER					4U			///< Border value for message access: wMessageLocationAndRemoval values.
#define messageLocationAndRemoval_LOCATION					0x0002U		///< Location mask for message access: wMessageLocationAndRemoval values.
#define messageLocationAndRemoval_REMOVAL					0x0001U		///< Removal mask for message access: wMessageLocationAndRemoval values.
#define rtCommandStackSize_BORDER							0x9FFFU		///< Command stack size border mask for RT configuration: wCommandStackSize values.
#define rtCommandStackSize_OFFSET_OF_SIZE					8U			///< The index of the lowest of the bits of the size for RT configuration: wCommandStackSize values.
#define bcControlWord_ACTUAL_OPTIONS						0xFFFFFFF8U	///< Actually offered message options: BC message control word masks.
#define bcControlWord_NON_SPECIAL_OPTIONS					0x0000FFFFU	///< Non special message options: BC message control word masks.
#define bcControlWord_BUS_SELECTOR							0x0080U		///< BC control word channel selector bit mask: BC message control word masks.
#define mtStack_BORDER										4U			///< Border value for MT stack specifier: wStackSelector values.
#define mtStackOption_BORDER								2U			///< Border value for MT configuration: wStackMode values.
#define mtCommandStackSize_MASK								0x1800U		///< Mask for MT configuration: wCommandStackSize values.
#define mtCommandStackSize_OFFSET_OF_SIZE					11U			///< The index of the lowest of the bits of the mask for MT configuration: wCommandStackSize values.
#define mtDataStackSize_MASK								0x0700U		///< Mask for MT configuration: wDataStackSize values.
#define mtDataStackSize_OFFSET_OF_SIZE						8U			///< The index of the lowest of the bits of the mask for MT configuration: wDataStackSize values.
#define messageType_BORDER									16U 		///< Border value for MIL-STD-1553 coded message types.

// General purpose flag state manipulation: Effect causing masks.
#define bcGpfEffect_LEAVE									0x0000U		///< GPF effect: Leave given GPF bit unchanged - Zero to the clear and set bits of given GPF condition at the GPF register.
#define bcGpfEffect_SET										0x0001U		///< GPF effect: Set given GPF bit - Zero to the clear bit and raise the set bit of given GPF condition at the GPF register.
#define bcGpfEffect_CLEAR									0x0100U		///< GPF effect: Clear given GPF bit - Raise to the clear bit and zero the set bit of given GPF condition at the GPF register.
#define	bcGpfEffect_TOGGLE									0x0101U		///< GPF effect: Toggle given GPF bit - Raise the clear and set bits of given GPF condition at the GPF register.

// Command opcode constants and masks.
#define commandOpcode_ODD_PARITY_MASK						0x8000U	///< A mask of the odd parity bit within a command opcode.
#define commandOpcode_MANDATORY_BITS_MASK					0x03E0U	///< A mask of mandatory preset bits within any command opcode.
#define commandOpcode_MANDATORY_BITS						0x0140U	///< Mandatory preset bits within commands of regular opcodes.
#define commandOpcode_SITAL_UNIQUE_MANDATORY_BITS			0x0240U	///< Mandatory preset bits within commands of Sital's unique opcodes.
#define commandOpcode_OFFSET_OF_OPCODE_MASK					10U		///< The index of the first bit of the opcode itself within a command opcode.
#define commandOpcode_OFFSET_OF_CONDITION_MASK				0U		///< The index of the first bit of the condition code within a command opcode.

// BC memory object sizes (in words).
#define bcMemoryObjectSize_GPQ_ENTRY						2U		///< The size (in words) of a single GPQ entry in device memory.
#define bcMemoryObjectSize_NORMAL_DATA_BLOCK				32U		///< The size (in words) of a data block in device memory.
#define bcMemoryObjectSize_DOUBLE_DATA_BLOCK				64U		///< The size (in words) of a double data block in device memory.
#define bcMemoryObjectSize_NORMAL_MESSAGE					8U		///< The allocated (and actual) size (in words) of a normal (i.e., non RT-to-RT) message in device memory.
#define bcMemoryObjectSize_LARGE_MESSAGE					16U		///< The allocated size (in words) of a large message, i.e., a RT-to-RT message, in device memory.
#define bcMemoryObjectSize_RT_TO_RT_MESSAGE					10U		///< The actual size (in words) of the largest message block, i.e., a RT-to-RT message block, in device memory.
#define bcMemoryObjectSize_DUAL_MESSAGE						32U		///< The allocated size (in words) of a dual message in device memory.
#define bcMemoryObjectSize_COMMAND							2U		///< The size (in words) of a command in device memory.
#define bcMemoryObjectSize_COMMAND_STACK_ENTRY				4U		///< The size (in words) of a single command stack entry in device memory, which consists of the following quadruplet: (block-status-word, time-tag, message-gap, message-block-address).
#define bcMemoryObjectSize_MESSAGE_BLOCK					38U		///< The size (in words) of the longest possible BC-style message block (for more information read about the Stack and the Message Block in the BC Users Manual).

// BC command stack entry internal offsets.
#define bcCommandStackEntry_OFFSET_OF_BLOCK_STATUS_WORD		0U		///< The offset (in words) in a BC command stack entry of the block status word.
#define bcCommandStackEntry_OFFSET_OF_TIME_TAG				1U		///< The offset (in words) in a BC command stack entry of the time tag.
#define bcCommandStackEntry_OFFSET_OF_MESSAGE_GAP			2U		///< The offset (in words) in a BC command stack entry of the message gap.
#define bcCommandStackEntry_OFFSET_OF_MESSAGE_POINTER		3U		///< The offset (in words) in a BC command stack entry of the message pointer.

// RT command stack entry internal offsets.
#define rtCommandStackEntry_OFFSET_OF_BLOCK_STATUS_WORD		0U		///< The offset (in words) in a RT command stack entry of the block status word.
#define rtCommandStackEntry_OFFSET_OF_TIME_TAG				1U		///< The offset (in words) in a RT command stack entry of the time tag.
#define rtCommandStackEntry_OFFSET_OF_DATA_BLOCK_ADDRESS	2U		///< The offset (in words) in a RT command stack entry of the device memory address of the related data block.
#define rtCommandStackEntry_OFFSET_OF_MODE_CODE_DATA		2U		///< The offset (in words) in a RT command stack entry of the single mode code data word, in case of mode code messages with data.
#define rtCommandStackEntry_OFFSET_OF_COMMAND				3U		///< The offset (in words) in a RT command stack entry of the received command.

// MT command stack entry internal offsets.
#define mtCommandStackEntry_OFFSET_OF_BLOCK_STATUS_WORD		0U		///< The offset (in words) in a MT command stack entry of the block status word.
#define mtCommandStackEntry_OFFSET_OF_TIME_TAG				1U		///< The offset (in words) in a MT command stack entry of the time tag.
#define mtCommandStackEntry_OFFSET_OF_DATA_BLOCK_ADDRESS	2U		///< The offset (in words) in a MT command stack entry of the device memory address of the related data block.
#define mtCommandStackEntry_OFFSET_OF_COMMAND				3U		///< The offset (in words) in a MT command stack entry of the received command.

// BC message block internal offsets.
#define bcMessageBlock_OFFSET_OF_BC_CONTROL_WORD			0U		///< The offset (in words) in a BC message block of the BC control word.
#define bcMessageBlock_OFFSET_OF_COMMAND_1					1U		///< The offset (in words) in a BC message block of the [first] command.
#define bcMessageBlock_OFFSET_OF_DATA_BLOCK_ADDRESS			2U		///< The offset (in words) in a BC message block of the device memory address of the related data block.
#define bcMessageBlock_OFFSET_OF_GAP_TO_NEXT_MESSAGE		3U		///< The offset (in words) in a BC message block of the gap to next message.
#define bcMessageBlock_OFFSET_OF_TIME_TAG					4U		///< The offset (in words) in a BC message block of the time tag.
#define bcMessageBlock_OFFSET_OF_BLOCK_STATUS				5U		///< The offset (in words) in a BC message block of the block status word.
#define bcMessageBlock_OFFSET_OF_LOOPBACK_WORD				6U		///< The offset (in words) in a BC message block of the loopback word.
#define bcMessageBlock_OFFSET_OF_RT_STATUS_WORD_1			7U		///< The offset (in words) in a BC message block of the [first] RT status word.
#define bcMessageBlock_OFFSET_OF_COMMAND_2					8U		///< The offset (in words) in a BC message block of the second command (relevant with RT-to-RT messages).
#define bcMessageBlock_OFFSET_OF_RT_STATUS_WORD_2			9U		///< The offset (in words) in a BC message block of the second RT status word.

// BC message block masks & values.
#define bcMessageBlock_Command1_SKIP_MESSAGE				0xFFFFU	///< The value of the command-1 word of a BC message block that designates "skip message".

// BC command block masks.
#define bcCommandBlock_ExecuteAndFlip_AddressFlipBitMask	0x0010U	///< The bit that's flipped in result of successful Tx by a XQF command.

// BC address map.
#define bcAddressMap_GPQ									0x0000U	///< The address in device memory of the GPQ.
#define bcAddressMap_FREE_MEMORY							0x0040U	///< The address in device memory where the free space begins.
#define bcAddressMap_COMMAND_STACK_IN_NON_AUTO_REPEAT_MODE	0x0100U	///< The address in device memory where the command stack begins when the BC is configured as non-enhanced-BC in frame non-auto-repeat mode.
#define bcAddressMap_FRAME_LENGTH_IN_NON_AUTO_REPEAT_MODE	0x0101U	///< The address in device memory where the number of entries in the command stack is stored when the BC is configured as non-enhanced-BC in frame non-auto-repeat mode.
#define bcAddressMap_COMMAND_STACK_IN_AUTO_REPEAT_MODE		0x0102U	///< The address in device memory where the command stack begins when the BC is configured as non-enhanced-BC in frame auto-repeat mode.
#define bcAddressMap_FRAME_LENGTH_IN_AUTO_REPEAT_MODE		0x0103U	///< The address in device memory where the number of entries in the command stack is stored when the BC is configured as non-enhanced-BC in frame auto-repeat mode.

// RT data block to subaddress mapping message types.
#define rtMessageType_RX						0U	///< Rx messages.
#define rtMessageType_TX						1U	///< Tx messages.
#define rtMessageType_BROADCAST					2U	///< Broadcast messages.
#define rtMessageType_COUNT						3U	///< The number of message types defined in regard with the subaddress lookup table, each of which has a dedicated sub lookup table.

// RT command illegalization table constants and offsets.
#define rtCommandIllegalizationTable_OFFSET_OF_SUBADDRESS								1U		///< The index of the lowest of the bits of the subaddress field within an entry of the command illegalization table.
#define rtCommandIllegalizationTable_OFFSET_OF_DIRECTION								6U		///< The index of the lowest of the bits of the direction field within an entry of the command illegalization table.
#define rtCommandIllegalizationTable_OFFSET_OF_ADDRESS_TYPE								7U		///< The index of the lowest of the bits of the address type field within an entry of the command illegalization table.

// RT busy lookup table constants and offsets.
#define rtBusyLookupTable_OFFSET_OF_DIRECTION_BIT										1U		///< The index of the direction bit in the binary representation of word entry offsets in the busy lookup table.
#define rtBusyLookupTable_OFFSET_OF_ADDRESS_BIT											2U		///< The index of the address type bit in the binary representation of word entry offsets in the busy lookup table.
#define rtBusyLookupTable_OFFSET_OF_ADDRESS_BIT_FOR_OWN_ADDRESS							0U		///< The value of the address bit for offsets of word entries in the busy lookup table in case of own address.
#define rtBusyLookupTable_OFFSET_OF_ADDRESS_BIT_FOR_BROADCAST							1U		///< The value of the address bit for offsets of word entries in the busy lookup table in case of broadcast address.

// RT lookup table constants and offsets.
#define rtLookupTable_SUBADDRESS_LOOKUP_SUBTABLE_MESSAGE_TYPE_RX						0U		///< The index of the sub lookup table of the subaddress lookup table that's dedicated for message type Rx.
#define rtLookupTable_SUBADDRESS_LOOKUP_SUBTABLE_MESSAGE_TYPE_TX						1U		///< The index of the sub lookup table of the subaddress lookup table that's dedicated for message type Tx.
#define rtLookupTable_SUBADDRESS_LOOKUP_SUBTABLE_MESSAGE_TYPE_BROADCAST					2U		///< The index of the sub lookup table of the subaddress lookup table that's dedicated for message type broadcast.
#define rtLookupTable_SUBADDRESS_LOOKUP_SUBTABLE_CONTROL_WORDS							3U		///< The index of the sub lookup table of the subaddress lookup table that's dedicated for subaddress control words.
#define rtLookupTable_SUBADDRESS_LOOKUP_SUBTABLE_COUNT									4U		///< The number of sub lookup tables that make up the subaddress lookup table.
#define rtLookupTable_OFFSET_OF_SUBADDRESS_CONTROL_WORD_MESSAGE_TYPE_RX					5U		///< The index of the lowest of the bits of the message type Rx section within a subaddress control word at the subaddress control word sub lookup table.
#define rtLookupTable_SUBADDRESS_CONTROL_WORD_MESSAGE_TYPE_RX							0x03E0U	///< The mask of the message type Rx section within a subaddress control word at the subaddress control word sub lookup table.
#define rtLookupTable_SUBADDRESS_CONTROL_WORD_MESSAGE_TYPE_RX_COMPLEMENT				0x7C1FU	///< The complement of the mask of the message type Rx section within a subaddress control word at the subaddress control word sub lookup table (not taking in account the double or common circular data block field).
#define rtLookupTable_OFFSET_OF_SUBADDRESS_CONTROL_WORD_MESSAGE_TYPE_TX					10U		///< The index of the lowest of the bits of the message type Tx section within a subaddress control word at the subaddress control word sub lookup table.
#define rtLookupTable_SUBADDRESS_CONTROL_WORD_MESSAGE_TYPE_TX							0x7C00U	///< The mask of the message type Tx section within a subaddress control word at the subaddress control word sub lookup table.
#define rtLookupTable_SUBADDRESS_CONTROL_WORD_MESSAGE_TYPE_TX_COMPLEMENT				0x03FFU	///< The complement of the mask of the message type Tx section within a subaddress control word at the subaddress control word sub lookup table (not taking in account the double or common circular data block field).
#define rtLookupTable_OFFSET_OF_SUBADDRESS_CONTROL_WORD_MESSAGE_TYPE_BROADCAST			0U		///< The index of the lowest of the bits of the message type broadcast section within a subaddress control word at the subaddress control word sub lookup table.
#define rtLookupTable_SUBADDRESS_CONTROL_WORD_MESSAGE_TYPE_BROADCAST					0x001FU	///< The mask of the message type broadcast section within a subaddress control word at the subaddress control word sub lookup table.
#define rtLookupTable_SUBADDRESS_CONTROL_WORD_MESSAGE_TYPE_BROADCAST_COMPLEMENT			0x7FE0U	///< The complement of the mask of the message type broadcast section within a subaddress control word at the subaddress control word sub lookup table (not taking in account the double or common circular data block field).
#define rtLookupTable_OFFSET_OF_MESSAGE_TYPE_INTERRUPT_ENABLER							3U		///< The index of the lowest of the bits of the interrupt enabler field of each message type section within a subaddress control word at the subaddress control word sub lookup table.
#define rtLookupTable_MESSAGE_TYPE_INTERRUPT_ENABLER									0x0018U	///< The mask of the interrupt enabler field of each message type section within a subaddress control word at the subaddress control word sub lookup table.
#define rtLookupTable_OFFSET_OF_SUBADDRESS_CONTROL_WORD_DOUBLE_OR_COMMON_DATA_BLOCK		15U		///< The index of the lowest of the bits of the double or common circular data block enabler field within a subaddress control word at the subaddress control word sub lookup table.
#define rtLookupTable_SUBADDRESS_CONTROL_WORD_MESSAGE_DOUBLE_OR_COMMON_DATA_BLOCK		0x8000U	///< The mask of the double or common circular data block enabler field within a subaddress control word at the subaddress control word sub lookup table.

// RT address map.
#define rtAddressMap_ISQ															rtMtAddressMap_ISQ	///< The address in device memory of the ISQ.
#define rtAddressMap_COMMAND_STACK_POINTER											0x0100U	///< The address in device memory of the command stack pointer.
#define rtAddressMap_GLOBAL_CIRCULAR_DATA_POINTER									0x0101U	///< The address in device memory of the global circular data pointer.
#define rtAddressMap_MODE_CODE_SELECTIVE_INTERRUPT_TABLE							0x0108U	///< The address in device memory of the mode code selective interrupt table.
#define rtAddressMap_MODE_CODE_DATA_TABLE											0x0110U	///< The address in device memory of the mode code data table.
#define rtAddressMap_ModeCodeWord_SYNCHRONIZE_WITH_DATA								0x0111U	///< The address in device memory of the mode code data table entry for synchronize-with-data.
#define rtAddressMap_ModeCodeWord_SELECTED_TRANSMITTER_SHUTDOWN						0x0114U	///< The address in device memory of the mode code data table entry for selected-transmitter-shutdown.
#define rtAddressMap_ModeCodeWord_OVERRIDE_SELECTED_TRANSMITTER_SHUTDOWN			0x0115U	///< The address in device memory of the mode code data table entry for override-selected-transmitter-shutdown.
#define rtAddressMap_ModeCodeWord_TRANSMIT_VECTOR_WORD								0x0120U	///< The address in device memory of the mode code data table entry for transmit-vector-word.
#define rtAddressMap_ModeCodeWord_TRANSMIT_LAST_COMMAND								0x0122U	///< The address in device memory of the mode code data table entry for transmit-last-command.
#define rtAddressMap_ModeCodeWord_TRANSMIT_BUILT_IN_TEST							0x0123U	///< The address in device memory of the mode code data table entry for transmit-built-in-test.
#define rtAddressMap_ModeCodeWord_BROADCAST_SYNCHRONIZE_WITH_DATA					0x0131U	///< The address in device memory of the mode code data table entry for broadcast-synchronize-with-data.
#define rtAddressMap_ModeCodeWord_BROADCAST_SELECTED_TRANSMITTER_SHUTDOWN			0x0134U	///< The address in device memory of the mode code data table entry for broadcast-selected-transmitter-shutdown.
#define rtAddressMap_ModeCodeWord_BROADCAST_OVERRIDE_SELECTED_TRANSMITTER_SHUTDOWN	0x0135U	///< The address in device memory of the mode code data table entry for broadcast-override-selected-transmitter-shutdown.
#define rtAddressMap_SUBADDRESS_LOOKUP_TABLE_RX										0x0140U	///< The address in device memory of the subaddress Rx messages sub lookup table.
#define rtAddressMap_SUBADDRESS_LOOKUP_TABLE_TX										0x0160U	///< The address in device memory of the subaddress Tx messages sub lookup table.
#define rtAddressMap_SUBADDRESS_LOOKUP_TABLE_BROADCAST								0x0180U	///< The address in device memory of the subaddress broadcast messages sub lookup table.
#define rtAddressMap_SUBADDRESS_LOOKUP_TABLE_SUBADDRESS_CONTROL_WORDS				0x01A0U	///< The address in device memory of the subaddress control words sub lookup table.
#define rtAddressMap_BUSY_LOOKUP_TABLE												0x0240U	///< The address in device memory of the busy lookup table.
#define rtAddressMap_COMMAND_ILLEGALIZATION_TABLE									0x0300U	///< The address in device memory of the command illegalization table.
#define rtAddressMap_FREE_MEMORY													0x0400U	///< The address in device memory where the free space begins.
#define rtAddressMap_COMMAND_STACK													0x0800U	///< The address in device memory of the command stack.

// MT monitoring lookup table constants and offsets.
#define mtMonitoringLookupTable_OFFSET_OF_DIRECTION_BIT								1U		///< The index of the direction bit in the binary representation of word entry offsets in the monitoring lookup table.
#define mtMonitoringLookupTable_OFFSET_OF_ADDRESS_BIT								2U		///< The index of the address bit in the binary representation of word entry offsets in the monitoring lookup table.

// MT address map.
#define mtAddressMap_ISQ															rtMtAddressMap_ISQ	///< The address in device memory of the ISQ.
#define mtAddressMap_MT_COMMAND_STACK_A_POINTER										0x0102U	///< The address in device memory of command stack A pointer.
#define mtAddressMap_MT_DATA_STACK_A_POINTER										0x0103U	///< The address in device memory of data stack A pointer.
#define mtAddressMap_MT_COMMAND_STACK_B_POINTER										0x0106U	///< The address in device memory of command stack B pointer.
#define mtAddressMap_MT_DATA_STACK_B_POINTER										0x0107U	///< The address in device memory of data stack B pointer.
#define mtAddressMap_MONITOR_LOOKUP_TABLE											0x0280U	///< The address in device memory of the monitor lookup table.
#define mtAddressMap_FREE_MEMORY													0x0300U	///< The address in device memory where the free space begins.

// RT&MT address map.
// Note: A RT&MT device combines the registers and tables of both RT and MT devices, and it is basically handled by RT-unique or MT-unique functions, which use RT-unique or MT-unique address map constants, respectively. These RT/MT-unique constants shouldn't be, therefore, redefined as RT&MT-unique ones.
#define rtmtAddressMap_FREE_MEMORY													0x0400U	///< The address in device memory where the free space begins.

// RT & MT memory object sizes (in words).
#define rtMtMemoryObjectSize_ISQ_ENTRY												2U		///< The size (in words) of a single ISQ entry in device memory.

// RT & MT address map.
#define rtMtAddressMap_ISQ															0x0000U	///< The address in device memory of the ISQ.

// RT & MT message container.
#define rtMtMessageContainerHostBuffer_NONE											0U		///< Neither the RT nor the MT host buffer parts of the RT&MT combined host buffer contains a message to be retrieved.
#define rtMtMessageContainerHostBuffer_RT											1U		///< The RT host buffer is the part of the RT&MT combined host buffer from which a message should be retrieved.
#define rtMtMessageContainerHostBuffer_MT											2U		///< The MT host buffer is the part of the RT&MT combined host buffer from which a message should be retrieved.

// RS422 configuration registers bit masks.
// see the structure of the RS422 configuration registers in the Sital Tester-1553 User Manual.
typedef enum Rs422ConfigRegtisterBitEnum
	{
	Rs422ConfigRegisterBit_BitsCount									= 0x0007, // these bits are set to 0b-100b for 5-9 bits per word, respectively.
	Rs422ConfigRegisterBit_RxTxMode										= 0x0008, // this bit is set on for tx-only mode, or off for rx-tx mode (the latter may, of course, serve for rx-only mode).
	Rs422ConfigRegisterBit_RxTxModeOffset								= 3, // the index of the lowest of the bit[s] of field rt-tx-mode.
	Rs422ConfigRegisterBit_RxTxMode_TxOnly								= 0x0000, // see above.
	Rs422ConfigRegisterBit_RxTxMode_RxTx								= 0x0008, // see above.
	Rs422ConfigRegisterBit_Parity										= 0x0030, // these bits are set to 00b/01b for no parity, to 10b for even parity, or to 11b for odd parity.
	Rs422ConfigRegisterBit_ParityOffset									= 4, // the index of the lowest of the bit[s] of field parity.
	Rs422ConfigRegisterBit_Parity_No									= 0x0010, // see above.
	Rs422ConfigRegisterBit_Parity_Even									= 0x0020, // see above.
	Rs422ConfigRegisterBit_Parity_Odd									= 0x0030, // see above.
	Rs422ConfigRegisterBit_StopBits										= 0x00C0, // these bits are set to 00b for 1 stop bit, 01b for 1.5 stop bits, or 10b/11b for 2 stop bits.
	Rs422ConfigRegisterBit_StopBitsOffset								= 6, // the index of the lowest of the bit[s] of field stop-bits.
	Rs422ConfigRegisterBit_StopBits_Single								= 0x0000, // see above.
	Rs422ConfigRegisterBit_StopBits_OneAndHalf							= 0x0040, // see above.
	Rs422ConfigRegisterBit_StopBits_Two									= 0x0080  // see above.
	} Rs422ConfigRegisterBitEnum;

// RS422 status registers bit masks.
// see the structure of the RS422 state registers in the Sital Tester-1553 User Manual.
typedef enum Rs422StatusRegisterBitEnum
	{
	Rs422StatusRegisterBit_OffsetOfNextRxWord						= 0x03FF, // these bits contains the offset where the next received word will be written in the related RS422 rx buffer.
	Rs422StatusRegisterBit_TransmitterBusy							= 0x0800, // this bit is set while the related RS422 line is transmitting.
	Rs422StatusRegisterBit_ReceiverBusy								= 0x1000, // this bit is set while the related RS422 line is transmitting.
	Rs422StatusRegisterBit_FormatError								= 0x2000, // this bit is set in case a format error (i.e., either start or stop bits error) is encountered along RS422 rx.
	Rs422StatusRegisterBit_IncorrectNumberOfBits					= 0x4000, // this bit is set in case there's an incorrect number of bits is received RS422 words.
	Rs422StatusRegisterBit_ParityError								= 0x8000, // this bit is set in case a parity error is encountered along RS422 rx.
	} Rs422StatusRegisterBitEnum;

// Macro definitions.

// Return a 'Y' / 'N' character in case given a boolean value of 'TRUE' / 'FALSE', respectively.
// Parameter[s]:
// - bBooleanValue (in):
//   - Description: The boolean value to evaluate
//   - Type: BOOLEAN
//   - Value: TRUE / FALSE
#define YES_NO(bBooleanValue) \
	((FALSE == (bBooleanValue)) ? 'N' : 'Y')

// Calculate the address of the GPQ entry whose index is given.
// Parameter[s]:
// - wQueueEntryIndex (in):
//   - Description: The index of an entry in the queue
//   - Type: Unsigned integer
//   - Value: 0 to (sitalBcCounter_GPQ_ENTRIES-1)
#define GPQ_ENTRY_ADDRESS(wQueueEntryIndex) \
	(bcAddressMap_GPQ + ((wQueueEntryIndex) * bcMemoryObjectSize_GPQ_ENTRY))

// Calculate the index of the GPQ entry whose device memory address is given.
// Parameter[s]:
// - wQueueEntryAddress (in):
//   - Description: The device memory address of an entry in the queue
//   - Type: Unsigned integer
//   - Value: bcAddressMap_GPQ to (bcAddressMap_GPQ + ((sitalBcCounter_GPQ_ENTRIES - 1) * bcMemoryObjectSize_GPQ_ENTRY))
#define GPQ_ENTRY_INDEX(wQueueEntryAddress) \
	(((wQueueEntryAddress) - bcAddressMap_GPQ) / bcMemoryObjectSize_GPQ_ENTRY)

// Calculate the address of the ISQ entry whose index is given.
// Parameter[s]:
// - wQueueEntryIndex (in):
//   - Description: The index of an entry in the queue
//   - Type: Unsigned integer
//   - Value: 0 to (sitalBcCounter_GPQ_ENTRIES-1)
#define ISQ_ENTRY_ADDRESS(wQueueEntryIndex) \
	((U16BIT)rtMtAddressMap_ISQ + ((wQueueEntryIndex) * (U16BIT)rtMtMemoryObjectSize_ISQ_ENTRY))

// Calculate the index of the ISQ entry whose device memory address is given.
// Parameter[s]:
// - wQueueEntryAddress (in):
//   - Description: The device memory address of an entry in the queue
//   - Type: Unsigned integer
//   - Value: bcAddressMap_GPQ to (bcAddressMap_GPQ + ((sitalBcCounter_GPQ_ENTRIES - 1) * bcMemoryObjectSize_GPQ_ENTRY))
#define ISQ_ENTRY_INDEX(wQueueEntryAddress) \
	(((wQueueEntryAddress) - (U16BIT)rtMtAddressMap_ISQ) / (U16BIT)rtMtMemoryObjectSize_ISQ_ENTRY)

// Calculate the starter address for the MT stack whose configuration mode, base address, and size are given.
// In case single stack is configured, the starter point is the base address of the stack.
// In case double stack is configured, the starter point is the middle of the stack.
// Parameter[s]:
// - wStackMode (in):
//   - Description: The configuration mode (single/double) of the target stack
//   - Type: Unsigned integer
//   - Value: sitalMtStackOption_*
// - wStackBaseAddress (in):
//   - Description: The base MT device memory address of the target stack
//   - Type: Unsigned integer
//   - Value: >=0
// - wStackSize (in):
//   - Description: The size (in words) of the target stack
//   - Type: Unsigned integer
//   - Value: >0
#define MT_STACK_STARTER_ADDRESS(wStackMode, wStackBaseAddress, wStackSize) \
	( (wStackBaseAddress) + ( (sitalMtStackOption_DOUBLE == (wStackMode)) ? ((wStackSize) / 2 ) : 0) )

// Convert given command word from 1553 command word format into HOO9 command word format.
// In the 1553 protocol command have the following structure:
// - Bits 11-15: Address.
// - Bit     10: T/R.
// - Bits  5- 9: Subaddress (or mode, what's designated using the command indicator in HOO9).
// - Bits  0- 4: Word count (or mode code, what's irrelevant with HOO9).
// In the HOO9 protocol command words are actually called select words, and have the following structure:
// - Bits 12-15: Address.
// - Bit     11: Command indicator (indicates what called "a mode command" in 1553).
// - Bits  5-10: Control (what's called subaddress in 1553).
// - Bit      4: T/R.
// - Bits  0- 3: Word count.
// Sital's MT194_H009 IP CORE uses 1553 command words in the following way in order to record HOO9 command words in the HOO9 MT stack:
// - Bit  4 of the HOO9 command word is stored as bit 10 of the 1553 command word (i.e., the T/R bit is simply shifted from place to place).
// - Bit 10 of the HOO9 command word is stored as bit 11 of the 1553 command word (i.e., the HOO9 subaddress' MSbit is stored as the 1553 address LSbit).
// - Bit 11 of the HOO9 command word is stored as bit  4 of the 1553 command word (i.e., the HOO9 mode command indicator is stored as the 1553 word count MSbit).
// This macro simply makes the opposite process, and retrieves the original HOO9 command word.
#define CONVERT_1553_COMMAND_WORD_TO_HOO9_COMMAND_WORD(wCommand) \
	{ \
		U16BIT wMaskForBit04 = ( ( 0x0400 & (wCommand) ) >> 6 ); /* Shifts bit 10 to bit  4. */ \
		U16BIT wMaskForBit10 = ( ( 0x0800 & (wCommand) ) >> 1 ); /* Shifts bit 11 to bit 10. */ \
		U16BIT wMaskForBit11 = ( ( 0x0010 & (wCommand) ) << 7 ); /* Shifts bit  4 to bit 11. */ \
		(wCommand) = ( (0xF3EF & (wCommand)) | wMaskForBit04 | wMaskForBit10 | wMaskForBit11 ); \
	}

// Convert given command word from HOO9 command word format into 1553 command word format.
// In the 1553 protocol command have the following structure:
// - Bits 11-15: Address.
// - Bit     10: T/R.
// - Bits  5- 9: Subaddress (or mode, what's designated using the command indicator in HOO9).
// - Bits  0- 4: Word count (or mode code, what's irrelevant with HOO9).
// In the HOO9 protocol command words are actually called select words, and have the following structure:
// - Bits 12-15: Address.
// - Bit     11: Command indicator (indicates what called "a mode command" in 1553).
// - Bits  5-10: Control (what's called subaddress in 1553).
// - Bit      4: T/R.
// - Bits  0- 3: Word count.
// Sital's MT194_H009 IP CORE uses 1553 command words in the following way in order to record HOO9 command words in the HOO9 MT stack:
// - Bit  4 of the HOO9 command word is stored as bit 10 of the 1553 command word (i.e., the T/R bit is simply shifted from place to place).
// - Bit 10 of the HOO9 command word is stored as bit 11 of the 1553 command word (i.e., the HOO9 subaddress' MSbit is stored as the 1553 address LSbit).
// - Bit 11 of the HOO9 command word is stored as bit  4 of the 1553 command word (i.e., the HOO9 mode command indicator is stored as the 1553 word count MSbit).
#define CONVERT_HOO9_COMMAND_WORD_TO_1553_COMMAND_WORD(wCommand) \
	{ \
		U16BIT wMaskForBit04 = ( ( (U16BIT)0x0800 & (wCommand) ) >> 7 ); /* Shifts bit 11 to bit  4. */ \
		U16BIT wMaskForBit10 = ( ( (U16BIT)0x0010 & (wCommand) ) << 6 ); /* Shifts bit  4 to bit 10. */ \
		U16BIT wMaskForBit11 = ( ( (U16BIT)0x0400 & (wCommand) ) << 1 ); /* Shifts bit 10 to bit 11. */ \
		(wCommand) = ( ((U16BIT)0xF3EF & (wCommand)) | wMaskForBit04 | wMaskForBit10 | wMaskForBit11 ); \
	}



// Type/structure declarations.

struct RtStackStateStructure;
struct MtStackStateStructure;
struct NestingStackStructure;
struct CircularDataBlockInformationStructure;
struct HostRegistersStructure;
struct HostInterruptServiceQueueStateStructure;
struct GeneralPurposeQueueStateStructure;
struct HostGeneralPurposeQueueStructure;
struct HostDataBlockStructure;
struct HostMessageStructure;
struct HostCommandStructure;
struct HostFrameStructure;
struct HostBufferStructure;
struct BcStateStructure;
struct RtStateStructure;
struct MtStateStructure;
struct DeviceStateStructure;



// Type/structure definitions.

///	RT message/command stack information and state.
typedef struct RtStackStateStructure
{
	/// The base RT device memory address of the command stack.
	U32BIT dwCommandStackBaseAddress;
	/// The border RT device memory address of the command stack (i.e., the address of the memory word that comes right after the stack).
	U32BIT dwCommandStackBorderAddress;
	/// The size (in words) of the command stack.
	U16BIT wCommandStackSize;
	/// The RT device memory address of the command stack entry where the next message will be read from.
	U32BIT dwAddressOfMessageToRead;
	/// The RT device memory address of the command stack entry where the next message will be written by the RT device.
	U32BIT dwAddressOfMessageToWrite;
	/// The count of messages that have been lost.
	U32BIT dwLostMessageCount;
	/// The current percentage of fullness of the RT command stack.
	/// This field must contain a value in the region 0 to 100.
	U16BIT wFullnessPercentage;
	/// The maximum encountered percentage of fullness of the RT command stack.
	/// This field must contain a value in the region 0 to 100.
	U16BIT wMaximumFullnessPercentage;
} RtStackStateStruct;

///	MT stack information and state.
typedef struct MtStackStateStructure
{
	/// The MT device memory address of the command stack pointer of this stack.
	U32BIT dwCommandStackPointerAddress;
	/// The MT device memory address of the data stack pointer of this stack.
	U32BIT dwDataStackPointerAddress;
	/// The base MT device memory address of the command stack.
	U32BIT dwCommandStackBaseAddress;
	/// The border MT device memory address of the command stack (i.e., the address of the memory word that comes right after the stack).
	U32BIT dwCommandStackBorderAddress;
	/// The size (in words) of the command stack.
	U16BIT wCommandStackSize;
	/// The initial/starter device memory address of the command stack, that is, the address in the stack from where the device should start recording messages.
	U32BIT dwCommandStackInitialAddress;
	/// The MT device memory address of the command stack entry where the next message will be read from.
	U32BIT dwAddressOfMessageToRead;
	/// The MT device memory address of the command stack entry where the next message will be written by the MT device.
	U32BIT dwAddressOfMessageToWrite;
	/// The base MT device memory address of the data stack.
	U32BIT dwDataStackBaseAddress;
	/// The border MT device memory address of the data stack (i.e., the address of the memory word that comes right after the stack).
	U32BIT dwDataStackBorderAddress;
	/// The size (in words) of the data stack.
	U16BIT wDataStackSize;
	/// The initial/starter device memory address of the data stack.
	U32BIT dwDataStackInitialAddress;
	/// The count of messages that have been lost.
	U32BIT dwLostMessageCount;
	/// The current percentage of fullness of the MT command stack.
	/// This field must contain a value in the region 0 to 100.
	U16BIT wFullnessPercentage;
	/// The maximum encountered percentage of fullness of the MT command stack.
	/// This field must contain a value in the region 0 to 100.
	U16BIT wMaximumFullnessPercentage;
} MtStackStateStruct;

/// Nesting stack (see full explanation in the documentation for function sitalBc_Start).
typedef struct NestingStackStructure
{
	/// An array that contains the IDs of the frames that currently appear in the nesting line.
	/// The number of currently filled entries in this array field is contained in field wCurrentSizeOfStack.
	S16BIT waFrameIdStack[sitalBcMaximum_FRAME_NESTING_STACK];
	/// The number of currently filled entries in array field waFrameIdStack.
	U16BIT wCurrentSizeOfStack;
} NestingStackStruct;

/// Information on circular data block used with a RT subaddress.
typedef struct CircularDataBlockInformationStructure
{
	/// A flag that says whether a circular data block is used.
	U16BIT bIsEnabled;
	/// The size (in words) of the device memory block that has been allocated for the circular data block.
	/// This field contains actual information only if field bIsEnabled contains TRUE.
	U16BIT wActualSize;
	/// The address of the circular data block in device memory.
	/// This field contains actual information only if field bIsEnabled contains TRUE.
	U32BIT dwAddress;
} CircularDataBlockInformationStruct;

///	Device registers.
typedef struct HostRegistersStructure
{
	/// Contains the registers in a way that the register address is used as its index.
	/// Note: Some of the register entries merely play as place holders, as their corresponding registers aren't manipulated using this structure.
	U16BIT waRegister[sitalRegisterAddress_BORDER];
} HostRegistersStruct;

/// Interrupt service queue state and statistics structure.
typedef struct HostInterruptServiceQueueStateStructure
{
	/// Index of next ISQ entry to read.
	/// This field contains actual information only if field wMode contains either sitalMode_RT, sitalMode_MT, or sitalMode_RT_AND_MT.
	/// This field must contain a value less than the the total number of ISQ entries.
	U16BIT wIndexOfNextReadIsqEntry;
	/// Count of lost ISQ entries.
	/// This field must contain a value less than the the total number of ISQ entries.
	U16BIT wLostIsqEntryCount;
	/// A flag that says whether interrupt status queue is currently enabled.
	/// Only relevant when field wMode of this structure is one of sitalMode_RT, sitalMode_MT, sitalMode_RT_AND_MT, sitalMode_MRT.
	BOOLEAN bIsIsqEnabled;
} HostInterruptServiceQueueStateStruct;

/// General purpose queue state and statistics structure.
typedef struct GeneralPurposeQueueStateStructure
{
	/// Index of next GPQ entry to read.
	/// This field must contain a value less than the the total number of GPQ entries.
	U16BIT wIndexOfNextReadGpqEntry;
	/// Count of lost GPQ entries.
	/// This field must contain a value less than the the total number of GPQ entries.
	U16BIT wLostGpqEntryCount;
	/// The current percentage of fullness of the GPQ.
	/// This field must contain a value in the region 0 to 100.
	U16BIT wFullnessPercentage;
	/// The maximum encountered percentage of fullness of the GPQ.
	/// This field must contain a value in the region 0 to 100.
	U16BIT wMaximumFullnessPercentage;
} GeneralPurposeQueueStateStruct;

/// General purpose queue contents and state structure.
typedef struct HostGeneralPurposeQueueStructure
{
	/// Index of next GPQ entry to read.
	/// This field must contain a value less than the the total number of GPQ entries.
	U16BIT wIndexOfNextReadGpqEntry;
	/// The index of GPQ entry that's going to be filled by the device in the next time when any instruction so instructs.
	/// This field must contain a value less than the the total number of GPQ entries.
	U16BIT wIndexOfNextFilledGpqEntry;
	/// An array that the host updates in the device GPQ.
	sitalGpqEntryStructure sgesaHostGpq[sitalBcCounter_GPQ_ENTRIES];
} HostGeneralPurposeQueueStruct;

///	Data block definition information.
typedef struct HostDataBlockStructure
{
	/// A flag that says whether this object is free for use.
	BOOLEAN bIsFreeForUse;
	/// The ID of this object, which is unique per object type.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wId;
	/// The address of this object in device memory.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This field contains actual information only if this is a regular data block and not a unique one (e.g., the default data block).
	U32BIT dwAddress;
	/// The size (in words) of the device memory block that has been (or should be) allocated for this object.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wDeviceMemorySize;
	/// The actual size (in words) of this object, i.e., the number of actually contained data words.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This field must contain a value less/equal to the value of field wDeviceMemorySize.
	U16BIT wActualSize;
	/// Device memory offset (in words) of the data word in this data block to be accessed next ('access' includes both read and write).
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U32BIT dwNextAccessedDataWord;
	/// A bitwise mask where bit-i is on when this data block is mapped to subaddress-i for Tx.
	/// This field is only relevant with RT devices.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U32BIT dwTxSubaddressMapping;
	/// A bitwise mask where bit-i is on when this data block is mapped to subaddress-i for Rx.
	/// This field is only relevant with RT devices.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U32BIT dwRxSubaddressMapping;
	/// A bitwise mask where bit-i is on when this data block is mapped to subaddress-i for broadcast.
	/// This field is only relevant with RT devices.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U32BIT dwBroadcastSubaddressMapping;
	/// Word-count-or-mode-code mask (used when enabling message legality for specific RT subaddress).
	/// A bitwise mask where:
	/// - Bit-0 is on when this data block is mapped to messages where the word-count is 32 words.
	/// - Bit-i (i>0) is on when this data block is mapped to messages where the word-count is i words.
	/// This field is only relevant with RT devices.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U32BIT dwWordCountOrModeCodeMask;
	/// The section of the subaddress control word that contains the memory mode field (used when enabling message legality for specific RT subaddress).
	/// The value of this field is determined according to the type of the buffer, as follows:
	/// - Non-circular buffer:
	///   - In this case field wActualSize contains a value less/equal sitalRtDataBlockType_DOUBLE.
	///   - Memory mode is single/double buffer.
	///   - This field contains zero.
	// - Circular buffer:
	///   - In this case field wActualSize contains a value of 2^i, where i may be in the range 7-13 (for data block sizes of 128 to 8192 words).
	///   - Memory mode is subaddress-specific circular buffer. 
	///   - For each possible value of field wActualSize (2^i as was just explained) this field contains i-6.
	/// This field is only relevant with RT devices.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wSubaddresControlWordMemoryModeBits;
	/// The address in device memory of the XQF command that transmits the message that owns this data block.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This field contains actual information only if field wActualSize contains bcMemoryObjectSize_DOUBLE_DATA_BLOCK.
	/// This field contains actual information only if this data block is assigned for some message, and that message is transmitted using a XQF command.
	U32BIT dwOwnerMessageXqfCommandAddress;
} HostDataBlockStruct;

///	Message definition information.
typedef struct HostMessageStructure
{
	/// A flag that says whether this object is free for use.
	BOOLEAN bIsFreeForUse;
	/// The ID of this object, which is unique per object type.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wId;
	/// The address of this object in device memory.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U32BIT dwAddress;
	/// The size (in words) of the device memory block that has been (or should be) allocated for this object.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wDeviceMemorySize;
	/// The actual size (in words) of this object.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This field must contain a value less/equal to the value of field wDeviceMemorySize.
	/// This field is set to:
	/// - bcMemoryObjectSize_NORMAL_MESSAGE for a regular message
	/// - bcMemoryObjectSize_LARGE_MESSAGE for a RT-to_RT message
	/// - bcMemoryObjectSize_DUAL_MESSAGE for a dual message
	U16BIT wActualSize;
	/// The BC control word of message 2.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	S16BIT swDataBlockIdForMessage1;
	/// A unique ID designating the data block of message 1.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wBcControlWordForMessage1;
	/// Command word 1 of message 1.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wCommandWord1ForMessage1;
	/// Command word 2 of message 1.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wCommandWord2ForMessage1;
	/// The gap time of message 1.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wGapTimeForMessage1;
	/// A unique ID designating the data block of message 2.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This field contains actual information only with a dual message.
	S16BIT swDataBlockIdForMessage2;
	/// The BC control word of message 1.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This field contains actual information only with a dual message.
	U16BIT wBcControlWordForMessage2;
	/// Command word 1 of message 2.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This field contains actual information only with a dual message.
	U16BIT wCommandWord1ForMessage2;
	/// Command word 2 of message 2.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This field contains actual information only with a dual message.
	U16BIT wCommandWord2ForMessage2;
	/// The gap time of message 2.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This field contains actual information only with a dual message.
	U16BIT wGapTimeForMessage2;
	/// The time (in us) required for the transmission of this message.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wMessageTxTime;
	/// The type of this message.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This message type may be interpreted as either sitalMessageType_* or as an or-ed combination of messageTypeComponent_*.
	U16BIT wMessageType;
	/// The number of data words in this message.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wDataWordCount;
	/// Message options.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This field is set to an or-ed combination of sitalBcMessageOption_*.
	U32BIT dwOptions;
	/// A flag that says whether this message is an asynchronous message (or otherwise a normal one).
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	BOOLEAN bIsAsynchronousMessage;
	/// A flag that says whether this message has already been assigned for Tx in the low priority asynchronous message Tx subroutine.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This field contains actual information only if field bIsAsynchronousMessage contains TRUE.
	BOOLEAN bIsAssignedForLowPriorityAsynchronousTx;
	/// A flag that says whether this message has already been transmitted as an asynchronous message.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This field contains actual information only if field bIsAsynchronousMessage contains TRUE.
	BOOLEAN bIsAnAlreadyTransmittedAsynchronousMessage;
	/// A flag that says whether this message has already been recorded in the host buffer.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This field contains actual information only if field bIsAsynchronousMessage contains TRUE.
	/// This field contains actual information only if field bIsAnAlreadyTransmittedAsynchronousMessage contains TRUE.
	BOOLEAN bIsAnAlreadyRecordedAsynchronousMessage;
	/// The device memory address within the low priority asynchronous message Tx subroutine where the address of this message has been written
	/// as the address parameter of the corresponding transmitter command.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This field contains actual information only if field bIsAsynchronousMessage contains TRUE.
	/// This field contains actual information only if field bIsAssignedForLowPriorityAsynchronousTx contains TRUE.
	U32BIT dwAddressOfTransmitterCommandParameter;
} HostMessageStruct;

///	Command definition information.
typedef struct HostCommandStructure
{
	/// A flag that says whether this object is free for use.
	BOOLEAN bIsFreeForUse;
	/// The ID of this object, which is unique per object type.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wId;
	///// The address of this object in device memory.
	///// This field contains actual information only if field bIsFreeForUse contains FALSE.
	//U16BIT wAddress;
	/// The size (in words) of the device memory block that has been (or should be) allocated for this object.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wDeviceMemorySize;
	/// The actual size (in words) of this object.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This field must contain a value equal to the value of field wDeviceMemorySize.
	U16BIT wActualSize;
	/// The opcode to be operated by this command.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wOpcode;
	/// The condition that must fulfill in order for this command to be executed.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wCondition;
	/// A parameter that's possibly required by some opcodes (see the opcodes description table under 'Instructions' in the eBC's user manual).
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U32BIT dwParameter1;
	/// Another parameter that's possibly required by some opcodes (see the opcodes description table under 'Instructions' in the eBC's user manual).
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U32BIT dwParameter2;
} HostCommandStruct;

///	Frame definition information.
typedef struct HostFrameStructure
{
	/// A flag that says whether this object is free for use.
	BOOLEAN bIsFreeForUse;
	/// The ID of this object, which is unique per object type.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wId;
	/// The address of this object in device memory.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U32BIT dwAddress;
	/// The size (in words) of the device memory block that has been (or should be) allocated for this object.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This size includes both the commands defined for this frame by the user and special framing commands that are added by this library.
	/// See full description of these framing commands per frame type in the documentation for function sitalBc_Start.
	U16BIT wDeviceMemorySize;
	/// The actual size (in words) of this object.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This field contains actual information only while this frame is executed.
	/// Frames are executed and device memory is actually allocated for them only at the moment when the user either:
	/// - Explicitly requests this library to run this frame (what may requested with major frames alone).
	/// - Implicitly requests this library to run some major frame within which this frame is nested.
	/// This field must contain either a zero or a value equal to the value of field wDeviceMemorySize.
	U16BIT wActualSize;
	/// An array containing the list of commands that the user requires to be executed in this frame.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// Field wCommandCount counts the actual number of elements in this array.
	S16BIT swaCommandId[sitalBcCounter_FRAME_COMMANDS];
	/// An array containing the addresses in device memory where the commands that the user requires to be executed in this frame are written.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// Field wCommandCount counts the actual number of elements in this array.
	/// This array is populated before writing this frame's user defined commands to device memory in order to facilitate the resolve of jump commands.
	U32BIT dwaCommandAddress[sitalBcCounter_FRAME_COMMANDS];
	/// The number of commands that the user requires to be executed in this frame.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wCommandCount;
	/// The type of this frame (sitalBcFrameType_*).
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wFrameType;
	/// The address of this frame's user defined commands (to distinguish from this frame's framing commands) in device memory.
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// This field contains actual information only along frame run, and if this frame is either the running major frame or any of its nested minor frames.
	/// See full description of these framing commands per frame type in the documentation for function sitalBc_Start.
	U32BIT dwUserCommandsBaseAddress;
	/// The time (in us) configured for this frame to complete (>=100).
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	/// If field wFrameType contains sitalBcFrameType_MAJOR, this time is enforced for all this frame's nested minor frame, so that their own frame time isn't used.
	U16BIT wFrameTime;
	/// Different options configured for this frame (sitalBcFrameFlag_*).
	/// This field contains actual information only if field bIsFreeForUse contains FALSE.
	U16BIT wFlags;
} HostFrameStruct;

typedef struct HostBufferStructure
{
	/// The size (in words) of this host buffer, which is the portion of field array waBuffer that's actually used.
	/// When this field contains zero, this host buffer isn't in use.
	U32BIT dwHostBufferSize;
	/// An array that serves as a host buffer in which messages are stored.
	/// This library avoids using any dynamic memory allocations, and therefore this array is statically allocated (see the documentation for sitalMaximum_SIZE_OF_HOST_BUFFER).
	/// This field array contains actual information only if field dwHostBufferSize isn't zero.
	U16BIT waBuffer[sitalMaximum_SIZE_OF_HOST_BUFFER];
	/// An host buffer completion array that serves to store within the values that the time tag rollover counter had when each of the messages in the message host buffer array field waBuffer has been recorded there.
	/// This library avoids using any dynamic memory allocations, and therefore this array is statically allocated (see the documentation for sitalMaximum_SIZE_OF_HOST_BUFFER).
	/// This field array contains actual information only if field dwHostBufferSize isn't zero.
	/// Only used when the user requires the next message received/captured by a RT&MT device, in order to decide whether to take the next received message from the RT stack, or the next captured message from the MT stack.
	U16BIT waTimeTagRolloverCount[sitalMaximum_MESSAGES_IN_HOST_BUFFER];
	/// The 32-bit time tag of the last recorded message, as follows:
	/// - Least-significant 16-bits: The 16-bit time tag that has been stored by the device for this last message in the stack.
	/// - Most-significant 16-bits: A 16-bit counter of time tag rollovers that this library had a chance to track down.
	/// Only used when the user requires the next message received/captured by a RT&MT device, in order to decide whether to take the next received message from the RT stack, or the next captured message from the MT stack.
	U32BIT dwLastMessageTimeTag;
	/// The offset (in words) from the beginning of the host buffer of the location where the next message will be read from.
	/// In case this field is equal to field dwOffsetOfNextMessageToWrite, then the host buffer is either empty or full; the distinction between these two possibilities is then made using field dwMessageCount.
	/// This field contains actual information only if field dwHostBufferSize isn't zero.
	U32BIT dwOffsetOfNextMessageToRead;
	/// The offset (in words) from the beginning of the host buffer of the location where the next message will be written.
	/// In case this field is equal to field dwOffsetOfNextMessageToRead, then the host buffer is either empty or full; the distinction between these two possibilities is then made using field dwMessageCount.
	/// This field contains actual information only if field dwHostBufferSize isn't zero.
	U32BIT dwOffsetOfNextMessageToWrite;
	/// The number of messages that are stored in the host buffer.
	/// In case this field is equal to dwOffsetOfNextMessageToRead, the buffer is full, and no more messages may be written into it.
	/// In case field dwOffsetOfNextMessageToRead is equal to field dwOffsetOfNextMessageToWrite, then the host buffer is either empty or full; the distinction between these two possibilities is then made using this field.
	/// This field contains actual information only if field dwHostBufferSize isn't zero.
	U32BIT dwMessageCount;
	/// Count of messages that have been lost in case the host buffer is full.
	/// This field contains actual information only if field dwHostBufferSize isn't zero.
	U32BIT dwLostMessageCount;
	/// The current percentage of fullness of the host buffer.
	/// This field must contain a value in the region 0 to 100.
	/// This field contains actual information only if field dwHostBufferSize isn't zero.
	U16BIT wFullnessPercentage;
	/// The maximum encountered percentage of fullness of the host buffer.
	/// This field must contain a value in the region 0 to 100.
	/// This field contains actual information only if field dwHostBufferSize isn't zero.
	U16BIT wMaximumFullnessPercentage;
} HostBufferStruct;

///	BC information and state.
/// Note: Included array and structure fields are statically defined in order to avoid dynamic memory allocations.
typedef struct BcStateStructure
{
	/// BC-specific operation options.
	U32BIT dwOptions;
	/// The watchdog timeout used along frame run with this BC.
	/// A value of zero designates that the watchdog timeout isn't currently used along frame run.
	/// This timer will trap the BC along frame run if the timeout value is exceeded.
	U16BIT wWatchDogTimeout;
	/// The number of major frames to run (>0), or "run forever" (=-1).
	S32BIT sdwMajorFrameIterationCount;
	/// A pointer to the major frame that's currently running on this device.
	/// This field contains actual information only along frame run sessions.
	/// The qualifiers of the currently running major frame that are used along frame run are:
	/// - Frame time: When not zero, the frame time of the major frame takes over the frame time of each of its nested minor frames.
	/// - Frame options: The options configured for the major frame are added to (that is, or-ed with) the options configured for each nested minor frame.
	HostFrameStructure* hfspRunningMajorFrame;
	/// The total number of minor frames that are directly/indirectly nested in the currently executed major frame.
	/// This field contains actual information only along frame run sessions.
	/// This field contains the number of entries in array field waLowAsynchronousTxSubroutineCallAddress that contain an actual value.
	U16BIT wNestedMinorFrameCount;
	/// The address in device memory of the high priority asynchronous messages Tx subroutine.
	/// This field contains actual information only along frame run sessions, if high priority asynchronous messages are supported.
	U32BIT dwAddressOfHighAsynchronousTxSubroutine;
	/// The address in device memory of the last word of the high priority asynchronous messages Tx subroutine.
	/// This field contains actual information only along frame run sessions, if high priority asynchronous messages are supported.
	U32BIT dwLastAddressOfHighAsynchronousTxSubroutine;

	/// The total number of currently defined asynchronous messages, both low and high priority ones.
	U16BIT wAsynchronousMessagesCount;
	/// An array that contains the addresses of the address parameter of the subroutine call commands that are aimed at calling the low priority asynchronous
	/// messages Tx subroutine.
	/// If low priority asynchronous messages are supported, such a call command is added as part of the framing commands for each minor frame.
	/// This field contains actual information only along frame run sessions, if low priority asynchronous messages are supported.
	/// The number of entries of this array that contain an actual value is stored in field wNestedMinorFrameCount.
	U32BIT dwaLowAsynchronousTxSubroutineCallAddress[sitalBcCounter_FRAMES];
	/// The address in device memory of the low priority asynchronous messages Tx subroutine.
	/// This field contains actual information only along frame run sessions, if low priority asynchronous messages are supported.
	U32BIT dwAddressOfLowAsynchronousTxSubroutine;
	/// The address in device memory of the last word of the low priority asynchronous messages Tx subroutine.
	/// This field contains actual information only along frame run sessions, if low priority asynchronous messages are supported.
	U32BIT dwLastAddressOfLowAsynchronousTxSubroutine;
	/// The size (in words) of the low priority asynchronous messages Tx subroutine.
	/// This field contains actual information only along frame run sessions, if low priority asynchronous messages are supported.
	U16BIT wSizeOfLowAsynchronousTxSubroutine;
	/// The total Tx time (in us) required for all the asynchronous messages currently included in the low priority asynchronous messages Tx subroutine.
	/// This field contains actual information only along frame run sessions, if low priority asynchronous messages are supported.
	U16BIT wTotalTxTimeOfLowAsynchronousTxSubroutine;

	/// The state of the device's GPQ.
	GeneralPurposeQueueStateStructure gpqssGpqState;
	/// A host GPQ that contains the part of the contents of the device's GPQ that's required by the user application.
	HostGeneralPurposeQueueStructure hgpqsUserGpqContents;
	/// A host GPQ that contains the part of the contents of the device's GPQ that's required by this library.
	HostGeneralPurposeQueueStructure hgpqsLibraryGpqContents;
	/// Array of data blocks.
	HostDataBlockStructure hdbsaDataBlock[sitalBcCounter_DATA_BLOCKS];
	/// Array of messages.
	HostMessageStructure hmsaMessage[sitalBcCounter_MESSAGES];
	/// Array of opcodes.
	HostCommandStructure hcsaCommand[sitalBcCounter_COMMANDS];
	/// Array of frames.
	HostFrameStructure hfsaFrame[sitalBcCounter_FRAMES];
	/// Host buffer information.
	HostBufferStructure hbsHostBuffer;
} BcStateStruct;

///	RT information and state.
/// Note: Included array and structure fields are statically defined in order to avoid dynamic memory allocations.
typedef struct RtStateStructure
{
	/// RT-specific operation options.
	U32BIT dwOptions;
	/// A flag that says whether this RT's default data block is now handled (i.e., created, read, written, mapped, &c).
	BOOLEAN bIsHandlingTheDefaultDataBlock;
	/// A data block that's used as default mapping for all subaddress and message type combinations.
	HostDataBlockStructure hdbsDefaultDataBlock;
	/// Array of data blocks.
	HostDataBlockStructure hdbsaDataBlock[sitalRtCounter_DATA_BLOCKS];
	/// A flag that says whether this RT is alternate status mode.
	BOOLEAN bIsAlternateStatusMode;
	/// A flag that says whether a circular data block is commonly used by this RT for all subaddresses.
	BOOLEAN bIsCommonCircularDataBlockUsed;
	/// The ID of a circular data block that's commonly used by this RT for all subaddresses.
	/// This field contains actual information only if field bIsCommonCircularDataBlockUsed contains TRUE.
	U16BIT wCommonCircularDataBlockId;
	/// Information on the usage of circular data blocks with the subaddresses of this RT for Rx.
	CircularDataBlockInformationStructure cdbisaSubaddressRxCommonCircularDataBlock[sitalIeee1553_SUBADDRESS_COUNT];
	/// Information on the usage of circular data blocks with the subaddresses of this RT for Tx.
	CircularDataBlockInformationStructure cdbisaSubaddressTxCommonCircularDataBlock[sitalIeee1553_SUBADDRESS_COUNT];
	/// Information on the usage of circular data blocks with the subaddresses of this RT for Rx Broadcast.
	CircularDataBlockInformationStructure cdbisaSubaddressRxBCstCommonCircularDataBlock[sitalIeee1553_SUBADDRESS_COUNT];
	/// Stack information.
	RtStackStateStructure rsssStackState;
	/// Host buffer information.
	HostBufferStructure hbsHostBuffer;
} RtStateStruct;

typedef enum 
{
	UnInitialized = 0,
	Ready,
	Running
} mRTRunningMode;

typedef struct mRtDeviceStruct_Type
{
	// This parameter points to running bus list or -1. 
	// there can be only a single running BusList per merDevice. 
	// mRT_Start links between the device and active BusList
	S16BIT RunningBusList;
	// Configuration registers array
	U16BIT Registers[32];
} mRtDeviceStruct;

typedef struct mRtBusListStruct_Type
{
	// The DeviceID that this Buslist is running on or -1.
	S16BIT RunningOnDeviceID;
	// Running Modes for this BusList
	mRTRunningMode Mode;
	// List of Elements that are part of this BusList
	U16BIT Elements[MAX_ELEMENTS];
	// Number of Elements in the BusList
	U16BIT NumOfElements;
	// A pointer to the first Element in the hardware device memory during run mode.
	U16BIT HWPointer;
} mRtBusListStruct;

typedef struct mRtElementsStruct_Type
{
	// The Buslist ID that this element is running on.
	//S16BIT BusListID;
	// Running Modes for this Element
	mRTRunningMode Mode;
	// Datablock number that is mapped to this element.
	S16BIT DataBlockID;
	// True if Datablock Id is mapped to this element
	BOOLEAN DataBlock_IsMapped;
	//Mil-Std-1553 command that this element services
	U16BIT Command_1553;
	// The Options field is loaded to the first word of the element and serves as the configuration of this element
	U16BIT Options;
	// Time Tag that was copied from the element in runtime, represents that last time that this element was served
	U32BIT TTag;
	// A pointer to this Element in the hardware device memory during run mode.
	U16BIT HWPointer;
	// The address of the Element in the HW memory
	U16BIT ElementAddress;
	// A pointer to last accessed address by the software offset from the base of the buffer (0)
	U16BIT SWOffsetPointer;
} mRtElementsStruct;

typedef struct mRtDataBlockStruct_Type
{
	// The unique device ID that contains this datablock that is mapped and running
	S16BIT DeviceIdRunningOn;
	// The Element ID that this Datablock is mapped to
	S16BIT ElementID;
	// Running Modes for this DataBlock
	mRTRunningMode Mode;
	// Data of an Element
	U16BIT* Data;
	// According to the Datablock Mode (Single = 0 | Double = 1 | Cyclics  = 2..5 | Global = 7). Can be 0-7, see details in HSID. 
	U16BIT DataBLockLength;
	// A pointer to the first word in the hardware device memory during run mode.
	U16BIT HWPointer;
	// A pointer to last accessed address by the software offset from the base of the buffer (0)
	//U16BIT SWOffsetPointer;
} mRtDataBlockStruct;



///	MT information and state.
/// Note: Included array and structure fields are statically defined in order to avoid dynamic memory allocations.
typedef struct MtStateStructure
{
	/// MT-specific operation options.
	U32BIT dwOptions;
	/// Says whether a single or double stack is used (sitalMtStackOption_*).
	U16BIT wStackMode;
	/// Stack A information.
	MtStackStateStructure msssStackStateA;
	/// Stack B information.
	MtStackStateStructure msssStackStateB;
	/// Host buffer information.
	HostBufferStructure hbsHostBuffer;
	/// A flag that says whether the user has defined a message capture trigger.
	BOOLEAN bIsMessageCaptureTriggerUsed;
	/// A flag that says whether a message capture trigger is currently triggered.
	/// This flag is set true only in case the user has defined a message capture trigger (in which case field bIsMessageCaptureTriggerUsed is set true) and no captured message triggered the defined trigger (i.e., met its terms) yet.
	BOOLEAN bIsMessageCaptureTriggerOn;
	/// The size (in words) of the portion of the host buffer that may be used to store uncounted messages before any captured message triggers the defined trigger.
	U32BIT dwPreTriggerMessageStoreSize;
} MtStateStruct;

///	Device information and state.
/// Note: Included array and structure fields are statically defined in order to avoid dynamic memory allocations.
typedef struct DeviceStateStructure
{
	/// A flag that says whether the device has already been opened.
	BOOLEAN bIsOpened;
	/// A description of the capabilities of the device.
	/// This field contains actual information only if field bIsOpened contains TRUE.
	sitalDeviceCapabilitiesStructure dcsDeviceCapabilities;
	/// A flag that says whether the device is an evaluation device, and only support a limited set of operations.
	/// This field contains actual information only if field bIsOpened contains TRUE.
	/// This field contains actual information only if field wMode contains sitalAccess_CARD.
	BOOLEAN bLimitedOperationDevice;
	/// Type of device access (sitalAccess_*).
	/// This field contains actual information only if field bIsOpened contains TRUE.
	U16BIT wAccess;
	/// Base operation mode (sitalMode_*).
	/// This field contains actual information only if field bIsOpened contains TRUE.
	U16BIT wMode;
	/// Operation mode variants (sitalModeVariant_*).
	/// This field contains actual information only if field bIsOpened contains TRUE.
	U16BIT wModeVariants;
	/// A flag that says whether special operational statistics should be collected with this device.
	/// This field contains actual information only if field bIsOpened contains TRUE.
	U16BIT bIsOperationalStatisticsCollected;
	/// A flag that says whether this device is configured to support protocol 1553-A.
	/// This field contains actual information only if field bIsOpened contains TRUE.
	U16BIT bIsProtocol1553aSupported;
	/// Current state (sitalDeviceState_*).
	/// This field contains actual information only if field bIsOpened contains TRUE.
	U16BIT wCurrentState;
	/// ISQ state.
	/// This field contains actual information only if field wMode contains sitalMode_RT or sitalMode_MT.
	/// This field contains actual information only if field bIsOpened contains TRUE.
	HostInterruptServiceQueueStateStructure hisqssIsqState;
	/// Current configuration for type of interrupt signal (sitalIrqMode_*).
	U16BIT wIrqConfig_InterruptMode;
	/// Current configuration for post-read auto-clearing of interrupt status (sitalIrqClear_*).
	U16BIT wIrqConfig_AutoClear;
	/// An external interrupt mask register that serves the user of the library.
	/// This field contains actual information only if field bIsOpened contains TRUE.
	U32BIT dwExternalImr;
	/// An internal interrupt mask register that serves the library itself.
	/// This field contains actual information only if field bIsOpened contains TRUE.
	U32BIT dwInternalImr;
	/// A pointer to the user's interrupt service routine, which is called whenever a relevant interrupt occurs with this device.
	/// Setting an ISR is done in an OS-Dependant way, and may even fail, in which case the device will function without ISR.
	/// This field contains actual information only if field bIsOpened contains TRUE.
	USER_ISR_FUNCTION funcpUserIsr;
	/// A pointer to the user's asynchronous messages interrupt service routine, which is called whenever some high priority asynchronous message violates the time frame of a minor frame.
	/// Setting an ISR is done in an OS-Dependant way, and may even fail, in which case the device will function without ISR.
	/// This field contains actual information only if field bIsOpened contains TRUE.
	ASYNCHRONOUS_MESSAGE_ISR_FUNCTION funcpAsynchronousMessagesIsr;
	/// An image of the required device registers.
	/// This field contains actual information only if field bIsOpened contains TRUE.
	HostRegistersStructure hrsRegistersImage;
	/// A counter that counts the number of occurring interrupts.
	/// Only used along internal tests that also verify the correct operation of the interrupt system.
	U32BIT dwInterruptCount;
	/// The IRQ status that has been informed by the device.
	/// Only used along internal tests that also verify the correct operation of the interrupt system.
	U32BIT dwIrqStatus;
	///	Device memory allocations map.
	/// This field contains actual information only if field bIsOpened contains TRUE.
	HostDeviceMemoryMapStructure hdmmsDeviceMemoryMap;
	union
	{
		/// BC state information.
		/// This field contains actual information only if field bIsOpened contains TRUE.
		/// This field contains actual information only if field wMode contains sitalMode_BC.
		BcStateStructure bsBcState;
		/// RT & MT state information.
		/// This field contains actual information only if field bIsOpened contains TRUE.
		/// This field contains actual information only if field wMode contains sitalMode_RT, sitalMode_MT, or sitalMode_RTMT.
		struct
		{
			/// RT state information.
			/// This field contains actual information only if field bIsOpened contains TRUE.
			/// This field contains actual information only if field wMode contains sitalMode_RT or sitalMode_RTMT.
			RtStateStructure rsRtState;
			/// MT state information.
			/// This field contains actual information only if field bIsOpened contains TRUE.
			/// This field contains actual information only if field wMode contains sitalMode_MT or sitalMode_RTMT.
			MtStateStructure msMtState;			
		} rms;
	};
} DeviceStateStruct;

////////////
// ARINC429
////////////
typedef struct ArincDeviceStructure{
	bool DeviceType_Tx_nRx;	// Rx=0; Tx=1;
	bool ChannelIsOpen;		// Opened by call to open = 1
	bool ChannelIsHighSpeed;// HighSpeed =1
}ArincDeviceStruct;

// ARINC429 Following bits are same for TX and RX modes:
#define STLA429_CFG_HIGH_RATE          0x0001  ///< Data rate: 100 KHz
#define STLA429_CFG_LOW_RATE           0x0000  ///< Data rate: 12.5 KHz
#define STLA429_CFG_MASK_RATE          0x0001
#define STLA429_CFG_PARITY_NONE        0x0000  ///< Data parity: none. MSB can be used as data.
#define STLA429_CFG_PARITY_EVEN        0x0002  ///< Data parity: even
#define STLA429_CFG_PARITY_ODD         0x0006  ///< Data parity: odd
#define STLA429_CFG_MASK_PARITY        0x0006  //   Mask for parity bits

// ARINC429 Following bits apply only for RX mode:
#define STLA429_CFG_RX_LABEL_MATCH     0x0008  ///< enable label matching
#define STLA429_CFG_MASK_RX_LABELS     0x0008
#define STLA429_CFG_RX_DECODER_ENABLE  0x0010
#define STLA429_CFG_RX_DECODER_DISABLE 0x0000
#define STLA429_CFG_MASK_RX_DECODER    0x0070

#define A_DEF_RX_TIMEOUT_MS 16 // Default RX timeout (in ms)


//// Internal-function declarations.
//
//INT16 a429_Write(UINT16 card, UINT16 channel, U32BIT address, DWORD len, DWORD* buffer);
//INT16 a429_Read(UINT16 card, UINT16 channel, U32BIT address, DWORD len, DWORD* buffer);

S16BIT _DECL sitalMRT_HostBuffer_Free (S16BIT swDevice);
S16BIT _DECL WMem(U16BIT swDevice, U16BIT Address, U16BIT Data);
S16BIT _DECL WReg(U16BIT swDevice, U16BIT Address, U16BIT Data);
S16BIT _DECL sital_mRt_Get_DataBlock_Words_Pending (U16BIT wElement, U16BIT wDataBlock, U16BIT* numPendingWords);
S16BIT _DECL sital_mRt_SetErrors (U16BIT swDevice, U16BIT wErrorType, U16BIT wErrorParams);
S16BIT _DECL sitalBc_SetErrors (U16BIT swDevice, U16BIT wErrorType, U16BIT wErrorParams);

S16BIT _DECL rs485ClearNumberOfBytes(S16BIT uiLine, S16BIT numOfBytes);

S16BIT _DECL MemModeToLength(U16BIT Mode);
S16BIT _DECL DumpHostToDevice(U16BIT swDevice, U16BIT* AddSource, U16BIT ADDDestination, U16BIT Length, U16BIT iterations);
S16BIT _DECL DumpDeviceToHost(U16BIT swDevice, U16BIT AddSource, U16BIT* AddDestination, U16BIT Length, U16BIT iterations);
U16BIT _DECL CyclicIncrement(U16BIT source, U16BIT size, U16BIT modulu);

S16BIT generalValidatingHelper(BOOLEAN bValidateDevice, S16BIT swDevice, 
								BOOLEAN bValidateStateReady, BOOLEAN bValidateStateRun, BOOLEAN bValidateStateReset, 
								BOOLEAN bValidateAccessCard, BOOLEAN bValidateAccessSim, BOOLEAN bValidateAccessUser );
S16BIT helperLibraries_Load (void);
S16BIT library_GetVersion (	U16BIT* wpMajorVersion,
							U16BIT* wpMinorVersion,
							U16BIT* wpBuildNumber,
							U16BIT* wpRevisionNumber);
S16BIT initializeLibrary(void);
S16BIT uninitializeLibrary(void);
S16BIT device_Register_UpdateDevice (S16BIT swDevice);
S16BIT device_Register_UpdateImage (	S16BIT swDevice,
										U16BIT wRegisterAddress,
										U16BIT wMask,
										U16BIT wValue);
S16BIT device_Register_GetImage (	S16BIT swDevice,
									U16BIT wRegisterAddress,
									U16BIT wMask,
									U16BIT* wpValue);
S16BIT device_Reset (S16BIT swDevice);
S16BIT _DECL device_TestIsr (const InterruptInformationStructure* iisp);
S16BIT _DECL bc_HandleInterrupt (const InterruptInformationStructure* iisp);
S16BIT _DECL rt_HandleInterrupt (const InterruptInformationStructure* iisp);
S16BIT _DECL mt_HandleInterrupt (const InterruptInformationStructure* iisp);
S16BIT _DECL rtmt_HandleInterrupt (const InterruptInformationStructure* iisp);
S16BIT bc_ConfigureDefault (S16BIT swDevice);
S16BIT rt_ConfigureDefault (S16BIT swDevice);
S16BIT mt_ConfigureDefault (S16BIT swDevice);
S16BIT rtmt_ConfigureDefault (S16BIT swDevice);
S16BIT bc_Gpq_Read (S16BIT swDevice, sitalGpqEntryStructure* gespGpqEntry, BOOLEAN bIsUserInitiatedGpqReadRequest);
S16BIT bc_Gpf_SetState (S16BIT swDevice, U16BIT wGpfNumber, U16BIT wEffect);
S16BIT bc_Frame_WriteCommands (S16BIT swDevice, U16BIT wFrameId, NestingStackStructure* nsspNestingStack);
S16BIT bc_Frame_WriteMajor (S16BIT swDevice, U16BIT wFrameId, NestingStackStructure* nsspNestingStack);
S16BIT bc_Frame_WriteMinor (S16BIT swDevice, U16BIT wFrameId, NestingStackStructure* nsspNestingStack);
S16BIT bc_Frame_Write (S16BIT swDevice, U16BIT wFrameId, NestingStackStructure* nsspNestingStack);
S16BIT bc_Message_Write (	S16BIT swDevice,
							S16BIT swMessageId,
							S16BIT swDataBlockIdForMessage1,
							U16BIT wBcControlWordForMessage1,
							U16BIT wCommandWord1ForMessage1,
							U16BIT wCommandWord2ForMessage1,
							U16BIT wGapTimeForMessage1,
							S16BIT swDataBlockIdForMessage2,
							U16BIT wBcControlWordForMessage2,
							U16BIT wCommandWord1ForMessage2,
							U16BIT wCommandWord2ForMessage2,
							U16BIT wGapTimeForMessage2,
							U32BIT dwOptions,
							HostMessageStructure* hmspMessage,
							HostDataBlockStructure* hdbspDataBlock1,
							HostDataBlockStructure* hdbspDataBlock2,
							BOOLEAN bIsNewMessage);
S16BIT bc_Message_GetByIdRaw (	S16BIT swDevice,
								S16BIT swMessageId,
								U16BIT* wapBuffer,
								U16BIT wIsPurgeRequired);
S16BIT bc_Message_GetInformation (	S16BIT swDevice,
									U16BIT *wpMessageBuffer,
									U16BIT* wpTxTime,
									U16BIT* wpType,
									U16BIT* wpDataWordsCount);
S16BIT bc_HostBuffer_RecordTransmittedMinorFrame (S16BIT swDevice, S16BIT swFrameId);
S16BIT rt_Initialize (	S16BIT swDevice,
						U16BIT wCommandStackSize,
						U32BIT dwOptions);
S16BIT rt_Start (S16BIT swDevice);
BOOLEAN rt_DataBlock_GetSubaddressLookupInformation (	HostDataBlockStructure* hdbspDataBlock,
														U16BIT* wpMappedSubaddress,
														U32BIT* dwpLookupLocation,
														U32BIT* dwpControlWordLocation);
S16BIT rt_Message_GetFromStackRaw (S16BIT swDevice,
									U16BIT* wapBuffer,
									U16BIT* wpMessageTimeTagRolloverCounter,
									BOOLEAN bIsNextMessageRequired,
									BOOLEAN bIsMessagePurgeRequired);
S16BIT mt_Initialize (	S16BIT swDevice,
						U16BIT wStackMode,
						U16BIT wCommandStackSize,
						U16BIT wDataStackSize,
						U32BIT dwOptions);
S16BIT mt_Start (S16BIT swDevice);
S16BIT mt_ResetStack (S16BIT swDevice, MtStackStateStructure* mssspTargetStackState);
S16BIT mt_ResetStacks (S16BIT swDevice);
S16BIT mt_MessageCaptureTrigger_ExamineMessage (S16BIT swDevice, U16BIT* wapBuffer);
S16BIT mt_Message_GetFromStackRaw (	S16BIT swDevice,
									MtStackStateStructure* mssspTargetStackState,
									U16BIT* wapBuffer,
									U16BIT* wpMessageTimeTagRolloverCounter,
									BOOLEAN bIsNextMessageRequired,
									BOOLEAN bIsMessagePurgeRequired);
S16BIT hoo9_Mt_MessageMonitoring_Configure (	S16BIT swDevice,
												U16BIT wRt,
												U16BIT wMessageDirection,
												U64BIT qwRtSubaddressMask,
												BOOLEAN bEnable);
S16BIT rtmt_HostBuffer_Message_FindContainer (S16BIT swDevice, U16BIT wMessageLocationAndRemoval, U16BIT* wpRequestedMessageContainerHostBuffer);



#ifdef __cplusplus
}
#endif



#endif // stld1553_internal_INCLUDED