/// @file
/// stld1553 library's device memory management definitions and declarations.

// Description  : A header file that contains the implementation of stld1553 library's device memory management functions
// Version      : 1.0.0.0
// Author       : Sital Technology R&D
//
// Modification history:
//



#ifndef stld1553_memoryManager_INCLUDED
#define stld1553_memoryManager_INCLUDED



#ifdef __cplusplus
// C++ compilers mangle function names, unless the function definitions are protected with extern "C"{}.
extern "C" {
#endif



// Enumeration definitions.



// Constant definitions.



// Macro definitions.



// Type/structure definitions.
struct HostDeviceMemoryMapStructure;



// Type/structure definitions.

///	Device memory allocations map.
typedef struct HostDeviceMemoryMapStructure
{
	/// An array of DWORDs in which a single bit is dedicated per continuous 32-word segment of device memory.
	/// The first bit corresponds the segment that's made of words 0-31, the second bit - words 32-63, etc.
	/// Such a bit is set off when the corresponding segment is free for use, and on if it is currently allocated.
	/// Note:
	/// - The maximum size of device memory is sitalMaximum_SIZE_OF_DEVICE_MEMORY words (which is assumed to be divisible by 32).
	/// - The maximum number of continuous 32-word segments is, hence, (sitalMaximum_SIZE_OF_DEVICE_MEMORY >> 5).
	/// - The 32 bits in each DWORD entry of this array represent 32 units of 32-word segment.
	/// - Therefore, the number of DWORD entries in this array must be (sitalMaximum_SIZE_OF_DEVICE_MEMORY >> 10).
	U32BIT dwaMemoryMap[sitalMaximum_SIZE_OF_DEVICE_MEMORY >> 10];
	/// The size (in words) of the RAM memory section of this device.
	U32BIT dwRamSize;
	/// The current border address of top (=regular) allocation section, which is the next address that may be allocated for this section.
	/// See description of this top section in the documentation for each of the Device_Memory_TopSection_* functions.
	/// Note:
	/// - As device memory is divided for allocation purposes into 32-word segments, an allocation of any word within a 32-word segment
	///   entails the allocation of the whole of this segment, and this border therefore moves to the top of the following 32-word segment.
	U32BIT dwCurrentTopSectionBorderAddress;
	/// The current border address of bottom (=special) allocation section, which is the next address that may be allocated for this section.
	/// See description of this bottom section in the documentation for each of the Device_Memory_BottomSection_* functions.
	/// Note:
	/// - As device memory is divided for allocation purposes into 32-word segments, an allocation of any word within a 32-word segment
	///   entails the allocation of the whole of this segment, and this border therefore moves to the bottom of the preceding 32-word segment.
	U32BIT dwCurrentBottomSectionBorderAddress;
} HostDeviceMemoryMapStruct;



// Internal-function declarations.

S16BIT Device_Memory_Initialize (HostDeviceMemoryMapStructure* hdmmspDeviceMemoryMap, U32BIT dwRamSize);
S16BIT Device_Memory_TopSection_FreeRegion (HostDeviceMemoryMapStructure* hdmmspDeviceMemoryMap, U32BIT dwBaseRegionAddress, U32BIT dwBottomRegionAddress);
S16BIT Device_Memory_TopSection_CatchRegion (HostDeviceMemoryMapStructure* hdmmspDeviceMemoryMap, U32BIT dwBaseRegionAddress, U32BIT dwBottomRegionAddress);
S16BIT Device_Memory_TopSection_AllocateContinuity (	HostDeviceMemoryMapStructure* hdmmspDeviceMemoryMap,
														U32BIT dwBaseRegionAddress,
														U32BIT dwBottomRegionAddress,
														U32BIT* dwpAllocationSize,
														U16BIT wAlignment,
														BOOLEAN* bpIsAllocationSuccessfullyAccomplished,
														U32BIT* dwpAllocationBaseAddress);
S16BIT Device_Memory_BottomSection_FreeAll (HostDeviceMemoryMapStructure* hdmmspDeviceMemoryMap);
S16BIT Device_Memory_BottomSection_AllocateContinuity (	HostDeviceMemoryMapStructure* hdmmspDeviceMemoryMap,
														U32BIT* dwpAllocationSize,
														U16BIT wAlignment,
														BOOLEAN* bpIsAllocationSuccessfullyAccomplished,
														U32BIT* dwpAllocationBaseAddress);


// Exported-function declarations.



#ifdef __cplusplus
}
#endif



#endif // stld1553_memoryManager_INCLUDED
