/// @file
/// Codes returned by stl1553 and stl1553-driver-API library functions.

// Description  : A header file that contains stld1553 library's exported definitions and declarations
// Version      : 1.0.0.0
// Author       : Sital Technology R&D
//
// Modification history:
//



#ifndef stld1553_ReturnCodes_INCLUDED
#define stld1553_ReturnCodes_INCLUDED



#ifdef __cplusplus
// C++ compilers mangle function names, unless the function definitions are protected with extern "C"{}.
extern "C" {
#endif



// Constant definitions.

// Function return codes.
// Note:
// - Some of below return codes aren't actually used, and are only retained in order to stay compatible with DDC.
// - Some of below return codes create a non required duplicity, and this situation is only retained in order to stay compatible with DDC.
#define sitalReturnCode_SUCCESS												(0U)		///< No error occurred. (Equivalent DDC definition: ACE_ERR_SUCCESS)
#define sitalReturnCode_ReadIsqEntry_NO_NEW_ONES							(0U)		///< Found no new entry in the interrupt status queue.
#define sitalReturnCode_ReadIsqEntry_READ_NEW_ENTRY							(1U)		///< Found a single new entry in the interrupt status queue.
#define sitalReturnCode_ReadIsqEntry_READ_NEW_ENTRY_AND_DETECTED_OVERRUN	(2U)		///< Found several new entries in the interrupt status queue, what implies that one or more entries have been lost.
#define sitalReturnCode_ReadGpqEntry_NO_NEW_ONES							(0U)		///< Found no new entry in the general purpose queue.
#define sitalReturnCode_ReadGpqEntry_READ_NEW_ENTRY							(1U)		///< Found a single new entry in the general purpose queue.
#define sitalReturnCode_ReadGpqEntry_READ_NEW_ENTRY_AND_DETECTED_OVERRUN	(2U)		///< Found several new entries in the general purpose queue, what implies that one or more entries have been lost.
// (From here on: warning return codes)
#define sitalReturnCode_POSSIBLY_DETRIMENTAL_CONFIGURATION					(400U)		///< Warning: Configuration possibly detrimental to card performance. (Equivalent DDC definition: ACE_WRN_RT_CFG_INVALID)
// (From here on: error return codes)
#define sitalReturnCode_UNKNOWN_ERROR										(-1)		///< An unknown error occurred.
#define sitalReturnCode_VERSION_ERROR										(-2)		///< Failed to get version number.
#define sitalReturnCode_LIBRARY_LOAD_ERROR									(-3)		///< Failed to load a required function library.
#define sitalReturnCode_SEMAPHORE_OPERATION_ERROR							(-4)		///< Failed to create or operate semaphore.
#define sitalReturnCode_INVALID_DEVICE_NUMBER								(-50)		///< Bad device number. (Equivalent DDC definition: ACE_ERR_INVALID_DEVNUM)
#define sitalReturnCode_INVALID_ACCESS										(-51)		///< Bad access type. (Equivalent DDC definition: ACE_ERR_INVALID_ACCESS)
#define sitalReturnCode_INVALID_MODE										(-52)		///< Bad mode type. (Equivalent DDC definition: ACE_ERR_INVALID_MODE)
#define sitalReturnCode_INVALID_STATE										(-53)		///< Bad device state. (Equivalent DDC definition: ACE_ERR_INVALID_STATE)
#define sitalReturnCode_INVALID_MEMORY_SIZE									(-54)		///< Bad memory size. (Equivalent DDC definition: ACE_ERR_INVALID_MEMSIZE)
#define sitalReturnCode_INVALID_ADDRESS										(-55)		///< Bad memory/register address. (Equivalent DDC definition: ACE_ERR_INVALID_ADDRESS)
#define sitalReturnCode_INVALID_OPERATING_SYSTEM							(-56)		///< Bad operating system. (Equivalent DDC definition: ACE_ERR_INVALID_OS)
#define sitalReturnCode_INVALID_ALLOCATION									(-57)		///< Bad memory allocation. (Equivalent DDC definition: ACE_ERR_INVALID_MALLOC)
#define sitalReturnCode_INVALID_BUFFER										(-58)		///< Bad buffer. (Equivalent DDC definition: ACE_ERR_INVALID_BUF)
#define sitalReturnCode_INVALID_ADDRESS_MODE								(-59)		///< Bad addressing mode. (Equivalent DDC definition: ACE_ERR_INVALID_ADMODE)
#define sitalReturnCode_INVALID_REGISTER_ADDRESS							(-60)		///< Bad simulated write register. (Equivalent DDC definition: ACE_ERR_SIMWRITEREG)
#define sitalReturnCode_INVALID_TIME_TAG_RESOLUTION							(-61)		///< Bad time tag resolution. (Equivalent DDC definition: ACE_ERR_TIMETAG_RES)
#define sitalReturnCode_INVALID_RESPONSE_TIMEOUT							(-62)		///< Bad response timeout value. (Equivalent DDC definition: ACE_ERR_RESPTIME)
#define sitalReturnCode_INVALID_CLOCK_FREQUENCY								(-63)		///< Bad clock input value. (Equivalent DDC definition: ACE_ERR_CLOCKIN)
#define sitalReturnCode_INVALID_MESSAGE_STRUCTURE							(-64)		///< Bad message structure. (Equivalent DDC definition: ACE_ERR_MSGSTRUCT)
#define sitalReturnCode_INVALID_PARAMETER									(-65)		///< Bad parameter. (Equivalent DDC definition: ACE_ERR_PARAMETER)
#define sitalReturnCode_INVALID_MODE_OPTIONS								(-66)		///< Invalid mode options. (Equivalent DDC definition: ACE_ERR_INVALID_MODE_OP)
#define sitalReturnCode_OPERATIONAL_STATISTICS_NOT_ENABLED					(-67)		///< Operational statistics collection not enabled. (Equivalent DDC definition: ACE_ERR_METRICS_NOT_ENA)
#define sitalReturnCode_NOT_SUPPORTED										(-68)		///< Function not supported. (Equivalent DDC definition: ACE_ERR_NOT_SUPPORTED)
#define sitalReturnCode_ISQ_DISABLED										(-69)		///< ISQ needs to be enabled for this function. (Equivalent DDC definition: ACE_ERR_ISQ_DISABLED)
#define sitalReturnCode_OPERATION_FAIL										(-70)		///< Operation failed. (Equivalent DDC definition: ACE_ERR_TASK_FAIL)
#define sitalReturnCode_INVALID_CAN_ADDRESS									(-71)		///< Invalid CAN address. (Equivalent DDC definition: ACE_ERR_CANADDR)
#define sitalReturnCode_INVALID_DIO_PORT									(-72)		///< Function should be DIO to perform action, not HUB. (Equivalent DDC definition: ACE_ERR_DIO)
#define sitalReturnCode_REGISTERS_ACCESS_FAIL								(-80)		///< Unable to access registers. (Equivalent DDC definition: ACE_ERR_REG_ACCESS)
#define sitalReturnCode_INVALID_CARD										(-81)		///< Invalid card. (Equivalent DDC definition: ACE_ERR_INVALID_CARD)
#define sitalReturnCode_DRIVER_OPEN_FAIL									(-82)		///< Unable to open device driver. (Equivalent DDC definition: ACE_ERR_DRIVER_OPEN)
#define sitalReturnCode_MAPPED_MEMORY_ACCESS_FAIL							(-83)		///< Error accessing mapped memory. (Equivalent DDC definition: ACE_ERR_MAPMEM_ACC)
#define sitalReturnCode_INVALID_CARD_NUMBER									(-84)		///< Bad card number. (Equivalent DDC definition: ACE_ERR_INVALID_CARDNUM)
#define sitalReturnCode_UNDEFINED_NODE										(-100)		///< Could not find node in list. (Equivalent DDC definition: ACE_ERR_NODE_NOT_FOUND)
#define sitalReturnCode_NODE_NOT_MEMORY_BLOCK								(-101)		///< Node not a memory block. (Equivalent DDC definition: ACE_ERR_NODE_MEMBLOCK)
#define sitalReturnCode_NODE_EXISTS											(-102)		///< Node ID already in list. (Equivalent DDC definition: ACE_ERR_NODE_EXISTS)
#define sitalReturnCode_ALLOCATION_FAIL										(-150)		///< Could not allocate memory block. (Equivalent DDC definition: ACE_ERR_MEMMGR_FAIL)
#define sitalReturnCode_INVALID_TEST_STRUCTURE								(-200)		///< Bad test result structure. (Equivalent DDC definition: ACE_ERR_TEST_BADSTRUCT)
#define sitalReturnCode_INVALID_FILE										(-201)		///< Invalid file. (Equivalent DDC definition: ACE_ERR_TEST_FILE)
#define sitalReturnCode_MT_INVALID_STACK_OPTION								(-300)		///< Invalid buffer mode. (Equivalent DDC definition: ACE_ERR_MT_BUFTYPE)
#define sitalReturnCode_MT_INVALID_COMMAND_STACK_SIZE						(-301)		///< Invalid command stack size. (Equivalent DDC definition: ACE_ERR_MT_CMDSTK)
#define sitalReturnCode_MT_INVALID_DATA_STACK_SIZE							(-302)		///< Invalid data stack size. (Equivalent DDC definition: ACE_ERR_MT_DATASTK)
#define sitalReturnCode_MT_INVALID_RT_ADDRESS								(-303)		///< Invalid RT address. (Equivalent DDC definition: ACE_ERR_MT_FILTER_RT)
#define sitalReturnCode_MT_INVALID_DIRECTION_BIT							(-304)		///< Invalid TR bit. (Equivalent DDC definition: ACE_ERR_MT_FILTER_TR)
#define sitalReturnCode_MT_INVALID_SUBADDRESS_BUFFER						(-305)		///< Invalid subaddress buffer. (Equivalent DDC definition: ACE_ERR_MT_FILTER_SA)
#define sitalReturnCode_MT_INVALID_STACK_SELECTOR							(-306)		///< Bad MT stack location. (Equivalent DDC definition: ACE_ERR_MT_STKLOC)
#define sitalReturnCode_MT_INVALID_MESSAGE_LOCATION							(-307)		///< Bad MT message location. (Equivalent DDC definition: ACE_ERR_MT_MSGLOC)
#define sitalReturnCode_MT_INVALID_HOST_BUFFER_SIZE							(-308)		///< Bad host buffer size. (Equivalent DDC definition: ACE_ERR_MT_HBUFSIZE)
#define sitalReturnCode_MT_HOST_BUFFER_NOT_INSTALLED						(-309)		///< Host buffer not allocated. (Equivalent DDC definition: ACE_ERR_MT_HBUF)
#define sitalReturnCode_RT_AND_MT_NON_COMBINED_HOST_BUFFER_MODE				(-310)		///< RT&MT combined host buffer wasn't requested upon RT&MT device initialization. (Equivalent DDC definition: ACE_ERR_RTMT_COMBO_HBUF)
#define sitalReturnCode_RT_AND_MT_INVALID_HOST_BUFFER_SIZE					(-311)  	///< Bad RT&MT host buffer size. (Equivalent DDC definition: ACE_ERR_RTMT_HBUFSIZE)
#define sitalReturnCode_RT_AND_MT_HOST_BUFFER_NOT_INSTALLED					(-312)   	///< RT&MT host buffer not allocated. (Equivalent DDC definition: ACE_ERR_RTMT_HBUF)
#define sitalReturnCode_RT_AND_MT_INVALID_MESSAGE_LOCATION					(-313)   	///< Bad RT&MT message location. (Equivalent DDC definition: ACE_ERR_RTMT_MSGLOC)
#define sitalReturnCode_RT_DATA_BLOCK_EXISTS								(-400)		///< Data block already exists. (Equivalent DDC definition: ACE_ERR_RT_DBLK_EXISTS)
#define sitalReturnCode_RT_DATA_BLOCK_ALLOCATION_FAIL						(-401)		///< Data block allocation failed. (Equivalent DDC definition: ACE_ERR_RT_DBLK_ALLOC)
#define sitalReturnCode_RT_DATA_BLOCK_MAPPED								(-402)		///< Data block linked to SA. (Equivalent DDC definition: ACE_ERR_RT_DBLK_MAPPED)
#define sitalReturnCode_RT_DATA_BLOCK_NOT_CIRCULAR							(-403)		///< Data block not a circular buffer. (Equivalent DDC definition: ACE_ERR_RT_DBLK_NOT_CB)
#define sitalReturnCode_RT_HOST_BUFFER_NOT_INSTALLED						(-410)		///< RT host buffer not allocated. (Equivalent DDC definition: ACE_ERR_RT_HBUF)
#define sitalReturnCode_BC_OBJECT_ALREADY_EXISTS							(-500)		///< Object already exists in BC device memory. (Equivalent DDC definition: ACE_ERR_BC_DBLK_EXISTS)
#define sitalReturnCode_BC_DATA_BLOCK_ALLOCATION_FAIL						(-501)		///< Data block allocation failed. (Equivalent DDC definition: ACE_ERR_BC_DBLK_ALLOC)
#define sitalReturnCode_BC_INVALID_DATA_BLOCK_SIZE							(-502)		///< Data block size incorrect. (Equivalent DDC definition: ACE_ERR_BC_DBLK_SIZE)
#define sitalReturnCode_UNDEFINED_DATA_BLOCK								(-503)		///< Data block not found. (Equivalent DDC definition: ACE_ERR_UNRES_DATABLK)
#define	sitalReturnCode_UNDEFINED_MESSAGE_BLOCK								(-504)		///< Message block not found. (Equivalent DDC definition: ACE_ERR_UNRES_MSGBLK)
#define sitalReturnCode_ILLEGAL_FRAME										(-505)		///< Illegal frame (e.g., causes underflow error). (Equivalent DDC definition: ACE_ERR_UNRES_FRAME)
#define sitalReturnCode_UNDEFINED_COMMAND									(-506)		///< Opcode block not found. (Equivalent DDC definition: ACE_ERR_UNRES_OPCODE)
#define sitalReturnCode_UNRESOLVED_JUMP										(-507)		///< Jump address out of frame. (Equivalent DDC definition: ACE_ERR_UNRES_JUMP)
#define sitalReturnCode_NOT_MAJOR_FRAME										(-508)		///< Frame not a major frame. (Equivalent DDC definition: ACE_ERR_FRAME_NOT_MAJOR)
#define sitalReturnCode_SUITABLE_ASYNCHRONOUS_MODE_UNDEFINED				(-509)		///< A suitable asynchronous mode has not been configured. (Equivalent DDC definition: ACE_ERR_NOT_ASYNC_MODE)
#define sitalReturnCode_UNRESOLVED_ASYNCHRONOUS_COMMAND						(-510)		///< Asynchronous opcode block not found. (Equivalent DDC definition: ACE_ERR_UNRES_ASYNC_OP)
#define sitalReturnCode_ASYNCHRONOUS_LIST_IS_EMPTY							(-511)  	///< Asynchronous message list is empty. (Equivalent DDC definition: ACE_ERR_UNRES_ASYNC_ID)
#define sitalReturnCode_ASYNCHRONOUS_LIST_NOT_EMPTY							(-512)   	///< Asynchronous message list is not empty. (Equivalent DDC definition: ACE_ERR_ASYNC_NOT_EMPTY)
#define sitalReturnCode_ASYNCHRONOUS_MESSAGE_ERROR							(-513)		///< Error with asynchronous message (e.g., maximum possible such messages already defined, not a suitable dual message, Tx failed). (Equivalent DDC definition: ACE_ERR_ASYNC_MSG)
#define sitalReturnCode_MESSAGE_ERROR										(-514)		///< Message error (e.g., message Tx not completed yet)
#define sitalReturnCode_ASYNCHRONOUS_SUBROUTINE_BUSY						(-515)		///< Cannot access an asynchronous message Tx subroutine while accessed by the device.
#define sitalReturnCode_NO_FRAME_TIME_SET_FOR_MAJOR_FRAME					(-516)		///< Frame time was not specified for currently running major frame.
#define sitalReturnCode_SYNCHRONIZATION_FAIL								(-517)		///< Failed to synchronize a required operation.
#define sitalReturnCode_BC_POSSIBLY_DETRIMENTAL_OPCODE						(500U) 		///< Opcode could cause detrimental performance. (Equivalent DDC definition: ACE_WRN_BC_OPCODE_INVALID)
#define sitalReturnCode_INVALID_HOST_BUFFER_SIZE							(-600)		///< Host buffer size incompatible. (Equivalent DDC definition: ACE_ERR_HBUFSIZE)
#define sitalReturnCode_HOST_BUFFER_NOT_INSTALLED							(-601)		///< Host buffer not allocated. (Equivalent DDC definition: ACE_ERR_HBUF)
#define sitalReturnCode_TOO_MANY_DEVICES									(-700)		///< Max number of devices reached. (Equivalent DDC definition: ACE_ERR_TOO_MANY_DEVS)
#define sitalReturnCode_DEVICE_CONNECTION_FAIL								(-800)		///< Error connecting to device. (Equivalent DDC definition: ACE_RESOURCE_REQ_ERR)
#define sitalReturnCode_WRITE_ERROR											(-801)		///< Error writing to device. (Equivalent DDC definition: ACE_IOWRITE_ERR)
#define sitalReturnCode_READ_ERROR											(-802)		///< Error reading from device. (Equivalent DDC definition: ACE_IOREAD_ERR)
#define sitalReturnCode_MEMORY_MAP_FAIL										(-803)		///< Error mapping/dismapping physical to virtual. (Equivalent DDC definition: ACE_MEM_MAP_ERR)
#define sitalReturnCode_TASK_SPAWN_FAIL										(-804)		///< Error creating and running task. (Equivalent DDC definition: ACE_TASK_SPAWN_ERR)
#define sitalReturnCode_INVALID_MESSAGE_TYPE								(-1000)		///< The raw representation of the message couldn't be analyzed.
#define sitalReturnCode_INVALID_RT_ADDRESS									(-1001)		///< Invalid RT address.
#define sitalReturnCode_INVALID_DIRECTION_BIT								(-1002)		///< Invalid Rx/Tx selector.
#define sitalReturnCode_INVALID_SUBADDRESS_OR_MODE_SELECTOR					(-1003)		///< Invalid subaddress/mode selector.
#define sitalReturnCode_INVALID_WORD_COUNT_OR_MODE_CODE						(-1004)		///< Invalid word-count/mode-code.
#define sitalReturnCode_INVALID_MESSAGE_OPTIONS								(-1005)		///< Invalid message options.
#define sitalReturnCode_FRAME_NESTING_STACK_OVERFLOW						(-1006)		///< The maximum number of frame IDs in the nesting stack has been exceeded (see the documentation for function sitalBc_Start).
#define sitalReturnCode_NESTED_MAJOR_FRAME									(-1007)		///< Same/another major frame is nested within the major frame whose execution is requested.
#define sitalReturnCode_FRAME_NESTING_RECURSION								(-1008)		///< A minor frame is nested within itself.
#define sitalReturnCode_MESSAGE_NOT_DETECTED								(-1009)		///< An expected message was not detected.
#define sitalReturnCode_TEST_FAIL											(-1010)		///< Test failed (though the test function succeeded in performing all its actions).
#define sitalReturnCode_LIMITED_DEVICE										(-1011)		///< Unsupported by an evaluation device, which is only capable of limited operation.
#define sitalReturnCode_DEVICE_BUSY											(-1012)		///< Device busy.

#define sitalReturnCode_BUSLIST_ALREADY_EXISTS								(-2000)		///User tried to create a buslist that was previously created.
#define sitalReturnCode_ELEMENT_ALREADY_EXISTS								(-2001)		///
#define sitalReturnCode_DATABLOCK_ALREADY_EXISTS							(-2002)		///
#define sitalReturnCode_DATABLOCK_SIZE_ASSINGMENT_ERROR						(-2003)		
#define sitalReturnCode_DATABLOCK_SIZE_TOO_SMALL							(-2004)		
#define sitalReturnCode_MAPPING_UNREADY_CONSTRUCTS							(-2005)		
#define sitalReturnCode_BUSLIST_CONTAINS_TOO_MANY_ELEMENTS					(-2006)		
#define sitalReturnCode_BUSLIST_IS_RUNNING									(-2007)		
#define sitalReturnCode_MRT_CODE_IN_REG_1A_INCORRECT						(-2008)		
#define sitalReturnCode_MRT_WRITING_TO_UNINITIALIZED_DATABLOCK				(-2009)		
#define sitalReturnCode_MRT_WRITING_TO_UNINITIALIZED_ELEMENT				(-2010)		
#define sitalReturnCode_MRT_WRITING_TO_UNMAPPED_DATABLOCK					(-2011)		
#define sitalReturnCode_MRT_ACCESSING_INVALID_DEVICE_ID						(-2012)		
#define sitalReturnCode_MRT_REQUESTED_ID_EXCEEDED_MAX_ALLOWED				(-2013)
#define sitalReturnCode_ELEMENT_IS_RUNNING									(-2014)
#define sitalReturnCode_DATABLOCK_IS_RUNNING								(-2015)
#define sitalReturnCode_MRT_REQUESTED_ID_UNINITIALIZED						(-2016)
#define sitalReturnCode_DATABLOCK_NOT_MAPPED_TO_ELEMENT						(-2017)
#define sitalReturnCode_ELEMENT_NOT_MAPPED_TO_BUSLIST						(-2018)
#define sitalReturnCode_MRT_READ_DATA_WHILE_TX_NOT_ALLOWED					(-2019)
#define sitalReturnCode_COMMAND_MODE_CODE_NOT_SUPPORTED						(-2020)
#define sitalReturnCode_READING_EMPTY_BUFFER								(-2021)
#define sitalReturnCode_MRT_NOT_IN_RUNNING_MODE								(-2022)
#define sitalReturnCode_MRT_STOP_RUN_FAILED									(-2023)
#define sitalReturnCode_MRT_START_RUN_FAILED								(-2024)
#define sitalReturnCode_MRT_GET_TIMETAG_FAILED_DATA_INCONSISTENT			(-2025)
#define sitalReturnCode_MRT_TIME_REQUESTED_NOT_IN_VALID_RANGE				(-2026)
#define sitalReturnCode_MRT_TIME_VALUE_REQUESTED_IS_INVALID					(-2027)
#define sitalReturnCode_MESSGE_NUMBER_TO_INSERT_ERROR_IS_INVALID			(-2028)
#define sitalReturnCode_WORD_NUMBER_TO_INSERT_ERROR_IS_INVALID				(-2029)
#define sitalReturnCode_NO_ERROR_SPECIFIED									(-2030)
#define sitalReturnCode_SYNC_INJECTION_PARAM_INVALID						(-2031)
#define sitalReturnCode_SPECIFIED_ERROR_INJECTION_NOT_SUPPORTED				(-2032)
#define sitalReturnCode_ZERO_CROSSING_INJECTION_PARAM_INVALID				(-2033)
#define sitalReturnCode_DEVICE_MEMORY_FULL									(-2034) /// During mRt start the datablock's allocation spiled over the memory limit of the device


#define sitalReturnCode_DISCRETE_TIMEOUT									(-2900)

#define sitalReturnCode_FUNCTION_NOT_IMPLEMENTED							(-3000)		

#define sitalReturnCode_CANNOT_SEND_ON_RX_CHANNEL							(-4300)// Arinc 429
#define sitalReturnCode_CANNOT_GET_ON_TX_CHANNEL							(-4301)// Arinc 429
#define sitalReturnCode_TIMEOUT												(-4302)// Arinc 429
#define sitalReturnCode_IO_OVERFLOW											(-4303)// Arinc 429
#define sitalReturnCode_A429_SIGNATURE_MISSING								(-4304)// Arinc 429
#define sitalReturnCode_A429_DEVICE_ALREADY_OPENED							(-4305)// Arinc 429


#ifdef __cplusplus
}
#endif



#endif // stld1553_ReturnCodes_INCLUDED
