/// @file
/// This file isn't part of the code of project stld1553 DLL.
/// A header file to be included by clients that would like to use the DDC library in projects where Sital naming (constants, structures, functions) is already used.
/// Such clients may want to keep using Sital naming, and keep their already existing code unchanged.
/// Still, they would like that this Sital-like code would result in actually calling DDC functions instead.
/// Moreover, as they would like a more efficient operation, they will prefer not to use the DDC-stub functions (what's required in case their linker does not support something like NSVC's "#pragma comment(linker, "/export:...)" to explicitly identify export names).
/// Therefore, this header file only includes conversion macros for Sital naming.

// Description  : A header file that contains conversion macros for Sital naming
// Version      : 1.0.0.0
// Author       : Sital Technology R&D
//
// Modification history:
//



#ifndef stld1553_stld1553ToDdc_definitions_INCLUDED
#define stld1553_stld1553ToDdc_definitions_INCLUDED



#ifdef __cplusplus
extern "C" {
#endif



// Enumeration definitions.



// Constant definitions.



// Macro definitions.



// Type/structure definitions.



// Internal-function declarations.



// Exported-function declarations.

// Configuration functions.
#define sitalStld1553_GetShortCoreVersion	aceGetCoreVersion				
#define sitalStld1553_GetShortLibraryVersion	aceGetLibVersion				
#define sitalDevice_Register_Read	aceRegRead						
#define sitalDevice_Register_Write	aceRegWrite						
#define sitalDevice_Memory_Read	aceMemRead						
#define sitalDevice_Memory_Write	aceMemWrite						
#define sitalStld1553_GetBlockStatusWordErrorString	aceGetBSWErrString				
#define sitalStld1553_GetMessageTypeString	aceGetMsgTypeString				
#define sitalDevice_Initialize	aceInitialize					
#define sitalDevice_Free	aceFree							
#define sitalDevice_TimeTag_Set	aceSetTimeTagValue				
#define sitalDevice_TimeTag_Get	aceGetTimeTagValue				
#define sitalDevice_TimeTag_Reset	aceResetTimeTag					
#define sitalDevice_TimeTag_Reset	aceResetTimeTag					
#define sitalDevice_TimeTag_SetResolution	aceSetTimeTagRes				
#define sitalDevice_OperationalStatisticsCollection_Configure	aceSetMetrics					
#define sitalDevice_Irq_Configure	aceSetIrqConfig					
#define sitalDevice_Irq_Manipulate	aceSetIrqConditions				
#define sitalDevice_SetAsynchronousMessagesIsr	aceSetAsyncIsr
#define sitalDevice_Clock_SetFrequency	aceSetClockFreq					
#define sitalDevice_Isq_ReadEntry(swDevice, iespIsqEntry)	aceISQRead((swDevice), (ISQENTRY*)(iespIsqEntry))
#define sitalDevice_Isq_Clear	aceISQClear						
#define sitalDevice_Isq_Configure	aceISQEnable					
#define sitalDevice_SetResponseTimeout	aceSetRespTimeOut				
#define	sitalDevice_ConfigureWatchdogTimeout	aceBCSetWatchDogTimer			
#define sitalDevice_ConfigureDecoder	aceSetDecoderConfig				
#define sitalDevice_ConfigureRamParityCheck	aceSetRamParityChecking			
#define sitalDevice_Test_Registers(swDevice, dtrspTestResult)	aceTestRegisters((swDevice), (TESTRESULT*)(dtrspTestResult))
#define sitalDevice_Test_Memory(swDevice, dtrspTestResult, wValue)	aceTestMemory((swDevice), (TESTRESULT*)(dtrspTestResult), (wValue))
#define sitalDevice_Test_Protocol(swDevice, dtrspTestResult)	aceTestProtocol((swDevice), (TESTRESULT*)(dtrspTestResult))
#define sitalDevice_Test_Interrupts(swDevice, dtrspTestResult)	aceTestIrqs((swDevice), (TESTRESULT*)(dtrspTestResult))
#define sitalDevice_Test_Vectors(swDevice, dtrspTestResult, szpVectorsFilePath)	aceTestVectors((swDevice), (TESTRESULT*)(dtrspTestResult), (szpVectorsFilePath))

// Service functions.
#define sitalStld1553_GetReturnCodeDescriberString	aceErrorStr
#define sitalBcStld1553_Command_GetCode	aceCmdWordCreate				
#define sitalBcStld1553_Command_ParseCode	aceCmdWordParse					

// BC functions.
#define sitalBc_Initialize	aceBCConfigure					
#define sitalBc_MessageRetryPolicy_Set	aceBCSetMsgRetry				
#define sitalBc_Start	aceBCStart						
#define sitalBc_Stop	aceBCStop	
//#define sitalBc_GetActivationState	aceBCGetStatus // Comment-in this definition ONLY in case of using a version of the DDC ACE library that exports this function (this function isn't part of the original API of the DDC ACE library).
#define sitalBc_DataBlock_Create	aceBCDataBlkCreate				
#define sitalBc_DataBlock_Delete	aceBCDataBlkDelete				
#define sitalBc_DataBlock_Write	aceBCDataBlkWrite				
#define sitalBc_DataBlock_Read	aceBCDataBlkRead				
#define sitalBc_Frame_Create	aceBCFrameCreate				
#define sitalBc_Frame_Delete	aceBCFrameDelete				
#define sitalBc_Command_Create	aceBCOpCodeCreate				
#define sitalBc_Command_Delete	aceBCOpCodeDelete				
#define sitalBc_Message_CreateBcToRt	aceBCMsgCreateBCtoRT			
#define sitalBc_Message_CreateRtToBc	aceBCMsgCreateRTtoBC			
#define sitalBc_Message_CreateRtToRt	aceBCMsgCreateRTtoRT			
#define sitalBc_Message_CreateBcToOrFromRtMode	aceBCMsgCreateMode				
#define sitalBc_Message_CreateBcToBroadcast	aceBCMsgCreateBcst				
#define sitalBc_Message_CreateRtToBroadcast	aceBCMsgCreateBcstRTtoRT		
#define sitalBc_Message_CreateBcToOrFromBroadcastMode	aceBCMsgCreateBcstMode			
#define sitalBc_Message_Create	aceBCMsgCreate					
#define sitalBc_Message_ModifyBcToRt	aceBCMsgModifyBCtoRT			
#define sitalBc_Message_ModifyRtToBc	aceBCMsgModifyRTtoBC			
#define sitalBc_Message_ModifyRtToRt	aceBCMsgModifyRTtoRT			
#define sitalBc_Message_ModifyBcToOrFromRtMode	aceBCMsgModifyMode				
#define sitalBc_Message_ModifyBcToBroadcast	aceBCMsgModifyBcst				
#define sitalBc_Message_ModifyRtToBroadcast	aceBCMsgModifyBcstRTtoRT		
#define sitalBc_Message_ModifyBcToOrFromBroadcastMode	aceBCMsgModifyBcstMode			
#define sitalBc_Message_Modify	aceBCMsgModify					
#define sitalBc_Message_Delete	aceBCMsgDelete					
#define sitalBc_Message_GetByIdRaw	aceBCGetMsgFromIDRaw			
#define sitalBc_Message_DecodeRaw(swDevice, wapBuffer, dmspDecodedMessage)	aceBCDecodeRawMsg((swDevice), (wapBuffer), (MSGSTRUCT*)(dmspDecodedMessage))
#define sitalBc_Message_GetByIdDecoded(swDevice, swMessageId, dmspDecodedMessage, wIsPurgeRequired)	aceBCGetMsgFromIDDecoded((swDevice), (swMessageId), (MSGSTRUCT*)(dmspDecodedMessage), (wIsPurgeRequired))		
#define	sitalBc_ConfigureMessageGapTimeFieldPolicy	aceBCMsgGapTimerEnable			
#define sitalBc_Gpf_SetState	aceBCSetGPFState				
#define sitalBc_GetConditionState	aceBCGetConditionCode			
#define sitalBc_Gpq_Read(swDevice, gespGpqEntry)	aceBCGPQRead((swDevice), (GPQENTRY*)(gespGpqEntry))
#define sitalBc_Gpq_GetEntriesCount	aceBCGPQGetCount				
#define sitalBc_Gpq_HandleNewEntries	aceBCFrmToHBuf
#define sitalBc_Gpq_GetOperationalStatistics	aceBCGetGPQMetric
#define sitalBc_AsynchronousMessage_CreateBcToRt	aceBCAsyncMsgCreateBCtoRT		
#define sitalBc_AsynchronousMessage_CreateRtToBc	aceBCAsyncMsgCreateRTtoBC		
#define sitalBc_AsynchronousMessage_CreateRtToRt	aceBCAsyncMsgCreateRTtoRT		
#define sitalBc_AsynchronousMessage_CreateBcToOrFromRtMode	aceBCAsyncMsgCreateMode			
#define sitalBc_AsynchronousMessage_CreateBcToBroadcast	aceBCAsyncMsgCreateBcst			
#define sitalBc_AsynchronousMessage_CreateRtToBroadcast	aceBCAsyncMsgCreateBcstRTtoRT	
#define sitalBc_AsynchronousMessage_CreateBcToOrFromBroadcastMode	aceBCAsyncMsgCreateBcstMode		
#define sitalBc_AsynchronousMessage_SendAtLowPriority	aceBCSendAsyncMsgLP				
#define sitalBc_AsynchronousMessage_SendAtHighPriority	aceBCSendAsyncMsgHP				
#define sitalBc_HostBuffer_Initialize	aceBCInstallHBuf				
#define sitalBc_HostBuffer_Free	aceBCUninstallHBuf				
#define sitalBc_HostBuffer_Message_GetCount	aceBCGetHBufMsgCount
#define sitalBc_HostBuffer_Message_GetDecoded(swDevice, dmspDecodedMessage, dwpMessageCount, dwpLostMessageCount, wMessageLocationAndRemoval)	aceBCGetHBufMsgDecoded			((swDevice), (MSGSTRUCT*)(dmspDecodedMessage), (dwpMessageCount), (dwpLostMessageCount), (wMessageLocationAndRemoval))
#define sitalBc_HostBuffer_Message_GetRaw	aceBCGetHBufMsgsRaw
#define sitalBc_HostBuffer_GetOperationalStatistics(swDevice, hbosspHostBufferOperationalStatistics, bIsResetOfHighestRecordedPercentageRequired)	aceBCGetHBufMetric((swDevice), (HBUFMETRIC*)(hbosspHostBufferOperationalStatistics), (bIsResetOfHighestRecordedPercentageRequired))

// RT functions.
#define sitalRt_Initialize	aceRTConfigure					
#define sitalRt_AddressSource_Set	aceRTSetAddrSource				
#define sitalRt_AddressSource_Get	aceRTGetAddrSource				
#define sitalRt_Address_Relatch	aceRTRelatchAddress				
#define sitalRt_Address_Set	aceRTSetAddress					
#define sitalRt_Address_Get	aceRTGetAddress					
#define sitalRt_Start	aceRTStart						
#define sitalRt_Stop	aceRTStop						
#define sitalRt_DataBlock_Create	aceRTDataBlkCreate				
#define sitalRt_DataBlock_Delete	aceRTDataBlkDelete				
#define sitalRt_DataBlock_Write	aceRTDataBlkWrite				
#define sitalRt_DataBlock_Read	aceRTDataBlkRead				
#define sitalRt_DataBlock_MapToSubaddress	aceRTDataBlkMapToSA				
#define sitalRt_DataBlock_UnmapFromSubaddress	aceRTDataBlkUnmapFromSA			
#define sitalRt_ModeCode_EnableIrq	aceRTModeCodeIrqEnable			
#define sitalRt_ModeCode_DisableIrq	aceRTModeCodeIrqDisable			
#define sitalRt_ModeCode_GetIrq	aceRTModeCodeIrqStatus			
#define sitalRt_ModeCode_ReadData	aceRTModeCodeReadData			
#define sitalRt_ModeCode_WriteData	aceRTModeCodeWriteData			
#define sitalRt_MessageLegality_Enable	aceRTMsgLegalityEnable			
#define sitalRt_MessageLegality_Disable	aceRTMsgLegalityDisable			
#define sitalRt_MessageLegality_GetStatus	aceRTMsgLegalityStatus			
#define sitalRt_MessageBusyBit_Set	aceRTBusyBitsTblSet				
#define sitalRt_MessageBusyBit_Clear	aceRTBusyBitsTblClear			
#define sitalRt_MessageBusyBit_GetStatus	aceRTBusyBitsTblStatus			
#define sitalRt_ResponseStatusBits_Set	aceRTStatusBitsSet				
#define sitalRt_ResponseStatusBits_Unset	aceRTStatusBitsClear			
#define sitalRt_ResponseStatusBits_Get	aceRTStatusBitsStatus			
#define sitalRt_Message_GetFromStackRaw	aceRTGetStkMsgsRaw				
#define sitalRt_Message_GetFromStackDecoded(swDevice, dmspDecodedMessage, wMessageLocationAndRemoval)	aceRTGetStkMsgDecoded((swDevice), (MSGSTRUCT*)(dmspDecodedMessage), (wMessageLocationAndRemoval))
#define sitalRt_Message_DecodeRaw(swDevice, wapBuffer, dmspDecodedMessage)	aceRTDecodeRawMsg((swDevice), (wapBuffer), (MSGSTRUCT*)(dmspDecodedMessage))
#define sitalRt_BuiltInTestWord_Configure aceRTBITWrdConfig
#define sitalRt_BuiltInTestWord_Read aceRTBITWrdRead
#define sitalRt_BuiltInTestWord_Write aceRTBITWrdWrite
#define sitalRt_HostBuffer_Initialize	aceRTInstallHBuf
#define sitalRt_HostBuffer_Free	aceRTUninstallHBuf
#define sitalRt_HostBuffer_Message_Record	aceRTStkToHBuf
#define sitalRt_HostBuffer_Message_GetCount	aceRTGetHBufMsgCount
#define sitalRt_HostBuffer_Message_GetDecoded(swDevice, dmspDecodedMessage, dwpMessageCount, dwpStackLostMessageCount, dwpHostBufferLostMessageCount, wMessageLocationAndRemoval)	aceRTGetHBufMsgDecoded			((swDevice), (MSGSTRUCT*)(dmspDecodedMessage), (dwpMessageCount), (dwpStackLostMessageCount), (dwpHostBufferLostMessageCount), (wMessageLocationAndRemoval))
#define sitalRt_HostBuffer_Message_GetRaw	aceRTGetHBufMsgsRaw
#define sitalRt_HostBuffer_GetOperationalStatistics(swDevice, hbosspHostBufferOperationalStatistics, bIsResetOfHighestRecordedPercentageRequired)	aceRTGetHBufMetric((swDevice), (HBUFMETRIC*)(hbosspHostBufferOperationalStatistics), (bIsResetOfHighestRecordedPercentageRequired))
#define sitalRt_Stack_GetOperationalStatistics(swDevice, sosspStackOperationalStatistics, bIsResetOfHighestRecordedPercentageRequired)	 aceRTGetStkMetric((swDevice), (STKMETRIC*)(sosspStackOperationalStatistics), (bIsResetOfHighestRecordedPercentageRequired))

// MT functions.
#define sitalMt_Initialize	aceMTConfigure					
#define sitalMt_Stack_GetOperationalStatistics(swDevice, sosspStackOperationalStatistics, wStackSelector, bIsResetOfHighestRecordedPercentageRequired)	aceMTGetStkMetric((swDevice), (STKMETRIC*)(sosspStackOperationalStatistics), (wStackSelector), (bIsResetOfHighestRecordedPercentageRequired))
#define sitalMt_Stack_Swap	aceMTSwapStks					
#define sitalMt_GetInformation(swDevice, mispMtInformation)	aceMTGetInfo((swDevice), (MTINFO*)(mispMtInformation))
#define sitalMt_Start	aceMTStart						
#define sitalMt_Stop	aceMTStop						
#define sitalMt_Pause	aceMTPause						
#define sitalMt_Continue	aceMTContinue					
#define sitalMt_MessageMonitoring_Enable	aceMTEnableRTFilter				
#define sitalMt_MessageMonitoring_Disable	aceMTDisableRTFilter			
#define sitalMt_MessageMonitoring_GetStatus	aceMTGetRTFilter				
#define sitalMt_Message_DecodeRaw(swDevice, wapBuffer, dmspDecodedMessage)	aceMTDecodeRawMsg((swDevice), (wapBuffer), (MSGSTRUCT*)(dmspDecodedMessage))
#define sitalMt_Message_GetFromStackRaw	aceMTGetStkMsgsRaw				
#define sitalMt_Message_GetFromStackDecoded(swDevice, dmspDecodedMessage, wMessageLocationAndRemoval, wStackSelector)	aceMTGetStkMsgDecoded((swDevice), (MSGSTRUCT*)(dmspDecodedMessage), (wMessageLocationAndRemoval), (wStackSelector))
#define sitalMt_HostBuffer_Initialize	aceMTInstallHBuf
#define sitalMt_HostBuffer_Free	aceMTUninstallHBuf
#define sitalMt_HostBuffer_Message_Record	aceMTStkToHBuf
#define sitalMt_HostBuffer_Message_GetCount	aceMTGetHBufMsgCount
#define sitalMt_HostBuffer_Message_GetDecoded(swDevice, dmspDecodedMessage, dwpMessageCount, dwpStackLostMessageCount, dwpHostBufferLostMessageCount, wMessageLocationAndRemoval)	aceMTGetHBufMsgDecoded			((swDevice), (MSGSTRUCT*)(dmspDecodedMessage), (dwpMessageCount), (dwpStackLostMessageCount), (dwpHostBufferLostMessageCount), (wMessageLocationAndRemoval))
#define sitalMt_HostBuffer_Message_GetRaw	aceMTGetHBufMsgsRaw
#define sitalMt_HostBuffer_GetOperationalStatistics(swDevice, hbosspHostBufferOperationalStatistics, bIsResetOfHighestRecordedPercentageRequired)	aceMTGetHBufMetric((swDevice), (HBUFMETRIC*)(hbosspHostBufferOperationalStatistics), (bIsResetOfHighestRecordedPercentageRequired))

// RT&MT functions.
#define sitalRtMt_Initialize					aceRTMTConfigure					
#define sitalRtMt_Start							aceRTMTStart					
#define sitalRtMt_Stop							aceRTMTStop					
#define sitalRtMt_HostBuffer_Initialize			aceRTMTInstallHBuf
#define sitalRtMt_HostBuffer_Free				aceMTUninstallHBuf
#define sitalRtMt_HostBuffer_Message_Record		aceRTMTStkToHBuf
#define sitalRtMt_HostBuffer_Message_GetCount	aceRTMTGetHBufMsgCount
#define sitalRtMt_HostBuffer_Message_GetDecoded(swDevice, dmspDecodedMessage, dwpMessageCount, dwpRtStackLostMessageCount, dwpMtStackLostMessageCount, dwpHostBufferLostMessageCount, wMessageLocationAndRemoval)	aceMTGetHBufMsgDecoded			((swDevice), (MSGSTRUCT*)(dmspDecodedMessage), (dwpMessageCount), (dwpRtStackLostMessageCount), (dwpMtStackLostMessageCount), (dwpHostBufferLostMessageCount), (wMessageLocationAndRemoval))
#define sitalRtMt_HostBuffer_Message_GetRaw		aceRTMTGetHBufMsgsRaw
#define sitalRtMt_HostBuffer_GetOperationalStatistics(swDevice, hbosspHostBufferOperationalStatistics, bIsResetOfHighestRecordedPercentageRequired)	aceRTMTGetHBufMetric((swDevice), (HBUFMETRIC*)(hbosspHostBufferOperationalStatistics), (bIsResetOfHighestRecordedPercentageRequired))

// Maximums.
#define sitalMaximum_DEVICES										MAX_NUM_OF_DEVICES		
#define sitalBcMaximum_MESSAGE_SIZE									ACE_MSGSIZE_BC		
#define sitalRtMaximum_MESSAGE_SIZE									ACE_MSGSIZE_RT		
#define sitalMtMaximum_MESSAGE_SIZE									ACE_MSGSIZE_MT		
#define sitalRtMtMaximum_MESSAGE_SIZE								ACE_MSGSIZE_RTMT		

// Parameter values.
#define sitalCommand_RX		ACE_RX_CMD		
#define sitalCommand_TX		ACE_TX_CMD		
#define sital1553_BROADCAST				ACE_BROADCAST		
#define sital1553_MODE_CODE1			ACE_MODE_CODE1		
#define sital1553_MODE_CODE2			ACE_MODE_CODE2		
#define sitalMessageType_BC_TO_RT						ACE_MSG_BCTORT		
#define sitalMessageType_RT_TO_BC						ACE_MSG_RTTOBC		
#define sitalMessageType_RT_TO_RT						ACE_MSG_RTTORT		
#define sitalMessageType_MODE_NO_DATA					ACE_MSG_MODENODATA		
#define sitalMessageType_MODE_DATA_RX					ACE_MSG_MODEDATARX		
#define sitalMessageType_MODE_DATA_TX					ACE_MSG_MODEDATATX		
#define sitalMessageType_BROADCAST						ACE_MSG_BRDCST		
#define sitalMessageType_BROADCAST_RT_TO_RT				ACE_MSG_BRDCSTRTTORT		
#define sitalMessageType_BROADCAST_MODE_NO_DATA			ACE_MSG_BRDCSTMODENODATA		
#define sitalMessageType_BROADCAST_MODE_DATA			ACE_MSG_BRDCSTMODEDATA		
#define sitalMessageType_INVALID						ACE_MSG_INVALID		
#define sitalAccess_CARD				ACE_ACCESS_CARD		
#define sitalAccess_SIMULATION			ACE_ACCESS_SIM		
#define sitalAccess_USER				ACE_ACCESS_USR		
#define sitalMode_TEST				ACE_MODE_TEST		
#define sitalMode_BC				ACE_MODE_BC		
#define sitalMode_RT				ACE_MODE_RT		
#define sitalMode_MT				ACE_MODE_MT		
#define sitalMode_RT_AND_MT			ACE_MODE_RTMT		
#define sitalModeVariant_NO_TIME_TAG_RESET			ACE_NO_TT_RESET		
#define sitalModeVariant_ADVANCED					ACE_ADVANCED_MODE		
#define sitalResponseTimeout_18US				ACE_RESPTIME_18US		
#define sitalResponseTimeout_22US				ACE_RESPTIME_22US		
#define sitalResponseTimeout_50US				ACE_RESPTIME_50US		
#define sitalResponseTimeout_130US				ACE_RESPTIME_130US		
#define sitalDeviceState_RESET			ACE_STATE_RESET		
#define sitalDeviceState_READY			ACE_STATE_READY		
#define sitalDeviceState_RUN			ACE_STATE_RUN		
#define sitalClockSetup_16MHZ			ACE_CLOCK_16MHZ		
#define sitalClockSetup_12MHZ			ACE_CLOCK_12MHZ		
#define sitalClockSetup_20MHZ			ACE_CLOCK_20MHZ		
#define sitalClockSetup_10MHZ			ACE_CLOCK_10MHZ		
#define sitalInputDevice_SingleEnded			ACE_SINGLE_ENDED		
#define sitalInputDevice_DoubleEnded			ACE_DOUBLE_ENDED		
#define sitalExpendedXing_Disable			ACE_DISABLE_EXPANDED_XING		
#define sitalExpendedXing_Enable			ACE_ENABLE_EXPANDED_XING		
#define sitalRamParityCheck_DISABLE			ACE_DISABLE_PARITY_CHECK		
#define sitalRamParityCheck_ENABLE			ACE_ENABLE_PARITY_CHECK		
#define sitalTimeTagResolution_2US						ACE_TT_2US		
#define sitalTimeTagResolution_4US						ACE_TT_4US		
#define sitalTimeTagResolution_8US						ACE_TT_8US		
#define sitalTimeTagResolution_16US						ACE_TT_16US		
#define sitalTimeTagResolution_32US						ACE_TT_32US		
#define sitalTimeTagResolution_64US						ACE_TT_64US		
#define sitalTimeTagResolution_TEST						ACE_TT_TEST		
#define sitalTimeTagResolution_EXTERNAL_CLOCK			ACE_TT_EXT		
#define sitalIrqMode_PULSE			ACE_IRQ_PULSE		
#define sitalIrqMode_LEVEL			ACE_IRQ_LEVEL		
#define sitalIrqClear_NO_AUTO_CLEAR		ACE_IRQ_NO_AUTO_CLR		
#define sitalIrqClear_AUTO_CLEAR			ACE_IRQ_AUTO_CLR		
#define sitalInterrupt_NON_MESSAGE								ACE_ISQ_MSG_NONMSG		
#define sitalInterrupt_TX_TIMEOUT								ACE_ISQ_TX_TIMEOUT		
#define sitalInterrupt_ILL_LOOKUP								ACE_ISQ_ILL_LKUP		
#define sitalInterrupt_MT_DATA_STACK_HALF_ROLLOVER				ACE_ISQ_MT_DSTK_50P_ROVR		
#define sitalInterrupt_MT_DATA_STACK_ROVER						ACE_ISQ_MT_DSTK_ROVER		
#define sitalInterrupt_RT_DATA_STACK_HALF_ROLLOVER				ACE_ISQ_RT_DSTK_50P_ROVR		
#define sitalInterrupt_RT_DATA_STACK_ROLLOVER					ACE_ISQ_RT_DSTK_ROVER		
#define sitalInterrupt_MT_COMMAND_STACK_HALF_ROLLOVER			ACE_ISQ_MT_CSTK_50P_ROVR		
#define sitalInterrupt_MT_COMMAND_STACK_ROLLOVER				ACE_ISQ_MT_CSTK_ROVR		
#define sitalInterrupt_RT_COMMAND_STACK_HALF_ROLLOVER			ACE_ISQ_RT_CSTK_50P_ROVR		
#define sitalInterrupt_RT_COMMAND_STACK_ROLLOVER				ACE_ISQ_RT_CSTK_ROVR		
#define sitalInterrupt_HANDSHAKE_FAIL							ACE_ISQ_HNDSHK_FAIL		
#define sitalInterrupt_FORMAT_ERROR								ACE_ISQ_FMT_ERR		
#define sitalInterrupt_MODE_CODE								ACE_ISQ_MCODE		
#define sitalInterrupt_SUBADDRESS_END_OF_MESSAGE				ACE_ISQ_SA_EOM		
#define sitalInterrupt_END_OF_MESSAGE							ACE_ISQ_EOM		
#define sitalInterrupt_TIME_TAG									ACE_ISQ_TIME_TAG		
#define sitalInterrupt_RT_ADDRESS_PARITY						ACE_ISQ_RT_ADDR_PAR		
#define sitalInterrupt_SELF_TEST								ACE_ISQ_SELF_TEST		
#define sitalInterruptRegister1_END_OF_MESSAGE 								ACE_IMR1_EOM		
#define sitalInterruptRegister1_BC_STATUS_SET								ACE_IMR1_BC_STATUS_SET		
#define sitalInterruptRegister1_RT_MODE_CODE								ACE_IMR1_RT_MODE_CODE		
#define sitalInterruptRegister1_MT_PATTERN_TRIGGER							ACE_IMR1_MT_PATTERN_TRIG		
#define sitalInterruptRegister1_FORMAT_ERROR 								ACE_IMR1_FORMAT_ERR		
#define sitalInterruptRegister1_BC_END_OF_FRAME								ACE_IMR1_BC_END_OF_FRM		
#define sitalInterruptRegister1_BC_END_OF_MESSAGE 							ACE_IMR1_BC_MSG_EOM		
#define sitalInterruptRegister1_RT_SUBADDRESS_END_OF_MESSAGE 				ACE_IMR1_RT_SUBADDR_EOM		
#define sitalInterruptRegister1_RT_CIRCULAR_BUFFER_ROLLOVER					ACE_IMR1_RT_CIRCBUF_ROVER		
#define sitalInterruptRegister1_TIME_TAG_ROLLOVER							ACE_IMR1_TT_ROVER		
#define sitalInterruptRegister1_RT_ADDRESS_PARITY_ERROR						ACE_IMR1_RT_ADDR_PAR_ERR		
#define sitalInterruptRegister1_BC_RETRY									ACE_IMR1_BC_RETRY		
#define sitalInterruptRegister1_HANDSHAKE_FAILURE								ACE_IMR1_HSHAKE_FAIL		
#define sitalInterruptRegister1_MT_DATA_STACK_ROLLOVER						ACE_IMR1_MT_DATASTK_ROVER		
#define sitalInterruptRegister1_MT_COMMAND_STACK_ROLLOVER					ACE_IMR1_MT_CMDSTK_ROVER		
#define sitalInterruptRegister1_BC_RT_COMMAND_STACK_ROLLOVER				ACE_IMR1_BCRT_CMDSTK_ROVER		
#define sitalInterruptRegister1_BC_RT_TRANSMITTER_TIMEOUT							ACE_IMR1_BCRT_TX_TIMEOUT		
#define sitalInterruptRegister1_RAM_PARITY_ERROR							ACE_IMR1_RAM_PAR_ERR		
#define sitalInterruptRegister2_BUILT_IN_TEST_COMPLETE							ACE_IMR2_BIT_COMPLETE		
#define sitalInterruptRegister2_BC_IRQ0										ACE_IMR2_BC_UIRQ0		
#define sitalInterruptRegister2_BC_IRQ1										ACE_IMR2_BC_UIRQ1		
#define sitalInterruptRegister2_BC_IRQ2										ACE_IMR2_BC_UIRQ2		
#define sitalInterruptRegister2_BC_IRQ3										ACE_IMR2_BC_UIRQ3		
#define sitalInterruptRegister2_MT_DATA_STACK_HALF_ROLLOVER					ACE_IMR2_MT_DSTK_50P_ROVER		
#define sitalInterruptRegister2_MT_COMMAND_STACK_HALF_ROLLOVER				ACE_IMR2_MT_CSTK_50P_ROVER		
#define sitalInterruptRegister2_RT_CIRCULAR_BUFFER_HALF_ROLLOVER			ACE_IMR2_RT_CIRC_50P_ROVER		
#define sitalInterruptRegister2_RT_COMMAND_STACK_HALF_ROLLOVER				ACE_IMR2_RT_CSTK_50P_ROVER		
#define sitalInterruptRegister2_BC_TRAP										ACE_IMR2_BC_TRAP		
#define sitalInterruptRegister2_BC_CALL_STACK_ERROR 						ACE_IMR2_BC_CALLSTK_ERR		
#define sitalInterruptRegister2_BC_GENERAL_PURPOSE_QUEUE_ROLLOVER		ACE_IMR2_GPQ_ISQ_ROVER
#define sitalInterruptRegister2_RT_INTERRUPT_SERVICE_QUEUE_ROLLOVER		ACE_IMR2_GPQ_ISQ_ROVER
#define sitalInterruptRegister2_GPQ_ISQ_ROLLOVER							ACE_IMR2_GPQ_ISQ_ROVER		
#define sitalInterruptRegister2_RT_ILLEGAL_COMMAND 								ACE_IMR2_RT_ILL_CMD		
#define sitalInterruptRegister2_BC_OPCODE_PARITY_ERROR							ACE_IMR2_BC_OPCODE_PARITY		
#define sitalBcMessageModifier_MESSAGE1_DATA_BLOCK				ACE_BC_MOD_DBLK1		
#define sitalBcMessageModifier_MESSAGE1_BC_CONTROL				ACE_BC_MOD_BCCTRL1		
#define sitalBcMessageModifier_MESSAGE1_COMMAND1				ACE_BC_MOD_CMDWRD1_1		
#define sitalBcMessageModifier_MESSAGE1_COMMAND2				ACE_BC_MOD_CMDWRD1_2		
#define sitalBcMessageModifier_MESSAGE1_GAPTIME					ACE_BC_MOD_GAPTIME1		
#define sitalBcMessageModifier_MESSAGE2_DATA_BLOCK				ACE_BC_MOD_DBLK2		
#define sitalBcMessageModifier_MESSAGE2_BC_CONTROL				ACE_BC_MOD_BCCTRL2		
#define sitalBcMessageModifier_MESSAGE2_COMMAND1				ACE_BC_MOD_CMDWRD2_1		
#define sitalBcMessageModifier_MESSAGE2_COMMAND2				ACE_BC_MOD_CMDWRD2_2		
#define sitalBcMessageModifier_MESSAGE2_GAPTIME					ACE_BC_MOD_GAPTIME2		

// BC activation state: wCurrentState values.
#define sitalBcActivationState_IDLE							0x0000		///< BC currently isn't running any frame. (Equivalent DDC definition: ACE_BC_IDLE)
#define sitalBcActivationState_BUSY							0x0001		///< BC currently running a frame. (Equivalent DDC definition: ACE_BC_BUSY)
//#define sitalBcActivationState_IDLE				ACE_BC_IDLE
//#define sitalBcActivationState_BUSY				ACE_BC_BUSY

#define sitalBcFrameFlag_MINOR_FRAME_IRQ_DISABLE				ACE_BC_MNRFRM_IRQ_DISABLE		
#define sitalMessageRetryCount_NONE				ACE_RETRY_NONE		
#define sitalMessageRetryCount_ONE				ACE_RETRY_ONCE		
#define sitalMessageRetryCount_TWO				ACE_RETRY_TWICE		
#define sitalMessageRetryBus_SAME				ACE_RETRY_SAME		
#define sitalMessageRetryBus_OTHER				ACE_RETRY_ALT		
#define sitalBcSetupOption_ASYNCHRONOUS_LOW_PRIORITY_MODE				ACE_BC_ASYNC_LMODE		
#define sitalBcSetupOption_ASYNCHRONOUS_HIGH_PRIORITY_MODE				ACE_BC_ASYNC_HMODE		
#define sitalBcSetupOption_ASYNCHRONOUS_BOTH_PRIORITY_MODES				ACE_BC_ASYNC_BOTH		
#define sitalBcDataBlockSizeOption_SINGLE			ACE_BC_DBLK_SINGLE		
#define sitalBcDataBlockSizeOption_DOUBLE			ACE_BC_DBLK_DOUBLE		
#define sitalBcControlWord_RT_TO_RT															ACE_BCCTRL_RT_TO_RT		
#define sitalBcControlWord_BROADCAST														ACE_BCCTRL_BCST		
#define sitalBcControlWord_MODE																ACE_BCCTRL_MODE		
#define sitalBcControlWord_1553A															ACE_BCCTRL_1553A		
#define sitalBcControlWord_BUS_B															ACE_BCCTRL_CHL_B		
#define sitalBcControlWord_1553B															ACE_BCCTRL_1553B		
#define sitalBcControlWord_END_OF_MESSAGE_INTERRUPT_ENABLED									ACE_BCCTRL_EOM_IRQ		
#define sitalBcControlWord_BROADCAST_CHECK_MASKED											ACE_BCCTRL_BCST_MSK		
#define sitalBcControlWord_LOOPBACK_TEST_PERFORMED											ACE_BCCTRL_SELFTST		
#define sitalBcControlWord_BUS_A															ACE_BCCTRL_CHL_A		
#define sitalBcControlWord_RETRY_ENABLED													ACE_BCCTRL_RETRY_ENA		
#define sitalBcControlWord_RESERVE_STATUS_BITS_MASKED										ACE_BCCTRL_RES_MSK		
#define sitalBcControlWord_TERMINAL_STATUS_FLAG_MASKED										ACE_BCCTRL_TFLG_MSK		
#define sitalBcControlWord_SUBSYSTEM_STATUS_FLAG_MASKED										ACE_BCCTRL_SSFLG_MSK		
#define sitalBcControlWord_BUSY_STATUS_BIT_MASKED											ACE_BCCTRL_SSBSY_MSK		
#define sitalBcControlWord_SERVICE_REQUEST_STATUS_BIT_MASKED								ACE_BCCTRL_SREQ_MSK		
#define sitalBcControlWord_MESSAGE_ERROR_STATUS_BIT_MASKED									ACE_BCCTRL_ME_MSK		
#define sitalBcMessageOption_DUAL_MESSAGE													ACE_MSGOPT_DOUBLE_BUFFER		
#define sitalBcMessageOption_STAY_ON_ALTERNATE_BUS											ACE_MSGOPT_STAY_ON_ALT		
#define sitalOpcode_TRAP								ACE_OPCODE_TRP		
#define sitalOpcode_EXECUTE_MESSAGE						ACE_OPCODE_XEQ		
#define sitalOpcode_JUMP								ACE_OPCODE_JMP		
#define sitalOpcode_CALL_SUBROUTINE						ACE_OPCODE_CAL		
#define sitalOpcode_RETURN_FROM_SUBROUTINE				ACE_OPCODE_RTN		
#define sitalOpcode_INTERRUPT_REQUEST					ACE_OPCODE_IRQ		
#define sitalOpcode_HALT								ACE_OPCODE_HLT		
#define sitalOpcode_DELAY								ACE_OPCODE_DLY		
#define sitalOpcode_WAIT_END_OF_FRAME					ACE_OPCODE_WFT		
#define sitalOpcode_COMPARE_TO_FRAME_TIMER				ACE_OPCODE_CFT		
#define sitalOpcode_UPDATE_GENERAL_PURPOSE_FLAG			ACE_OPCODE_FLG		
#define sitalOpcode_LOAD_TIME_TAG_COUNTER				ACE_OPCODE_LTT		
#define sitalOpcode_LOAD_FRAME_TIMER					ACE_OPCODE_LFT		
#define sitalOpcode_START_FRAME_TIMER					ACE_OPCODE_SFT		
#define sitalOpcode_PUSH_TIME_TAG_COUNTER				ACE_OPCODE_PTT		
#define sitalOpcode_PUSH_BLOCK_STATUS_WORD				ACE_OPCODE_PBS		
#define sitalOpcode_PUSH_VALUE							ACE_OPCODE_PSI		
#define sitalOpcode_PUSH_INDERCT_VALUE					ACE_OPCODE_PSM		
#define sitalOpcode_WAIT_FOR_TRIGGER					ACE_OPCODE_WTG		
#define sitalOpcode_EXECUTE_AND_FLIP					ACE_OPCODE_XQF		
#define sitalOpcode_TIME_CONDITIONED_MESSAGE_TX			ACE_S_OPCODE_AMSG		
#define sitalOpcodeCondition_LESS_THAN					ACE_CNDTST_LT		
#define sitalOpcodeCondition_GREATER_THAN				ACE_CNDTST_GT		
#define sitalOpcodeCondition_EQUAL						ACE_CNDTST_EQ		
#define sitalOpcodeCondition_NOT_EQUAL					ACE_CNDTST_NEQ		
#define sitalOpcodeCondition_GP1_1						ACE_CNDTST_GP1_1		
#define sitalOpcodeCondition_GP1_0						ACE_CNDTST_GP1_0		
#define sitalOpcodeCondition_GP2_1						ACE_CNDTST_GP2_1		
#define sitalOpcodeCondition_GP2_0						ACE_CNDTST_GP2_0		
#define sitalOpcodeCondition_GP3_1						ACE_CNDTST_GP3_1		
#define sitalOpcodeCondition_GP3_0						ACE_CNDTST_GP3_0		
#define sitalOpcodeCondition_GP4_1						ACE_CNDTST_GP4_1		
#define sitalOpcodeCondition_GP4_0						ACE_CNDTST_GP4_0		
#define sitalOpcodeCondition_GP5_1						ACE_CNDTST_GP5_1		
#define sitalOpcodeCondition_GP5_0						ACE_CNDTST_GP5_0		
#define sitalOpcodeCondition_GP6_1						ACE_CNDTST_GP6_1		
#define sitalOpcodeCondition_GP6_0						ACE_CNDTST_GP6_0		
#define sitalOpcodeCondition_GP7_1						ACE_CNDTST_GP7_1		
#define sitalOpcodeCondition_GP7_0						ACE_CNDTST_GP7_0		
#define sitalOpcodeCondition_NO_RESPONSE				ACE_CNDTST_NO_RES		
#define sitalOpcodeCondition_RESPONSE					ACE_CNDTST_RES		
#define sitalOpcodeCondition_FORMAT_ERROR				ACE_CNDTST_FMT_ERR		
#define sitalOpcodeCondition_NO_FORMAT_ERROR			ACE_CNDTST_NO_FMT_ERR		
#define sitalOpcodeCondition_GOOD_TRANSFER				ACE_CNDTST_GD_XFER		
#define sitalOpcodeCondition_BAD_TRANFER				ACE_CNDTST_BAD_XFER		
#define sitalOpcodeCondition_MASKED_STATUS_SET				ACE_CNDTST_MSK_STS_SET		
#define sitalOpcodeCondition_MASKED_STATUS_CLEAR			ACE_CNDTST_MSK_STS_CLR		
#define sitalOpcodeCondition_BAD_MESSAGE				ACE_CNDTST_BAD_MSG		
#define sitalOpcodeCondition_GOOD_MESSAGE				ACE_CNDTST_GOOD_MSG		
#define sitalOpcodeCondition_NO_RETRY					ACE_CNDTST_0RETRY		
#define sitalOpcodeCondition_1_RETRY					ACE_CNDTST_1RETRY		
#define sitalOpcodeCondition_2_RETRIES					ACE_CNDTST_2RETRY		
#define sitalOpcodeCondition_ALWAYS						ACE_CNDTST_ALWAYS		
#define sitalOpcodeCondition_NEVER						ACE_CNDTST_NEVER		
#define sitalGeneralPurposeQueueFlag_END_OF_MAJOR_FRAME						ACE_GPQ_MJR_EOF		
#define sitalGeneralPurposeQueueFlag_END_OF_MINOR_FRAME						ACE_GPQ_MNR_EOF		
#define sitalGeneralPurposeQueueFlag_WATCHDOG_TIMEOUT						ACE_GPQ_MRR_TIME_EXP		
#define sitalBcConditionCode_GPF_EQUAL_FLAG						ACE_CND_LT_GT		
#define sitalBcConditionCode_GPF_LESS_THAN_FLAG					ACE_CND_EQ_NE		
#define sitalBcConditionCode_GPF0								ACE_CND_GPF0		
#define sitalBcConditionCode_GPF1								ACE_CND_GPF1		
#define sitalBcConditionCode_GPF2								ACE_CND_GPF2		
#define sitalBcConditionCode_GPF3								ACE_CND_GPF3		
#define sitalBcConditionCode_GPF4								ACE_CND_GPF4		
#define sitalBcConditionCode_GPF5								ACE_CND_GPF5		
#define sitalBcConditionCode_GPF6								ACE_CND_GPF6		
#define sitalBcConditionCode_GPF7								ACE_CND_GPF7		
#define sitalBcConditionCode_NO_RESPONSE						ACE_CND_NORES		
#define sitalBcConditionCode_FORMAT_ERROR						ACE_CND_FMT_ERR		
#define sitalBcConditionCode_GOOD_DATA_BLOCK_TRANSFER			ACE_CND_GD_DATA		
#define sitalBcConditionCode_MASKED_STATUS						ACE_CND_MSKED_STS		
#define sitalBcConditionCode_BAD_MESSAGE						ACE_CND_BAD_MSG		
#define sitalBcConditionCode_RETRY_COUNT						ACE_CND_RETRY		
#define sitalBcConditionCode_ALWAYS								ACE_CND_ALWAYS		
#define sitalBcFrameType_MAJOR			ACE_FRAME_MAJOR		
#define sitalBcFrameType_MINOR			ACE_FRAME_MINOR		
#define sitalBcGpf_GPF0					ACE_GPF0		
#define sitalBcGpf_GPF1					ACE_GPF1		
#define sitalBcGpf_GPF2					ACE_GPF2		
#define sitalBcGpf_GPF3					ACE_GPF3		
#define sitalBcGpf_GPF4					ACE_GPF4		
#define sitalBcGpf_GPF5					ACE_GPF5		
#define sitalBcGpf_GPF6					ACE_GPF6		
#define sitalBcGpf_GPF7					ACE_GPF7		
#define sitalBcGpfEffect_LEAVE			ACE_GPF_LEAVE		
#define sitalBcGpfEffect_SET			ACE_GPF_SET		
#define sitalBcGpfEffect_CLEAR			ACE_GPF_CLEAR		
#define sitalBcGpfEffect_TOGGLE			ACE_GPF_TOGGLE		
#define sitalRtCommandStackSize_256			ACE_RT_CMDSTK_256		
#define sitalRtCommandStackSize_512			ACE_RT_CMDSTK_512		
#define sitalRtCommandStackSize_1024		ACE_RT_CMDSTK_1K		
#define sitalRtCommandStackSize_2048		ACE_RT_CMDSTK_2K		
#define sitalRtAddressSource_EXTERNAL		ACE_RT_EXTERNAL_ADDR		
#define sitalRtAddressSource_INTERNAL		ACE_RT_INTERNAL_ADDR		
#define sitalRtSetupOption_CLEAR_SERVICE_REQUEST			ACE_RT_OPT_CLR_SREQ		
#define sitalRtSetupOption_LOAD_TIME_TAG					ACE_RT_OPT_LOAD_TT		
#define sitalRtSetupOption_CLEAR_TIME_TAG					ACE_RT_OPT_CLEAR_TT		
#define sitalRtSetupOption_OVERWRITE_DATA					ACE_RT_OPT_OVR_DATA		
#define sitalRtSetupOption_OVERRIDE_MODE_BIT				ACE_RT_OPT_OVR_MBIT		
#define sitalRtSetupOption_ALTERNATE_STATUS					ACE_RT_OPT_ALT_STS		
#define sitalRtSetupOption_ILL_RX_DISABLE					ACE_RT_OPT_IL_RX_D		
#define sitalRtSetupOption_BUSY_RX_DISABLE					ACE_RT_OPT_BSY_RX_D		
#define sitalRtSetupOption_SET_RT_FLAG						ACE_RT_OPT_SET_RTFG		
#define sitalRtSetupOption_1553A_MODE_CODES					ACE_RT_OPT_1553A_MC		
#define sitalRtSetupOption_MODE_COMMAND_OVERRIDE_BUSY		ACE_RT_OPT_MC_O_BSY		
#define sitalRtSetupOption_BROADCAST_DISABLE				ACE_RT_OPT_BCST_DIS		
#define sitalRtDataBlockType_SINGLE_32					ACE_RT_DBLK_SINGLE		
#define sitalRtDataBlockType_DOUBLE						ACE_RT_DBLK_DOUBLE		
#define sitalRtDataBlockType_CIRCULAR_128				ACE_RT_DBLK_C_128		
#define sitalRtDataBlockType_CIRCULAR_256				ACE_RT_DBLK_C_256		
#define sitalRtDataBlockType_CIRCULAR_512				ACE_RT_DBLK_C_512		
#define sitalRtDataBlockType_CIRCULAR_1024				ACE_RT_DBLK_C_1K		
#define sitalRtDataBlockType_CIRCULAR_2048				ACE_RT_DBLK_C_2K		
#define sitalRtDataBlockType_CIRCULAR_4096				ACE_RT_DBLK_C_4K		
#define sitalRtDataBlockType_CIRCULAR_8192				ACE_RT_DBLK_C_8K		
#define sitalRtDataBlockType_COMMON_CIRCULAR_128		ACE_RT_DBLK_GBL_C_128		
#define sitalRtDataBlockType_COMMON_CIRCULAR_256		ACE_RT_DBLK_GBL_C_256		
#define sitalRtDataBlockType_COMMON_CIRCULAR_512		ACE_RT_DBLK_GBL_C_512		
#define sitalRtDataBlockType_COMMON_CIRCULAR_1024		ACE_RT_DBLK_GBL_C_1K		
#define sitalRtDataBlockType_COMMON_CIRCULAR_2048		ACE_RT_DBLK_GBL_C_2K		
#define sitalRtDataBlockType_COMMON_CIRCULAR_4096		ACE_RT_DBLK_GBL_C_4K		
#define sitalRtDataBlockType_COMMON_CIRCULAR_8192		ACE_RT_DBLK_GBL_C_8K		
#define sitalRtModeCodeType_RX_NO_DATA					ACE_RT_MCTYPE_RX_NO_DATA		
#define sitalRtModeCodeType_RX_DATA						ACE_RT_MCTYPE_RX_DATA		
#define sitalRtModeCodeType_TX_NO_DATA					ACE_RT_MCTYPE_TX_NO_DATA		
#define sitalRtModeCodeType_TX_DATA						ACE_RT_MCTYPE_TX_DATA		
#define sitalRtModeCodeType_BROADCAST_RX_NO_DATA		ACE_RT_MCTYPE_BCST_RX_NO_DATA		
#define sitalRtModeCodeType_BROADCAST_RX_DATA			ACE_RT_MCTYPE_BCST_RX_DATA		
#define sitalRtModeCodeType_BROADCAST_TX_NO_DATA		ACE_RT_MCTYPE_BCST_TX_NO_DATA		
#define sitalRtModeCodeType_BROADCAST_TX_DATA			ACE_RT_MCTYPE_BCST_TX_DATA		
#define sitalRtModeCodeIrq_DYNAMIC_BUS_CONTROL						ACE_RT_MCIRQ_DYN_BUS_CTRL		
#define sitalRtModeCodeIrq_SYNCHRONIZE								ACE_RT_MCIRQ_SYNCHRONIZE		
#define sitalRtModeCodeIrq_TRANSMIT_STATUS							ACE_RT_MCIRQ_TRNS_STATUS		
#define sitalRtModeCodeIrq_INITIALIZE_SELF_TEST						ACE_RT_MCIRQ_INIT_SELF_TEST		
#define sitalRtModeCodeIrq_TRANSMITTER_SHUTDOWN						ACE_RT_MCIRQ_TRNS_SHUTDOWN		
#define sitalRtModeCodeIrq_OVERRIDE_TRANSMITTER_SHUTDOWN				ACE_RT_MCIRQ_OVR_TRNS_SHUTDWN		
#define sitalRtModeCodeIrq_INHIBIT_TERMINAL_FLAG					ACE_RT_MCIRQ_INH_TERM_FLAG		
#define sitalRtModeCodeIrq_OVERRIDE_INHIBIT_TERMINAL_FLAG			ACE_RT_MCIRQ_OVR_INH_TERM_FLG		
#define sitalRtModeCodeIrq_RESET_REMOTE_TERMINAL					ACE_RT_MCIRQ_RESET_REMOTE_TERM		
#define sitalRtModeCodeIrq_TRANSMIT_VECTOR							ACE_RT_MCIRQ_TRNS_VECTOR		
#define sitalRtModeCodeIrq_TRANSMIT_LAST_COMMAND					ACE_RT_MCIRQ_TRNS_LAST_CMD		
#define sitalRtModeCodeIrq_TRANSMIT_BUILT_IN_TEST								ACE_RT_MCIRQ_TRNS_BIT		
#define sitalRtModeCodeIrq_SELECTED_TRANSMITTER_SHUTDOWN					ACE_RT_MCIRQ_SEL_TRNS_SHUTDWN		
#define sitalRtModeCodeIrq_OVERRIDE_SELECTED_TRANSMITTER_SHUTDOWN			ACE_RT_MCIRQ_OVR_SEL_TRNS_SHUTDWN		
#define sitalRtModeCodeIrq_RESERVED_BIT6							ACE_RT_MCIRQ_RESERVED_BIT6		
#define sitalRtModeCodeIrq_RESERVED_BIT7							ACE_RT_MCIRQ_RESERVED_BIT7		
#define sitalRtModeCodeIrq_RESERVED_BIT7							ACE_RT_MCIRQ_RESERVED_BIT7		
#define sitalRtModeCodeIrq_RESERVED_BIT7							ACE_RT_MCIRQ_RESERVED_BIT7		
#define sitalRtModeCodeIrq_RESERVED_BIT8							ACE_RT_MCIRQ_RESERVED_BIT8		
#define sitalRtModeCodeIrq_RESERVED_BIT9							ACE_RT_MCIRQ_RESERVED_BIT9		
#define sitalRtModeCodeIrq_RESERVED_BIT10							ACE_RT_MCIRQ_RESERVED_BIT10		
#define sitalRtModeCodeIrq_RESERVED_BIT11							ACE_RT_MCIRQ_RESERVED_BIT11		
#define sitalRtModeCodeIrq_RESERVED_BIT12							ACE_RT_MCIRQ_RESERVED_BIT12		
#define sitalRtModeCodeIrq_RESERVED_BIT13							ACE_RT_MCIRQ_RESERVED_BIT13		
#define sitalRtModeCodeIrq_RESERVED_BIT14							ACE_RT_MCIRQ_RESERVED_BIT14		
#define sitalRtModeCodeIrq_RESERVED_BIT15							ACE_RT_MCIRQ_RESERVED_BIT15		
#define sitalRtDataContainerModeCode_RX_SYNCHRONIZE									ACE_RT_MCDATA_RX_SYNCHRONIZE		
#define sitalRtDataContainerModeCode_RX_TRANSMITTER_SHUTDOWN							ACE_RT_MCDATA_RX_SEL_T_SHUTDWN		
#define sitalRtDataContainerModeCode_RX_OVERRIDE_TRANSMITTER_SHUTDOWN						ACE_RT_MCDATA_RX_OVR_SEL_T_SHUTDWN		
#define sitalRtDataContainerModeCode_TX_TRANSMIT_VECTOR_WORD								ACE_RT_MCDATA_TX_TRNS_VECTOR		
#define sitalRtDataContainerModeCode_TX_TRANSMIT_LAST_COMMAND_WORD						ACE_RT_MCDATA_TX_TRNS_LAST_CMD		
#define sitalRtDataContainerModeCode_TX_TRANSMIT_BUILT_IN_TEST_WORD								ACE_RT_MCDATA_TX_TRNS_BIT		
#define sitalRtDataContainerModeCode_BROADCAST_SYNCHRONIZE							ACE_RT_MCDATA_BCST_SYNCHRONIZE		
#define sitalRtDataContainerModeCode_BROADCAST_SELECTED_TRANSMITTER_SHUTDOWN					ACE_RT_MCDATA_BCST_SEL_T_SHUTDWN		
#define sitalRtDataContainerModeCode_BROADCAST_OVERRIDE_SELECTED_TRANSMITTER_SHUTDOWN			ACE_RT_MCDATA_BCST_OVR_SEL_T_SHUTDWN		
#define sitalRtAddressType_BROADCAST			ACE_RT_BCST_ADDRSS		
#define sitalRtAddressType_OWN					ACE_RT_OWN_ADDRESS		
#define sitalRtAddressType_BOTH	ACE_RT_MODIFY_ALL		
#define sitalRtSubaddress_ALL				ACE_RT_MODIFY_ALL		
#define sitalRtSubaddressMask_ALL			ACE_RT_SA_ALL // or ACE_MT_FILTER_SA_ALL
#define sitalRtSubaddressMask_0					ACE_RT_SA0		
#define sitalRtSubaddressMask_1					ACE_RT_SA1		
#define sitalRtSubaddressMask_2					ACE_RT_SA2		
#define sitalRtSubaddressMask_3					ACE_RT_SA3		
#define sitalRtSubaddressMask_4					ACE_RT_SA4		
#define sitalRtSubaddressMask_5					ACE_RT_SA5		
#define sitalRtSubaddressMask_6					ACE_RT_SA6		
#define sitalRtSubaddressMask_7					ACE_RT_SA7		
#define sitalRtSubaddressMask_8					ACE_RT_SA8		
#define sitalRtSubaddressMask_9					ACE_RT_SA9		
#define sitalRtSubaddressMask_10				ACE_RT_SA10		
#define sitalRtSubaddressMask_11				ACE_RT_SA11		
#define sitalRtSubaddressMask_12				ACE_RT_SA12		
#define sitalRtSubaddressMask_13				ACE_RT_SA13		
#define sitalRtSubaddressMask_14				ACE_RT_SA14		
#define sitalRtSubaddressMask_15				ACE_RT_SA15		
#define sitalRtSubaddressMask_16				ACE_RT_SA16		
#define sitalRtSubaddressMask_17				ACE_RT_SA17		
#define sitalRtSubaddressMask_18				ACE_RT_SA18		
#define sitalRtSubaddressMask_19				ACE_RT_SA19		
#define sitalRtSubaddressMask_20				ACE_RT_SA20		
#define sitalRtSubaddressMask_21				ACE_RT_SA21		
#define sitalRtSubaddressMask_22				ACE_RT_SA22		
#define sitalRtSubaddressMask_23				ACE_RT_SA23		
#define sitalRtSubaddressMask_24				ACE_RT_SA24		
#define sitalRtSubaddressMask_25				ACE_RT_SA25		
#define sitalRtSubaddressMask_26				ACE_RT_SA26		
#define sitalRtSubaddressMask_27				ACE_RT_SA27		
#define sitalRtSubaddressMask_28				ACE_RT_SA28		
#define sitalRtSubaddressMask_29				ACE_RT_SA29		
#define sitalRtSubaddressMask_30				ACE_RT_SA30		
#define sitalRtSubaddressMask_31				ACE_RT_SA31		
#define sitalRtStatusWordBit_DBCA					ACE_RT_STSBIT_DBCA		
#define sitalRtStatusWordBit_BUSY					ACE_RT_STSBIT_BUSY		
#define sitalRtStatusWordBit_SERVICE_REQUSET		ACE_RT_STSBIT_SREQ		
#define sitalRtStatusWordBit_SUBSYSTEM_FLAG			ACE_RT_STSBIT_SSFLAG		
#define sitalRtStatusWordBit_RT_FLAG				ACE_RT_STSBIT_RTFLAG		
#define sitalRtStatusWordBit_S10					ACE_RT_STSBIT_S10		
#define sitalRtStatusWordBit_S09					ACE_RT_STSBIT_S09		
#define sitalRtStatusWordBit_S08					ACE_RT_STSBIT_S08		
#define sitalRtStatusWordBit_S07					ACE_RT_STSBIT_S07		
#define sitalRtStatusWordBit_S06					ACE_RT_STSBIT_S06		
#define sitalRtStatusWordBit_S05					ACE_RT_STSBIT_S05		
#define sitalRtStatusWordBit_S04					ACE_RT_STSBIT_S04		
#define sitalRtStatusWordBit_S03					ACE_RT_STSBIT_S03		
#define sitalRtStatusWordBit_S02					ACE_RT_STSBIT_S02		
#define sitalRtStatusWordBit_S01					ACE_RT_STSBIT_S01		
#define sitalRtStatusWordBit_S00					ACE_RT_STSBIT_S00		
#define sitalRtMessageType_RX				ACE_RT_MSGTYPE_RX		
#define sitalRtMessageType_TX				ACE_RT_MSGTYPE_TX		
#define sitalRtMessageType_BROADCAST		ACE_RT_MSGTYPE_BCST		
#define sitalRtMessageType_ALL				ACE_RT_MSGTYPE_ALL		
#define sitalMessageLocationAndRemoval_NEXT_PURGE	ACE_BC_MSGLOC_NEXT_PURGE		
#define sitalMessageLocationAndRemoval_NEXT_NO_PURGE	ACE_BC_MSGLOC_NEXT_NPURGE		
#define sitalMessageLocationAndRemoval_LATEST_PURGE	ACE_BC_MSGLOC_LATEST_PURGE		
#define sitalMessageLocationAndRemoval_LATEST_NO_PURGE	ACE_BC_MSGLOC_LATEST_NPURGE		
//#define sitalMessageLocationAndRemoval_NEXT_PURGE	ACE_RT_MSGLOC_NEXT_PURGE		
//#define sitalMessageLocationAndRemoval_NEXT_NO_PURGE	ACE_RT_MSGLOC_NEXT_NPURGE		
//#define sitalMessageLocationAndRemoval_LATEST_PURGE	ACE_RT_MSGLOC_LATEST_PURGE		
//#define sitalMessageLocationAndRemoval_LATEST_NO_PURGE	ACE_RT_MSGLOC_LATEST_NPURGE		
//#define sitalMessageLocationAndRemoval_NEXT_PURGE	ACE_MT_MSGLOC_NEXT_PURGE		
//#define sitalMessageLocationAndRemoval_NEXT_NO_PURGE	ACE_MT_MSGLOC_NEXT_NPURGE		
//#define sitalMessageLocationAndRemoval_LATEST_PURGE	ACE_MT_MSGLOC_LATEST_PURGE		
//#define sitalMessageLocationAndRemoval_LATEST_NO_PURGE	ACE_MT_MSGLOC_LATEST_NPURGE		
#define sitalRtDataBlockIrq_CIRCULAR_BUFFER			ACE_RT_DBLK_CIRC_IRQ		
#define sitalRtDataBlockIrq_END_OF_MESSAGE			ACE_RT_DBLK_EOM_IRQ		
#define sitalBcBlockStatusWord_INVALID_WORD	ACE_BC_BSW_INVWRD		
#define sitalBcBlockStatusWord_BAD_SYNCHRONIZATION	ACE_BC_BSW_BADSYNC		
#define sitalBcBlockStatusWord_WORD_COUNT_ERROR	ACE_BC_BSW_WCERR		
#define sitalBcBlockStatusWord_WRONG_RT_ADDRESS	ACE_BC_BSW_WRGADDR_NGAP		
#define sitalBcBlockStatusWord_GOOD_DATA_BLOCK_RECEIVED	ACE_BC_BSW_GDATA		
#define sitalBcBlockStatusWord_RETRIES_COUNT	ACE_BC_BSW_RETRY		
#define sitalBcBlockStatusWord_MASKED_STATUS	ACE_BC_BSW_MSKED_STS		
#define sitalBcBlockStatusWord_LOOPBACK_FAIL	ACE_BC_BSW_LPFAIL		
#define sitalBcBlockStatusWord_NO_RESPONSE	ACE_BC_BSW_NORES		
#define sitalBcBlockStatusWord_FORMAT_ERROR	ACE_BC_BSW_FMTERR		
#define sitalBcBlockStatusWord_STATUS_SET	ACE_BC_BSW_STS_SET		
#define sitalBcBlockStatusWord_ERROR_FLAG	ACE_BC_BSW_ERRFLG		
#define sitalBcBlockStatusWord_BUS_B	ACE_BC_BSW_CHNL		
#define sitalBcBlockStatusWord_START_OF_MESSAGE	ACE_BC_BSW_SOM		
#define sitalBcBlockStatusWord_END_OF_MESSAGE	ACE_BC_BSW_EOM		
#define sitalRtBlockStatusWord_COMMAND_ERROR	ACE_RT_BSW_CMDERR		
#define sitalRtBlockStatusWord_RT_TO_RT_COMMAND_ERROR	ACE_RT_BSW_RTRTERR_2CMD		
#define sitalRtBlockStatusWord_RT_TO_RT_GSA_ERROR	ACE_RT_BSW_RTRTERR_GSA		
#define sitalRtBlockStatusWord_INVALID_WORD	ACE_RT_BSW_INVWRD		
#define sitalRtBlockStatusWord_BAD_SYNCHRONIZATION	ACE_RT_BSW_BADSYNC		
#define sitalRtBlockStatusWord_WORD_COUNT_ERROR	ACE_RT_BSW_WCERR		
#define sitalRtBlockStatusWord_ILLEGAL_COMMAND	ACE_RT_BSW_ILLCMD		
#define sitalRtBlockStatusWord_CIRCULAR_ROLLOVER	ACE_RT_BSW_CIRCOVR		
#define sitalRtBlockStatusWord_LOOPBACK_FAIL	ACE_RT_BSW_LPFAIL		
#define sitalRtBlockStatusWord_NO_RESPONSE	ACE_RT_BSW_NORES		
#define sitalRtBlockStatusWord_FORMAT_ERROR	ACE_RT_BSW_FMTERR		
#define sitalRtBlockStatusWord_RT_TO_RT	ACE_RT_BSW_RTRT		
#define sitalRtBlockStatusWord_ERROR_FLAG	ACE_RT_BSW_ERRFLG		
#define sitalRtBlockStatusWord_BUS_B	ACE_RT_BSW_CHNL		
#define sitalRtBlockStatusWord_START_OF_MESSAGE	ACE_RT_BSW_SOM		
#define sitalRtBlockStatusWord_END_OF_MESSAGE	ACE_RT_BSW_EOM		
#define sitalMtBlockStatusWord_COMMAND_ERROR						ACE_MT_BSW_CMDERR		
#define sitalMtBlockStatusWord_RT_TO_RT_MESSAGE_COMMAND_ERROR				ACE_MT_BSW_RTRTERR_2CMD		
#define sitalMtBlockStatusWord_RT_TO_RT_MESSAGE_RESPOND_ERROR					ACE_MT_BSW_RTRTERR_GSA		
#define sitalMtBlockStatusWord_INVALID_WORD							ACE_MT_BSW_INVWRD		
#define sitalMtBlockStatusWord_BAD_SYNCHRONIZATION					ACE_MT_BSW_BADSYNC		
#define sitalMtBlockStatusWord_WORD_COUNT_ERROR						ACE_MT_BSW_WCERR		
#define sitalMtBlockStatusWord_ROLLOVER					ACE_MT_BSW_DSTK_ROVER		
#define sitalMtBlockStatusWord_GOOD_DATA							ACE_MT_BSW_GDATA		
#define sitalMtBlockStatusWord_NO_RESPONSE							ACE_MT_BSW_NORES		
#define sitalMtBlockStatusWord_PROTOCOL_VIOLATION							ACE_MT_BSW_FMTERR		
#define sitalMtBlockStatusWord_RT_TO_RT_MESSAGE								ACE_MT_BSW_RTRT		
#define sitalMtBlockStatusWord_ERROR_FLAG							ACE_MT_BSW_ERRFLG		
#define sitalMtBlockStatusWord_BUS_B								ACE_MT_BSW_CHNL		
#define sitalMtBlockStatusWord_START_OF_MESSAGE						ACE_MT_BSW_SOM		
#define sitalMtBlockStatusWord_END_OF_MESSAGE						ACE_MT_BSW_EOM		
#define sitalMtSetupOption_1553A_MODE_CODES_ENABLED			ACE_MT_OPT_1553A_MC		
#define sitalRtMtSetupOption_COMBINED_HOST_BUFFER		ACE_RTMT_COMBO_HBUF
#define sitalMtStack_ACTIVE					ACE_MT_STKLOC_ACTIVE		
#define sitalMtStack_INACTIVE				ACE_MT_STKLOC_INACTIVE		
#define sitalMtStack_STACK_A				ACE_MT_STKLOC_STKA		
#define sitalMtStack_STACK_B				ACE_MT_STKLOC_STKB		
#define sitalMtStackSelector_STACK_A				ACE_MT_STKA		
#define sitalMtStackSelector_STACK_B				ACE_MT_STKB		
#define sitalMtStackSelector_STACK_COMBINED				ACE_MT_STK_CMB		
#define sitalMtStackOption_SINGLE			ACE_MT_SINGLESTK		
#define sitalMtStackOption_DOUBLE			ACE_MT_DOUBLESTK		
#define sitalMtCommandStackSize_256			ACE_MT_CMDSTK_256		
#define sitalMtCommandStackSize_1024		ACE_MT_CMDSTK_1K		
#define sitalMtCommandStackSize_4096		ACE_MT_CMDSTK_4K		
#define sitalMtCommandStackSize_16384		ACE_MT_CMDSTK_16K		
#define sitalMtDataStackSize_512			ACE_MT_DATASTK_512		
#define sitalMtDataStackSize_1024			ACE_MT_DATASTK_1K		
#define sitalMtDataStackSize_2048			ACE_MT_DATASTK_2K		
#define sitalMtDataStackSize_4096			ACE_MT_DATASTK_4K		
#define sitalMtDataStackSize_8192			ACE_MT_DATASTK_8K		
#define sitalMtDataStackSize_16384			ACE_MT_DATASTK_16K		
#define sitalMtDataStackSize_32768			ACE_MT_DATASTK_32K		
#define sitalMessageDirection_BOTH		ACE_MT_FILTER_ALL		
#define sitalMessageDirection_RX		ACE_MT_FILTER_RX		
#define sitalMessageDirection_TX		ACE_MT_FILTER_TX		
//#define sitalRtSubaddress_ALL			ACE_MT_FILTER_SA_ALL		
//#define sitalRtSubaddressMask_0			ACE_MT_FILTER_SA0		
//#define sitalRtSubaddressMask_1			ACE_MT_FILTER_SA1		
//#define sitalRtSubaddressMask_2			ACE_MT_FILTER_SA2		
//#define sitalRtSubaddressMask_3			ACE_MT_FILTER_SA3		
//#define sitalRtSubaddressMask_4			ACE_MT_FILTER_SA4		
//#define sitalRtSubaddressMask_5			ACE_MT_FILTER_SA5		
//#define sitalRtSubaddressMask_6			ACE_MT_FILTER_SA6		
//#define sitalRtSubaddressMask_7			ACE_MT_FILTER_SA7		
//#define sitalRtSubaddressMask_8			ACE_MT_FILTER_SA8		
//#define sitalRtSubaddressMask_9			ACE_MT_FILTER_SA9		
//#define sitalRtSubaddressMask_10			ACE_MT_FILTER_SA10		
//#define sitalRtSubaddressMask_11			ACE_MT_FILTER_SA11		
//#define sitalRtSubaddressMask_12			ACE_MT_FILTER_SA12		
//#define sitalRtSubaddressMask_13			ACE_MT_FILTER_SA13		
//#define sitalRtSubaddressMask_14			ACE_MT_FILTER_SA14		
//#define sitalRtSubaddressMask_15			ACE_MT_FILTER_SA15		
//#define sitalRtSubaddressMask_16			ACE_MT_FILTER_SA16		
//#define sitalRtSubaddressMask_17			ACE_MT_FILTER_SA17		
//#define sitalRtSubaddressMask_18			ACE_MT_FILTER_SA18		
//#define sitalRtSubaddressMask_19			ACE_MT_FILTER_SA19		
//#define sitalRtSubaddressMask_20			ACE_MT_FILTER_SA20		
//#define sitalRtSubaddressMask_21			ACE_MT_FILTER_SA21		
//#define sitalRtSubaddressMask_22			ACE_MT_FILTER_SA22		
//#define sitalRtSubaddressMask_23			ACE_MT_FILTER_SA23		
//#define sitalRtSubaddressMask_24			ACE_MT_FILTER_SA24		
//#define sitalRtSubaddressMask_25			ACE_MT_FILTER_SA25		
//#define sitalRtSubaddressMask_26			ACE_MT_FILTER_SA26		
//#define sitalRtSubaddressMask_27			ACE_MT_FILTER_SA27		
//#define sitalRtSubaddressMask_28			ACE_MT_FILTER_SA28		
//#define sitalRtSubaddressMask_29			ACE_MT_FILTER_SA29		
//#define sitalRtSubaddressMask_30			ACE_MT_FILTER_SA30		
//#define sitalRtSubaddressMask_31			ACE_MT_FILTER_SA31		
#define sitalDeviceTestResult_PASS						ACE_TEST_PASSED
#define sitalDeviceTestResult_NON_UNPERFORMANCE			ACE_TEST_NOT_PERFORMED
#define sitalDeviceTestResult_RAM_FAIL					ACE_TEST_FAILED_RAM
#define sitalDeviceTestResult_REGISTER_FAIL				ACE_TEST_FAILED_REGISTER
#define sitalDeviceTestResult_PROTOCOL_FAIL				ACE_TEST_FAILED_PROTOCOL
#define sitalDeviceTestResult_INTERRUPT_FAIL			ACE_TEST_FAILED_INTERRUPT
#define sitalDeviceTestResult_MEMORY_READ_VECTOR_FAIL				ACE_TEST_FAILED_MVECTOR
#define sitalDeviceTestResult_REGISTER_READ_VECTOR_FAIL				ACE_TEST_FAILED_RVECTOR

// RT built-in test word sources: wWordLocation values.
#define sitalRtBuiltInTestWordSource_REGISTER			ACE_RT_BIT_INTERNAL
#define sitalRtBuiltInTestWordSource_MEMORY				ACE_RT_BIT_EXTERNAL

// RT built-in test permission options: wPermitOrInihibitIfRtBusy values.
#define sitalRtBuiltInTestPermitOnBusy_ENABLED			ACE_RT_BIT_NO_INHIBIT
#define sitalRtBuiltInTestPermitOnBusy_DISABLED			ACE_RT_BIT_INHIBIT

// Return codes.
#define sitalReturnCode_SUCCESS													ACE_ERR_SUCCESS		
#define sitalReturnCode_POSSIBLY_DETRIMENTAL_CONFIGURATION						ACE_WRN_RT_CFG_INVALID		
#define sitalReturnCode_INVALID_DEVICE_NUMBER									ACE_ERR_INVALID_DEVNUM		
#define sitalReturnCode_INVALID_ACCESS											ACE_ERR_INVALID_ACCESS		
#define sitalReturnCode_INVALID_MODE											ACE_ERR_INVALID_MODE		
#define sitalReturnCode_INVALID_STATE											ACE_ERR_INVALID_STATE		
#define sitalReturnCode_INVALID_MEMORY_SIZE										ACE_ERR_INVALID_MEMSIZE		
#define sitalReturnCode_INVALID_ADDRESS											ACE_ERR_INVALID_ADDRESS		
#define sitalReturnCode_INVALID_OPERATING_SYSTEM								ACE_ERR_INVALID_OS		
#define sitalReturnCode_INVALID_ALLOCATION										ACE_ERR_INVALID_MALLOC		
#define sitalReturnCode_INVALID_BUFFER											ACE_ERR_INVALID_BUF		
#define sitalReturnCode_INVALID_ADDRESS_MODE									ACE_ERR_INVALID_ADMODE		
#define sitalReturnCode_INVALID_REGISTER_ADDRESS									ACE_ERR_SIMWRITEREG		
#define sitalReturnCode_INVALID_TIME_TAG_RESOLUTION										ACE_ERR_TIMETAG_RES		
#define sitalReturnCode_INVALID_RESPONSE_TIMEOUT									ACE_ERR_RESPTIME		
#define sitalReturnCode_INVALID_CLOCK_FREQUENCY											ACE_ERR_CLOCKIN		
#define sitalReturnCode_INVALID_MESSAGE_STRUCTURE									ACE_ERR_MSGSTRUCT		
#define sitalReturnCode_INVALID_PARAMETER											ACE_ERR_PARAMETER		
#define sitalReturnCode_INVALID_MODE_OPTIONS									ACE_ERR_INVALID_MODE_OP		
#define sitalReturnCode_OPERATIONAL_STATISTICS_NOT_ENABLED										ACE_ERR_METRICS_NOT_ENA		
#define sitalReturnCode_NOT_SUPPORTED											ACE_ERR_NOT_SUPPORTED		
#define sitalReturnCode_ISQ_DISABLED											ACE_ERR_ISQ_DISABLED		
#define sitalReturnCode_OPERATION_FAIL										ACE_ERR_TASK_FAIL		
#define sitalReturnCode_INVALID_CAN_ADDRESS										ACE_ERR_CANADDR		
#define sitalReturnCode_INVALID_DIO_PORT													ACE_ERR_DIO		
#define sitalReturnCode_REGISTERS_ACCESS_FAIL									ACE_ERR_REG_ACCESS		
#define sitalReturnCode_INVALID_CARD											ACE_ERR_INVALID_CARD		
#define sitalReturnCode_DRIVER_OPEN_FAIL										ACE_ERR_DRIVER_OPEN		
#define sitalReturnCode_MAPPED_MEMORY_ACCESS_FAIL								ACE_ERR_MAPMEM_ACC		
#define sitalReturnCode_INVALID_CARD_NUMBER										ACE_ERR_INVALID_CARDNUM		
#define sitalReturnCode_UNDEFINED_NODE											ACE_ERR_NODE_NOT_FOUND		
#define sitalReturnCode_NODE_NOT_MEMORY_BLOCK									ACE_ERR_NODE_MEMBLOCK		
#define sitalReturnCode_NODE_EXISTS												ACE_ERR_NODE_EXISTS		
#define sitalReturnCode_ALLOCATION_FAIL											ACE_ERR_MEMMGR_FAIL		
#define sitalReturnCode_INVALID_TEST_STRUCTURE										ACE_ERR_TEST_BADSTRUCT		
#define sitalReturnCode_INVALID_FILE											ACE_ERR_TEST_FILE		
#define sitalReturnCode_MT_INVALID_STACK_OPTION									ACE_ERR_MT_BUFTYPE		
#define sitalReturnCode_MT_INVALID_COMMAND_STACK_SIZE								ACE_ERR_MT_CMDSTK		
#define sitalReturnCode_MT_INVALID_DATA_STACK_SIZE									ACE_ERR_MT_DATASTK		
#define sitalReturnCode_MT_INVALID_RT_ADDRESS									ACE_ERR_MT_FILTER_RT		
#define sitalReturnCode_MT_INVALID_DIRECTION_BIT										ACE_ERR_MT_FILTER_TR		
#define sitalReturnCode_MT_INVALID_SUBADDRESS_BUFFER									ACE_ERR_MT_FILTER_SA		
#define sitalReturnCode_MT_INVALID_STACK_SELECTOR									ACE_ERR_MT_STKLOC		
#define sitalReturnCode_MT_INVALID_MESSAGE_LOCATION									ACE_ERR_MT_MSGLOC		
#define sitalReturnCode_MT_INVALID_HOST_BUFFER_SIZE									ACE_ERR_MT_HOST_BUFFERSIZE		
#define sitalReturnCode_MT_HOST_BUFFER_NOT_INSTALLED							ACE_ERR_MT_HOST_BUFFER		
#define sitalReturnCode_RT_AND_MT_NON_COMBINED_HOST_BUFFER_MODE						ACE_ERR_RTMT_COMBO_HOST_BUFFER		
#define sitalReturnCode_RT_AND_MT_INVALID_HOST_BUFFER_SIZE								ACE_ERR_RTMT_HOST_BUFFERSIZE		
#define sitalReturnCode_RT_AND_MT_HOST_BUFFER_NOT_INSTALLED							ACE_ERR_RTMT_HOST_BUFFER		
#define sitalReturnCode_RT_AND_MT_INVALID_MESSAGE_LOCATION							ACE_ERR_RTMT_MSGLOC		
#define sitalReturnCode_RT_DATA_BLOCK_EXISTS									ACE_ERR_RT_DBLK_EXISTS		
#define sitalReturnCode_RT_DATA_BLOCK_ALLOCATION_FAIL							ACE_ERR_RT_DBLK_ALLOC		
#define sitalReturnCode_RT_DATA_BLOCK_MAPPED									ACE_ERR_RT_DBLK_MAPPED		
#define sitalReturnCode_RT_DATA_BLOCK_NOT_CIRCULAR								ACE_ERR_RT_DBLK_NOT_CB		
#define sitalReturnCode_RT_HOST_BUFFER_NOT_INSTALLED							ACE_ERR_RT_HOST_BUFFER		
#define sitalReturnCode_BC_OBJECT_ALREADY_EXISTS								ACE_ERR_BC_DBLK_EXISTS		
#define sitalReturnCode_BC_DATA_BLOCK_ALLOCATION_FAIL							ACE_ERR_BC_DBLK_ALLOC		
#define sitalReturnCode_BC_INVALID_DATA_BLOCK_SIZE									ACE_ERR_BC_DBLK_SIZE		
#define sitalReturnCode_UNDEFINED_DATA_BLOCK									ACE_ERR_UNRES_DATABLK		
#define sitalReturnCode_UNDEFINED_MESSAGE_BLOCK								ACE_ERR_UNRES_MSGBLK		
#define sitalReturnCode_ILLEGAL_FRAME										ACE_ERR_UNRES_FRAME		
#define sitalReturnCode_UNDEFINED_COMMAND										ACE_ERR_UNRES_OPCODE		
#define sitalReturnCode_UNRESOLVED_JUMP											ACE_ERR_UNRES_JUMP		
#define sitalReturnCode_NOT_MAJOR_FRAME											ACE_ERR_FRAME_NOT_MAJOR		
#define sitalReturnCode_SUITABLE_ASYNCHRONOUS_MODE_UNDEFINED					ACE_ERR_NOT_ASYNC_MODE		
#define sitalReturnCode_UNRESOLVED_ASYNCHRONOUS_COMMAND							ACE_ERR_UNRES_ASYNC_OP		
#define sitalReturnCode_ASYNCHRONOUS_LIST_IS_EMPTY								ACE_ERR_UNRES_ASYNC_ID		
#define sitalReturnCode_ASYNCHRONOUS_LIST_NOT_EMPTY								ACE_ERR_ASYNC_NOT_EMPTY		
#define sitalReturnCode_ASYNCHRONOUS_MESSAGE_ERROR								ACE_ERR_ASYNC_MSG		
#define sitalReturnCode_BC_POSSIBLY_DETRIMENTAL_OPCODE										ACE_WRN_BC_OPCODE_INVALID		
#define sitalReturnCode_INVALID_HOST_BUFFER_SIZE									ACE_ERR_HBUFSIZE		
#define sitalReturnCode_HOST_BUFFER_NOT_INSTALLED								ACE_ERR_HOST_BUFFER		
#define sitalReturnCode_TOO_MANY_DEVICES										ACE_ERR_TOO_MANY_DEVS		
#define sitalReturnCode_DEVICE_CONNECTION_FAIL											ACE_RESOURCE_REQ_ERR		
#define sitalReturnCode_WRITE_ERROR												ACE_IOWRITE_ERR		
#define sitalReturnCode_READ_ERROR												ACE_IOREAD_ERR		
#define sitalReturnCode_MEMORY_MAP_FAIL										ACE_MEM_MAP_ERR		
#define sitalReturnCode_TASK_SPAWN_FAIL									ACE_TASK_SPAWN_ERR		

// Structures.
/// RT/MT interrupt status queue entry.
/// Equivalent DDC definition: ISQENTRY
typedef struct sitalIsqEntryStructure
{
	/// Interrupt header.
	/// Equivalent DDC definition: wISQHeader
	U16BIT wHeader;
	/// Interrupt data.
	/// Equivalent DDC definition: wISQData
	U16BIT wData;
} sitalIsqEntryStructure;

/// BC GPQ entry.
/// Equivalent DDC definition: GPQENTRY.
typedef struct sitalGpqEntryStructure
{
	/// Entry header.
	/// Equivalent DDC definition: wGPQHeader
	U16BIT wHeader;
	/// Entry data.
	/// Equivalent DDC definition: wGPQData
	U16BIT wData;
} sitalGpqEntryStructure;

/// BC command information.
/// Equivalent DDC definition: OPCODESTRUCT.
typedef struct sitalCommandStructure
{
	/// Unique command ID.
	/// Equivalent DDC definition: nOpCodeID
	S16BIT swCommandId;
	/// Opcode.
	/// Equivalent DDC definition: wOpcode
	U16BIT wOpcode;
	/// Opcode parameter.
	/// Equivalent DDC definition: wParameter
	U32BIT dwParameter;
	/// Opcode condition.
	/// Equivalent DDC definition: wCondition
	U16BIT wCondition;
} sitalCommandStructure;

/// A decoded MIL-STD-1553 message.
/// Equivalent DDC definition: MSGSTRUCT
typedef struct sitalDecodedMessageStructure
{
	/// Message type.
	/// Equivalent DDC definition: wType
	U16BIT wType;
	/// Block status word.
	/// Equivalent DDC definition: wBlkSts
	U16BIT wBlockStatus;
	/// Time tag - 3rd word (UNUSED).
	/// Equivalent DDC definition: wTimeTag3
	U16BIT wTimeTag3;
	/// Time tag - 2nd word (UNUSED).
	/// Equivalent DDC definition: wTimeTag2
	U16BIT wTimeTag2;
	/// Time tag - 1st word.
	/// Equivalent DDC definition: wTimeTag
	U16BIT wTimeTag;
	/// First command word.
	/// Equivalent DDC definition: wCmdWrd1
	U16BIT wCommandWord1;
	/// Second command word.
	/// Relevant only if field bIsCommandWord2Relevant is TRUE.
	/// Equivalent DDC definition: wCmdWrd2
	U16BIT wCommandWord2;
	/// A flag that says if first command word is relevant.
	/// This field is always TRUE and therefore irrelevant, but it is nevertheless kept in order to be compatible with DDC.
	/// Equivalent DDC definition: wCmdWrd1Flg
	U16BIT bIsCommandWord1Relevant;
	/// A flag that says if second command word is relevant.
	/// Equivalent DDC definition: wCmdWrd2Flg
	U16BIT bIsCommandWord2Relevant;
	/// The [first] status word that's actually identified on the bus.
	/// Relevant only if field bIsStatus1Relevant is TRUE.
	/// Equivalent DDC definition: wStsWrd1
	U16BIT wStatus1;
	/// The second status word that's actually identified on the bus.
	/// Relevant only if field bIsStatus2Relevant is TRUE.
	/// Equivalent DDC definition: wStsWrd2
	U16BIT wStatus2;
	/// A flag that says if first status word is relevant.
	/// Equivalent DDC definition: wStsWrd1Flg
	U16BIT bIsStatus1Relevant;
	/// A flag that says if second status word is relevant.
	/// Equivalent DDC definition: wStsWrd2Flg
	U16BIT bIsStatus2Relevant;
	/// The actual number of valid data words that have been received for this message.
	/// Equivalent DDC definition: wWordCount
	U16BIT wDataWordCount;
	/// Data words.
	/// The number of relevant entries (i.e., those that actually contain data words) is stored in field wDataWordCount.
	/// Equivalent DDC definition: aDataWrds
	U16BIT waData[sitalIeee1553_MAXIMUM_COUNT_OF_MESSAGE_DATA_WORDS];
	/// Control word.
	/// Only relevant in BC mode.
	/// Equivalent DDC definition: wBCCtrlWrd
	U16BIT wBcControlWord;
	/// Message gap time.
	/// Only relevant in BC mode.
	/// Equivalent DDC definition: wBCGapTime
	U16BIT wBcGapTime;
	/// The echo of the last word transmitted by the BC.
	/// Only relevant in BC mode.
	/// Equivalent DDC definition: wBCLoopBack1
	U16BIT wBcLoopbackWord1;
	/// An unused field, kept only in order to be compatible with DDC.
	/// Equivalent DDC definition: wBCLoopBack2
	U16BIT wUnused01;
	/// A flag that says if first loopback word is relevant.
	/// Only relevant in BC mode.
	/// Equivalent DDC definition: wBCLoopBack1Flg
	U16BIT bIsBcLoopbackWord1Relevant;
	/// An unused field, kept only in order to be compatible with DDC.
	/// Only relevant in BC mode.
	/// Equivalent DDC definition: wBCLoopBack2Flg
	U16BIT wUnused02;
} sitalDecodedMessageStructure;

/// General purpose queue operational statistics information.
/// Equivalent DDC definition: GPQMETRIC
typedef struct sitalGpqOperationalStatisticsStructure
{
	/// The count of messages that have been lost.
	/// Equivalent DDC definition: dwLost
	U32BIT dwLostMessageCount;
	/// The current percentage of fullness of the related stack/queue.
	/// This field must contain a value in the region 0 to 100.
	/// Equivalent DDC definition: wPctFull
	U16BIT wFullnessPercentage;
	/// The maximum encountered percentage of fullness of the related stack/queue.
	/// This field must contain a value in the region 0 to 100.
	/// Equivalent DDC definition: wHighPct
	U16BIT wMaximumFullnessPercentage;
} sitalGpqOperationalStatisticsStructure;

/// MT operational information.
/// Equivalent DDC definition: MTINFO
typedef struct sitalMtInformationStructure
{
	/// The configured stack mode, which is either single or double.
	/// Equivalent DDC definition: wStkMode
	U16BIT wStackMode;
	/// The size of the command stack.
	/// Equivalent DDC definition: wCmdStkSize
	U16BIT wCommandStackSize;
	/// The size of the data stack.
	/// Equivalent DDC definition: wDataStkSize
	U16BIT wDataStackSize;
	/// A flag that says whether this device is configured to support protocol 1553-A.
	/// Equivalent DDC definition: b1553aMCodes
	U16BIT bIsProtocol1553aSupported;
	/// The size of the installed host buffer.
	/// Equivalent DDC definition: dwHBufSize
	U32BIT dwHostBufferSize;
} sitalMtInformationStructure;

/// Stack operational statistics information.
/// Equivalent DDC definition: STKMETRIC
typedef struct sitalStackOperationalStatisticsStructure
{
	/// The count of messages that have been lost.
	/// Equivalent DDC definition: dwLost
	U32BIT dwLostMessageCount;
	/// The current percentage of fullness of the related stack/queue.
	/// This field must contain a value in the region 0 to 100.
	/// Equivalent DDC definition: dwPctFull
	U32BIT dwFullnessPercentage;
	/// The maximum encountered percentage of fullness of the related stack/queue.
	/// This field must contain a value in the region 0 to 100.
	/// Equivalent DDC definition: dwHighPct
	U32BIT dwMaximumFullnessPercentage;
} sitalStackOperationalStatisticsStructure;

/// Host buffer operational statistics information.
/// Equivalent DDC definition: HBUFMETRIC
typedef struct sitalHostBufferOperationalStatisticsStructure
{
	/// The count of messages currently stored in the host buffer.
	/// Equivalent DDC definition: dwCount
	U32BIT dwMessageCount;
	/// The count of messages that have been lost.
	/// Equivalent DDC definition: dwLost
	U32BIT dwLostMessageCount;
	/// The current percentage of fullness of the host buffer.
	/// This field must contain a value in the region 0 to 100.
	/// Equivalent DDC definition: dwPctFull
	U32BIT dwFullnessPercentage;
	/// The maximum encountered percentage of fullness of the host buffer.
	/// This field must contain a value in the region 0 to 100.
	/// Equivalent DDC definition: dwHighPct
	U32BIT dwMaximumFullnessPercentage;
} sitalHostBufferOperationalStatisticsStructure;

/// Device test result information.
/// Equivalent DDC definition: TESTRESULT
typedef struct sitalDeviceTestResultStructure
{
	/// Test result (sitalDeviceTestResult_*).
	/// Equivalent DDC definition: wResult
	U16BIT wResult;
	/// A value that designates an expected value that was not eventually found (i.e., a value expected to be found in some device memory address or register, possibly after being passed a suitable transformation).
	/// Only relevant in case field wResult contains sitalDeviceTestResult_*_FAIL.
	/// Equivalent DDC definition: wExpData
	U16BIT wExpectedValue;
	/// A value that designates an actual value that was eventually found (i.e., a value expected to be found in some device memory address or register, possibly after being passed a suitable transformation).
	/// Only relevant in case field wResult contains sitalDeviceTestResult_*_FAIL.
	/// Equivalent DDC definition: wActData
	U16BIT wActualValue;
	/// An unused field, kept only in order to be compatible with DDC.
	/// Equivalent DDC definition: dwExpData
	U32BIT dwUnused01;
	/// An unused field, kept only in order to be compatible with DDC.
	/// Equivalent DDC definition: dwActData
	U32BIT dwUnused02;
	/// An unused field, kept only in order to be compatible with DDC.
	/// Equivalent DDC definition: PciMode32
	BOOLEAN bUnused03;
	/// A device memory address where an unexpected value has been found.
	/// Only relevant in case field wResult contains sitalDeviceTestResult_*_FAIL.
	/// Equivalent DDC definition: wAceAddr
	U16BIT wDeviceMemoryAddress;
	/// The nature and the exact possible values for this field is unique for each test function (see the documentation of the relevant test function).
	/// Yet, in general, this field is set as following:
	/// - In case field wResult contains sitalDeviceTestResult_*_FAIL: The ID of the exact check that failed the test.
	/// - In case field wResult contains sitalDeviceTestResult_PASSED: Any required result detail.
	/// Equivalent DDC definition: wCount
	U16BIT wCheckId;
} sitalDeviceTestResultStructure;



#ifdef __cplusplus
}
#endif



#endif // stld1553_stld1553ToDdc_definitions_INCLUDED
