/// @file
/// stld1553 library's exported definitions and declarations.

// Description  : A header file that contains stld1553 library's exported definitions and declarations
// Version      : 1.0.0.0
// Author       : Sital Technology R&D
//
// Modification history:
//



#ifndef stld1553_INCLUDED
#define stld1553_INCLUDED



#ifdef __cplusplus
// C++ compilers mangle function names, unless the function definitions are protected with extern "C"{}.
extern "C" {
#endif



// Enumeration definitions.

#ifndef stld1553_PRINTINGS_LEVEL
#define stld1553_PRINTINGS_LEVEL
/// Levels of printings to console.
typedef enum // sitalPrintingsLevelEnum
	{
		sitalPrintingsLevel_Information														= 0,	///< Any required informative.
		sitalPrintingsLevel_Warning,																///< Warning message.
		sitalPrintingsLevel_Error,																	///< Error message.
		sitalPrintingsLevel_None																	///< No printing.
	} sitalPrintingsLevelEnum;
#endif // stld1553_PRINTINGS_LEVEL

// Constant definitions.

// General constants.

//	Register addresses.
#define sitalRegisterAddress_INTERRUPT_MASK_1									0x0000U // R/W
#define sitalRegisterAddress_CONFIGURATION_1									0x0001U // R/W
#define sitalRegisterAddress_CONFIGURATION_2									0x0002U // R/W
#define sitalRegisterAddress_START_OR_RESET										0x0003U //   W
#define sitalRegisterAddress_BC_INSTRUCTION_LIST_POINTER						0x0003U // R
#define sitalRegisterAddress_RT_MT_COMMAND_STACK_POINTER						0x0003U // R
#define sitalRegisterAddress_BC_CONTROL_WORD									0x0004U // R/W
#define sitalRegisterAddress_RT_SUBADDRESS_CONTROL_WORD							0x0004U // R/W
#define sitalRegisterAddress_TIME_TAG											0x0005U // R/W
#define sitalRegisterAddress_INTERRUPT_STATUS_1									0x0006U // R
#define sitalRegisterAddress_CONFIGURATION_3									0x0007U // R/W
#define sitalRegisterAddress_CONFIGURATION_4									0x0008U // R/W
#define sitalRegisterAddress_CONFIGURATION_5									0x0009U // R/W
#define sitalRegisterAddress_RT_MT_DATA_STACK_ADDRESS							0x000AU // R/W
#define sitalRegisterAddress_BC_REMAINING_FRAME_TIME							0x000BU // R
#define sitalRegisterAddress_BC_INITIAL_INSTRUCTION_POINTER						0x000DU // R/W
#define sitalRegisterAddress_RT_LAST_COMMAND									0x000DU // R/W
#define sitalRegisterAddress_MT_TRIGGER_WORD									0x000DU // R/W
#define sitalRegisterAddress_LIMITATIONS										0x000EU // R
#define sitalRegisterAddress_RT_STATUS_WORD										0x000EU // R
#define sitalRegisterAddress_RT_BUILT_IN_TEST_WORD								0x000FU // R
#define sitalRegisterAddress_CONFIGURATION_6									0x0018U // R/W
#define sitalRegisterAddress_CONFIGURATION_7									0x0019U // R/W
#define sitalRegisterAddress_SITAL_FIRMWARE_VERSION								0x001AU // R  
#define sitalRegisterAddress_BC_CONDITION_CODE									0x001BU // R  
#define sitalRegisterAddress_BC_GENERAL_PURPOSE_FLAG							0x001BU //   W
#define sitalRegisterAddress_INTERRUPT_MASK_2									0x001DU // R/W
#define sitalRegisterAddress_INTERRUPT_STATUS_2									0x001EU // R
#define sitalRegisterAddress_BC_RT_MT_QUEUE_POINTER								0x001FU // R/W
#define sitalRegisterAddress_BC_GENERAL_PURPOSE_QUEUE_POINTER					0x001FU // R/W
#define sitalRegisterAddress_RT_MT_INTERRUPT_STATUS_QUEUE_POINTER				0x001FU // R/W

// Error injection (for BC) -> no DDC equivalent
#define sitalRegisterAddress_ERRORINJ1											0x0010 //	W
#define sitalRegisterAddress_ERRORINJ2											0x0014 //	W
#define sitalRegisterAddress_ERRORINJ1_MASK										0xFFFF
#define sitalRegisterAddress_ERRORINJ2_MASK										0xFFFF


// Interrupt mask register #1 masks.
#define sitalInterruptMaskRegister1_END_OF_MESSAGE								0x0001U
#define sitalInterruptMaskRegister1_BC_STATUS_SET								0x0002U
#define sitalInterruptMaskRegister1_RT_MODE_CODE								0x0002U
#define sitalInterruptMaskRegister1_MT_PATTREN_TRIGGER							0x0002U
#define sitalInterruptMaskRegister1_FORMAT_ERROR								0x0004U
#define sitalInterruptMaskRegister1_BC_END_OF_FRAME								0x0008U
#define sitalInterruptMaskRegister1_BC_RT_CONTROL_WORD_END_OF_MESSAGE			0x0010U
#define sitalInterruptMaskRegister1_RT_CIRCULAR_BUFFER_ROLLOVER					0x0020U
#define sitalInterruptMaskRegister1_TIME_TAG_ROLLOVER							0x0040U
#define sitalInterruptMaskRegister1_RT_ADDRESS_PARITY_ERROR						0x0080U
#define sitalInterruptMaskRegister1_BC_RETRY									0x0100U
#define sitalInterruptMaskRegister1_HANDSHAKE_FAILURE							0x0200U
#define sitalInterruptMaskRegister1_MT_DATA_STACK_ROLLOVER						0x0400U
#define sitalInterruptMaskRegister1_MT_COMMAND_STACK_ROLLOVER					0x0800U
#define sitalInterruptMaskRegister1_BC_RT_COMMAND_STACK_ROLLOVER				0x1000U
#define sitalInterruptMaskRegister1_BC_RT_TRANSMITTER_TIMEOUT					0x2000U
#define sitalInterruptMaskRegister1_RAM_PARITY_ERROR							0x4000U

// Configuration register #1 masks.
#define sitalConfigurationRegister1_FUNCTION_MASK								0xC000U
#define sitalConfigurationRegister1_FUNCTION_BC									0x0000U
#define sitalConfigurationRegister1_FUNCTION_RT									0x8000U
#define sitalConfigurationRegister1_FUNCTION_MT									0x4000U

#define sitalConfigurationRegister1_BC_MESSAGE_IN_PROGRESS						0x0001U
#define sitalConfigurationRegister1_BC_FRAME_IN_PROGRESS						0x0002U
#define sitalConfigurationRegister1_BC_BUSY										0x0004U
#define sitalConfigurationRegister1_BC_DOUBLE_RETRY								0x0008U
#define sitalConfigurationRegister1_BC_RETRY_ENABLED							0x0010U
#define sitalConfigurationRegister1_BC_SINGLE_RETRY_ENABLED						0x0010U
#define sitalConfigurationRegister1_BC_DOUBLE_RETRY_ENABLED						0x0018U
#define sitalConfigurationRegister1_BC_RETRY_MASK								0x0018U
#define sitalConfigurationRegister1_BC_MESSAGE_GAP_TIME_FIELD_ENABLED			0x0020U
#define sitalConfigurationRegister1_BC_INTERNAL_TRIGGER_ENABLED					0x0040U
#define sitalConfigurationRegister1_BC_EXTERNAL_TRIGGER_ENABLED					0x0080U
#define sitalConfigurationRegister1_BC_FRAME_AUTOREPEAT							0x0100U
#define sitalConfigurationRegister1_BC_STATUS_SET_STOP_ON_FRAME					0x0200U
#define sitalConfigurationRegister1_BC_STATUS_SET_STOP_ON_MESSAGE				0x0400U
#define sitalConfigurationRegister1_BC_FRAME_STOP_ON_ERROR						0x0800U
#define sitalConfigurationRegister1_BC_MESSAGE_STOP_ON_ERROR					0x1000U

#define sitalConfigurationRegister1_RT_MESSAGE_IN_PROGRESS						0x0001U
#define sitalConfigurationRegister1_RT_S00										0x0002U
#define sitalConfigurationRegister1_RT_S01										0x0004U
#define sitalConfigurationRegister1_RT_S02										0x0008U
#define sitalConfigurationRegister1_RT_S03										0x0010U
#define sitalConfigurationRegister1_RT_S04										0x0020U
#define sitalConfigurationRegister1_RT_S05										0x0040U
#define sitalConfigurationRegister1_RT_S06										0x0080U
#define sitalConfigurationRegister1_RT_FLAG										0x0080U
#define sitalConfigurationRegister1_RT_SUBSYSTEM_FLAG							0x0100U
#define sitalConfigurationRegister1_RT_SERVICE_REQUEST							0x0200U
#define sitalConfigurationRegister1_RT_BUSY										0x0400U
#define sitalConfigurationRegister1_RT_DYNAMIC_BUS_CONTROL_ACCEPTANCE			0x0800U
#define sitalConfigurationRegister1_RT_MESSAGE_MONITOR_ENABLED					0x1000U

#define sitalConfigurationRegister1_MT_ACTIVE									0x0001U
#define sitalConfigurationRegister1_MT_TRIGGERED								0x0002U
#define sitalConfigurationRegister1_MT_ENABLED									0x0004U
#define sitalConfigurationRegister1_MT_EXTERNAL_TRIGGER_ENABLED					0x0080U
#define sitalConfigurationRegister1_MT_STOP_ON_TRIGGER							0x0200U
#define sitalConfigurationRegister1_MT_START_ON_TRIGGER							0x0400U
#define sitalConfigurationRegister1_MT_TRIGGER_WORD_ENABLED						0x0800U
#define sitalConfigurationRegister1_MT_MESSAGE_MONITOR_ENABLED					0x1000U
#define sitalConfigurationRegister1_MT_ACTIVE_STACK								0x2000U

// Configuration register #2 masks.
#define sitalConfigurationRegister2_RT_SEPARATE_BROADCAST_DATA					0x0001U
#define sitalConfigurationRegister2_RT_ENHANCED_MEMORY_MANAGEMENT				0x0002U
#define sitalConfigurationRegister2_RT_CLEAR_SERVICE_REQUSET					0x0004U
#define sitalConfigurationRegister2_LEVEL_OR_PULSE_INTERRUPTS					0x0008U
#define sitalConfigurationRegister2_LEVEL_INTERRUPTS							0x0008U
#define sitalConfigurationRegister2_INTERRUPT_STATUS_AUTO_CLEAR					0x0010U
#define sitalConfigurationRegister2_RT_LOAD_TIME_TAG_ON_SYNCHRONIZE				0x0020U
#define sitalConfigurationRegister2_RT_CLEAR_TIME_TAG_ON_SYNCHRONIZE			0x0040U
#define sitalConfigurationRegister2_BC_RT_256_WORD_BOUNDRY_DISABLE				0x0400U
#define sitalConfigurationRegister2_RT_OVERWRITE_INVALID_DATA					0x0800U
#define sitalConfigurationRegister2_RT_SUBADDRESS_DOUBLE_BUFFER					0x1000U
#define sitalConfigurationRegister2_RT_BUSY_LOOKUP_TABLE						0x2000U
#define sitalConfigurationRegister2_RAM_PARITY									0x4000U
#define sitalConfigurationRegister2_ENHANCED_INTERRUPTS							0x8000U

#define sitalConfigurationRegister2_TIME_TAG_RESOLUTION_MASK					0x0380U
#define sitalConfigurationRegister2_TIME_TAG_2US								0x0280U
#define sitalConfigurationRegister2_TIME_TAG_4US								0x0200U
#define sitalConfigurationRegister2_TIME_TAG_8US								0x0180U
#define sitalConfigurationRegister2_TIME_TAG_16US								0x0100U
#define sitalConfigurationRegister2_TIME_TAG_32US								0x0080U
#define sitalConfigurationRegister2_TIME_TAG_64US								0x0000U
#define sitalConfigurationRegister2_TIME_TAG_TEST								0x0300U
#define sitalConfigurationRegister2_TIME_TAG_EXTERNAL_CLOCK						0x0380U

// Start/reset register masks.
#define sitalStartResetRegister_RESET											0x0001U
#define sitalStartResetRegister_BC_MT_START										0x0002U
#define sitalStartResetRegister_INTERRUPT_RESET									0x0004U
#define sitalStartResetRegister_TIME_TAG_RESET									0x0008U
#define sitalStartResetRegister_TIME_TAG_TEST_CLOCK								0x0010U
#define sitalStartResetRegister_BC_STOP_AT_END_OF_FRAME							0x0020U
#define sitalStartResetRegister_BC_MT_STOP_AT_END_OF_MESSAGE					0x0040U
#define sitalStartResetRegister_INITIATE_PROTOCOL_SELF_TEST						0x0080U
#define sitalStartResetRegister_INITIATE_RAM_SELF_TEST							0x0200U
#define sitalStartResetRegister_CLEAR_SELF_TEST_REGISTER						0x0400U
#define sitalStartResetRegister_CLEAR_RT_HALT									0x0800U

// Interrupt status register #1 masks.
#define sitalInterruptStatusRegister1_END_OF_MESSAGE							0x0001U
#define sitalInterruptStatusRegister1_BC_STATUS_SET								0x0002U
#define sitalInterruptStatusRegister1_RT_MODE_CODE								0x0002U
#define sitalInterruptStatusRegister1_MT_PATTERN_TRIGGER						0x0002U
#define sitalInterruptStatusRegister1_FORMAT_ERROR								0x0004U
#define sitalInterruptStatusRegister1_BC_END_OF_FRAME							0x0008U
#define sitalInterruptStatusRegister1_BC_CONTROL_WORD_END_OF_MESSAGE			0x0010U
#define sitalInterruptStatusRegister1_RT_SUBADDRESS_END_OF_MESSAGE				0x0010U
#define sitalInterruptStatusRegister1_RT_CIRCULAR_BUFFER_ROLLOVER				0x0020U
#define sitalInterruptStatusRegister1_TIME_TAG_ROLLOVER							0x0040U
#define sitalInterruptStatusRegister1_RT_ADDRESS_PARITY_ERROR					0x0080U
#define sitalInterruptStatusRegister1_BC_RETRY									0x0100U
#define sitalInterruptStatusRegister1_HANDSHAKE_FAILURE							0x0200U
#define sitalInterruptStatusRegister1_MT_DATA_STACK_ROLLOVER					0x0400U
#define sitalInterruptStatusRegister1_MT_COMMAND_STACK_ROLLOVER					0x0800U
#define sitalInterruptStatusRegister1_BC_RT_COMMAND_STACK_ROLLOVER				0x1000U
#define sitalInterruptStatusRegister1_BC_RT_TX_TIMEOUT							0x2000U
#define sitalInterruptStatusRegister1_RAM_PARITY_ERROR							0x4000U
#define sitalInterruptStatusRegister1_MASTER_INTERRUPT							0x8000U

//MULTI RT SECTION
#define MAX_ELEMENTS_PER_BUSLIST												256		// User can allocate 256  elements of 4 words (total of 1024) in a buslist.

//	Multi RT Register addresses.
#define sitalRegisterAddress_MRT_INTERRUPT_ENABLE_REGISTER_1					0x0000U // R/W
#define sitalRegisterAddress_MRT_INTERRUPT_STATUS_REGISTER_1					0x0001U // R
#define sitalRegisterAddress_MRT_CONFIGURATION_REGISTER							0x0002U // R/W
#define sitalRegisterAddress_MRT_CONFIGURATION_REGISTER_2						0x0003U // R/W (For future use)
#define sitalRegisterAddress_MRT_TIME_TAG_LSB									0x0004U // R/W
#define sitalRegisterAddress_MRT_TIME_TAG_MSB									0x0005U // R/W
#define sitalRegisterAddress_MRT_START_RESET									0x0006U //	 W
#define sitalRegisterAddress_MRT_RT15_TO_0_ENABLE								0x0008U //   W
#define sitalRegisterAddress_MRT_RT30_TO_16_ENABLE								0x0009U //   W
#define sitalRegisterAddress_MRT_COMMAND_LIST_POINTER							0x000AU // R/W
#define sitalRegisterAddress_MRT_COMMAND_LIST_LENGTH							0x000BU // R/W
#define sitalRegisterAddress_MRT_GLOBAL_RX_DATA_POINTER							0x000CU // R
#define sitalRegisterAddress_MRT_GLOBAL_TX_DATA_POINTER							0x000DU // R
#define sitalRegisterAddress_MRT_MESSAGES_COUNT									0x000EU // R/W
#define sitalRegisterAddress_MRT_VERSION_OF_CORE								0x000FU // R
#define sitalRegisterAddress_MRT_ERROR_DEFINITION								0x0010U // R/W
#define sitalRegisterAddress_MRT_ERROR_PARAMETERS								0x0011U // R/W
// Multi RT Error Types 
#define MRT_NO_ERROR															0x0000	
#define MRT_PARITY_ERROR														0x1000
#define MRT_BIPHASE_ERROR														0x2000
#define MRT_SYNC_ERROR															0x3000
#define MRT_ZERO_CROSSING_ERROR													0x4000

#define sitalRegisterAddress_MRT_CODE											0x001AU // 
#define sitalRegisterVALUE_MRT_CODE												0xA001U // R

// BC Error Types 
#define NO_ERROR_SPEC															0x0000	
#define PARITY_ERROR															0x1000
#define BIPHASE_ERROR															0x2000
#define SYNC_ERROR																0x3000
#define ZERO_CROSSING_ERROR														0x4000

// Multi RT  Command Entry Configuration offset 0 bits 8-15
#define sitalCommandEntryConfiguration_MRT_TERMINAL_FLAG						0x0100
#define sitalCommandEntryConfiguration_MRT_DYNAMIC_BUS_CONTROL					0x0200
#define sitalCommandEntryConfiguration_MRT_SUB_SYSTEM_FLAG						0x0400
#define sitalCommandEntryConfiguration_MRT_BUSY									0x0800
#define sitalCommandEntryConfiguration_MRT_SERVICE_REQUEST						0x1000
#define sitalCommandEntryConfiguration_MRT_SET_EOM_INTERRUPT					0x4000
#define sitalCommandEntryConfiguration_MRT_END_OF_MESSAGE						0x8000

//Interrupt enable register #1 Address 0X0 Multi RT
#define sitalInterruptEnableRegister1_MRT_END_OF_MESSAGE						0x0001U
#define sitalInterruptEnableRegister1_MRT_MESSAGE_ERROR_OCCURED					0x0004U
//#define sitalInterruptEnableRegister1_MRT_END_OF_LAST_MESSAGE_IN_BUSLIST		0x0008U
#define sitalInterruptEnableRegister1_MRT_MESSAGE_HAS_ENDED						0x0010U
#define sitalInterruptEnableRegister1_MRT_TIMETAG_COUNTER_ROLLOVER				0x0040U
#define sitalInterruptEnableRegister1_MRT_TX_TIMEOUT							0x2000U
#define sitalInterruptEnableRegister1_MRT_MSB_HIGH_BIT_MASK						0x8000U

// Interrupt status register #1 Address 0X1 Multi RT
#define sitalInterruptStatusRegister1_MRT_END_OF_MESSAGE						0x0001U
#define sitalInterruptStatusRegister1_MRT_MESSAGE_ERROR_OCCURED					0x0004U
#define sitalInterruptStatusRegister1_MRT_END_OF_LAST_MESSAGE_IN_BUSLIST		0x0008U
#define sitalInterruptStatusRegister1_MRT_MESSAGE_HAS_ENDED						0x0010U
#define sitalInterruptStatusRegister1_MRT_LSB_TIMETAG_ROLLOVER					0x0040U
#define sitalInterruptStatusRegister1_MRT_TX_FAILSAFE_TIMEOUT					0x2000U
#define sitalInterruptStatusRegister1_MRT_HW_INTERRUPT_LEVEL_MODE				0x8000U

// Configuration register #1 Address 0X1 Multi RT
#define sitalConfigurationRegister1_MRT_MESSAGE_ACTIVE							0x0001U	//R
#define sitalConfigurationRegister1_MRT_BUS_ACTIVE								0x0002U	//R
#define sitalConfigurationRegister1_MRT_ACTIVE									0x0004U	//R
#define sitalConfigurationRegister1_MRT_SET_STOP_ON_MESSAGE						0x0008U	//R/W
#define sitalConfigurationRegister1_MRT_ENABLE_ILLEGALIZATION					0x0010U	//R/W
#define sitalConfigurationRegister1_MRT_INT_LEVEL_MODE							0x0020U	//R/W

#define sitalConfigurationRegister1_MRT_TIME_TAG_COUNTER_CONTROLLER				0x0040U	//R/W
#define sitalConfigurationRegister1_MRT_TIME_TAG_RESOLUTION_MASK				0x0700U	//R/W
#define sitalConfigurationRegister1_MRT_TIME_TAG_64US							0x0000U	//R/W
#define sitalConfigurationRegister1_MRT_TIME_TAG_32US							0x0100U	//R/W
#define sitalConfigurationRegister1_MRT_TIME_TAG_16US							0x0200U	//R/W
#define sitalConfigurationRegister1_MRT_TIME_TAG_8US							0x0300U	//R/W
#define sitalConfigurationRegister1_MRT_TIME_TAG_4US							0x0400U	//R/W
#define sitalConfigurationRegister1_MRT_TIME_TAG_2US							0x0500U	//R/W
#define sitalConfigurationRegister1_MRT_TIME_TAG_RESOLUTION_INCREMENT			0x0600U	//R/W
#define sitalConfigurationRegister1_MRT_TIME_TAG_INCREMENT_TAG_CLK				0x0700U	//R/W

#define sitalConfigurationRegister1_MRT_TX_GLOBAL_CIRCULAR_BUFFER_MASK			0x3000U	//R/W
#define sitalConfigurationRegister1_MRT_TX_GLOBAL_CIRCULAR_BUFFER_256_WORDS		0x0000U	//R/W
#define sitalConfigurationRegister1_MRT_TX_GLOBAL_CIRCULAR_BUFFER_1K_WORDS		0x1000U	//R/W
#define sitalConfigurationRegister1_MRT_TX_GLOBAL_CIRCULAR_BUFFER_4K_WORDS		0x2000U	//R/W
#define sitalConfigurationRegister1_MRT_TX_GLOBAL_CIRCULAR_BUFFER_16K_WORDS		0x3000U	//R/W

#define sitalConfigurationRegister1_MRT_RX_GLOBAL_CIRCULAR_BUFFER_MASK			0x0000U	//R/W
#define sitalConfigurationRegister1_MRT_RX_GLOBAL_CIRCULAR_BUFFER_256_WORDS		0x0000U	//R/W
#define sitalConfigurationRegister1_MRT_RX_GLOBAL_CIRCULAR_BUFFER_1K_WORDS		0x4000U	//R/W
#define sitalConfigurationRegister1_MRT_RX_GLOBAL_CIRCULAR_BUFFER_4K_WORDS		0x8000U	//R/W
#define sitalConfigurationRegister1_MRT_RX_GLOBAL_CIRCULAR_BUFFER_16K_WORDS		0xC000U	//R/W

#define sital_mRt_DataBlockMode_32_WORDS										0x0000U	//R/W
#define sital_mRt_DataBlockMode_64_WORDS										0x0010U	//R/W
#define sital_mRt_DataBlockMode_256_WORDS										0x0020U	//R/W
#define sital_mRt_DataBlockMode_1K_WORDS										0x0030U	//R/W
#define sital_mRt_DataBlockMode_4K_WORDS										0x0040U	//R/W
#define sital_mRt_DataBlockMode_16K_WORDS										0x0050U	//R/W
#define sital_mRt_DataBlockMode_RESERVED										0x0060U	//R/W
#define sital_mRt_DataBlockMode_GLOBAL											0x0070U	//R/W

// Configuration register #2 Address 0X3 Multi RT
// Place holder for future configurations

// Start/reset register Address 0X6 Multi RT
#define sitalStartResetRegister_MRT_RESET										0x0001U //W
#define sitalStartResetRegister_MRT_START										0x0002U //W
#define sitalStartResetRegister_MRT_TIME_TAG_COUNTER_RESET						0x0008U //W
#define sitalStartResetRegister_MRT_TIME_TAG_INCREMENT_1						0x0010U //W
//#define sitalStartResetRegister_MRT_STOP_AT_END_OF_LAST_MESSAGE					0x0020U //W
#define sitalStartResetRegister_MRT_STOP_AT_END_OF_CURRENT_MESSAGE				0x0040U //W


// Configuration register #3 masks.
#define sitalConfigurationRegister3_RT_ENHANCED_MODE_CODE_HANDLING				0x0001U
#define sitalConfigurationRegister3_RT_MT_1553A_MODE_CODES						0x0002U
#define sitalConfigurationRegister3_RT_FAIL_FLAG_WRAP							0x0004U
#define sitalConfigurationRegister3_RT_BUSY_RX_TRANSFER_DISABLE					0x0008U
#define sitalConfigurationRegister3_RT_ILLEGAL_RX_TRANSFER_DISABLE				0x0010U
#define sitalConfigurationRegister3_RT_ALTERNATE_STATUS_WORD					0x0020U
#define sitalConfigurationRegister3_RT_OVERRIDE_MODE_CODE_ERROR					0x0040U
#define sitalConfigurationRegister3_RT_ILLEGALIZATION_DISABLED					0x0080U
#define sitalConfigurationRegister3_ENHANCED_MODE								0x8000U

#define sitalConfigurationRegister3_MT_DATA_STACK_SIZE							0x0700U
#define sitalConfigurationRegister3_MT_DATA_STACK_65536							0x0000U
#define sitalConfigurationRegister3_MT_DATA_STACK_32768							0x0100U
#define sitalConfigurationRegister3_MT_DATA_STACK_16384							0x0200U
#define sitalConfigurationRegister3_MT_DATA_STACK_8192							0x0300U
#define sitalConfigurationRegister3_MT_DATA_STACK_4096							0x0400U
#define sitalConfigurationRegister3_MT_DATA_STACK_2048							0x0500U
#define sitalConfigurationRegister3_MT_DATA_STACK_1024							0x0600U
#define sitalConfigurationRegister3_MT_DATA_STACK_512							0x0700U

#define sitalConfigurationRegister3_MT_COMMAND_STACK_SIZE						0x1800U
#define sitalConfigurationRegister3_MT_COMMAND_STACK_256						0x0000U
#define sitalConfigurationRegister3_MT_COMMAND_STACK_1024						0x0800U
#define sitalConfigurationRegister3_MT_COMMAND_STACK_4096						0x1000U
#define sitalConfigurationRegister3_MT_COMMAND_STACK_16384						0x1800U

#define sitalConfigurationRegister3_BC_RT_COMMAND_STACK_SIZE					0x6000U
#define sitalConfigurationRegister3_BC_RT_COMMAND_STACK_256						0x0000U
#define sitalConfigurationRegister3_BC_RT_COMMAND_STACK_512						0x2000U
#define sitalConfigurationRegister3_BC_RT_COMMAND_STACK_1024					0x4000U
#define sitalConfigurationRegister3_BC_RT_COMMAND_STACK_2048					0x6000U

// Configuration register #4 masks.
#define sitalConfigurationRegister4_RT_LATCH_ADDRESS							0x0008U
#define sitalConfigurationRegister4_MT_TIME_GAP_OPTION							0x0010U
#define sitalConfigurationRegister4_BC_VALID_BUSY_BIT_NO_DATA					0x0020U
#define sitalConfigurationRegister4_BC_VALID_MESSAGE_ERROR_BIT_NO_DATA			0x0040U
#define sitalConfigurationRegister4_BC_RETRY_BUS_2								0x0080U
#define sitalConfigurationRegister4_BC_RETRY_BUS_1								0x0100U
#define sitalConfigurationRegister4_BC_RETRY_IF_STATUS_SET						0x0200U
#define sitalConfigurationRegister4_BC_RETRY_IF_1553A_AND_MESSAGE_ERROR			0x0400U
#define sitalConfigurationRegister4_BC_BROADCAST_MASK_XOR						0x0800U
#define sitalConfigurationRegister4_BC_ENHANCED_CONTROL_WORD					0x1000U
#define sitalConfigurationRegister4_RT_MODE_CODE_OVERRIDE_BUSY					0x2000U
#define sitalConfigurationRegister4_RT_INHIBIT_BUILT_IN_TEST_WORD_IF_BUSY		0x4000U
#define sitalConfigurationRegister4_RT_EXTERNAL_BUILT_IN_TEST_WORD				0x8000U

#define sitalConfigurationRegister4_TEST_MODE_NORMAL							0x0000U
#define sitalConfigurationRegister4_TEST_MODE_DECODER							0x0001U
#define sitalConfigurationRegister4_TEST_MODE_ENCODER							0x0002U
#define sitalConfigurationRegister4_TEST_MODE_PROTOCOL							0x0003U
#define sitalConfigurationRegister4_TEST_MODE_FAIL_SAFE_TIMER					0x0004U
#define sitalConfigurationRegister4_TEST_MODE_REGISTER							0x0005U
#define sitalConfigurationRegister4_TEST_MODE_TEST								0x0007U

// Configuration register #5 masks.
#define sitalConfigurationRegister5_RT_ADDRESS_PARITY							0x0001U
#define sitalConfigurationRegister5_RT_ADDRESS_MASK								0x003EU
#define sitalConfigurationRegister5_RT_ADDRESS_LATCH							0x0040U
#define sitalConfigurationRegister5_RT_MT_BROADCAST_DISABLE						0x0080U
#define sitalConfigurationRegister5_GAP_CHECK									0x0100U
#define sitalConfigurationRegister5_EXPANDED_CROSSING							0x0800U
#define sitalConfigurationRegister5_BC_RT_EXTERNAL_TX_INHIBIT_B					0x1000U
#define sitalConfigurationRegister5_BC_RT_EXTERNAL_TX_INHIBIT_A					0x2000U
#define sitalConfigurationRegister5_SINGLE_ENDED_SELECT							0x4000U
#define sitalConfigurationRegister5_CLOCK_SELECT_MASK							0x8000U
#define sitalConfigurationRegister5_CLOCK_SELECT_12MHZ							0x8000U
#define sitalConfigurationRegister5_CLOCK_SELECT_16MHZ							0x0000U

#define sitalConfigurationRegister5_RESPONSE_TIMEOUT_MASK						0x0600U
#define sitalConfigurationRegister5_RESPONSE_TIMEOUT_18US						0x0000U
#define sitalConfigurationRegister5_RESPONSE_TIMEOUT_22US						0x0200U
#define sitalConfigurationRegister5_RESPONSE_TIMEOUT_50US						0x0400U
#define sitalConfigurationRegister5_RESPONSE_TIMEOUT_130US						0x0600U

// Limitations register masks.
#define sitalLimitationsRegister_LIMITED_PERFORMANCE							0x8000U

// Configuration register #6 masks.
#define sitalConfigurationRegister6_64_WORD_REGISTER_SPACE						0x0004U
#define sitalConfigurationRegister6_MT_ENHANCED									0x0010U
#define sitalConfigurationRegister6_RT_ADDRESS_SOURCE							0x0020U
#define sitalConfigurationRegister6_RT_MT_INTERRUPT_STATUS_QUEUE				0x0040U
#define sitalConfigurationRegister6_RT_MT_VALID_MESSAGE_QUEUE_DISABLE			0x0080U
#define sitalConfigurationRegister6_RT_MT_INVALID_MESSAGE_QUEUE_DISABLE			0x0100U
#define sitalConfigurationRegister6_RT_GLOBAL_CIRCULAR_BUFFER_MASK				0x1000U
#define sitalConfigurationRegister6_RT_GLOBAL_CIRCULAR_BUFFER_ENABLE			0x1000U
#define sitalConfigurationRegister6_RT_MT_END_OF_MESSAGE_COMMAND_INCREMENT		0x2000U
#define sitalConfigurationRegister6_ENHANCED_CPU_ACCESS							0x4000U
#define sitalConfigurationRegister6_BC_ENHANCED									0x8000U

#define sitalConfigurationRegister6_CLOCK_SELECT_MASK							0x0003U
#define sitalConfigurationRegister6_CLOCK_SELECT_16MHZ							0x0000U
#define sitalConfigurationRegister6_CLOCK_SELECT_12MHZ							0x0001U
#define sitalConfigurationRegister6_CLOCK_SELECT_20MHZ							0x0002U
#define sitalConfigurationRegister6_CLOCK_SELECT_10MHZ							0x0003U

#define sitalConfigurationRegister6_RT_GLOBAL_CIRCULAR_BUFFER_ENABLE_SIZE_MASK			0x0E00U
#define sitalConfigurationRegister6_RT_GLOBAL_CIRCULAR_BUFFER_ENABLE_SIZE_SINGLE		0x0000U
#define sitalConfigurationRegister6_RT_GLOBAL_CIRCULAR_BUFFER_ENABLE_SIZE_128			0x0200U
#define sitalConfigurationRegister6_RT_GLOBAL_CIRCULAR_BUFFER_ENABLE_SIZE_256			0x0400U
#define sitalConfigurationRegister6_RT_GLOBAL_CIRCULAR_BUFFER_ENABLE_SIZE_512			0x0600U
#define sitalConfigurationRegister6_RT_GLOBAL_CIRCULAR_BUFFER_ENABLE_SIZE_1024			0x0800U
#define sitalConfigurationRegister6_RT_GLOBAL_CIRCULAR_BUFFER_ENABLE_SIZE_2048			0x0A00U
#define sitalConfigurationRegister6_RT_GLOBAL_CIRCULAR_BUFFER_ENABLE_SIZE_4096			0x0C00U
#define sitalConfigurationRegister6_RT_GLOBAL_CIRCULAR_BUFFER_ENABLE_SIZE_8192			0x0E00U

// Configuration register #7 masks.
#define sitalConfigurationRegister7_MODE_CODE_RESET_IN_COMMAND_SELECT			0x0001U
#define sitalConfigurationRegister7_BC_ENHANCED_WATCHDOG_TIMER_ENABLE			0x0002U
#define sitalConfigurationRegister7_BC_RT_ENHANCED_TIME_TAG_SYNCHRONIZE			0x0004U
#define sitalConfigurationRegister7_1553B_RESPONSE_TIME							0x0008U
#define sitalConfigurationRegister7_RT_HALT										0x0010U

// Interrupt mask register #2 masks.
#define sitalInterruptMaskRegister2_BUILT_IN_TEST_COMPLETE						0x0002U
#define sitalInterruptMaskRegister2_BC_INTERRUPT_0								0x0004U
#define sitalInterruptMaskRegister2_BC_INTERRUPT_1								0x0008U
#define sitalInterruptMaskRegister2_BC_INTERRUPT_2								0x0010U
#define sitalInterruptMaskRegister2_BC_INTERRUPT_3								0x0020U
#define sitalInterruptMaskRegister2_MT_DATA_STACK_HALF_ROLLOVER					0x0040U
#define sitalInterruptMaskRegister2_MT_COMMAND_STACK_HALF_ROLLOVER				0x0080U
#define sitalInterruptMaskRegister2_RT_CIRCULAR_BUFFER_HALF_ROLLOVER			0x0100U
#define sitalInterruptMaskRegister2_RT_COMMAND_STACK_HALF_ROLLOVER				0x0200U
#define sitalInterruptMaskRegister2_BC_TRAP										0x0400U
#define sitalInterruptMaskRegister2_BC_CALL_STACK_ERROR							0x0800U
#define sitalInterruptMaskRegister2_BC_GENERAL_PURPOSE_QUEUE_ROLLOVER			0x1000U
#define sitalInterruptMaskRegister2_RT_INTERRUPT_SERVICE_QUEUE_ROLLOVER			0x1000U
#define sitalInterruptMaskRegister2_RT_ILLEGAL_COMMAND							0x2000U
#define sitalInterruptMaskRegister2_BC_OPCODE_PARITY_ERROR						0x4000U

// Interrupt status register #2 masks.
#define sitalInterruptStatusRegister2_INTERRUPT_CHAIN							0x0001U
#define sitalInterruptStatusRegister2_BUILT_IN_TEST_COMPLETE					0x0002U
#define sitalInterruptStatusRegister2_BC_ENHANCED_INTERRUPTS_0					0x0004U
#define sitalInterruptStatusRegister2_BC_ENHANCED_INTERRUPTS_1					0x0008U
#define sitalInterruptStatusRegister2_BC_ENHANCED_INTERRUPTS_2					0x0010U
#define sitalInterruptStatusRegister2_BC_ENHANCED_INTERRUPTS_3					0x0020U
#define sitalInterruptStatusRegister2_MT_DATA_STACK_HALF_ROLLOVER				0x0040U
#define sitalInterruptStatusRegister2_MT_COMMAND_STACK_HALF_ROLLOVER			0x0080U
#define sitalInterruptStatusRegister2_RT_CIRCULAR_HALF_ROLLOVER					0x0100U
#define sitalInterruptStatusRegister2_RT_COMMAND_STACK_HALF_ROLLOVER			0x0200U
#define sitalInterruptStatusRegister2_BC_TRAP_OPCODE							0x0400U
#define sitalInterruptStatusRegister2_BC_CALL_STACK_ERROR						0x0800U
#define sitalInterruptStatusRegister2_QUEUE_ROLLOVER							0x1000U
#define sitalInterruptStatusRegister2_RT_ILLEGAL_COMMAND						0x2000U
#define sitalInterruptStatusRegister2_BC_OPCODE_PARITY_ERROR					0x4000U
#define sitalInterruptStatusRegister2_MASTER_INTERRUPT							0x8000U

// IEEE-1553 constants.
#define sitalIeee1553_SUBADDRESS_COUNT										32U		///< The number of subaddresses defined by protocol IEEE-1533.
#define sitalIeee1553_MAXIMUM_COUNT_OF_MESSAGE_DATA_WORDS					32U		///< The maximum number of message data words supported by protocol IEEE-1533.

#define sitalIeee1553_Status_TERMINAL_ADDRESS								0xF800U	///< The terminal address field mask in the status word of protocol IEEE-1533.
#define sitalIeee1553_Status_OFFSET_OF_TERMINAL_ADDRESS						11U		///< The index of the lowest of the bits of the terminal address field mask in the status word of protocol IEEE-1533.
#define sitalIeee1553_Status_ERROR_SECTION									0x07EFU	///< The error flags section field mask in the status word of protocol IEEE-1533, i.e., the whole status word excluding the terminal address field and the broadcast command received field.
#define sitalIeee1553_Status_MESSAGE_ERROR									0x0400U	///< The message error field mask in the status word of protocol IEEE-1533. Set in case of a data error or an illegal command.
#define sitalIeee1553_Status_INSTRUMENTATION								0x0200U	///< The instrumentation field mask in the status word of protocol IEEE-1533. Must be a zero.
#define sitalIeee1553_Status_SERVICE_REQUEST								0x0100U	///< The service request field mask in the status word of protocol IEEE-1533. Set only in case the remote terminal requires service.
#define sitalIeee1553_Status_BROADCAST_COMMAND_RECEIVED						0x0010U	///< The broadcast command received field mask in the status word of protocol IEEE-1533. Set only in case of a respond to a "Transmit Status Word" or "Transmit Last Command Word" mode code messages, if these are received by a remote terminal right after it received a broadcast message.
#define sitalIeee1553_Status_BUSY											0x0008U	///< The busy field mask in the status word of protocol IEEE-1533. Set in case the remote terminal in unable to move data.
#define sitalIeee1553_Status_SUBSYSTEM_FAULT_FLAG							0x0004U	///< The subsystem flag field mask in the status word of protocol IEEE-1533. Set in case a fault or failure is identified in any of the subsystems to which the remote terminal is connected.
#define sitalIeee1553_Status_DYNAMIC_BUS_CONTROL_ACCEPTANCE					0x0002U	///< The dynamic bus control acceptance field mask in the status word of protocol IEEE-1533. Must be a zero, as dynamic bus control acceptance  isn't supported.
#define sitalIeee1553_Status_TERMINAL_FAULT_FLAG							0x0001U	///< The terminal flag field mask in the status word of protocol IEEE-1533. Set in case of a fault of a failure within the remote terminal circuitry.

// General minimums & maximums.
#ifdef sitalMaximum_DEVICES_RESTRICTED
#define sitalMaximum_DEVICES									sitalMaximum_DEVICES_RESTRICTED	///< Maximum number of devices in the system. (Equivalent DDC definition: MAX_NUM_OF_DEVICES)
#else // not sitalMaximum_DEVICES_RESTRICTED
#define sitalMaximum_DEVICES									32U			///< Maximum number of devices in the system. (Equivalent DDC definition: MAX_NUM_OF_DEVICES)
#endif // sitalMaximum_DEVICES_RESTRICTED
#define sitalMaximum_CARDS										10U			///< Maximum number of cards in the system.
#define sitalMinimum_SIZE_OF_RT_AND_MT_DEVICE_MEMORY			4096U		///< Minimum size (in words) of RT&MT device memory (must be be divisible by 32).
#define sitalMinimum_SIZE_OF_DEVICE_MEMORY						2048U		///< Minimum size (in words) of device memory (must be be divisible by 32).
#define sitalMaximum_SIZE_OF_DEVICE_MEMORY						65536U		///< Maximum size (in words) of device memory (must be be divisible by 32).
#define sitalMinimum_SIZE_OF_HOST_BUFFER						4096U		///< Minimum size (in words) of a host buffer.
#define sitalMaximum_SIZE_OF_HOST_BUFFER						131072U		///< Maximum size (in words) of a host buffer. This constant is smaller than the one offered by DDC ACE in order to save memory, as this library avoids using any dynamic memory allocations, and therefore statically allocates maximal host buffers for all possible devices.
#define sitalMaximum_MESSAGES_IN_HOST_BUFFER					(min(sitalRtMaximum_MESSAGE_SIZE,sitalMtMaximum_MESSAGE_SIZE))	///< Maximum number of messages the may be stored for a RT&MT device in case the maximum possible host buffer has been installed.

// BC maximums.
#define sitalBcMaximum_MESSAGE_SIZE								42U		///< Maximum size (in words) of a raw message. (Equivalent DDC definition: ACE_MSGSIZE_BC)
#define sitalBcMaximum_ACTUAL_MESSAGE_BLOCK						10U		///< The actual size (in words) of the largest message block, i.e., a RT-to-RT message data block, in device memory.
#define sitalBcMaximum_FRAME_NESTING_STACK						17U		///< The maximum number of frame IDs in the nesting stack, which includes all frames, from the starter major frame to the last one called (see the documentation for function sitalBc_Start).
#define sitalBcMaximum_FRAME_NESTING_DEPTH						4U		///< The maximum number of nesting frame IDs in the nesting stack (to exclude the leading major frame: see the documentation for function sitalBc_Start).
#define sitalBcMaximum_ASYNCHRONOUS_MESSAGES					256U		///< The maximum number of asynchronous messages per BC (if equal-to/bigger-than sitalBcCounter_MESSAGES, no limitation is practically imposed).

// RT maximums.
#define sitalRtMaximum_MESSAGE_SIZE								36U		///< Maximum size (in words) of a raw message. (Equivalent DDC definition: ACE_MSGSIZE_RT)

// RT minimums.
#define sitalRtMinimum_COMMAND_STACKS_IN_HOST_BUFFER			3U		///< Minimum size (in units of "the number of messages that may be stored in the command stack in its current size") of a host buffer.

// MT maximums.
#define sitalMtMaximum_MESSAGE_SIZE								40U		///< Maximum size (in words) of a raw message. (Equivalent DDC definition: ACE_MSGSIZE_MT)

// MT minimums.
#define sitalMtMinimum_COMMAND_STACKS_IN_HOST_BUFFER			3U		///< Minimum size (in units of "the number of messages that may be stored in the command stack in its current size") of a host buffer.

// RT&MT maximums.
#define sitalRtMtMaximum_MESSAGE_SIZE							42U		///< Maximum size (in words) of a raw message. (Equivalent DDC definition: ACE_MSGSIZE_RTMT)

// RT memory object sizes (in words).
#define sitalRtMemoryObjectSize_COMMAND_STACK_ENTRY				4U		///< The size (in words) of a single command stack entry in device memory.

// MT memory object sizes (in words).
#define sitalMtMemoryObjectSize_COMMAND_STACK_ENTRY				4U		///< The size (in words) of a single command stack entry in device memory.

// RT&MT memory object sizes (in words).
#define sitalRtMtMemoryObjectSize_COMMAND_STACK_ENTRY			4U		///< The size (in words) of a single command stack entry in device memory.

// ARINC429 Max devices for single PC (consider PC104 stack-up)
#define sitalMaximum_DEVICES_ARINC429							32U	///< Maximum number of devices in the system per card.
#define sitalMaximum_CARDS_ARINC429								10U	///< Maximum number of devices in the system per card.

// BC counters.
#define sitalBcCounter_GPQ_ENTRIES								32U		///< Number of available GPQ entries per BC.
#define sitalBcCounter_ISQ_ENTRIES								32U		///< Number of available ISQ entries per BC.
#define sitalBcCounter_COMMANDS									512U		///< Number of available user defined commands per BC.
#define sitalBcCounter_FRAME_COMMANDS							128U		///< Number of available user defined commands per BC frame.
#define sitalBcCounter_MESSAGES									300U		///< Number of available user defined messages per BC.
#define sitalBcCounter_DATA_BLOCKS								300U		///< Number of available user defined data blocks per BC.
#define sitalBcCounter_FRAMES									300U		///< Number of available user defined frames per BC.

// RT counters.
#define sitalRtCounter_DATA_BLOCKS								256U		///< Number of available data blocks per RT.
#define sitalRtCounter_MODE_CODES								48U		///< Number of available mode codes in the RT mode code table.

// BC message creation: wMessageDirection values.
#define sitalCommand_RX	0x0000U	///< Receive command. (Equivalent DDC definition: ACE_RX_CMD)
#define sitalCommand_TX	0x0001U	///< Transmit command. (Equivalent DDC definition: ACE_TX_CMD)

// MIL-STD-1553 constants.
#define sital1553_BROADCAST			0x001FU		///< Broadcast address. (Equivalent DDC definition: ACE_BROADCAST)
#define sital1553_MODE_CODE1		0x0000U		///< Mode code subaddress. (Equivalent DDC definition: ACE_MODE_CODE1)
#define sital1553_MODE_CODE2		0x001FU		///< Mode code subaddress. (Equivalent DDC definition: ACE_MODE_CODE2)

// MIL-STD-1553 coded message types.
// The Tx/Rx bit says whether the Tx/Rx bit is set in the [first] command word of messages of the type.
#define sitalMessageType_BC_TO_RT					 0U 	///< BC-to-RT message:					Broadcast=0	Mode=0	Data=0	Tx/Rx=0		(Equivalent DDC definition: ACE_MSG_BCTORT)
#define sitalMessageType_RT_TO_BC					 1U 	///< Rt-to-BC message:					Broadcast=0	Mode=0	Data=0	Tx/Rx=1		(Equivalent DDC definition: ACE_MSG_RTTOBC)
#define sitalMessageType_RT_TO_RT					 2U 	///< RT-to-RT message:					Broadcast=0	Mode=0	Data=1	Tx/Rx=0		(Equivalent DDC definition: ACE_MSG_RTTORT)
#define sitalMessageType_MODE_NO_DATA				 5U 	///< Mode-no-Data message:				Broadcast=0	Mode=1	Data=0	Tx/Rx=1		(Equivalent DDC definition: ACE_MSG_MODENODATA)
#define sitalMessageType_MODE_DATA_RX				 6U 	///< Mode-data-Rx message:				Broadcast=0	Mode=1	Data=1	Tx/Rx=0		(Equivalent DDC definition: ACE_MSG_MODEDATARX)
#define sitalMessageType_MODE_DATA_TX				 7U 	///< Mode-data-Tx message:				Broadcast=0	Mode=1	Data=1	Tx/Rx=1		(Equivalent DDC definition: ACE_MSG_MODEDATATX)
#define sitalMessageType_BROADCAST					 8U 	///< Broadcast message:					Broadcast=1	Mode=0	Data=0	Tx/Rx=0		(Equivalent DDC definition: ACE_MSG_BRDCST)
#define sitalMessageType_BROADCAST_RT_TO_RT			10U 	///< Broadcast-RT-to-RT message:		Broadcast=1	Mode=0	Data=1	Tx/Rx=0		(Equivalent DDC definition: ACE_MSG_BRDCSTRTTORT)
#define sitalMessageType_BROADCAST_MODE_NO_DATA		13U 	///< Broadcast-mode-no-data message:	Broadcast=1	Mode=1	Data=0	Tx/Rx=1		(Equivalent DDC definition: ACE_MSG_BRDCSTMODENODATA)
#define sitalMessageType_BROADCAST_MODE_DATA		14U	///< Broadcast-mode-data message:		Broadcast=1	Mode=1	Data=1	Tx/Rx=0		(Equivalent DDC definition: ACE_MSG_BRDCSTMODEDATA)
#define sitalMessageType_INVALID					15U	///< Invalid message:					Broadcast=1	Mode=1	Data=1	Tx/Rx=1		(Equivalent DDC definition: ACE_MSG_INVALID)

// Device initialization: wAccess values.
#define sitalAccess_CARD			0x0000U		// Card. (Equivalent DDC definition: ACE_ACCESS_CARD)
#define sitalAccess_SIMULATION		0x0001U		// Simulation. (Equivalent DDC definition: ACE_ACCESS_SIM)
#define sitalAccess_USER			0x0002U		// User. (Equivalent DDC definition: ACE_ACCESS_USR)

// Device initialization: wMode values.
#define sitalMode_TEST			0x0000U		///< Test. (Equivalent DDC definition: ACE_MODE_TEST)
#define sitalMode_BC			0x0001U		///< BC - Bus Controller. (Equivalent DDC definition: ACE_MODE_BC)
#define sitalMode_RT			0x0002U		///< RT - Remote Terminal. (Equivalent DDC definition: ACE_MODE_RT)
#define sitalMode_MT			0x0003U		///< MT - Monitor Terminal. (Equivalent DDC definition: ACE_MODE_MT)
#define sitalMode_RT_AND_MT		0x0004U		///< RT & MT - dual function, Remote Terminal and Monitor Terminal. (Equivalent DDC definition: ACE_MODE_RTMT)
#define sitalMode_MRT			0x0005U		///< MRT - Multi RT (No DDC Equivalence)
#define sitalMode_RS485			0x0006U		///< RS 485 (No DDC Equivalence)
#define sitalMode_ARINC429		0x0007U		///< ARINC 429 (No DDC Equivalence)

// Device initialization: wMode diversification values.
#define sitalModeVariant_NONE					0x0000U		///< No advanced mode requested.
#define sitalModeVariant_NO_TIME_TAG_RESET		0x1000U		///< Don't reset time tag. (Equivalent DDC definition: ACE_NO_TT_RESET)
#define sitalModeVariant_ADVANCED				0x2000U		///< Advanced mode. (Equivalent DDC definition: ACE_ADVANCED_MODE)

// Device core configuration: (*wpCoreConfiguration) values.
#define sitalCoreConfiguration_LIMITED_OPERATION	0x0001U ///< An evaluation device that is only capable of limited operation.

// Response timeout: wResponseTimeout values.
#define sitalResponseTimeout_18US			0U		///< Response timeout of 18.5us. (Equivalent DDC definition: ACE_RESPTIME_18US)
#define sitalResponseTimeout_22US			1U		///< Response timeout of 22.5us. (Equivalent DDC definition: ACE_RESPTIME_22US)
#define sitalResponseTimeout_50US			2U		///< Response timeout of 50.5us. (Equivalent DDC definition: ACE_RESPTIME_50US)
#define sitalResponseTimeout_130US			3U		///< Response timeout of 130us. (Equivalent DDC definition: ACE_RESPTIME_130US)

// Logical device states.
#define sitalDeviceState_RESET		0U		///< Not initialized. (Equivalent DDC definition: ACE_STATE_RESET)
#define sitalDeviceState_READY		1U		///< Initialized but idle. (Equivalent DDC definition: ACE_STATE_READY)
#define sitalDeviceState_RUN		2U		///< Running. (Equivalent DDC definition: ACE_STATE_RUN)

// Device clock frequency configuration: wClockFrequency values.
#define sitalClockSetup_16MHZ		0U		///< Frequency of 16MHZ. (Equivalent DDC definition: ACE_CLOCK_16MHZ)
#define sitalClockSetup_12MHZ		1U		///< Frequency of 12MHZ. (Equivalent DDC definition: ACE_CLOCK_12MHZ)
#define sitalClockSetup_20MHZ		2U		///< Frequency of 20MHZ. (Equivalent DDC definition: ACE_CLOCK_20MHZ)
#define sitalClockSetup_10MHZ		3U		///< Frequency of 10MHZ. (Equivalent DDC definition: ACE_CLOCK_10MHZ)

// The use of the inputs to the Manchester-II decoder: wDoubleOrSingleEndedInputDevice values.
#define sitalInputDevice_SingleEnded		0U		///< Decode single ended input. (Equivalent DDC definition: ACE_SINGLE_ENDED)
#define sitalInputDevice_DoubleEnded		1U		///< Decode double ended input. (Equivalent DDC definition: ACE_DOUBLE_ENDED)

// The way zero crossing of the bus signal is detected: wExpendedXingOption values.
#define sitalExpendedXing_Disable		0U		///< Sample single clock edge. (Equivalent DDC definition: ACE_DISABLE_EXPANDED_XING)
#define sitalExpendedXing_Enable		1U		///< Sample both clock edges. (Equivalent DDC definition: ACE_ENABLE_EXPANDED_XING)

// Does RAM parity check take place: wRamParityCheckEnabler values.
#define sitalRamParityCheck_DISABLE		0U		///< Disable RAM parity check. (Equivalent DDC definition: ACE_DISABLE_PARITY_CHECK)
#define sitalRamParityCheck_ENABLE		1U		///< Enable RAM parity check. (Equivalent DDC definition: ACE_ENABLE_PARITY_CHECK)

// Time tag resolution: wTimeTagResolution values.
#define sitalTimeTagResolution_2US					0U		///< Time tag resolution of 2us. (Equivalent DDC definition: ACE_TT_2US)
#define sitalTimeTagResolution_4US					1U		///< Time tag resolution of 4us. (Equivalent DDC definition: ACE_TT_4US)
#define sitalTimeTagResolution_8US					2U		///< Time tag resolution of 8us. (Equivalent DDC definition: ACE_TT_8US)
#define sitalTimeTagResolution_16US					3U		///< Time tag resolution of 16us. (Equivalent DDC definition: ACE_TT_16US)
#define sitalTimeTagResolution_32US					4U		///< Time tag resolution of 32us. (Equivalent DDC definition: ACE_TT_32US)
#define sitalTimeTagResolution_64US					5U		///< Time tag resolution of 64us. (Equivalent DDC definition: ACE_TT_64US)
#define sitalTimeTagResolution_TEST					6U		///< Test time tag clock. (Equivalent DDC definition: ACE_TT_TEST)
#define sitalTimeTagResolution_EXTERNAL_CLOCK		7U		///< Use external time tag clock. (Equivalent DDC definition: ACE_TT_EXT)

// Device IRQ configuration: wInterruptMode values.
#define sitalIrqMode_PULSE		0U		///< Pulse mode interrupts. (Equivalent DDC definition: ACE_IRQ_PULSE)
#define sitalIrqMode_LEVEL		1U		///< Level mode interrupts. (Equivalent DDC definition: ACE_IRQ_LEVEL)

// Device IRQ configuration: wAutoClear values.
#define sitalIrqClear_NO_AUTO_CLEAR	0U		///< Auto clear IRQs disabled. (Equivalent DDC definition: ACE_IRQ_NO_AUTO_CLR)
#define sitalIrqClear_AUTO_CLEAR	1U		///< Auto clear IRQs enabled. (Equivalent DDC definition: ACE_IRQ_AUTO_CLR)

// RT/MT interrupt status queue entry manipulation: sitalIsqEntryStructure.wHeader values.
#define sitalInterrupt_NON_MESSAGE							0x0001U		///< Non message. (Equivalent DDC definition: ACE_ISQ_MSG_NONMSG)
// (From here on: message based)
#define sitalInterrupt_TX_TIMEOUT							0x8000U		///< Tx timeout. (Equivalent DDC definition: ACE_ISQ_TX_TIMEOUT)
#define sitalInterrupt_ILL_LOOKUP							0x4000U		///< Illegal LKUP. (Equivalent DDC definition: ACE_ISQ_ILL_LKUP)
#define sitalInterrupt_MT_DATA_STACK_HALF_ROLLOVER			0x2000U		///< MT data stack 50% full. (Equivalent DDC definition: ACE_ISQ_MT_DSTK_50P_ROVR)
#define sitalInterrupt_MT_DATA_STACK_ROVER					0x1000U		///< MT data stack rollover. (Equivalent DDC definition: ACE_ISQ_MT_DSTK_ROVER)
#define sitalInterrupt_RT_DATA_STACK_HALF_ROLLOVER			0x0800U		///< RT data stack 50% full. (Equivalent DDC definition: ACE_ISQ_RT_DSTK_50P_ROVR)
#define sitalInterrupt_RT_DATA_STACK_ROLLOVER				0x0400U		///< RT data stack rollover. (Equivalent DDC definition: ACE_ISQ_RT_DSTK_ROVER)
#define sitalInterrupt_MT_COMMAND_STACK_HALF_ROLLOVER		0x0200U		///< MT command stack 50% full. (Equivalent DDC definition: ACE_ISQ_MT_CSTK_50P_ROVR)
#define sitalInterrupt_MT_COMMAND_STACK_ROLLOVER			0x0100U		///< MT command stack rollover. (Equivalent DDC definition: ACE_ISQ_MT_CSTK_ROVR)
#define sitalInterrupt_RT_COMMAND_STACK_HALF_ROLLOVER		0x0080U		///< RT command stack 50% full. (Equivalent DDC definition: ACE_ISQ_RT_CSTK_50P_ROVR)
#define sitalInterrupt_RT_COMMAND_STACK_ROLLOVER			0x0040U		///< RT command stack rollover. (Equivalent DDC definition: ACE_ISQ_RT_CSTK_ROVR)
#define sitalInterrupt_HANDSHAKE_FAIL						0x0020U		///< Handshake fail. (Equivalent DDC definition: ACE_ISQ_HNDSHK_FAIL)
#define sitalInterrupt_FORMAT_ERROR							0x0010U		///< Format error. (Equivalent DDC definition: ACE_ISQ_FMT_ERR)
#define sitalInterrupt_MODE_CODE							0x0008U		///< Mode code. (Equivalent DDC definition: ACE_ISQ_MCODE)
#define sitalInterrupt_SUBADDRESS_END_OF_MESSAGE			0x0004U		///< Subaddress end of message. (Equivalent DDC definition: ACE_ISQ_SA_EOM)
#define sitalInterrupt_END_OF_MESSAGE						0x0002U		///< End of message. (Equivalent DDC definition: ACE_ISQ_EOM)
// (From here on: non-message based)
#define sitalInterrupt_TIME_TAG								0x0010U		///< Time tag. (Equivalent DDC definition: ACE_ISQ_TIME_TAG)
#define sitalInterrupt_RT_ADDRESS_PARITY					0x0008U		///< RT address parity error. (Equivalent DDC definition: ACE_ISQ_RT_ADDR_PAR)
#define sitalInterrupt_SELF_TEST							0x0004U		///< Self test. (Equivalent DDC definition: ACE_ISQ_SELF_TEST)

// Device IRQ configuration: dwIrqMask values.
#define sitalInterruptRegister1_END_OF_MESSAGE 							0x00000001U		///< End of message. (Equivalent DDC definition: ACE_IMR1_EOM)
#define sitalInterruptRegister1_BC_STATUS_SET							0x00000002U		///< RT status with incorrect RT address. (Equivalent DDC definition: ACE_IMR1_BC_STATUS_SET)
#define sitalInterruptRegister1_RT_MODE_CODE							0x00000002U		///< Mode code. (Equivalent DDC definition: ACE_IMR1_RT_MODE_CODE)
#define sitalInterruptRegister1_MT_PATTERN_TRIGGER						0x00000002U		///< Pattern trigger. (Equivalent DDC definition: ACE_IMR1_MT_PATTERN_TRIG)
#define sitalInterruptRegister1_FORMAT_ERROR 							0x00000004U		///< Loop test error or message failure. (Equivalent DDC definition: ACE_IMR1_FORMAT_ERR)
#define sitalInterruptRegister1_BC_END_OF_FRAME							0x00000008U		///< End of frame. (Equivalent DDC definition: ACE_IMR1_BC_END_OF_FRM)
#define sitalInterruptRegister1_BC_END_OF_MESSAGE 						0x00000010U		///< BC end of message. (Equivalent DDC definition: ACE_IMR1_BC_MSG_EOM)
#define sitalInterruptRegister1_RT_SUBADDRESS_END_OF_MESSAGE 			0x00000010U		///< RT subaddress end of message. (Equivalent DDC definition: ACE_IMR1_RT_SUBADDR_EOM)
#define sitalInterruptRegister1_RT_CIRCULAR_BUFFER_ROLLOVER				0x00000020U		///< RT circular buffer rollover. (Equivalent DDC definition: ACE_IMR1_RT_CIRCBUF_ROVER)
#define sitalInterruptRegister1_TIME_TAG_ROLLOVER						0x00000040U		///< Time tag register rollover. (Equivalent DDC definition: ACE_IMR1_TT_ROVER)
#define sitalInterruptRegister1_RT_ADDRESS_PARITY_ERROR					0x00000080U		///< RT address parity error. (Equivalent DDC definition: ACE_IMR1_RT_ADDR_PAR_ERR)
#define sitalInterruptRegister1_BC_RETRY								0x00000100U		///< BC message retry. (Equivalent DDC definition: ACE_IMR1_BC_RETRY)
#define sitalInterruptRegister1_HANDSHAKE_FAILURE						0x00000200U		///< Handshake timeout. (Equivalent DDC definition: ACE_IMR1_HSHAKE_FAIL)
#define sitalInterruptRegister1_MT_DATA_STACK_ROLLOVER					0x00000400U		///< Data stack rollover. (Equivalent DDC definition: ACE_IMR1_MT_DATASTK_ROVER)
#define sitalInterruptRegister1_MT_COMMAND_STACK_ROLLOVER				0x00000800U		///< MT command stack rollover. (Equivalent DDC definition: ACE_IMR1_MT_CMDSTK_ROVER)
#define sitalInterruptRegister1_BC_RT_COMMAND_STACK_ROLLOVER			0x00001000U		///< BC/RT command stack rollover. (Equivalent DDC definition: ACE_IMR1_BCRT_CMDSTK_ROVER)
#define sitalInterruptRegister1_BC_RT_TRANSMITTER_TIMEOUT				0x00002000U		///< BC/RT Tx timeout. (Equivalent DDC definition: ACE_IMR1_BCRT_TX_TIMEOUT)
#define sitalInterruptRegister1_RAM_PARITY_ERROR						0x00004000U		///< RAM parity error. (Equivalent DDC definition: ACE_IMR1_RAM_PAR_ERR)
#define sitalInterruptRegister1_MASTER_INTERRUPT						0x00008000U		///< Master interrupt.
#define sitalInterruptRegister2_INTERRUPT_CHAIN							0x00010000U		///< Interrupt chain.
#define sitalInterruptRegister2_BUILT_IN_TEST_COMPLETE					0x00020000U		///< Built in test complete. (Equivalent DDC definition: ACE_IMR2_BIT_COMPLETE)
#define sitalInterruptRegister2_BC_IRQ0									0x00040000U		///< BC IRQ h/w instruction generated. (Equivalent DDC definition: ACE_IMR2_BC_UIRQ0)
#define sitalInterruptRegister2_BC_IRQ1									0x00080000U		///< BC IRQ h/w instruction generated. (Equivalent DDC definition: ACE_IMR2_BC_UIRQ1)
#define sitalInterruptRegister2_BC_IRQ2									0x00100000U		///< BC IRQ h/w instruction generated. (Equivalent DDC definition: ACE_IMR2_BC_UIRQ2)
#define sitalInterruptRegister2_BC_IRQ3									0x00200000U		///< BC IRQ h/w instruction generated. (Equivalent DDC definition: ACE_IMR2_BC_UIRQ3)
#define sitalInterruptRegister2_MT_DATA_STACK_HALF_ROLLOVER				0x00400000U		///< MT data stack 50% full. (Equivalent DDC definition: ACE_IMR2_MT_DSTK_50P_ROVER)
#define sitalInterruptRegister2_MT_COMMAND_STACK_HALF_ROLLOVER			0x00800000U		///< MT command stack 50% full. (Equivalent DDC definition: ACE_IMR2_MT_CSTK_50P_ROVER)
#define sitalInterruptRegister2_RT_CIRCULAR_BUFFER_HALF_ROLLOVER		0x01000000U		///< RT circular buffer rollover. (Equivalent DDC definition: ACE_IMR2_RT_CIRC_50P_ROVER)
#define sitalInterruptRegister2_RT_COMMAND_STACK_HALF_ROLLOVER			0x02000000U		///< RT command stack rollover. (Equivalent DDC definition: ACE_IMR2_RT_CSTK_50P_ROVER)
#define sitalInterruptRegister2_BC_TRAP									0x04000000U		///< BC trap - illegal opcode or watchdog timeout. (Equivalent DDC definition: ACE_IMR2_BC_TRAP)
#define sitalInterruptRegister2_BC_CALL_STACK_ERROR 					0x08000000U		///< BC call stack overflow/underflow error. (Equivalent DDC definition: ACE_IMR2_BC_CALLSTK_ERR)
#define sitalInterruptRegister2_BC_GENERAL_PURPOSE_QUEUE_ROLLOVER		0x10000000U		///< BC GPQ rollover. (Equivalent DDC definition: ACE_IMR2_GPQ_ISQ_ROVER)
#define sitalInterruptRegister2_RT_INTERRUPT_SERVICE_QUEUE_ROLLOVER		0x10000000U		///< RT ISQ rollover. (Equivalent DDC definition: ACE_IMR2_GPQ_ISQ_ROVER)
#define sitalInterruptRegister2_RT_ILLEGAL_COMMAND 						0x20000000U		///< RT received illegal message. (Equivalent DDC definition: ACE_IMR2_RT_ILL_CMD)
#define sitalInterruptRegister2_BC_OPCODE_PARITY_ERROR					0x40000000U		///< BC instruction opcode parity error. (Equivalent DDC definition: ACE_IMR2_BC_OPCODE_PARITY)
#define sitalInterruptRegister2_MASTER_INTERRUPT						0x80000000U		///< Master interrupt.

// BC message modification: wModificationFlags values.
#define sitalBcMessageModifier_MESSAGE1_DATA_BLOCK			0x0001U		///< Modified part of message: Data block 1. (Equivalent DDC definition: ACE_BC_MOD_DBLK1)
#define sitalBcMessageModifier_MESSAGE1_BC_CONTROL			0x0002U		///< Modified part of message: BC control 1. (Equivalent DDC definition: ACE_BC_MOD_BCCTRL1)
#define sitalBcMessageModifier_MESSAGE1_COMMAND1			0x0004U		///< Modified part of message: Message 1 - Command 1. (Equivalent DDC definition: ACE_BC_MOD_CMDWRD1_1)
#define sitalBcMessageModifier_MESSAGE1_COMMAND2			0x0008U		///< Modified part of message: Message 1 - Command 2. (Equivalent DDC definition: ACE_BC_MOD_CMDWRD1_2)
#define sitalBcMessageModifier_MESSAGE1_GAPTIME				0x0010U		///< Modified part of message: Gap time 1. (Equivalent DDC definition: ACE_BC_MOD_GAPTIME1)
#define sitalBcMessageModifier_MESSAGE2_DATA_BLOCK			0x0020U		///< Modified part of message: Data block 2. (Equivalent DDC definition: ACE_BC_MOD_DBLK2)
#define sitalBcMessageModifier_MESSAGE2_BC_CONTROL			0x0040U		///< Modified part of message: BC control 2. (Equivalent DDC definition: ACE_BC_MOD_BCCTRL2)
#define sitalBcMessageModifier_MESSAGE2_COMMAND1			0x0080U		///< Modified part of message: Message 2 - Command 1. (Equivalent DDC definition: ACE_BC_MOD_CMDWRD2_1)
#define sitalBcMessageModifier_MESSAGE2_COMMAND2			0x0100U		///< Modified part of message: Message 2 - Command 2. (Equivalent DDC definition: ACE_BC_MOD_CMDWRD2_2)
#define sitalBcMessageModifier_MESSAGE2_GAPTIME				0x0200U		///< Modified part of message: Gap time 2. (Equivalent DDC definition: ACE_BC_MOD_GAPTIME2)

// BC activation state: wCurrentState values.
#define sitalBcActivationState_IDLE							0x0000U		///< BC currently isn't running any frame. (Equivalent DDC definition: ACE_BC_IDLE)
#define sitalBcActivationState_BUSY							0x0001U		///< BC currently running a frame. (Equivalent DDC definition: ACE_BC_BUSY)

// BC frame creation: wFlags values.
#define sitalBcFrameFlag_DEFAULT							0x0000U		///< Default frame options.
#define sitalBcFrameFlag_MINOR_FRAME_IRQ_DISABLE			0x0001U		///< Disable interrupt at end of frame. (Equivalent DDC definition: ACE_BC_MNRFRM_IRQ_DISABLE)

// BC message retries: wNumberOfRetries values.
#define sitalMessageRetryCount_NONE			0U		///< No retry on message failure. (Equivalent DDC definition: ACE_RETRY_NONE)
#define sitalMessageRetryCount_ONE			1U		///< One retry on message failure. (Equivalent DDC definition: ACE_RETRY_ONCE)
#define sitalMessageRetryCount_TWO			2U		///< Two retries on message failure. (Equivalent DDC definition: ACE_RETRY_TWICE)

// BC message retries: wFirstRetryBus/wSecondRetryBus values.
#define sitalMessageRetryBus_SAME			0U		///< Upon message failure do retry on same bus. (Equivalent DDC definition: ACE_RETRY_SAME)
#define sitalMessageRetryBus_OTHER			1U		///< Upon message failure do retry on the other bus. (Equivalent DDC definition: ACE_RETRY_ALT)

// BC configuration dwOptions values.
#define sitalBcSetupOption_ASYNCHRONOUS_LOW_PRIORITY_MODE			0x00000001U		///< Low priority asynchronous mode. (Equivalent DDC definition: ACE_BC_ASYNC_LMODE)
#define sitalBcSetupOption_ASYNCHRONOUS_HIGH_PRIORITY_MODE			0x00000002U		///< High priority asynchronous mode. (Equivalent DDC definition: ACE_BC_ASYNC_HMODE)
#define sitalBcSetupOption_ASYNCHRONOUS_BOTH_PRIORITY_MODES			0x00000003U		///< Both low & high priority asynchronous modes. (Equivalent DDC definition: ACE_BC_ASYNC_BOTH)
// NB - 9.1.2017 - added a High Async single message option
#define sitalBcSetupOption_ASYNCHRONOUS_HIGH_PRIORITY_ONCE_ANYWAY	0x00000200U		///NON DDC compatible option, will transmit once even when no response

// BC data block creation: wDataBlockSize values.
#define sitalBcDataBlockSizeOption_SINGLE		32U		///< Single data block of 32 words. (Equivalent DDC definition: ACE_BC_DBLK_SINGLE)
#define sitalBcDataBlockSizeOption_DOUBLE		33U		///< Double buffered data block of 64 words. (Equivalent DDC definition: ACE_BC_DBLK_DOUBLE)

// BC message control word masks.
#define sitalBcControlWord_RT_TO_RT														0x0001U		///< BC control word mask: RT to RT. (Equivalent DDC definition: ACE_BCCTRL_RT_TO_RT)
#define sitalBcControlWord_BROADCAST													0x0002U		///< BC control word mask: Broadcast. (Equivalent DDC definition: ACE_BCCTRL_BCST)
#define sitalBcControlWord_MODE															0x0004U		///< BC control word mask: Mode. (Equivalent DDC definition: ACE_BCCTRL_MODE)
// (From here on: dwOptions values)
#define sitalBcControlWord_1553A														0x0008U		///< BC control word mask: 1553A. (Equivalent DDC definition: ACE_BCCTRL_1553A)
#define sitalBcControlWord_1553B														0x0000U		///< BC control word mask: 1553B. (Equivalent DDC definition: ACE_BCCTRL_1553B)
#define sitalBcControlWord_END_OF_MESSAGE_INTERRUPT_ENABLED								0x0010U		///< BC control word mask: EOM interrupt enabled. (Equivalent DDC definition: ACE_BCCTRL_EOM_IRQ)
#define sitalBcControlWord_BROADCAST_CHECK_MASKED										0x0020U		///< BC control word mask: Broadcast check masked. (Equivalent DDC definition: ACE_BCCTRL_BCST_MSK)
#define sitalBcControlWord_LOOPBACK_TEST_PERFORMED										0x0040U		///< BC control word mask: Enable offline self test performed. (Equivalent DDC definition: ACE_BCCTRL_SELFTST)
#define sitalBcControlWord_BUS															0x0080U		///< BC control word mask: The channel to use.
#define sitalBcControlWord_BUS_A														0x0080U		///< BC control word mask: Use channel A. (Equivalent DDC definition: ACE_BCCTRL_CHL_A)
#define sitalBcControlWord_BUS_B														0x0000U		///< BC control word mask: Use channel B. (Equivalent DDC definition: ACE_BCCTRL_CHL_B)
#define sitalBcControlWord_RETRY_ENABLED												0x0100U		///< BC control word mask: Retry enabled. (Equivalent DDC definition: ACE_BCCTRL_RETRY_ENA)
#define sitalBcControlWord_RESERVE_STATUS_BITS_MASKED									0x0200U		///< BC control word mask: Reserved status bit masked. (Equivalent DDC definition: ACE_BCCTRL_RES_MSK)
#define sitalBcControlWord_TERMINAL_STATUS_FLAG_MASKED									0x0400U		///< BC control word mask: Terminal status flag masked. (Equivalent DDC definition: ACE_BCCTRL_TFLG_MSK)
#define sitalBcControlWord_SUBSYSTEM_STATUS_FLAG_MASKED									0x0800U		///< BC control word mask: Subsystem status flag masked. (Equivalent DDC definition: ACE_BCCTRL_SSFLG_MSK)
#define sitalBcControlWord_BUSY_STATUS_BIT_MASKED										0x1000U		///< BC control word mask: Busy status bit masked. (Equivalent DDC definition: ACE_BCCTRL_SSBSY_MSK)
#define sitalBcControlWord_SERVICE_REQUEST_STATUS_BIT_MASKED							0x2000U		///< BC control word mask: Service request status bit masked. (Equivalent DDC definition: ACE_BCCTRL_SREQ_MSK)
#define sitalBcControlWord_MESSAGE_ERROR_STATUS_BIT_MASKED								0x4000U		///< BC control word mask: Message error status bit mask. (Equivalent DDC definition: ACE_BCCTRL_ME_MSK)
#define sitalBcControlWord_TX_TIME_TAG_IN_SYNCHRONIZE_WITH_DATA_MODE_COMMAND			0x8000U		///< BC control word mask: Tx time tag in synchronize with data mode command.
// (From here on: special dwOptions values; though these aren't not coded as part of a message's BC control word, they are combined with BC control word options in the dwOptions parameter of specific message creation function (i.e., to exclude function sitalBc_Message_Create).
#define sitalBcMessageOption_DUAL_MESSAGE												0x80000000U		///< A pair of messages stored one after the other in device memory to support an XQF opcode. (Equivalent DDC definition: ACE_MSGOPT_DOUBLE_BUFFER)
#define sitalBcMessageOption_STAY_ON_ALTERNATE_BUS										0x40000000U		///< A specific usage of XQF opcode when the message fails, flip to the double buffered message and stay on it until next error. (Equivalent DDC definition: ACE_MSGOPT_STAY_ON_ALT)

// BC command creation: wOpcode values.
#define sitalOpcode_TRAP							0x0000U		///< Trap. (Equivalent DDC definition: ACE_OPCODE_TRP)
#define sitalOpcode_EXECUTE_MESSAGE					0x0001U		///< Execute message. (Equivalent DDC definition: ACE_OPCODE_XEQ)
#define sitalOpcode_JUMP							0x0002U		///< Jump. (Equivalent DDC definition: ACE_OPCODE_JMP)
#define sitalOpcode_CALL_SUBROUTINE					0x0003U		///< Call subroutine. (Equivalent DDC definition: ACE_OPCODE_CAL)
#define sitalOpcode_RETURN_FROM_SUBROUTINE			0x0004U		///< Return from subroutine. (Equivalent DDC definition: ACE_OPCODE_RTN)
#define sitalOpcode_INTERRUPT_REQUEST				0x0006U		///< Interrupt request. (Equivalent DDC definition: ACE_OPCODE_IRQ)
#define sitalOpcode_HALT							0x0007U		///< Halt the BC. (Equivalent DDC definition: ACE_OPCODE_HLT)
#define sitalOpcode_DELAY							0x0008U		///< Delay in microseconds. (Equivalent DDC definition: ACE_OPCODE_DLY)
#define sitalOpcode_WAIT_END_OF_FRAME				0x0009U		///< Wait until frame counter is zero. (Equivalent DDC definition: ACE_OPCODE_WFT)
#define sitalOpcode_COMPARE_TO_FRAME_TIMER			0x000AU		///< Compare frame timer to value. (Equivalent DDC definition: ACE_OPCODE_CFT)
#define sitalOpcode_COMPARE_TO_MESSAGE_TIMER		0x000BU		///< Compare message timer to value.
#define sitalOpcode_UPDATE_GENERAL_PURPOSE_FLAG		0x000CU		///< Set/clear/toggle the 8 GP bits. (Equivalent DDC definition: ACE_OPCODE_FLG)
#define sitalOpcode_LOAD_TIME_TAG_COUNTER			0x000DU		///< Load time tag counter. (Equivalent DDC definition: ACE_OPCODE_LTT)
#define sitalOpcode_LOAD_FRAME_TIMER				0x000EU		///< Load frame time register. (Equivalent DDC definition: ACE_OPCODE_LFT)
#define sitalOpcode_START_FRAME_TIMER				0x000FU		///< Start frame time counter. (Equivalent DDC definition: ACE_OPCODE_SFT)
#define sitalOpcode_PUSH_TIME_TAG_COUNTER			0x0010U		///< Push time tag reg to queue. (Equivalent DDC definition: ACE_OPCODE_PTT)
#define sitalOpcode_PUSH_BLOCK_STATUS_WORD			0x0011U		///< Push block status word to queue. (Equivalent DDC definition: ACE_OPCODE_PBS)
#define sitalOpcode_PUSH_VALUE						0x0012U		///< Push data to queue. (Equivalent DDC definition: ACE_OPCODE_PSI)
#define sitalOpcode_PUSH_INDERCT_VALUE				0x0013U		///< Push memory to queue. (Equivalent DDC definition: ACE_OPCODE_PSM)
#define sitalOpcode_WAIT_FOR_TRIGGER				0x0014U		///< Wait for external trigger. (Equivalent DDC definition: ACE_OPCODE_WTG)
#define sitalOpcode_EXECUTE_AND_FLIP				0x0015U		///< Execute and flip message. (Equivalent DDC definition: ACE_OPCODE_XQF)
// (From here on: Sital's unique hardware opcodes)
#define sitalOpcode_FOCUS_ON_VARIABLE				0x0016U		///< Focus on variable.
#define sitalOpcode_ADD_TO_VARIABLE					0x0017U		///< Add value to the currently focused variable.
#define sitalOpcode_LOAD_TO_VARIABLE				0x0018U		///< Load value to the currently focused variable.
#define sitalOpcode_COMPARE_VARIABLE				0x0019U		///< Compare the currently focused variable.
#define sitalOpcode_PUSH_VARIABLE					0x001AU		///< Focus on variable and push its value to the general purpose queue.
// (From here on: software opcodes)
#define sitalOpcode_TIME_CONDITIONED_MESSAGE_TX		0xC000U		///< A software opcode that's parsed into a series of hardware opcodes that condition the Tx of a message with available frame time, similar to what's done asynchronous messages. (Equivalent DDC definition: ACE_S_OPCODE_AMSG)

// BC command creation: wCondition values.
#define sitalOpcodeCondition_LESS_THAN				0x0000U	///< Opcode condition: Less than. (Equivalent DDC definition: ACE_CNDTST_LT)
#define sitalOpcodeCondition_GREATER_THAN			0x0010U	///< Opcode condition: Greater than. (Equivalent DDC definition: ACE_CNDTST_GT)
#define sitalOpcodeCondition_EQUAL					0x0001U	///< Opcode condition: Equal. (Equivalent DDC definition: ACE_CNDTST_EQ)
#define sitalOpcodeCondition_NOT_EQUAL				0x0011U	///< Opcode condition: Not equal. (Equivalent DDC definition: ACE_CNDTST_NEQ)
#define sitalOpcodeCondition_GP1_1					0x0001U	///< Opcode condition: GP1 is logic 1. (Equivalent DDC definition: ACE_CNDTST_GP1_1)
#define sitalOpcodeCondition_GP1_0					0x0011U	///< Opcode condition: GP1 is logic 0. (Equivalent DDC definition: ACE_CNDTST_GP1_0)
#define sitalOpcodeCondition_GP2_1					0x0002U	///< Opcode condition: GP2 is logic 1. (Equivalent DDC definition: ACE_CNDTST_GP2_1)
#define sitalOpcodeCondition_GP2_0					0x0012U	///< Opcode condition: GP2 is logic 0. (Equivalent DDC definition: ACE_CNDTST_GP2_0)
#define sitalOpcodeCondition_GP3_1					0x0003U	///< Opcode condition: GP3 is logic 1. (Equivalent DDC definition: ACE_CNDTST_GP3_1)
#define sitalOpcodeCondition_GP3_0					0x0013U	///< Opcode condition: GP3 is logic 0. (Equivalent DDC definition: ACE_CNDTST_GP3_0)
#define sitalOpcodeCondition_GP4_1					0x0004U	///< Opcode condition: GP4 is logic 1. (Equivalent DDC definition: ACE_CNDTST_GP4_1)
#define sitalOpcodeCondition_GP4_0					0x0014U	///< Opcode condition: GP4 is logic 0. (Equivalent DDC definition: ACE_CNDTST_GP4_0)
#define sitalOpcodeCondition_GP5_1					0x0005U	///< Opcode condition: GP5 is logic 1. (Equivalent DDC definition: ACE_CNDTST_GP5_1)
#define sitalOpcodeCondition_GP5_0					0x0015U	///< Opcode condition: GP5 is logic 0. (Equivalent DDC definition: ACE_CNDTST_GP5_0)
#define sitalOpcodeCondition_GP6_1					0x0006U	///< Opcode condition: GP6 is logic 1. (Equivalent DDC definition: ACE_CNDTST_GP6_1)
#define sitalOpcodeCondition_GP6_0					0x0016U	///< Opcode condition: GP6 is logic 0. (Equivalent DDC definition: ACE_CNDTST_GP6_0)
#define sitalOpcodeCondition_GP7_1					0x0007U	///< Opcode condition: GP7 is logic 1. (Equivalent DDC definition: ACE_CNDTST_GP7_1)
#define sitalOpcodeCondition_GP7_0					0x0017U	///< Opcode condition: GP8 is logic 0. (Equivalent DDC definition: ACE_CNDTST_GP7_0)
#define sitalOpcodeCondition_NO_RESPONSE			0x0008U	///< Opcode condition: No response from RT. (Equivalent DDC definition: ACE_CNDTST_NO_RES)
#define sitalOpcodeCondition_RESPONSE				0x0018U	///< Opcode condition: Response from RT. (Equivalent DDC definition: ACE_CNDTST_RES)
#define sitalOpcodeCondition_FORMAT_ERROR			0x0009U	///< Opcode condition: Format error. (Equivalent DDC definition: ACE_CNDTST_FMT_ERR)
#define sitalOpcodeCondition_NO_FORMAT_ERROR		0x0019U	///< Opcode condition: No format error. (Equivalent DDC definition: ACE_CNDTST_NO_FMT_ERR)
#define sitalOpcodeCondition_GOOD_TRANSFER			0x000AU	///< Opcode condition: Good data block transfer. (Equivalent DDC definition: ACE_CNDTST_GD_XFER)
#define sitalOpcodeCondition_BAD_TRANFER			0x001AU	///< Opcode condition: Bad data block transfer. (Equivalent DDC definition: ACE_CNDTST_BAD_XFER)
#define sitalOpcodeCondition_MASKED_STATUS_SET		0x000BU	///< Opcode condition: Masked status set. (Equivalent DDC definition: ACE_CNDTST_MSK_STS_SET)
#define sitalOpcodeCondition_MASKED_STATUS_CLEAR	0x001BU	///< Opcode condition: Masked status clread. (Equivalent DDC definition: ACE_CNDTST_MSK_STS_CLR)
#define sitalOpcodeCondition_BAD_MESSAGE			0x000CU	///< Opcode condition: Bad message. (Equivalent DDC definition: ACE_CNDTST_BAD_MSG)
#define sitalOpcodeCondition_GOOD_MESSAGE			0x001CU	///< Opcode condition: Good message. (Equivalent DDC definition: ACE_CNDTST_GOOD_MSG)
#define sitalOpcodeCondition_NO_RETRY				0x001DU	///< Opcode condition: No retries. (Equivalent DDC definition: ACE_CNDTST_0RETRY)
#define sitalOpcodeCondition_1_RETRY				0x000DU	///< Opcode condition: One retry. (Equivalent DDC definition: ACE_CNDTST_1RETRY)
#define sitalOpcodeCondition_2_RETRIES				0x000EU	///< Opcode condition: Two retries. (Equivalent DDC definition: ACE_CNDTST_2RETRY)
#define sitalOpcodeCondition_ALWAYS					0x000FU	///< Opcode condition: Always run opcode. (Equivalent DDC definition: ACE_CNDTST_ALWAYS)
#define sitalOpcodeCondition_NEVER					0x001FU	///< Opcode condition: Never run opcode. (Equivalent DDC definition: ACE_CNDTST_NEVER)

// BC command distortion: wDistortionManner values.
#define sitalOpcodeDistortion_None					0x0000U		///< No command distortion required from now on.
#define sitalOpcodeDistortion_FlipBit				0x0001U		///< Flip a specific bit in the command word (the number of the bit to flip, 0-15, is a required parameter).
#define sitalOpcodeDistortion_SetCommand			0x0002U		///< Set the command word to a specific value (that value, 0x0000-0xFFFF, is a required parameter).

// General purpose Queue flags.
#define sitalGeneralPurposeQueueFlag_END_OF_MAJOR_FRAME					0xFFFFU	///< . (Equivalent DDC definition: ACE_GPQ_MJR_EOF)
#define sitalGeneralPurposeQueueFlag_END_OF_MINOR_FRAME					0xFFF8U	///< . (Equivalent DDC definition: ACE_GPQ_MNR_EOF)
#define sitalGeneralPurposeQueueFlag_WATCHDOG_TIMEOUT					0xFFF1U	///< . (Equivalent DDC definition: ACE_GPQ_MRR_TIME_EXP)

// BC frame run: sdwFrameCount values.
#define sitalBcFrameIterations_RUN_FOREVER					(-1)		///< Run a major frame forever.

// BC condition code manipulation: wConditionCode values.
#define sitalBcConditionCode_GPF_EQUAL_FLAG					0U		///< Condition code: Equal. (Equivalent DDC definition: ACE_CND_LT_GT)
#define sitalBcConditionCode_GPF_LESS_THAN_FLAG				1U		///< Condition code: Less than. (Equivalent DDC definition: ACE_CND_EQ_NE)
#define sitalBcConditionCode_GPF0							0U		///< Condition code: GPF-0. (Equivalent DDC definition: ACE_CND_GPF0)
#define sitalBcConditionCode_GPF1							1U		///< Condition code: GPF-1. (Equivalent DDC definition: ACE_CND_GPF1)
#define sitalBcConditionCode_GPF2							2U		///< Condition code: GPF-2. (Equivalent DDC definition: ACE_CND_GPF2)
#define sitalBcConditionCode_GPF3							3U		///< Condition code: GPF-3. (Equivalent DDC definition: ACE_CND_GPF3)
#define sitalBcConditionCode_GPF4							4U		///< Condition code: GPF-4. (Equivalent DDC definition: ACE_CND_GPF4)
#define sitalBcConditionCode_GPF5							5U		///< Condition code: GPF-5. (Equivalent DDC definition: ACE_CND_GPF5)
#define sitalBcConditionCode_GPF6							6U		///< Condition code: GPF-6. (Equivalent DDC definition: ACE_CND_GPF6)
#define sitalBcConditionCode_GPF7							7U		///< Condition code: GPF-7. (Equivalent DDC definition: ACE_CND_GPF7)
#define sitalBcConditionCode_NO_RESPONSE					8U		///< Condition code: No response. (Equivalent DDC definition: ACE_CND_NORES)
#define sitalBcConditionCode_FORMAT_ERROR					9U		///< Condition code: Format error. (Equivalent DDC definition: ACE_CND_FMT_ERR)
#define sitalBcConditionCode_GOOD_DATA_BLOCK_TRANSFER		10U		///< Condition code: Good data block transfer. (Equivalent DDC definition: ACE_CND_GD_DATA)
#define sitalBcConditionCode_MASKED_STATUS					11U		///< Condition code: Masked status. (Equivalent DDC definition: ACE_CND_MSKED_STS)
#define sitalBcConditionCode_BAD_MESSAGE					12U		///< Condition code: Bad message. (Equivalent DDC definition: ACE_CND_BAD_MSG)
#define sitalBcConditionCode_RETRY_COUNT					13U		///< Condition code: Retry count. (Equivalent DDC definition: ACE_CND_RETRY)
#define sitalBcConditionCode_ALWAYS							15U		///< Condition code: Always. (Equivalent DDC definition: ACE_CND_ALWAYS)

// BC frame creation: wFrameType values.
#define sitalBcFrameType_MAJOR		0x0000U		///< Major frame. (Equivalent DDC definition: ACE_FRAME_MAJOR)
#define sitalBcFrameType_MINOR		0x0002U		///< Minor frame. (Equivalent DDC definition: ACE_FRAME_MINOR)

// BC general purpose flag state manipulation: wGpfNumber values.
#define sitalBcGpf_GPF0				0x0000U		///< GFP-0. (Equivalent DDC definition: ACE_GPF0)
#define sitalBcGpf_GPF1				0x0001U		///< GFP-1. (Equivalent DDC definition: ACE_GPF1)
#define sitalBcGpf_GPF2				0x0002U		///< GFP-2. (Equivalent DDC definition: ACE_GPF2)
#define sitalBcGpf_GPF3				0x0003U		///< GFP-3. (Equivalent DDC definition: ACE_GPF3)
#define sitalBcGpf_GPF4				0x0004U		///< GFP-4. (Equivalent DDC definition: ACE_GPF4)
#define sitalBcGpf_GPF5				0x0005U		///< GFP-5. (Equivalent DDC definition: ACE_GPF5)
#define sitalBcGpf_GPF6				0x0006U		///< GFP-6. (Equivalent DDC definition: ACE_GPF6)
#define sitalBcGpf_GPF7				0x0007U		///< GFP-7. (Equivalent DDC definition: ACE_GPF7)
		
// General purpose flag state manipulation: wEffect values.
#define sitalBcGpfEffect_LEAVE		0U		///< GPF effect: Leave bit unchanged. (Equivalent DDC definition: ACE_GPF_LEAVE)
#define sitalBcGpfEffect_SET		1U		///< GPF effect: Set bit. (Equivalent DDC definition: ACE_GPF_SET)
#define sitalBcGpfEffect_CLEAR		2U		///< GPF effect: Clear bit. (Equivalent DDC definition: ACE_GPF_CLEAR)
#define	sitalBcGpfEffect_TOGGLE		3U		///< GPF effect: Toggle bit. (Equivalent DDC definition: ACE_GPF_TOGGLE)

// RT command stack access: Message location values.
#define sitalMessageLocation_NEXT				0U	///< Get the next unread message.
#define sitalMessageLocation_LATEST				2U	///< Get the latest message.

// RT command stack access: Message removal values.
#define sitalMessageRemoval_PURGE				0U	///< Get the next unread message.
#define sitalMessageRemoval_DO_NOT_PURGE		1U	///< Get the latest message.

// RT configuration: wCommandStackSize values.
#define sitalRtCommandStackSize_256		0x0000U	///< Command stack size is  256 words. (Equivalent DDC definition: ACE_RT_CMDSTK_256)
#define sitalRtCommandStackSize_512		0x2000U	///< Command stack size is  512 words. (Equivalent DDC definition: ACE_RT_CMDSTK_512)
#define sitalRtCommandStackSize_1024	0x4000U	///< Command stack size is 1024 words. (Equivalent DDC definition: ACE_RT_CMDSTK_1K)
#define sitalRtCommandStackSize_2048	0x6000U	///< Command stack size is 2048 words. (Equivalent DDC definition: ACE_RT_CMDSTK_2K)

// RT address sources: wRtAddressSource values.
#define sitalRtAddressSource_EXTERNAL	0x0000U 	///< RT address source is external. (Equivalent DDC definition: ACE_RT_EXTERNAL_ADDR)
#define sitalRtAddressSource_INTERNAL	0x0001U 	///< RT address source is internal. (Equivalent DDC definition: ACE_RT_INTERNAL_ADDR)

// RT configuration: dwOptions values.
#define sitalRtSetupOption_CLEAR_SERVICE_REQUEST		0x00000001U		///< Clear service request after Tx vector word. (Equivalent DDC definition: ACE_RT_OPT_CLR_SREQ)
#define sitalRtSetupOption_LOAD_TIME_TAG				0x00000002U		///< Load time tag on synchronize command. (Equivalent DDC definition: ACE_RT_OPT_LOAD_TT)
#define sitalRtSetupOption_CLEAR_TIME_TAG				0x00000004U		///< Clear time tag on synchronize command. (Equivalent DDC definition: ACE_RT_OPT_CLEAR_TT)
#define sitalRtSetupOption_OVERWRITE_DATA				0x00000008U		///< Overwrite invalid data. (Equivalent DDC definition: ACE_RT_OPT_OVR_DATA)
#define sitalRtSetupOption_OVERRIDE_MODE_BIT			0x00000010U		///< Override mode T/R* error. (Equivalent DDC definition: ACE_RT_OPT_OVR_MBIT)
#define sitalRtSetupOption_ALTERNATE_STATUS				0x00000020U		///< RT alternate status word enable. (Equivalent DDC definition: ACE_RT_OPT_ALT_STS)
#define sitalRtSetupOption_ILL_RX_DISABLE				0x00000040U		///< Illegal receive transfer disable. (Equivalent DDC definition: ACE_RT_OPT_IL_RX_D)
#define sitalRtSetupOption_BUSY_RX_DISABLE				0x00000080U		///< Busy receive transfer disable. (Equivalent DDC definition: ACE_RT_OPT_BSY_RX_D)
#define sitalRtSetupOption_SET_RT_FLAG					0x00000100U		///< Flag if loopback test failed. (Equivalent DDC definition: ACE_RT_OPT_SET_RTFG)
#define sitalRtSetupOption_1553A_MODE_CODES				0x00000200U		///< 1553a mode codes enabled. (Equivalent DDC definition: ACE_RT_OPT_1553A_MC)
#define sitalRtSetupOption_MODE_COMMAND_OVERRIDE_BUSY	0x00000400U		///< Busy bit and data word sent. (Equivalent DDC definition: ACE_RT_OPT_MC_O_BSY)
#define sitalRtSetupOption_BROADCAST_DISABLE			0x00000800U		///< Broadcast disabled. (Equivalent DDC definition: ACE_RT_OPT_BCST_DIS)

// RT data block creation: wDataBlockType values.
#define sitalRtDataBlockType_SINGLE_01				01U	///< Single message data block, 1 word.
#define sitalRtDataBlockType_SINGLE_02				02U	///< Single message data block, 2 words.
#define sitalRtDataBlockType_SINGLE_03				03U	///< Single message data block, 3 words.
#define sitalRtDataBlockType_SINGLE_04				04U	///< Single message data block, 4 words.
#define sitalRtDataBlockType_SINGLE_05				05U	///< Single message data block, 5 words.
#define sitalRtDataBlockType_SINGLE_06				06U	///< Single message data block, 6 words.
#define sitalRtDataBlockType_SINGLE_07				07U	///< Single message data block, 7 words.
#define sitalRtDataBlockType_SINGLE_08				08U	///< Single message data block, 8 words.
#define sitalRtDataBlockType_SINGLE_09				09U	///< Single message data block, 9 words.
#define sitalRtDataBlockType_SINGLE_10				10U	///< Single message data block, 10 words.
#define sitalRtDataBlockType_SINGLE_11				11U	///< Single message data block, 11 words.
#define sitalRtDataBlockType_SINGLE_12				12U	///< Single message data block, 12 words.
#define sitalRtDataBlockType_SINGLE_13				13U	///< Single message data block, 13 words.
#define sitalRtDataBlockType_SINGLE_14				14U	///< Single message data block, 14 words.
#define sitalRtDataBlockType_SINGLE_15				15U	///< Single message data block, 15 words.
#define sitalRtDataBlockType_SINGLE_16				16U	///< Single message data block, 16 words.
#define sitalRtDataBlockType_SINGLE_17				17U	///< Single message data block, 17 words.
#define sitalRtDataBlockType_SINGLE_18				18U	///< Single message data block, 18 words.
#define sitalRtDataBlockType_SINGLE_19				19U	///< Single message data block, 19 words.
#define sitalRtDataBlockType_SINGLE_20				20U	///< Single message data block, 20 words.
#define sitalRtDataBlockType_SINGLE_21				21U	///< Single message data block, 21 words.
#define sitalRtDataBlockType_SINGLE_22				22U	///< Single message data block, 22 words.
#define sitalRtDataBlockType_SINGLE_23				23U	///< Single message data block, 23 words.
#define sitalRtDataBlockType_SINGLE_24				24U	///< Single message data block, 24 words.
#define sitalRtDataBlockType_SINGLE_25				25U	///< Single message data block, 25 words.
#define sitalRtDataBlockType_SINGLE_26				26U	///< Single message data block, 26 words.
#define sitalRtDataBlockType_SINGLE_27				27U	///< Single message data block, 27 words.
#define sitalRtDataBlockType_SINGLE_28				28U	///< Single message data block, 28 words.
#define sitalRtDataBlockType_SINGLE_29				29U	///< Single message data block, 29 words.
#define sitalRtDataBlockType_SINGLE_30				30U	///< Single message data block, 30 words.
#define sitalRtDataBlockType_SINGLE_31				31U	///< Single message data block, 31 words.
#define sitalRtDataBlockType_SINGLE_32				32U	///< Single message data block, 32 words. (Equivalent DDC definition: ACE_RT_DBLK_SINGLE)
#define sitalRtDataBlockType_DOUBLE					33U	///< Doubled buffered msg data block, 64 words. (Equivalent DDC definition: ACE_RT_DBLK_DOUBLE)
#define sitalRtDataBlockType_CIRCULAR_128			34U	///< Circular buffer,  128 words long. (Equivalent DDC definition: ACE_RT_DBLK_C_128)
#define sitalRtDataBlockType_CIRCULAR_256			35U	///< Circular buffer,  256 words long. (Equivalent DDC definition: ACE_RT_DBLK_C_256)
#define sitalRtDataBlockType_CIRCULAR_512			36U	///< Circular buffer,  512 words long. (Equivalent DDC definition: ACE_RT_DBLK_C_512)
#define sitalRtDataBlockType_CIRCULAR_1024			37U	///< Circular buffer, 1024 words long. (Equivalent DDC definition: ACE_RT_DBLK_C_1K)
#define sitalRtDataBlockType_CIRCULAR_2048			38U	///< Circular buffer, 2048 words long. (Equivalent DDC definition: ACE_RT_DBLK_C_2K)
#define sitalRtDataBlockType_CIRCULAR_4096			39U	///< Circular buffer, 4096 words long. (Equivalent DDC definition: ACE_RT_DBLK_C_4K)
#define sitalRtDataBlockType_CIRCULAR_8192			40U	///< Circular buffer, 8192 words long. (Equivalent DDC definition: ACE_RT_DBLK_C_8K)
#define sitalRtDataBlockType_COMMON_CIRCULAR_128	41U	///< Common circular buffer,  128 words long. (Equivalent DDC definition: ACE_RT_DBLK_GBL_C_128)
#define sitalRtDataBlockType_COMMON_CIRCULAR_256	42U	///< Common circular buffer,  256 words long. (Equivalent DDC definition: ACE_RT_DBLK_GBL_C_256)
#define sitalRtDataBlockType_COMMON_CIRCULAR_512	43U	///< Common circular buffer,  512 words long. (Equivalent DDC definition: ACE_RT_DBLK_GBL_C_512)
#define sitalRtDataBlockType_COMMON_CIRCULAR_1024	44U	///< Common circular buffer, 1024 words long. (Equivalent DDC definition: ACE_RT_DBLK_GBL_C_1K)
#define sitalRtDataBlockType_COMMON_CIRCULAR_2048	45U	///< Common circular buffer, 2048 words long. (Equivalent DDC definition: ACE_RT_DBLK_GBL_C_2K)
#define sitalRtDataBlockType_COMMON_CIRCULAR_4096	46U	///< Common circular buffer, 4096 words long. (Equivalent DDC definition: ACE_RT_DBLK_GBL_C_4K)
#define sitalRtDataBlockType_COMMON_CIRCULAR_8192	47U	///< Common circular buffer, 8192 words long. (Equivalent DDC definition: ACE_RT_DBLK_GBL_C_8K)

// RT mode code manipulation: wModeCodeType values.
#define sitalRtModeCodeType_RX_NO_DATA				0x0000U		///< Undefined mode codes. (Equivalent DDC definition: ACE_RT_MCTYPE_RX_NO_DATA)
#define sitalRtModeCodeType_RX_DATA					0x0001U		///< Rx mode codes with data. (Equivalent DDC definition: ACE_RT_MCTYPE_RX_DATA)
#define sitalRtModeCodeType_TX_NO_DATA				0x0002U		///< Tx mode codes without data. (Equivalent DDC definition: ACE_RT_MCTYPE_TX_NO_DATA)
#define sitalRtModeCodeType_TX_DATA					0x0003U		///< Tx mode codes with data. (Equivalent DDC definition: ACE_RT_MCTYPE_TX_DATA)
#define sitalRtModeCodeType_BROADCAST_RX_NO_DATA	0x0004U		///< Undefined mode codes. (Equivalent DDC definition: ACE_RT_MCTYPE_BCST_RX_NO_DATA)
#define sitalRtModeCodeType_BROADCAST_RX_DATA		0x0005U		///< Broadcast Rx mode codes with data. (Equivalent DDC definition: ACE_RT_MCTYPE_BCST_RX_DATA)
#define sitalRtModeCodeType_BROADCAST_TX_NO_DATA	0x0006U		///< Broadcast Tx mode codes without data. (Equivalent DDC definition: ACE_RT_MCTYPE_BCST_TX_NO_DATA)
#define sitalRtModeCodeType_BROADCAST_TX_DATA		0x0007U		///< Broadcast transmit mode codes with data. (Equivalent DDC definition: ACE_RT_MCTYPE_BCST_TX_DATA)

// RT mode code manipulation: wModeCodeType base values.
#define sitalRtModeCodeTypeBase_NO_DATA				0x0000U		///< Base value for mode code without data.
#define sitalRtModeCodeTypeBase_DATA				0x0001U		///< Base value for mode code with data.
#define sitalRtModeCodeTypeBase_RX					0x0000U		///< Base value for mode code Rx.
#define sitalRtModeCodeTypeBase_TX					0x0002U		///< Base value for mode code Tx.
#define sitalRtModeCodeTypeBase_NOT_BROADCAST		0x0000U		///< Base value for non broadcast mode code.
#define sitalRtModeCodeTypeBase_BROADCAST			0x0004U		///< Base value for broadcast mode code.

// RT mode code manipulation: wModeCodeIrq/*wpModeCodeIrq values.
#define sitalRtModeCodeIrq_DYNAMIC_BUS_CONTROL							0x0001U		///< Relevant with mode code type[s]: TX_NO_DATA. (Equivalent DDC definition: ACE_RT_MCIRQ_DYN_BUS_CTRL)
#define sitalRtModeCodeIrq_SYNCHRONIZE									0x0002U		///< Relevant with mode code type[s]: (BROADCAST_)(TX|RX)(_NO)_DATA. (Equivalent DDC definition: ACE_RT_MCIRQ_SYNCHRONIZE)
#define sitalRtModeCodeIrq_TRANSMIT_STATUS								0x0004U		///< Relevant with mode code type[s]: TX_NO_DATA. (Equivalent DDC definition: ACE_RT_MCIRQ_TRNS_STATUS)
#define sitalRtModeCodeIrq_INITIALIZE_SELF_TEST							0x0008U		///< Relevant with mode code type[s]: (BROADCAST_)TX_NO_DATA. (Equivalent DDC definition: ACE_RT_MCIRQ_INIT_SELF_TEST)
#define sitalRtModeCodeIrq_TRANSMITTER_SHUTDOWN							0x0010U		///< Relevant with mode code type[s]: (BROADCAST_)TX_NO_DATA. (Equivalent DDC definition: ACE_RT_MCIRQ_TRNS_SHUTDOWN)
#define sitalRtModeCodeIrq_OVERRIDE_TRANSMITTER_SHUTDOWN				0x0020U		///< Relevant with mode code type[s]: (BROADCAST_)TX_NO_DATA. (Equivalent DDC definition: ACE_RT_MCIRQ_OVR_TRNS_SHUTDWN)
#define sitalRtModeCodeIrq_INHIBIT_TERMINAL_FLAG						0x0040U		///< Relevant with mode code type[s]: (BROADCAST_)TX_NO_DATA. (Equivalent DDC definition: ACE_RT_MCIRQ_INH_TERM_FLAG)
#define sitalRtModeCodeIrq_OVERRIDE_INHIBIT_TERMINAL_FLAG				0x0080U		///< Relevant with mode code type[s]: (BROADCAST_)TX_NO_DATA. (Equivalent DDC definition: ACE_RT_MCIRQ_OVR_INH_TERM_FLG)
#define sitalRtModeCodeIrq_RESET_REMOTE_TERMINAL						0x0100U		///< Relevant with mode code type[s]: (BROADCAST_)TX_NO_DATA. (Equivalent DDC definition: ACE_RT_MCIRQ_RESET_REMOTE_TERM)
#define sitalRtModeCodeIrq_TRANSMIT_VECTOR								0x0001U		///< Relevant with mode code type[s]: TX_DATA. (Equivalent DDC definition: ACE_RT_MCIRQ_TRNS_VECTOR)
#define sitalRtModeCodeIrq_TRANSMIT_LAST_COMMAND						0x0004U		///< Relevant with mode code type[s]: TX_DATA. (Equivalent DDC definition: ACE_RT_MCIRQ_TRNS_LAST_CMD)
#define sitalRtModeCodeIrq_TRANSMIT_BUILT_IN_TEST						0x0008U		///< Relevant with mode code type[s]: TX_DATA. (Equivalent DDC definition: ACE_RT_MCIRQ_TRNS_BIT)
#define sitalRtModeCodeIrq_SELECTED_TRANSMITTER_SHUTDOWN				0x0010U		///< Relevant with mode code type[s]: (BROADCAST_)RX_DATA. (Equivalent DDC definition: ACE_RT_MCIRQ_SEL_TRNS_SHUTDWN)
#define sitalRtModeCodeIrq_OVERRIDE_SELECTED_TRANSMITTER_SHUTDOWN		0x0020U		///< Relevant with mode code type[s]: (BROADCAST_)RX_DATA. (Equivalent DDC definition: ACE_RT_MCIRQ_OVR_SEL_TRNS_SHUTDWN)
#define sitalRtModeCodeIrq_RESERVED_BIT6								0x0040U		///< Reserved. (Equivalent DDC definition: ACE_RT_MCIRQ_RESERVED_BIT6)
#define sitalRtModeCodeIrq_RESERVED_BIT7								0x0080U		///< Reserved. (Equivalent DDC definition: ACE_RT_MCIRQ_RESERVED_BIT7)
#define sitalRtModeCodeIrq_RESERVED_BIT7								0x0080U		///< Reserved. (Equivalent DDC definition: ACE_RT_MCIRQ_RESERVED_BIT7)
#define sitalRtModeCodeIrq_RESERVED_BIT7								0x0080U		///< Reserved. (Equivalent DDC definition: ACE_RT_MCIRQ_RESERVED_BIT7)
#define sitalRtModeCodeIrq_RESERVED_BIT8								0x0100U		///< Reserved. (Equivalent DDC definition: ACE_RT_MCIRQ_RESERVED_BIT8)
#define sitalRtModeCodeIrq_RESERVED_BIT9								0x0200U		///< Reserved. (Equivalent DDC definition: ACE_RT_MCIRQ_RESERVED_BIT9)
#define sitalRtModeCodeIrq_RESERVED_BIT10								0x0400U		///< Reserved. (Equivalent DDC definition: ACE_RT_MCIRQ_RESERVED_BIT10)
#define sitalRtModeCodeIrq_RESERVED_BIT11								0x0800U		///< Reserved. (Equivalent DDC definition: ACE_RT_MCIRQ_RESERVED_BIT11)
#define sitalRtModeCodeIrq_RESERVED_BIT12								0x1000U		///< Reserved. (Equivalent DDC definition: ACE_RT_MCIRQ_RESERVED_BIT12)
#define sitalRtModeCodeIrq_RESERVED_BIT13								0x2000U		///< Reserved. (Equivalent DDC definition: ACE_RT_MCIRQ_RESERVED_BIT13)
#define sitalRtModeCodeIrq_RESERVED_BIT14								0x4000U		///< Reserved. (Equivalent DDC definition: ACE_RT_MCIRQ_RESERVED_BIT14)
#define sitalRtModeCodeIrq_RESERVED_BIT15								0x8000U		///< Reserved. (Equivalent DDC definition: ACE_RT_MCIRQ_RESERVED_BIT15)

// RT mode code data manipulation: wModeCode values.
#define sitalRtDataContainerModeCode_RX_SYNCHRONIZE											0x0001U		///< Data containing mode code: Rx - synchronize. (Equivalent DDC definition: ACE_RT_MCDATA_RX_SYNCHRONIZE)
#define sitalRtDataContainerModeCode_RX_TRANSMITTER_SHUTDOWN								0x0004U		///< Data containing mode code: Rx - transmitter shutdown. (Equivalent DDC definition: ACE_RT_MCDATA_RX_SEL_T_SHUTDWN)
#define sitalRtDataContainerModeCode_RX_OVERRIDE_TRANSMITTER_SHUTDOWN						0x0005U		///< Data containing mode code: Rx - override transmitter shutdown. (Equivalent DDC definition: ACE_RT_MCDATA_RX_OVR_SEL_T_SHUTDWN)
#define sitalRtDataContainerModeCode_TX_TRANSMIT_VECTOR_WORD								0x0010U		///< Data containing mode code: Tx - transmit vector word. (Equivalent DDC definition: ACE_RT_MCDATA_TX_TRNS_VECTOR)
#define sitalRtDataContainerModeCode_TX_TRANSMIT_LAST_COMMAND_WORD							0x0012U		///< Data containing mode code: Tx - transmit last command word. (Equivalent DDC definition: ACE_RT_MCDATA_TX_TRNS_LAST_CMD)
#define sitalRtDataContainerModeCode_TX_TRANSMIT_BUILT_IN_TEST_WORD							0x0013U		///< Data containing mode code: Tx - transmit built in test word. (Equivalent DDC definition: ACE_RT_MCDATA_TX_TRNS_BIT)
#define sitalRtDataContainerModeCode_BROADCAST_SYNCHRONIZE									0x0021U		///< Data containing mode code: Broadcast - synchronize. (Equivalent DDC definition: ACE_RT_MCDATA_BCST_SYNCHRONIZE)
#define sitalRtDataContainerModeCode_BROADCAST_SELECTED_TRANSMITTER_SHUTDOWN				0x0024U		///< Data containing mode code: Broadcast - selected transmitter shutdown. (Equivalent DDC definition: ACE_RT_MCDATA_BCST_SEL_T_SHUTDWN)
#define sitalRtDataContainerModeCode_BROADCAST_OVERRIDE_SELECTED_TRANSMITTER_SHUTDOWN		0x0025U		///< Data containing mode code: Broadcast - override selected transmitter shutdown. (Equivalent DDC definition: ACE_RT_MCDATA_BCST_OVR_SEL_T_SHUTDWN)

// RT manipulation: wOwnAddressOrBroadcast values.
#define sitalRtAddressType_BROADCAST		0x0000U		///< Broadcast address. (Equivalent DDC definition: ACE_RT_BCST_ADDRSS)
#define sitalRtAddressType_OWN				0x0001U		///< Own RT address. (Equivalent DDC definition: ACE_RT_OWN_ADDRESS)
#define sitalRtAddressType_BOTH				0xFFFFU		///< All addresses, both broadcast and own RT address. (Equivalent DDC definition: ACE_RT_MODIFY_ALL)

// RT manipulation: wMessageDirection values.
#define sitalMessageDirection_RX			0x0000U		///< Rx message[s].
#define sitalMessageDirection_TX			0x0001U		///< Tx message[s].
#define sitalMessageDirection_BOTH			0xFFFFU		///< All directions, both Rx and Tx. (Equivalent DDC definition: ACE_RT_MODIFY_ALL)

// RT manipulation: wRtAddress values.
#define sitalRtAddress_ALL					0xFFFFU		///< All RT addresses. (Equivalent DDC definition: ACE_RT_MODIFY_ALL, ACE_MT_FILTER_ALL)
#define sitalRtAddress_0					0U			///< RT address 0.
#define sitalRtAddress_1					1U			///< RT address 1.
#define sitalRtAddress_2					2U			///< RT address 2.
#define sitalRtAddress_3					3U			///< RT address 3.
#define sitalRtAddress_4					4U			///< RT address 4.
#define sitalRtAddress_5					5U			///< RT address 5.
#define sitalRtAddress_6					6U			///< RT address 6.
#define sitalRtAddress_7					7U			///< RT address 7.
#define sitalRtAddress_8					8U			///< RT address 8.
#define sitalRtAddress_9					9U			///< RT address 9.
#define sitalRtAddress_10					10U			///< RT address 10.
#define sitalRtAddress_11					11U			///< RT address 11.
#define sitalRtAddress_12					12U			///< RT address 12.
#define sitalRtAddress_13					13U			///< RT address 13.
#define sitalRtAddress_14					14U			///< RT address 14.
#define sitalRtAddress_15					15U			///< RT address 15.
#define sitalRtAddress_16					16U			///< RT address 16.
#define sitalRtAddress_17					17U			///< RT address 17.
#define sitalRtAddress_18					18U			///< RT address 18.
#define sitalRtAddress_19					19U			///< RT address 19.
#define sitalRtAddress_20					20U			///< RT address 20.
#define sitalRtAddress_21					21U			///< RT address 21.
#define sitalRtAddress_22					22U			///< RT address 22.
#define sitalRtAddress_23					23U			///< RT address 23.
#define sitalRtAddress_24					24U			///< RT address 24.
#define sitalRtAddress_25					25U			///< RT address 25.
#define sitalRtAddress_26					26U			///< RT address 26.
#define sitalRtAddress_27					27U			///< RT address 27.
#define sitalRtAddress_28					28U			///< RT address 28.
#define sitalRtAddress_29					29U			///< RT address 29.
#define sitalRtAddress_30					30U			///< RT address 30.
#define sitalRtAddress_31					31U			///< RT address 31, which is actually the broadcast address, sital1553_BROADCAST.

// RT manipulation: dwWordCountOrModeCodeMask values.
#define sitalWordCountOrModeCodeMask_ALL	0xFFFFFFFFU	///< All word-count or mode-code options.

// RT manipulation: wSubaddress values.
#define sitalRtSubaddress_ALL				0xFFFFU		///< All RT subaddresses. (Equivalent DDC definition: ACE_RT_MODIFY_ALL)
#define sitalRtSubaddress_0					0U			///< RT subaddress 0 (this "subaddress" is actually reserved to designate a mode message, and is not a legal subaddress).
#define sitalRtSubaddress_1					1U			///< RT subaddress 1.
#define sitalRtSubaddress_2					2U			///< RT subaddress 2.
#define sitalRtSubaddress_3					3U			///< RT subaddress 3.
#define sitalRtSubaddress_4					4U			///< RT subaddress 4.
#define sitalRtSubaddress_5					5U			///< RT subaddress 5.
#define sitalRtSubaddress_6					6U			///< RT subaddress 6.
#define sitalRtSubaddress_7					7U			///< RT subaddress 7.
#define sitalRtSubaddress_8					8U			///< RT subaddress 8.
#define sitalRtSubaddress_9					9U			///< RT subaddress 9.
#define sitalRtSubaddress_10				10U			///< RT subaddress 10.
#define sitalRtSubaddress_11				11U			///< RT subaddress 11.
#define sitalRtSubaddress_12				12U			///< RT subaddress 12.
#define sitalRtSubaddress_13				13U			///< RT subaddress 13.
#define sitalRtSubaddress_14				14U			///< RT subaddress 14.
#define sitalRtSubaddress_15				15U			///< RT subaddress 15.
#define sitalRtSubaddress_16				16U			///< RT subaddress 16.
#define sitalRtSubaddress_17				17U			///< RT subaddress 17.
#define sitalRtSubaddress_18				18U			///< RT subaddress 18.
#define sitalRtSubaddress_19				19U			///< RT subaddress 19.
#define sitalRtSubaddress_20				20U			///< RT subaddress 20.
#define sitalRtSubaddress_21				21U			///< RT subaddress 21.
#define sitalRtSubaddress_22				22U			///< RT subaddress 22.
#define sitalRtSubaddress_23				23U			///< RT subaddress 23.
#define sitalRtSubaddress_24				24U			///< RT subaddress 24.
#define sitalRtSubaddress_25				25U			///< RT subaddress 25.
#define sitalRtSubaddress_26				26U			///< RT subaddress 26.
#define sitalRtSubaddress_27				27U			///< RT subaddress 27.
#define sitalRtSubaddress_28				28U			///< RT subaddress 28.
#define sitalRtSubaddress_29				29U			///< RT subaddress 29.
#define sitalRtSubaddress_30				30U			///< RT subaddress 30.
#define sitalRtSubaddress_31				31U			///< RT subaddress 31 (this "subaddress" is actually reserved to designate a mode message, and is not a legal subaddress).

// RT manipulation: dwSubaddressMask values.
#define sitalRtSubaddressMask_ALL			0xFFFFFFFFU		///< All RT subaddresses. (Equivalent DDC definition: ACE_RT_SA_ALL, ACE_MT_FILTER_SA_ALL)
#define sitalRtSubaddressMask_0				0x00000001U		///< RT subaddress  0. (Equivalent DDC definition: ACE_RT_SA0, ACE_MT_FILTER_SA0)
#define sitalRtSubaddressMask_1				0x00000002U		///< RT subaddress	 1. (Equivalent DDC definition: ACE_RT_SA1, ACE_MT_FILTER_SA1)
#define sitalRtSubaddressMask_2				0x00000004U		///< RT subaddress  2. (Equivalent DDC definition: ACE_RT_SA2, ACE_MT_FILTER_SA2)
#define sitalRtSubaddressMask_3				0x00000008U		///< RT subaddress  3. (Equivalent DDC definition: ACE_RT_SA3, ACE_MT_FILTER_SA3)
#define sitalRtSubaddressMask_4				0x00000010U		///< RT subaddress  4. (Equivalent DDC definition: ACE_RT_SA4, ACE_MT_FILTER_SA4)
#define sitalRtSubaddressMask_5				0x00000020U		///< RT subaddress  5. (Equivalent DDC definition: ACE_RT_SA5, ACE_MT_FILTER_SA5)
#define sitalRtSubaddressMask_6				0x00000040U		///< RT subaddress  6. (Equivalent DDC definition: ACE_RT_SA6, ACE_MT_FILTER_SA6)
#define sitalRtSubaddressMask_7				0x00000080U		///< RT subaddress  7. (Equivalent DDC definition: ACE_RT_SA7, ACE_MT_FILTER_SA7)
#define sitalRtSubaddressMask_8				0x00000100U		///< RT subaddress  8. (Equivalent DDC definition: ACE_RT_SA8, ACE_MT_FILTER_SA8)
#define sitalRtSubaddressMask_9				0x00000200U		///< RT subaddress  9. (Equivalent DDC definition: ACE_RT_SA9, ACE_MT_FILTER_SA9)
#define sitalRtSubaddressMask_10			0x00000400U		///< RT subaddress 10. (Equivalent DDC definition: ACE_RT_SA10, ACE_MT_FILTER_SA10)
#define sitalRtSubaddressMask_11			0x00000800U		///< RT subaddress 11. (Equivalent DDC definition: ACE_RT_SA11, ACE_MT_FILTER_SA11)
#define sitalRtSubaddressMask_12			0x00001000U		///< RT subaddress 12. (Equivalent DDC definition: ACE_RT_SA12, ACE_MT_FILTER_SA12)
#define sitalRtSubaddressMask_13			0x00002000U		///< RT subaddress 13. (Equivalent DDC definition: ACE_RT_SA13, ACE_MT_FILTER_SA13)
#define sitalRtSubaddressMask_14			0x00004000U		///< RT subaddress 14. (Equivalent DDC definition: ACE_RT_SA14, ACE_MT_FILTER_SA14)
#define sitalRtSubaddressMask_15			0x00008000U		///< RT subaddress 15. (Equivalent DDC definition: ACE_RT_SA15, ACE_MT_FILTER_SA15)
#define sitalRtSubaddressMask_16			0x00010000U		///< RT subaddress 16. (Equivalent DDC definition: ACE_RT_SA16, ACE_MT_FILTER_SA16)
#define sitalRtSubaddressMask_17			0x00020000U		///< RT subaddress 17. (Equivalent DDC definition: ACE_RT_SA17, ACE_MT_FILTER_SA17)
#define sitalRtSubaddressMask_18			0x00040000U		///< RT subaddress 18. (Equivalent DDC definition: ACE_RT_SA18, ACE_MT_FILTER_SA18)
#define sitalRtSubaddressMask_19			0x00080000U		///< RT subaddress 19. (Equivalent DDC definition: ACE_RT_SA19, ACE_MT_FILTER_SA19)
#define sitalRtSubaddressMask_20			0x00100000U		///< RT subaddress 20. (Equivalent DDC definition: ACE_RT_SA20, ACE_MT_FILTER_SA20)
#define sitalRtSubaddressMask_21			0x00200000U		///< RT subaddress 21. (Equivalent DDC definition: ACE_RT_SA21, ACE_MT_FILTER_SA21)
#define sitalRtSubaddressMask_22			0x00400000U		///< RT subaddress 22. (Equivalent DDC definition: ACE_RT_SA22, ACE_MT_FILTER_SA22)
#define sitalRtSubaddressMask_23			0x00800000U		///< RT subaddress 23. (Equivalent DDC definition: ACE_RT_SA23, ACE_MT_FILTER_SA23)
#define sitalRtSubaddressMask_24			0x01000000U		///< RT subaddress 24. (Equivalent DDC definition: ACE_RT_SA24, ACE_MT_FILTER_SA24)
#define sitalRtSubaddressMask_25			0x02000000U		///< RT subaddress 25. (Equivalent DDC definition: ACE_RT_SA25, ACE_MT_FILTER_SA25)
#define sitalRtSubaddressMask_26			0x04000000U		///< RT subaddress 26. (Equivalent DDC definition: ACE_RT_SA26, ACE_MT_FILTER_SA26)
#define sitalRtSubaddressMask_27			0x08000000U		///< RT subaddress 27. (Equivalent DDC definition: ACE_RT_SA27, ACE_MT_FILTER_SA27)
#define sitalRtSubaddressMask_28			0x10000000U		///< RT subaddress 28. (Equivalent DDC definition: ACE_RT_SA28, ACE_MT_FILTER_SA28)
#define sitalRtSubaddressMask_29			0x20000000U		///< RT subaddress 29. (Equivalent DDC definition: ACE_RT_SA29, ACE_MT_FILTER_SA29)
#define sitalRtSubaddressMask_30			0x40000000U		///< RT subaddress 30. (Equivalent DDC definition: ACE_RT_SA30, ACE_MT_FILTER_SA30)
#define sitalRtSubaddressMask_31			0x80000000		///< RTU subaddress 31. (Equivalent DDC definition: ACE_RT_SA31, ACE_MT_FILTER_SA31)

// HOO9 RT manipulation: qwSubaddressMask values.
#define sitalHoo9RtSubaddressMask_ALL			0xFFFFFFFFFFFFFFFFU		///< All RT subaddresses.
#define sitalHoo9RtSubaddressMask_0				0x0000000000000001U		///< RT subaddress  0.
#define sitalHoo9RtSubaddressMask_1				0x0000000000000002U		///< RT subaddress	1.
#define sitalHoo9RtSubaddressMask_2				0x0000000000000004U		///< RT subaddress  2.
#define sitalHoo9RtSubaddressMask_3				0x0000000000000008U		///< RT subaddress  3.
#define sitalHoo9RtSubaddressMask_4				0x0000000000000010U		///< RT subaddress  4.
#define sitalHoo9RtSubaddressMask_5				0x0000000000000020U		///< RT subaddress  5.
#define sitalHoo9RtSubaddressMask_6				0x0000000000000040U		///< RT subaddress  6.
#define sitalHoo9RtSubaddressMask_7				0x0000000000000080U		///< RT subaddress  7.
#define sitalHoo9RtSubaddressMask_8				0x0000000000000100U		///< RT subaddress  8.
#define sitalHoo9RtSubaddressMask_9				0x0000000000000200U		///< RT subaddress  9.
#define sitalHoo9RtSubaddressMask_10			0x0000000000000400U		///< RT subaddress 10.
#define sitalHoo9RtSubaddressMask_11			0x0000000000000800U		///< RT subaddress 11.
#define sitalHoo9RtSubaddressMask_12			0x0000000000001000U		///< RT subaddress 12.
#define sitalHoo9RtSubaddressMask_13			0x0000000000002000U		///< RT subaddress 13.
#define sitalHoo9RtSubaddressMask_14			0x0000000000004000U		///< RT subaddress 14.
#define sitalHoo9RtSubaddressMask_15			0x0000000000008000U		///< RT subaddress 15.
#define sitalHoo9RtSubaddressMask_16			0x0000000000010000U		///< RT subaddress 16.
#define sitalHoo9RtSubaddressMask_17			0x0000000000020000U		///< RT subaddress 17.
#define sitalHoo9RtSubaddressMask_18			0x0000000000040000U		///< RT subaddress 18.
#define sitalHoo9RtSubaddressMask_19			0x0000000000080000U		///< RT subaddress 19.
#define sitalHoo9RtSubaddressMask_20			0x0000000000100000U		///< RT subaddress 20.
#define sitalHoo9RtSubaddressMask_21			0x0000000000200000U		///< RT subaddress 21.
#define sitalHoo9RtSubaddressMask_22			0x0000000000400000U		///< RT subaddress 22.
#define sitalHoo9RtSubaddressMask_23			0x0000000000800000U		///< RT subaddress 23.
#define sitalHoo9RtSubaddressMask_24			0x0000000001000000U		///< RT subaddress 24.
#define sitalHoo9RtSubaddressMask_25			0x0000000002000000U		///< RT subaddress 25.
#define sitalHoo9RtSubaddressMask_26			0x0000000004000000U		///< RT subaddress 26.
#define sitalHoo9RtSubaddressMask_27			0x0000000008000000U		///< RT subaddress 27.
#define sitalHoo9RtSubaddressMask_28			0x0000000010000000U		///< RT subaddress 28.
#define sitalHoo9RtSubaddressMask_29			0x0000000020000000U		///< RT subaddress 29.
#define sitalHoo9RtSubaddressMask_30			0x0000000040000000U		///< RT subaddress 30.
#define sitalHoo9RtSubaddressMask_31			0x0000000080000000U		///< RT subaddress 31.
#define sitalHoo9RtSubaddressMask_32			0x0000000100000000U		///< RT subaddress 32.
#define sitalHoo9RtSubaddressMask_33			0x0000000200000000U		///< RT subaddress 33.
#define sitalHoo9RtSubaddressMask_34			0x0000000400000000U		///< RT subaddress 34.
#define sitalHoo9RtSubaddressMask_35			0x0000000800000000U		///< RT subaddress 35.
#define sitalHoo9RtSubaddressMask_36			0x0000001000000000U		///< RT subaddress 36.
#define sitalHoo9RtSubaddressMask_37			0x0000002000000000U		///< RT subaddress 37.
#define sitalHoo9RtSubaddressMask_38			0x0000004000000000U		///< RT subaddress 38.
#define sitalHoo9RtSubaddressMask_39			0x0000008000000000U		///< RT subaddress 39.
#define sitalHoo9RtSubaddressMask_40			0x0000010000000000U		///< RT subaddress 40.
#define sitalHoo9RtSubaddressMask_41			0x0000020000000000U		///< RT subaddress 41.
#define sitalHoo9RtSubaddressMask_42			0x0000040000000000U		///< RT subaddress 42.
#define sitalHoo9RtSubaddressMask_43			0x0000080000000000U		///< RT subaddress 43.
#define sitalHoo9RtSubaddressMask_44			0x0000100000000000U		///< RT subaddress 44.
#define sitalHoo9RtSubaddressMask_45			0x0000200000000000U		///< RT subaddress 45.
#define sitalHoo9RtSubaddressMask_46			0x0000400000000000U		///< RT subaddress 46.
#define sitalHoo9RtSubaddressMask_47			0x0000800000000000U		///< RT subaddress 47.
#define sitalHoo9RtSubaddressMask_48			0x0001000000000000U		///< RT subaddress 48.
#define sitalHoo9RtSubaddressMask_49			0x0002000000000000U		///< RT subaddress 49.
#define sitalHoo9RtSubaddressMask_50			0x0004000000000000U		///< RT subaddress 50.
#define sitalHoo9RtSubaddressMask_51			0x0008000000000000U		///< RT subaddress 51.
#define sitalHoo9RtSubaddressMask_52			0x0010000000000000U		///< RT subaddress 52.
#define sitalHoo9RtSubaddressMask_53			0x0020000000000000U		///< RT subaddress 53.
#define sitalHoo9RtSubaddressMask_54			0x0040000000000000U		///< RT subaddress 54.
#define sitalHoo9RtSubaddressMask_55			0x0080000000000000U		///< RT subaddress 55.
#define sitalHoo9RtSubaddressMask_56			0x0100000000000000U		///< RT subaddress 56.
#define sitalHoo9RtSubaddressMask_57			0x0200000000000000U		///< RT subaddress 57.
#define sitalHoo9RtSubaddressMask_58			0x0400000000000000U		///< RT subaddress 58.
#define sitalHoo9RtSubaddressMask_59			0x0800000000000000U		///< RT subaddress 59.
#define sitalHoo9RtSubaddressMask_60			0x1000000000000000U		///< RT subaddress 60.
#define sitalHoo9RtSubaddressMask_61			0x2000000000000000U		///< RT subaddress 61.
#define sitalHoo9RtSubaddressMask_62			0x4000000000000000U		///< RT subaddress 62.
#define sitalHoo9RtSubaddressMask_63			0x8000000000000000U		///< RT subaddress 63.
			
// RT status bits manipulation: wStatusBits/pwStatusBits values.
#define sitalRtStatusWordBit_DBCA				0x0800U		///< Deactivate the dynamic BC acceptance bit. (Equivalent DDC definition: ACE_RT_STSBIT_DBCA)
#define sitalRtStatusWordBit_BUSY				0x0400U		///< Activate the busy bit . (Equivalent DDC definition: ACE_RT_STSBIT_BUSY)
#define sitalRtStatusWordBit_SERVICE_REQUSET	0x0200U		///< Activate the service request bit. (Equivalent DDC definition: ACE_RT_STSBIT_SREQ)
#define sitalRtStatusWordBit_SUBSYSTEM_FLAG		0x0100U		///< Activate the subsystem flag. (Equivalent DDC definition: ACE_RT_STSBIT_SSFLAG)
#define sitalRtStatusWordBit_RT_FLAG			0x0080U		///< Activate the RT flag. (Equivalent DDC definition: ACE_RT_STSBIT_RTFLAG)
// (From here on: alternate status mode values)
#define sitalRtStatusWordBit_S10				0x0800U		///< Clear status bit 11. (Equivalent DDC definition: ACE_RT_STSBIT_S10)
#define sitalRtStatusWordBit_S09				0x0400U		///< Clear status bit 10. (Equivalent DDC definition: ACE_RT_STSBIT_S09)
#define sitalRtStatusWordBit_S08				0x0200U		///< Clear status bit  9. (Equivalent DDC definition: ACE_RT_STSBIT_S08)
#define sitalRtStatusWordBit_S07				0x0100U		///< Clear status bit  8. (Equivalent DDC definition: ACE_RT_STSBIT_S07)
#define sitalRtStatusWordBit_S06				0x0080U		///< Clear status bit  7. (Equivalent DDC definition: ACE_RT_STSBIT_S06)
#define sitalRtStatusWordBit_S05				0x0040U		///< Clear status bit  6. (Equivalent DDC definition: ACE_RT_STSBIT_S05)
#define sitalRtStatusWordBit_S04				0x0020U		///< Clear status bit  5. (Equivalent DDC definition: ACE_RT_STSBIT_S04)
#define sitalRtStatusWordBit_S03				0x0010U		///< Clear status bit  4. (Equivalent DDC definition: ACE_RT_STSBIT_S03)
#define sitalRtStatusWordBit_S02				0x0008U		///< Clear status bit  3. (Equivalent DDC definition: ACE_RT_STSBIT_S02)
#define sitalRtStatusWordBit_S01				0x0004U		///< Clear status bit  2. (Equivalent DDC definition: ACE_RT_STSBIT_S01)
#define sitalRtStatusWordBit_S00				0x0002U		///< Clear status bit  1. (Equivalent DDC definition: ACE_RT_STSBIT_S00)

// RT data block to subaddress mapping manipulation: wMessageTypes values.
#define sitalRtMessageType_RX			0x0001U	///< Rx messages to subaddress will use data block. (Equivalent DDC definition: ACE_RT_MSGTYPE_RX)
#define sitalRtMessageType_TX			0x0002U	///< Tx messages to subaddress will use data block. (Equivalent DDC definition: ACE_RT_MSGTYPE_TX)
#define sitalRtMessageType_BROADCAST	0x0004U	///< Broadcast messages to subaddress will use data block. (Equivalent DDC definition: ACE_RT_MSGTYPE_BCST)
#define sitalRtMessageType_ALL			0x0007U	///< Rx, Tx, and broadcast message will use data block. (Equivalent DDC definition: ACE_RT_MSGTYPE_ALL)

// RT data block to subaddress mapping manipulation: wIrqOptions values.
#define sitalRtDataBlockIrq_NONE				0x0000U		///< No IRQs generated.
#define sitalRtDataBlockIrq_CIRCULAR_BUFFER		0x0001U		///< IRQs generated on circular buffer rollover. (Equivalent DDC definition: ACE_RT_DBLK_CIRC_IRQ)
#define sitalRtDataBlockIrq_END_OF_MESSAGE		0x0002U		///< IRQs generated on end of message. (Equivalent DDC definition: ACE_RT_DBLK_EOM_IRQ)
#define sitalRtDataBlockIrq_ALL					0x0003U		///< IRQs generated on all above mentioned occasions.

// RT built-in test word sources: wWordLocation values.
#define sitalRtBuiltInTestWordSource_REGISTER			0U ///< Use the RT built-in test word register (default). (Equivalent DDC definition: ACE_RT_BIT_INTERNAL)
#define sitalRtBuiltInTestWordSource_MEMORY				1U ///< Use the RT memory word at the appropriate predefined address as the RT built-in test word. (Equivalent DDC definition: ACE_RT_BIT_EXTERNAL)

// RT built-in test permission options: wPermitOrInihibitIfRtBusy values.
#define sitalRtBuiltInTestPermitOnBusy_ENABLED			0U ///< Enable the built-in test when the RT is busy (default). (Equivalent DDC definition: ACE_RT_BIT_NO_INHIBIT)
#define sitalRtBuiltInTestPermitOnBusy_DISABLED			1U ///< Disable the built-in test when the RT is busy (default). (Equivalent DDC definition: ACE_RT_BIT_INHIBIT)

// BC block status word masks.
#define sitalBcBlockStatusWord_INVALID_WORD						0x0001U		///< Block status word: Invalid word. (Equivalent DDC definition: ACE_BC_BSW_INVWRD)
#define sitalBcBlockStatusWord_BAD_SYNCHRONIZATION				0x0002U		///< Block status word: Bad synchronization. (Equivalent DDC definition: ACE_BC_BSW_BADSYNC)
#define sitalBcBlockStatusWord_WORD_COUNT_ERROR					0x0004U		///< Block status word: Word count error. (Equivalent DDC definition: ACE_BC_BSW_WCERR)
#define sitalBcBlockStatusWord_WRONG_RT_ADDRESS					0x0008U		///< Block status word: Wrong RT address. (Equivalent DDC definition: ACE_BC_BSW_WRGADDR_NGAP)
#define sitalBcBlockStatusWord_GOOD_DATA_BLOCK_RECEIVED			0x0010U		///< Block status word: Good data block received. (Equivalent DDC definition: ACE_BC_BSW_GDATA)
#define sitalBcBlockStatusWord_RETRIES_COUNT					0x0060U		///< Block status word: Retries count. (Equivalent DDC definition: ACE_BC_BSW_RETRY)
#define sitalBcBlockStatusWord_MASKED_STATUS					0x0080U		///< Block status word: Masked status. (Equivalent DDC definition: ACE_BC_BSW_MSKED_STS)
#define sitalBcBlockStatusWord_LOOPBACK_FAIL					0x0100U		///< Block status word: Loopback fail. (Equivalent DDC definition: ACE_BC_BSW_LPFAIL)
#define sitalBcBlockStatusWord_NO_RESPONSE						0x0200U		///< Block status word: No response. (Equivalent DDC definition: ACE_BC_BSW_NORES)
#define sitalBcBlockStatusWord_FORMAT_ERROR						0x0400U		///< Block status word: Format error. (Equivalent DDC definition: ACE_BC_BSW_FMTERR)
#define sitalBcBlockStatusWord_STATUS_SET						0x0800U		///< Block status word: Status set. (Equivalent DDC definition: ACE_BC_BSW_STS_SET)
#define sitalBcBlockStatusWord_ERROR_FLAG						0x1000U		///< Block status word: Error flag. (Equivalent DDC definition: ACE_BC_BSW_ERRFLG)
#define sitalBcBlockStatusWord_BUS_B							0x2000U		///< Block status word: Bus B (or bus A is bit off). (Equivalent DDC definition: ACE_BC_BSW_CHNL)
#define sitalBcBlockStatusWord_START_OF_MESSAGE					0x4000U		///< Block status word: Start of message. (Equivalent DDC definition: ACE_BC_BSW_SOM)
#define sitalBcBlockStatusWord_END_OF_MESSAGE					0x8000U		///< Block status word: End of message. (Equivalent DDC definition: ACE_BC_BSW_EOM)

// RT block status word masks.
#define sitalRtBlockStatusWord_COMMAND_ERROR					0x0001U		///< Block status word: Command error. (Equivalent DDC definition: ACE_RT_BSW_CMDERR)
#define sitalRtBlockStatusWord_RT_TO_RT_COMMAND_ERROR			0x0002U		///< Block status word: RT to RT command error. (Equivalent DDC definition: ACE_RT_BSW_RTRTERR_2CMD)
#define sitalRtBlockStatusWord_RT_TO_RT_RESPONSE_ERROR			0x0004U		///< Block status word: RT to RT gap/synchronization/address error. (Equivalent DDC definition: ACE_RT_BSW_RTRTERR_GSA)
#define sitalRtBlockStatusWord_INVALID_WORD						0x0008U		///< Block status word: Invalid word. (Equivalent DDC definition: ACE_RT_BSW_INVWRD)
#define sitalRtBlockStatusWord_BAD_SYNCHRONIZATION				0x0010U		///< Block status word: Bad synchronization. (Equivalent DDC definition: ACE_RT_BSW_BADSYNC)
#define sitalRtBlockStatusWord_WORD_COUNT_ERROR					0x0020U		///< Block status word: Word count error. (Equivalent DDC definition: ACE_RT_BSW_WCERR)
#define sitalRtBlockStatusWord_ILLEGAL_COMMAND					0x0040U		///< Block status word: Illegal command. (Equivalent DDC definition: ACE_RT_BSW_ILLCMD)
#define sitalRtBlockStatusWord_CIRCULAR_ROLLOVER				0x0080U		///< Block status word: Circular rollover. (Equivalent DDC definition: ACE_RT_BSW_CIRCOVR)
#define sitalRtBlockStatusWord_LOOPBACK_FAIL					0x0100U		///< Block status word: Loopback fail. (Equivalent DDC definition: ACE_RT_BSW_LPFAIL)
#define sitalRtBlockStatusWord_NO_RESPONSE						0x0200U		///< Block status word: No response. (Equivalent DDC definition: ACE_RT_BSW_NORES)
#define sitalRtBlockStatusWord_FORMAT_ERROR						0x0400U		///< Block status word: Format error. (Equivalent DDC definition: ACE_RT_BSW_FMTERR)
#define sitalRtBlockStatusWord_RT_TO_RT							0x0800U		///< Block status word: RT to RT. (Equivalent DDC definition: ACE_RT_BSW_RTRT)
#define sitalRtBlockStatusWord_ERROR_FLAG						0x1000U		///< Block status word: Error flag. (Equivalent DDC definition: ACE_RT_BSW_ERRFLG)
#define sitalRtBlockStatusWord_BUS_B							0x2000U		///< Block status word: Bus B (or bus A is bit off). (Equivalent DDC definition: ACE_RT_BSW_CHNL)
#define sitalRtBlockStatusWord_START_OF_MESSAGE					0x4000U		///< Block status word: Start of message. (Equivalent DDC definition: ACE_RT_BSW_SOM)
#define sitalRtBlockStatusWord_END_OF_MESSAGE					0x8000U		///< Block status word: End of message. (Equivalent DDC definition: ACE_RT_BSW_EOM)

// MT block status word masks.
#define sitalMtBlockStatusWord_COMMAND_ERROR					0x0001U		///< Block status word: Command error. (Equivalent DDC definition: ACE_MT_BSW_CMDERR)
#define sitalMtBlockStatusWord_RT_TO_RT_COMMAND_ERROR			0x0002U		///< Block status word: RT to RT command error. (Equivalent DDC definition: ACE_MT_BSW_RTRTERR_2CMD)
#define sitalMtBlockStatusWord_RT_TO_RT_RESPONSE_ERROR			0x0004U		///< Block status word: RT to RT gap/synchronization/address error. (Equivalent DDC definition: ACE_MT_BSW_RTRTERR_GSA)
#define sitalMtBlockStatusWord_INVALID_WORD						0x0008U		///< Block status word: Invalid word. (Equivalent DDC definition: ACE_MT_BSW_INVWRD)
#define sitalMtBlockStatusWord_BAD_SYNCHRONIZATION				0x0010U		///< Block status word: Bad synchronization. (Equivalent DDC definition: ACE_MT_BSW_BADSYNC)
#define sitalMtBlockStatusWord_WORD_COUNT_ERROR					0x0020U		///< Block status word: Word count error. (Equivalent DDC definition: ACE_MT_BSW_WCERR)
#define sitalMtBlockStatusWord_ILLEGAL_MESSAGE					0x0040U		///< Block status word: Illegal message.
#define sitalMtBlockStatusWord_ROLLOVER							0x0080U		///< Block status word: RT circular buffer rollover -OR- MT data stack rollover. (Equivalent DDC definition: ACE_MT_BSW_DSTK_ROVER)
#define sitalMtBlockStatusWord_LOOPBACK_FAILURE					0x0100U		///< Block status word: Loopback failure.
#define sitalMtBlockStatusWord_GOOD_DATA						0x0100U		///< Block status word: Good data block received. (Equivalent DDC definition: ACE_MT_BSW_GDATA)
#define sitalMtBlockStatusWord_NO_RESPONSE						0x0200U		///< Block status word: No response. (Equivalent DDC definition: ACE_MT_BSW_NORES)
#define sitalMtBlockStatusWord_PROTOCOL_VIOLATION				0x0400U		///< Block status word: Protocol violation. (Equivalent DDC definition: ACE_MT_BSW_FMTERR)
#define sitalMtBlockStatusWord_RT_TO_RT_MESSAGE					0x0800U		///< Block status word: RT to RT message. (Equivalent DDC definition: ACE_MT_BSW_RTRT)
#define sitalMtBlockStatusWord_ERROR_FLAG						0x1000U		///< Block status word: Error flag. (Equivalent DDC definition: ACE_MT_BSW_ERRFLG)
#define sitalMtBlockStatusWord_BUS_B							0x2000U		///< Block status word: Bus B (or bus A is bit off). (Equivalent DDC definition: ACE_MT_BSW_CHNL)
#define sitalMtBlockStatusWord_START_OF_MESSAGE					0x4000U		///< Block status word: Start of message. (Equivalent DDC definition: ACE_MT_BSW_SOM)
#define sitalMtBlockStatusWord_END_OF_MESSAGE					0x8000U		///< Block status word: End of message. (Equivalent DDC definition: ACE_MT_BSW_EOM)
#define sitalRtMtMessageBlockStatusWord_ERROR_MASK				0x163FU		///< A mask in which all the bits that may designate any error with a monitored IEEE-1553 message are on.

// MT configuration: wOptions values.
#define sitalMtSetupOption_1553A_MODE_CODES_ENABLED					0x00000200U		///< 1553a mode codes enabled. (Equivalent DDC definition: ACE_MT_OPT_1553A_MC)

// RTMT configuration: wOptions values.
#define sitalRtMtSetupOption_COMBINED_HOST_BUFFER					0x80000000U		///< The messages received by the RT and the MT components of the combined device are merged prior to passing them to the user. (Equivalent DDC definition: ACE_RTMT_COMBO_HBUF)

// Stack message access: wMessageLocationAndRemoval values.
#define sitalMessageLocationAndRemoval_NEXT_PURGE				0U	///< Get the next unread message, and remove it from the stack. (Equivalent DDC definition: ACE_RT_MSGLOC_NEXT_PURGE/ACE_MT_MSGLOC_NEXT_PURGE)
#define sitalMessageLocationAndRemoval_NEXT_NO_PURGE			1U	///< Get the next unread message, and leave it in the stack. (Equivalent DDC definition: ACE_RT_MSGLOC_NEXT_NPURGE/ACE_MT_MSGLOC_NEXT_NPURGE)
#define sitalMessageLocationAndRemoval_LATEST_PURGE				2U	///< Get the latest message, and remove it from the stack. (Equivalent DDC definition: ACE_RT_MSGLOC_LATEST_PURGE/ACE_MT_MSGLOC_LATEST_PURGE)
#define sitalMessageLocationAndRemoval_LATEST_NO_PURGE			3U	///< Get the latest message, and leave it in the stack. (Equivalent DDC definition: ACE_RT_MSGLOC_LATEST_NPURGE/ACE_MT_MSGLOC_LATEST_NPURGE)

// MT stack specifier: wStackSelector values.
#define sitalMtStack_ACTIVE				0U	///< Use the active stack. (Equivalent DDC definition: ACE_MT_STKLOC_ACTIVE)
#define sitalMtStack_INACTIVE			1U	///< Use the inactive stack. (Equivalent DDC definition: ACE_MT_STKLOC_INACTIVE)
#define sitalMtStack_STACK_A			2U	///< Use stack A. (Equivalent DDC definition: ACE_MT_STKLOC_STKA)
#define sitalMtStack_STACK_B			3U	///< Use stack B. (Equivalent DDC definition: ACE_MT_STKLOC_STKB)

// MT stack specifier: wStackSelector values.
#define sitalMtStackSelector_STACK_A					0x0000U	///< Stack A. (Equivalent DDC definition: ACE_MT_STKA)
#define sitalMtStackSelector_STACK_B					0x2000U	///< Stack B. (Equivalent DDC definition: ACE_MT_STKB)
#define sitalMtStackSelector_STACK_COMBINED				0x4000U	///< Combined stacks information. (Equivalent DDC definition: ACE_MT_STK_CMB)

// MT currently active stack designator.
#define sitalMtActiveStack_A			0U		///< The currently active stack is stack A.
#define sitalMtActiveStack_B			1U		///< The currently active stack is stack B.

// MT configuration: wStackMode values.
#define sitalMtStackOption_SINGLE		0U		///< Use a single stack. (Equivalent DDC definition: ACE_MT_SINGLESTK)
#define sitalMtStackOption_DOUBLE		1U		///< Use the two stacks, A and B. (Equivalent DDC definition: ACE_MT_DOUBLESTK)

// MT configuration: wCommandStackSize values.
#define sitalMtCommandStackSize_256		0x0000U	///< Command stack size is   256 words =   64 messages. (Equivalent DDC definition: ACE_MT_CMDSTK_256)
#define sitalMtCommandStackSize_1024	0x0800U	///< Command stack size is  1024 words =  256 messages. (Equivalent DDC definition: ACE_MT_CMDSTK_1K)
#define sitalMtCommandStackSize_4096	0x1000U	///< Command stack size is  4096 words = 1024 messages. (Equivalent DDC definition: ACE_MT_CMDSTK_4K)
#define sitalMtCommandStackSize_16384	0x1800U	///< Command stack size is 16384 words = 4096 messages. (Equivalent DDC definition: ACE_MT_CMDSTK_16K)

// MT configuration: wDataStackSize values.
#define sitalMtDataStackSize_512		0x0700U	///< Data stack size is   512 words. (Equivalent DDC definition: ACE_MT_DATASTK_512)
#define sitalMtDataStackSize_1024		0x0600U	///< Data stack size is  1024 words. (Equivalent DDC definition: ACE_MT_DATASTK_1K)
#define sitalMtDataStackSize_2048		0x0500U	///< Data stack size is  4096 words. (Equivalent DDC definition: ACE_MT_DATASTK_2K)
#define sitalMtDataStackSize_4096		0x0400U	///< Data stack size is 16384 words. (Equivalent DDC definition: ACE_MT_DATASTK_4K)
#define sitalMtDataStackSize_8192		0x0300U	///< Data stack size is 16384 words. (Equivalent DDC definition: ACE_MT_DATASTK_8K)
#define sitalMtDataStackSize_16384		0x0200U	///< Data stack size is 16384 words. (Equivalent DDC definition: ACE_MT_DATASTK_16K)
#define sitalMtDataStackSize_32768		0x0100U	///< Data stack size is 32768 words. (Equivalent DDC definition: ACE_MT_DATASTK_32K)

// Device vector test constants.
#define sitalDeviceVectorTest_MAXIMUM_NUMBER_OF_CHARACTERS_IN_A_LINE_OF_THE_VECTORS_FILE			512 ///< The maximum possible number of characters in a single line of a vectors file to use along a vector test.

// Device test: result values.
#define sitalDeviceTestResult_PASS									0x0000U	///< Test passed. (Equivalent DDC definition: ACE_TEST_PASSED)
#define sitalDeviceTestResult_NON_UNPERFORMANCE						0x0001U	///< Test unperformed. (Equivalent DDC definition: ACE_TEST_NOT_PERFORMED)
#define sitalDeviceTestResult_RAM_FAIL								0x0002U	///< Test failed: Unexpected value read from RAM. (Equivalent DDC definition: ACE_TEST_FAILED_RAM)
#define sitalDeviceTestResult_REGISTER_FAIL							0x0003U	///< Test failed: Unexpected value found in register. (Equivalent DDC definition: ACE_TEST_FAILED_REGISTER)
#define sitalDeviceTestResult_PROTOCOL_FAIL							0x0004U	///< Test failed: Protocol unmet. (Equivalent DDC definition: ACE_TEST_FAILED_PROTOCOL)
#define sitalDeviceTestResult_INTERRUPT_FAIL						0x0005U	///< Test failed: IRQ handling unmet. (Equivalent DDC definition: ACE_TEST_FAILED_INTERRUPT)
#define sitalDeviceTestResult_MEMORY_READ_VECTOR_FAIL				0x0006U	///< Test failed: Vectors test operation of type "read - register" un-succeeded. (Equivalent DDC definition: ACE_TEST_FAILED_MVECTOR)
#define sitalDeviceTestResult_REGISTER_READ_VECTOR_FAIL				0x0007U	///< Test failed: Vectors test operation of type "read - memory" un-succeeded. (Equivalent DDC definition: ACE_TEST_FAILED_RVECTOR)

// RS485
#define SIZE_OF_RS485_TX_BUFFER										1008
#define SIZE_OF_RS485_RX_BUFFER										1024

#define RS485_Status_Register								0
#define RS485_Configuration_Register						1
#define RS485_BaudRate_Register								2

#define RS485_NumberOfBytesToSend							1023

// Macro definitions.

// Type definitions.

///< A pointer to the user's interrupt service routine, which is called whenever a relevant interrupt occurs with this device.
typedef void(_DECL *USER_ISR_FUNCTION)(S16BIT swDevice, U32BIT dwIrqStatus);

///< A pointer to the user's asynchronous messages interrupt service routine, which is called whenever some high priority asynchronous message violates the time frame of a minor frame.
typedef void(_DECL *ASYNCHRONOUS_MESSAGE_ISR_FUNCTION)(S16BIT swDevice, U16BIT wMinorFrameId);



// Type/structure declarations.

struct sitalIsqEntryStructure;
struct sitalGpqEntryStructure;
struct sitalCommandStructure;
struct sitalDecodedMessageStructure;
struct sitalMtInformationStructure;
struct sitalStackOperationalStatisticsStructure;
struct sitalHostBufferOperationalStatisticsStructure;
struct sitalDeviceTestResultStructure;
struct MSGSTRUCT;


// Type/structure definitions.

/// RT/MT interrupt status queue entry.
/// Equivalent DDC definition: ISQENTRY
typedef struct sitalIsqEntryStructure
{
	/// Interrupt header.
	/// Equivalent DDC definition: wISQHeader
	U16BIT wHeader;
	/// Interrupt data.
	/// Equivalent DDC definition: wISQData
	U16BIT wData;
} sitalIsqEntryStruct;

/// BC GPQ entry.
/// Equivalent DDC definition: GPQENTRY.
typedef struct sitalGpqEntryStructure
{
	/// Entry header.
	/// Equivalent DDC definition: wGPQHeader
	U16BIT wHeader;
	/// Entry data.
	/// Equivalent DDC definition: wGPQData
	U16BIT wData;
} sitalGpqEntryStruct;

/// BC command information.
/// Equivalent DDC definition: OPCODESTRUCT.
typedef struct sitalCommandStructure
{
	/// Unique command ID.
	/// Equivalent DDC definition: nOpCodeID
	S16BIT swCommandId;
	/// Opcode.
	/// Equivalent DDC definition: wOpcode
	U16BIT wOpcode;
	/// Opcode parameter.
	/// Equivalent DDC definition: wParameter
	U32BIT dwParameter;
	/// Opcode condition.
	/// Equivalent DDC definition: wCondition
	U16BIT wCondition;
} sitalCommandStruct;

/// A decoded MIL-STD-1553 message.
/// Equivalent DDC definition: MSGSTRUCT
typedef struct sitalDecodedMessageStructure
{
	/// Message type (sitalMessageType_*).
	/// Equivalent DDC definition: wType
	U16BIT wType;
	/// Block status word.
	/// Equivalent DDC definition: wBlkSts
	U16BIT wBlockStatus;
	/// Time tag - 3rd word (UNUSED).
	/// Equivalent DDC definition: wTimeTag3
	U16BIT wTimeTag3;
	/// Time tag - 2nd word (UNUSED).
	/// Equivalent DDC definition: wTimeTag2
	U16BIT wTimeTag2;
	/// Time tag - 1st word.
	/// An automatically rolled over 16-bit real time stamp whose units depend on the time tag resolution that's currently set for the device (see function sitalDevice_TimeTag_SetResolution and the initialization value given by function sitalDevice_Initialize).
	/// Equivalent DDC definition: wTimeTag
	U16BIT wTimeTag;
	/// First command word.
	/// Equivalent DDC definition: wCmdWrd1
	U16BIT wCommandWord1;
	/// Second command word.
	/// Relevant only if field bIsCommandWord2Relevant is TRUE.
	/// Equivalent DDC definition: wCmdWrd2
	U16BIT wCommandWord2;
	/// A flag that says if first command word is relevant.
	/// This field is always TRUE and therefore irrelevant, but it is nevertheless kept in order to be compatible with DDC.
	/// Equivalent DDC definition: wCmdWrd1Flg
	U16BIT bIsCommandWord1Relevant;
	/// A flag that says if second command word is relevant.
	/// Equivalent DDC definition: wCmdWrd2Flg
	U16BIT bIsCommandWord2Relevant;
	/// The [first] status word that's actually identified on the bus.
	/// Relevant only if field bIsStatus1Relevant is TRUE.
	/// Equivalent DDC definition: wStsWrd1
	U16BIT wStatus1;
	/// The second status word that's actually identified on the bus.
	/// Relevant only if field bIsStatus2Relevant is TRUE.
	/// Equivalent DDC definition: wStsWrd2
	U16BIT wStatus2;
	/// A flag that says if first status word is relevant.
	/// Equivalent DDC definition: wStsWrd1Flg
	U16BIT bIsStatus1Relevant;
	/// A flag that says if second status word is relevant.
	/// Equivalent DDC definition: wStsWrd2Flg
	U16BIT bIsStatus2Relevant;
	/// The actual number of valid data words that have been received for this message.
	/// Equivalent DDC definition: wWordCount
	U16BIT wDataWordCount;
	/// Data words.
	/// The number of relevant entries (i.e., those that actually contain data words) is stored in field wDataWordCount.
	/// Equivalent DDC definition: aDataWrds
	U16BIT waData[sitalIeee1553_MAXIMUM_COUNT_OF_MESSAGE_DATA_WORDS];
	/// Control word.
	/// Only relevant in BC mode.
	/// Equivalent DDC definition: wBCCtrlWrd
	U16BIT wBcControlWord;
	/// Message gap time.
	/// Only relevant in BC mode.
	/// Equivalent DDC definition: wBCGapTime
	U16BIT wBcGapTime;
	/// The echo of the last word transmitted by the BC.
	/// Only relevant in BC mode.
	/// Equivalent DDC definition: wBCLoopBack1
	U16BIT wBcLoopbackWord1;
	/// An unused field, kept only in order to be compatible with DDC.
	/// Equivalent DDC definition: wBCLoopBack2
	U16BIT wUnused01;
	/// A flag that says if first loopback word is relevant.
	/// Only relevant in BC mode.
	/// Equivalent DDC definition: wBCLoopBack1Flg
	U16BIT bIsBcLoopbackWord1Relevant;
	/// An unused field, kept only in order to be compatible with DDC.
	/// Only relevant in BC mode.
	/// Equivalent DDC definition: wBCLoopBack2Flg
	U16BIT wUnused02;
} sitalDecodedMessageStruct;

/// General purpose queue operational statistics information.
/// Equivalent DDC definition: GPQMETRIC
typedef struct sitalGpqOperationalStatisticsStructure
{
	/// The count of messages that have been lost.
	/// Equivalent DDC definition: dwLost
	U32BIT dwLostMessageCount;
	/// The current percentage of fullness of the related stack/queue.
	/// This field must contain a value in the region 0 to 100.
	/// Equivalent DDC definition: wPctFull
	U16BIT wFullnessPercentage;
	/// The maximum encountered percentage of fullness of the related stack/queue.
	/// This field must contain a value in the region 0 to 100.
	/// Equivalent DDC definition: wHighPct
	U16BIT wMaximumFullnessPercentage;
} sitalGpqOperationalStatisticsStruct;

/// MT operational information.
/// Equivalent DDC definition: MTINFO
typedef struct sitalMtInformationStructure
{
	/// The configured stack mode, which is either single or double.
	/// Equivalent DDC definition: wStkMode
	U16BIT wStackMode;
	/// The size of the command stack.
	/// Equivalent DDC definition: wCmdStkSize
	U16BIT wCommandStackSize;
	/// The size of the data stack.
	/// Equivalent DDC definition: wDataStkSize
	U16BIT wDataStackSize;
	/// A flag that says whether this device is configured to support protocol 1553-A.
	/// Equivalent DDC definition: b1553aMCodes
	U16BIT bIsProtocol1553aSupported;
	/// The size of the installed host buffer.
	/// Equivalent DDC definition: dwHBufSize
	U32BIT dwHostBufferSize;
} sitalMtInformationStruct;

/// Stack operational statistics information.
/// Equivalent DDC definition: STKMETRIC
typedef struct sitalStackOperationalStatisticsStructure
{
	/// The count of messages that have been lost.
	/// Equivalent DDC definition: dwLost
	U32BIT dwLostMessageCount;
	/// The current percentage of fullness of the related stack/queue.
	/// This field must contain a value in the region 0 to 100.
	/// Equivalent DDC definition: dwPctFull
	U32BIT dwFullnessPercentage;
	/// The maximum encountered percentage of fullness of the related stack/queue.
	/// This field must contain a value in the region 0 to 100.
	/// Equivalent DDC definition: dwHighPct
	U32BIT dwMaximumFullnessPercentage;
} sitalStackOperationalStatisticsStruct;

/// Host buffer operational statistics information.
/// Equivalent DDC definition: HBUFMETRIC
typedef struct sitalHostBufferOperationalStatisticsStructure
{
	/// The count of messages currently stored in the host buffer.
	/// Equivalent DDC definition: dwCount
	U32BIT dwMessageCount;
	/// The count of messages that have been lost.
	/// Equivalent DDC definition: dwLost
	U32BIT dwLostMessageCount;
	/// The current percentage of fullness of the host buffer.
	/// This field must contain a value in the region 0 to 100.
	/// Equivalent DDC definition: dwPctFull
	U32BIT dwFullnessPercentage;
	/// The maximum encountered percentage of fullness of the host buffer.
	/// This field must contain a value in the region 0 to 100.
	/// Equivalent DDC definition: dwHighPct
	U32BIT dwMaximumFullnessPercentage;
} sitalHostBufferOperationalStatisticsStruct;

/// Device test result information.
/// Equivalent DDC definition: TESTRESULT
typedef struct sitalDeviceTestResultStructure
{
	/// Test result (sitalDeviceTestResult_*).
	/// Equivalent DDC definition: wResult
	U16BIT wResult;
	/// A value that designates an expected value that was not eventually found (i.e., a value expected to be found in some device memory address or register, possibly after being passed a suitable transformation).
	/// Only relevant in case field wResult contains sitalDeviceTestResult_*_FAIL.
	/// Equivalent DDC definition: wExpData
	U16BIT wExpectedValue;
	/// A value that designates an actual value that was eventually found (i.e., a value expected to be found in some device memory address or register, possibly after being passed a suitable transformation).
	/// Only relevant in case field wResult contains sitalDeviceTestResult_*_FAIL.
	/// Equivalent DDC definition: wActData
	U16BIT wActualValue;
	/// An unused field, kept only in order to be compatible with DDC.
	/// Equivalent DDC definition: dwExpData
	U32BIT dwUnused01;
	/// An unused field, kept only in order to be compatible with DDC.
	/// Equivalent DDC definition: dwActData
	U32BIT dwUnused02;
	/// An unused field, kept only in order to be compatible with DDC.
	/// Equivalent DDC definition: PciMode32
	BOOLEAN bUnused03;
	/// A device memory address where an unexpected value has been found.
	/// Only relevant in case field wResult contains sitalDeviceTestResult_*_FAIL.
	/// Equivalent DDC definition: wAceAddr
	U16BIT wDeviceMemoryAddress;
	/// The nature and the exact possible values for this field is unique for each test function (see the documentation of the relevant test function).
	/// Yet, in general, this field is set as following:
	/// - In case field wResult contains sitalDeviceTestResult_*_FAIL: The ID of the exact check that failed the test.
	/// - In case field wResult contains sitalDeviceTestResult_PASSED: Any required result detail.
	/// Equivalent DDC definition: wCount
	U16BIT wCheckId;
} sitalDeviceTestResultStruct;

//Arinc429
typedef struct sitalA429ChannelInformation
{
    /// The size in bytes of this structure.
    /// Caller must set this field to sizeof(stla429ChannelInformationStructure).
    /// This is to prevent buffer overwrite when compilers are incompatible or definitions change.
    U32BIT  dwStructureSize;
    U32BIT dwUserTag;        // Arbitrary user provided value
    union {
        struct /*characteristics*/ {
           U32BIT channelIsAvailable : 1;    // true = available for use
           U32BIT channelRunning : 1;        // true = running, false = not running
           U32BIT channelFailure : 1;        // true = failure detected
           U32BIT channelIsTX : 1;           // true = configured as TX, false = as RX
           U32BIT channelIsHighSpeed : 1;    // true = configured for high speed, else low speed
           U32BIT channelSupportsTX : 1;     // true = can be configured as TX
           U32BIT channelSupportsRX : 1;     // true = can be configured as RX
           U32BIT channelSupportsHighSpeed : 1;  // true = can be configured for high speed
           U32BIT channelSupportsLowSpeed : 1;   // true = can be configured for low speed
        }sital_A429ChannelInfoInner;
        U32BIT  dwFlags; // above struct as integer
    };
    U32BIT  dwTransferSize;   // Size of transfer buffer required for bulk RX
    U32BIT  dwCardNumber;     // Card number on which channel is located
    U32BIT  dwReserved1;      // Padding
} sital_A429ChannelInfo;

// Following bits are same for TX and RX modes:
#define sital_A429_CFG_HIGH_RATE			0x0001  ///< Data rate: 100 KHz
#define sital_A429_CFG_LOW_RATE				0x0000  ///< Data rate: 12.5 KHz
#define sital_A429_CFG_MASK_RATE			0x0001
#define sital_A429_CFG_PARITY_NONE			0x0000  ///< Data parity: none. MSB can be used as data.
#define sital_A429_CFG_PARITY_EVEN			0x0002  ///< Data parity: even
#define sital_A429_CFG_PARITY_ODD			0x0006  ///< Data parity: odd
#define sital_A429_CFG_MASK_PARITY			0x0006  //   Mask for parity bits

#define sital_A429_NUMBER_OF_WORDS_MASK		0x00FF0000  //   Number of words in FIFO mask - Bits 16-23
#define sital_A429_FIFO_FULL		        0x01000000  //   FIFO full
#define sital_A429_FIFO_EMPTY		        0x02000000  //   FIFO empty
#define sital_A429_RX_LABEL_TABLE_READY		0x04000000  //   Labels table ready

// Following bits apply only for RX mode:
#define sital_A429_CFG_RX_LABEL_MATCH		0x0008  ///< enable label matching
#define sital_A429_CFG_MASK_RX_LABELS		0x0008
#define sital_A429_CFG_RX_DECODER_ENABLE	0x0010
#define sital_A429_CFG_RX_DECODER_DISABLE	0x0000
#define sital_A429_CFG_MASK_RX_DECODER		0x0070

#define sital_A429_CARD_DISABLE_INTERNAL_LOOPBACK          0x00000000  // sets the card to disable internal loopback, external Arinc429 Tx Rx data is accepted
#define sital_A429_CARD_ENABLE_INTERNAL_LOOPBACK           0x00000001  // sets the card to enable internal loopback, external Arinc429 Tx Rx data is not accepted


// Exported-function declarations.

// General Stld1553 functions.

_EXTERN S16BIT _DECL sitalStld1553_GetLibraryVersion (	U16BIT* wpMajorVersion,
														U16BIT* wpMinorVersion,
														U16BIT* wpBuildNumber,
														U16BIT* wpRevisionNumber);
_EXTERN U16BIT _DECL sitalStld1553_GetShortLibraryVersion (void);
_EXTERN U16BIT _DECL sitalStld1553_GetShortCoreVersion (void);
_EXTERN S16BIT _DECL sitalStld1553_ConfigurePrintings (BOOLEAN bIsConsoleScreen, sitalPrintingsLevelEnum pleBasePrintingsLevel);
_EXTERN S8BIT* _DECL sitalStld1553_GetBlockStatusWordErrorString (U16BIT wMode, U16BIT wBlockStatus);
_EXTERN S16BIT _DECL sitalStld1553_GetReturnCodeDescriberString (S16BIT swError, S8BIT* szpErrorString, U16BIT wMaximumStringLength);
_EXTERN S8BIT* _DECL sitalStld1553_GetMessageTypeString (U16BIT wMessageType);
_EXTERN S16BIT _DECL sitalBcStld1553_Command_GetCode (	U16BIT* wpCommandWord,
														U16BIT wRtAddress,
														U16BIT wMessageDirection,
														U16BIT wSubaddressOrMode,
														U16BIT wWordCountOrModeCode);
_EXTERN S16BIT _DECL sitalBcStld1553_Command_Parse (	U16BIT wCommandWord,
														U16BIT* wpRtAddress,
														U16BIT* wpMessageDirection,
														U16BIT* wpSubaddressOrMode,
														U16BIT* wpWordCountOrModeCode);

// Configuration functions.
_EXTERN U16BIT _DECL sitalDevice_Register_Read (S16BIT swDevice, U16BIT wRegisterAddress);
_EXTERN S16BIT _DECL sitalDevice_Register_Write (S16BIT swDevice, U16BIT wRegisterAddress, U16BIT wRegisterValue);
_EXTERN S16BIT _DECL sitalDevice_Register_UpdateDevice (S16BIT swDevice, U16BIT wRegisterAddress);
_EXTERN U16BIT _DECL sitalDevice_Memory_Read (S16BIT swDevice, U16BIT wDeviceMemoryAddress);
_EXTERN S16BIT _DECL sitalDevice_Memory_Write (S16BIT swDevice, U16BIT wDeviceMemoryAddress, U16BIT wDeviceMemoryValue);
_EXTERN S16BIT _DECL sitalDevice_Initialize (	S16BIT swDevice,
												U16BIT wAccess,
												U16BIT wMode,
												U32BIT dwSizeOfAllocatedMemory,
												U32BIT dwRegistersAddress,
												U32BIT dwMemoryAddress);
_EXTERN S16BIT _DECL sitalDevice_Free (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalDevice_CoreConfiguration_Get (S16BIT swDevice, U16BIT* wpCoreConfiguration);
_EXTERN S16BIT _DECL sitalDevice_TimeTag_Set (S16BIT swDevice, U16BIT wTimeTag);
_EXTERN S16BIT _DECL sitalDevice_TimeTag_Get (S16BIT swDevice, U16BIT* wpTimeTag);
_EXTERN S16BIT _DECL sitalDevice_TimeTag_Reset (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalDevice_TimeTag_SetResolution (S16BIT swDevice, U16BIT wTimeTagResolution);
_EXTERN S16BIT _DECL sitalDevice_OperationalStatisticsCollection_Configure (S16BIT swDevice, U16BIT bIsOperationalStatisticsCollected);
_EXTERN S16BIT _DECL sitalDevice_Irq_GetMode (S16BIT swDevice, U16BIT* wpInterruptMode, U16BIT* wpAutoClear);
_EXTERN S16BIT _DECL sitalDevice_Irq_Configure (S16BIT swDevice, U16BIT wInterruptMode, U16BIT wAutoClear);
_EXTERN S16BIT _DECL sitalDevice_Irq_Manipulate (	S16BIT swDevice,
													U16BIT bIsInterruptEnabled,
													U32BIT dwIrqMask,
													USER_ISR_FUNCTION funcpExternalIsr);
_EXTERN S16BIT _DECL sitalDevice_SetAsynchronousMessagesIsr (S16BIT swDevice, ASYNCHRONOUS_MESSAGE_ISR_FUNCTION funcpAsynchronousMessagesIsr);
_EXTERN S16BIT _DECL sitalDevice_Clock_SetFrequency (S16BIT swDevice, U16BIT wClockFrequency);
_EXTERN S16BIT _DECL sitalDevice_Isq_ReadEntry (S16BIT swDevice, struct sitalIsqEntryStructure* iespIsqEntry);
_EXTERN S16BIT _DECL sitalDevice_Isq_Clear (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalDevice_Isq_Configure (S16BIT swDevice, U16BIT bIsIsqEnabled);
_EXTERN S16BIT _DECL sitalDevice_SetResponseTimeout (S16BIT swDevice, U16BIT wResponseTimeout);
_EXTERN S16BIT _DECL sitalDevice_ConfigureWatchdogTimeout (S16BIT swDevice, U16BIT bIsWatchdogEnabled, U16BIT wWatchdogTimeout);
_EXTERN S16BIT _DECL sitalDevice_ConfigureDecoder (S16BIT swDevice, U16BIT wDoubleOrSingleEndedInputDevice, U16BIT wExpendedXingOption);
_EXTERN S16BIT _DECL sitalDevice_ConfigureRamParityCheck (S16BIT swDevice, U16BIT wRamParityCheckEnabler);
_EXTERN S16BIT _DECL sitalDevice_Test_Registers (S16BIT swDevice, struct sitalDeviceTestResultStructure* dtrspTestResult);
_EXTERN S16BIT _DECL sitalDevice_Test_Memory (S16BIT swDevice, struct sitalDeviceTestResultStructure* dtrspTestResult, U16BIT wWrittenValue);
_EXTERN S16BIT _DECL sitalDevice_Test_Protocol (S16BIT swDevice, struct sitalDeviceTestResultStructure* dtrspTestResult);
_EXTERN S16BIT _DECL sitalDevice_Test_Interrupts (S16BIT swDevice, struct sitalDeviceTestResultStructure* dtrspTestResult);
_EXTERN S16BIT _DECL sitalDevice_Test_Vectors (S16BIT swDevice, struct sitalDeviceTestResultStructure* dtrspTestResult, char* szpVectorsFilePath);

// BC functions.
_EXTERN S16BIT _DECL sitalBc_Initialize (S16BIT swDevice, U32BIT dwOptions);
_EXTERN S16BIT _DECL sitalBc_MessageRetryPolicy_Set (	S16BIT swDevice,
														U16BIT wNumberOfRetries,
														U16BIT wFirstRetryBus,
														U16BIT wSecondRetryBus,
														U16BIT wReserved);
_EXTERN S16BIT _DECL sitalBc_Start (S16BIT swDevice, S16BIT swFrameId, S32BIT sdwFrameCount);
_EXTERN S16BIT _DECL sitalBc_Stop (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalBc_GetActivationState (S16BIT swDevice, U16BIT *wpCurrentState);
_EXTERN S16BIT _DECL sitalBc_DataBlock_Create (	S16BIT swDevice,
												S16BIT swDataBlockId,
												U16BIT wDataBlockSize,
												U16BIT* wapBuffer,
												U16BIT wBufferSize);
_EXTERN S16BIT _DECL sitalBc_DataBlock_Delete (S16BIT swDevice, S16BIT swDataBlockId);
_EXTERN S16BIT _DECL sitalBc_DataBlock_Write (	S16BIT swDevice,
												S16BIT swDataBlockId,
												U16BIT* wapBuffer,
												U16BIT wBufferSize,
												U16BIT wOffset);
_EXTERN S16BIT _DECL sitalBc_DataBlock_Read (	S16BIT swDevice,
												S16BIT swDataBlockId,
												U16BIT* wapBuffer,
												U16BIT wBufferSize,
												U16BIT wOffset);
_EXTERN S16BIT _DECL sitalBc_Frame_Create (	S16BIT swDevice,
											S16BIT swFrameId,
											U16BIT wFrameType,
											S16BIT* swapCommandIds,
											U16BIT wCommandCount,
											U16BIT wFrameTime,
											U16BIT wFlags);
_EXTERN S16BIT _DECL sitalBc_Frame_Delete (S16BIT swDevice, S16BIT swFrameId);
_EXTERN S16BIT _DECL sitalBc_Command_DistortWord (U16BIT wHardwareOpcode, U16BIT wDistortionManner, U16BIT wDistortionParameter);
_EXTERN S16BIT _DECL sitalBc_Command_GetWord (U16BIT wHardwareOpcode, U16BIT wCondition, U16BIT* wpCommandOpcode);
_EXTERN S16BIT _DECL sitalBc_Command_Create (	S16BIT swDevice,
												S16BIT swCommandId,
												U16BIT wOpcode,
												U16BIT wCondition,
												U32BIT dwParameter1,
												U32BIT dwParameter2,
												U32BIT dwReserved);
_EXTERN S16BIT _DECL sitalBc_Command_Delete (S16BIT swDevice, S16BIT swCommandId);
_EXTERN S16BIT _DECL sitalBc_Message_CreateBcToRt (	S16BIT swDevice,
													S16BIT swMessageId,
													S16BIT swDataBlockId,
													U16BIT wReceiverRt,
													U16BIT wReceiverRtSubaddress,
													U16BIT wWordCount,
													U16BIT wGapTime,
													U32BIT dwOptions);
_EXTERN S16BIT _DECL sitalBc_Message_CreateRtToBc (	S16BIT swDevice,
													S16BIT swMessageId,
													S16BIT swDataBlockId,
													U16BIT wTransmitterRt,
													U16BIT wTransmitterRtSubaddress,
													U16BIT wWordCount,
													U16BIT wGapTime,
													U32BIT dwOptions);
_EXTERN S16BIT _DECL sitalBc_Message_CreateRtToRt (	S16BIT swDevice,
													S16BIT swMessageId,
													S16BIT swDataBlockId,
													U16BIT wReceiverRt,
													U16BIT wReceiverRtSubaddress,
													U16BIT wWordCount,
													U16BIT wTransmitterRt,
													U16BIT wTransmitterRtSubaddress,
													U16BIT wGapTime,
													U32BIT dwOptions);
_EXTERN S16BIT _DECL sitalBc_Message_CreateBcToOrFromRtMode (	S16BIT swDevice,
																S16BIT swMessageId,
																S16BIT swDataBlockId,
																U16BIT wRt,
																U16BIT wMessageDirection,
																U16BIT wModeCommand,
																U16BIT wGapTime,
																U32BIT dwOptions);
_EXTERN S16BIT _DECL sitalBc_Message_CreateBcToBroadcast (	S16BIT swDevice,
															S16BIT swMessageId,
															S16BIT swDataBlockId,
															U16BIT wReceiverRtSubaddress,
															U16BIT wWordCount,
															U16BIT wGapTime,
															U32BIT dwOptions);
_EXTERN S16BIT _DECL sitalBc_Message_CreateRtToBroadcast (	S16BIT swDevice,
															S16BIT swMessageId,
															S16BIT swDataBlockId,
															U16BIT wReceiverRtSubaddress,
															U16BIT wWordCount,
															U16BIT wTransmitterRt,
															U16BIT wTransmitterRtSubaddress,
															U16BIT wGapTime,
															U32BIT dwOptions);
_EXTERN S16BIT _DECL sitalBc_Message_CreateBcToOrFromBroadcastMode (	S16BIT swDevice,
																		S16BIT swMessageId,
																		S16BIT swDataBlockId,
																		U16BIT wMessageDirection,
																		U16BIT wModeCommand,
																		U16BIT wGapTime,
																		U32BIT dwOptions);
_EXTERN S16BIT _DECL sitalBc_Message_Create (	S16BIT swDevice,
												S16BIT swMessageId,
												S16BIT swDataBlockIdForMessage1,
												U16BIT wBcControlWordForMessage1,
												U16BIT wCommandWord1ForMessage1,
												U16BIT wCommandWord2ForMessage1,
												U16BIT wGapTimeForMessage1,
												S16BIT swDataBlockIdForMessage2,
												U16BIT wBcControlWordForMessage2,
												U16BIT wCommandWord1ForMessage2,
												U16BIT wCommandWord2ForMessage2,
												U16BIT wGapTimeForMessage2,
												U32BIT dwOptions);
_EXTERN S16BIT _DECL sitalBc_Message_ModifyBcToRt (	S16BIT swDevice,
													S16BIT swMessageId,
													S16BIT swDataBlockId,
													U16BIT wReceiverRt,
													U16BIT wReceiverRtSubaddress,
													U16BIT wWordCount,
													U16BIT wGapTime,
													U32BIT dwOptions,
													U16BIT wModificationFlags);
_EXTERN S16BIT _DECL sitalBc_Message_ModifyRtToBc (	S16BIT swDevice,
													S16BIT swMessageId,
													S16BIT swDataBlockId,
													U16BIT wTransmitterRt,
													U16BIT wTransmitterRtSubaddress,
													U16BIT wWordCount,
													U16BIT wGapTime,
													U32BIT dwOptions,
													U16BIT wModificationFlags);
_EXTERN S16BIT _DECL sitalBc_Message_ModifyRtToRt (	S16BIT swDevice,
													S16BIT swMessageId,
													S16BIT swDataBlockId,
													U16BIT wReceiverRt,
													U16BIT wReceiverRtSubaddress,
													U16BIT wWordCount,
													U16BIT wTransmitterRt,
													U16BIT wTransmitterRtSubaddress,
													U16BIT wGapTime,
													U32BIT dwOptions,
													U16BIT wModificationFlags);
_EXTERN S16BIT _DECL sitalBc_Message_ModifyBcToOrFromRtMode (	S16BIT swDevice,
																S16BIT swMessageId,
																S16BIT swDataBlockId,
																U16BIT wRt,
																U16BIT wMessageDirection,
																U16BIT wModeCommand,
																U16BIT wGapTime,
																U32BIT dwOptions,
																U16BIT wModificationFlags);
_EXTERN S16BIT _DECL sitalBc_Message_ModifyBcToBroadcast (	S16BIT swDevice,
													S16BIT swMessageId,
													S16BIT swDataBlockId,
													U16BIT wReceiverRtSubaddress,
													U16BIT wWordCount,
													U16BIT wGapTime,
													U32BIT dwOptions,
													U16BIT wModificationFlags);
_EXTERN S16BIT _DECL sitalBc_Message_ModifyRtToBroadcast (	S16BIT swDevice,
															S16BIT swMessageId,
															S16BIT swDataBlockId,
															U16BIT wReceiverRtSubaddress,
															U16BIT wWordCount,
															U16BIT wTransmitterRt,
															U16BIT wTransmitterRtSubaddress,
															U16BIT wGapTime,
															U32BIT dwOptions,
															U16BIT wModificationFlags);
_EXTERN S16BIT _DECL sitalBc_Message_ModifyBcToOrFromBroadcastMode (	S16BIT swDevice,
																		S16BIT swMessageId,
																		S16BIT swDataBlockId,
																		U16BIT wMessageDirection,
																		U16BIT wModeCommand,
																		U16BIT wGapTime,
																		U32BIT dwOptions,
																		U16BIT wModificationFlags);
_EXTERN S16BIT _DECL sitalBc_Message_Modify (	S16BIT swDevice,
												S16BIT swMessageId,
												S16BIT swDataBlockIdForMessage1,
												U16BIT wBcControlWordForMessage1,
												U16BIT wCommandWord1ForMessage1,
												U16BIT wCommandWord2ForMessage1,
												U16BIT wGapTimeForMessage1,
												S16BIT swDataBlockIdForMessage2,
												U16BIT wBcControlWordForMessage2,
												U16BIT wCommandWord1ForMessage2,
												U16BIT wCommandWord2ForMessage2,
												U16BIT wGapTimeForMessage2,
												U16BIT wModificationFlags);
_EXTERN S16BIT _DECL sitalBc_Message_Delete (S16BIT swDevice, S16BIT swMessageId);
_EXTERN S16BIT _DECL sitalBc_Message_GetByIdRaw (	S16BIT swDevice,
													S16BIT swMessageId,
													U16BIT* wapBuffer,
													U16BIT wIsPurgeRequired);
_EXTERN S16BIT _DECL sitalBc_Message_DecodeRaw (S16BIT swDevice, U16BIT* wapBuffer, struct sitalDecodedMessageStructure* dmspDecodedMessage);
_EXTERN S16BIT _DECL sitalBc_Message_GetByIdDecoded (	S16BIT swDevice,
														S16BIT swMessageId,
														struct sitalDecodedMessageStructure* dmspDecodedMessage,
														U16BIT wIsPurgeRequired);
_EXTERN S16BIT _DECL sitalBc_ConfigureMessageGapTimeFieldPolicy (S16BIT swDevice, U16BIT bIsMessageGapTimeFieldEnabled);
_EXTERN S16BIT _DECL sitalBc_Gpf_SetState (S16BIT swDevice, U16BIT wGpf, U16BIT wEffect);
_EXTERN S16BIT _DECL sitalBc_GetConditionState (S16BIT swDevice, U16BIT wConditionCode, U16BIT* wpCurrentState);
_EXTERN S16BIT _DECL sitalBc_Gpq_Read (S16BIT swDevice, struct sitalGpqEntryStructure* gespGpqEntry);
_EXTERN S16BIT _DECL sitalBc_Gpq_GetEntriesCount (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalBc_Gpq_HandleNewEntries (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalBc_Gpq_GetOperationalStatistics (S16BIT swDevice, struct sitalGpqOperationalStatisticsStructure* gosspGpqOperationalStatistics, U16BIT bIsResetOfHighestRecordedPercentageRequired);
_EXTERN S16BIT _DECL sitalBc_AsynchronousMessage_CreateBcToRt (	S16BIT swDevice,
																S16BIT swMessageId,
																S16BIT swDataBlockId,
																U16BIT wReceiverRt,
																U16BIT wReceiverRtSubaddress,
																U16BIT wWordCount,
																U16BIT wGapTime,
																U32BIT dwOptions,
																U16BIT* wapBuffer);
_EXTERN S16BIT _DECL sitalBc_AsynchronousMessage_CreateRtToBc (	S16BIT swDevice,
																S16BIT swMessageId,
																S16BIT swDataBlockId,
																U16BIT wReceiverRt,
																U16BIT wReceiverRtSubaddress,
																U16BIT wWordCount,
																U16BIT wGapTime,
																U32BIT dwOptions,
																U16BIT* wapBuffer);
_EXTERN S16BIT _DECL sitalBc_AsynchronousMessage_CreateRtToRt (	S16BIT swDevice,
																S16BIT swMessageId,
																S16BIT swDataBlockId,
																U16BIT wReceiverRt,
																U16BIT wReceiverRtSubaddress,
																U16BIT wWordCount,
																U16BIT wTransmitterOrReceiverRt,
																U16BIT wTransmitterOrReceiverRtSubaddress,
																U16BIT wGapTime,
																U32BIT dwOptions,
																U16BIT* wapBuffer);
_EXTERN S16BIT _DECL sitalBc_AsynchronousMessage_CreateBcToOrFromRtMode (	S16BIT swDevice,
																			S16BIT swMessageId,
																			S16BIT swDataBlockId,
																			U16BIT wRt,
																			U16BIT wMessageDirection,
																			U16BIT wModeCommand,
																			U16BIT wGapTime,
																			U32BIT dwOptions,
																			U16BIT* wapBuffer);
_EXTERN S16BIT _DECL sitalBc_AsynchronousMessage_CreateBcToBroadcast (	S16BIT swDevice,
																		S16BIT swMessageId,
																		S16BIT swDataBlockId,
																		U16BIT wReceiverRtSubaddress,
																		U16BIT wWordCount,
																		U16BIT wGapTime,
																		U32BIT dwOptions,
																		U16BIT* wapBuffer);
_EXTERN S16BIT _DECL sitalBc_AsynchronousMessage_CreateRtToBroadcast (	S16BIT swDevice,
																		S16BIT swMessageId,
																		S16BIT swDataBlockId,
																		U16BIT wReceiverRtSubadress,
																		U16BIT wWordCount,
																		U16BIT wTransmitterRt,
																		U16BIT wTransmitterRtSubaddress,
																		U16BIT wGapTime,
																		U32BIT dwOptions,
																		U16BIT* wapBuffer);
_EXTERN S16BIT _DECL sitalBc_AsynchronousMessage_CreateBcToOrFromBroadcastMode (	S16BIT swDevice,
																					S16BIT swMessageId,
																					S16BIT swDataBlockId,
																					U16BIT wMessageDirection,
																					U16BIT wModeCommand,
																					U16BIT wGapTime,
																					U32BIT dwOptions,
																					U16BIT* wapBuffer);
_EXTERN S16BIT _DECL sitalBc_AsynchronousMessage_SendAtLowPriority_ExecuteOnce (S16BIT swDevice, U16BIT* wpRemainingMessageCount, U16BIT wTimeFactor);
_EXTERN S16BIT _DECL sitalBc_AsynchronousMessage_SendAtLowPriority (S16BIT swDevice, U16BIT* wpRemainingMessageCount, U16BIT wTimeFactor);
_EXTERN S16BIT _DECL sitalBc_AsynchronousMessage_SendAtHighPriority_ExecuteOnce (S16BIT swDevice, U16BIT wMessageId, U16BIT wTimeFactor);
_EXTERN S16BIT _DECL sitalBc_AsynchronousMessage_SendAtHighPriority (S16BIT swDevice, U16BIT wMessageId, U16BIT wTimeFactor);
_EXTERN S16BIT _DECL sitalBc_HostBuffer_Initialize (S16BIT swDevice, U32BIT dwHostBufferSize);
_EXTERN S16BIT _DECL sitalBc_HostBuffer_Free (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalBc_HostBuffer_Message_GetCount (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalBc_HostBuffer_Message_GetDecoded (	S16BIT swDevice,
																struct sitalDecodedMessageStructure* dmspDecodedMessage,
																U32BIT* dwpMessageCount,
																U32BIT* dwpLostMessageCount,
																U16BIT wMessageLocationAndRemoval);
_EXTERN S16BIT _DECL sitalBc_HostBuffer_Message_GetRaw (	S16BIT swDevice,
															U16BIT* wapBuffer,
															U16BIT wBufferSize,
															U32BIT* dwpMessageCount,
															U32BIT* dwpLostMessageCount);
_EXTERN S16BIT _DECL sitalBc_HostBuffer_GetOperationalStatistics (S16BIT swDevice, struct sitalHostBufferOperationalStatisticsStructure* hbosspHostBufferOperationalStatistics, U16BIT bIsResetOfHighestRecordedPercentageRequired);
_EXTERN S16BIT _DECL sitalBc_Set_Error(U16BIT swDevice, U16BIT wErrorType, U16BIT wMessageNumber, U16BIT wWordNumber, U16BIT wInjectionParameters, S16BIT wZXDistortion);

//MultiRT functions
_EXTERN S16BIT _DECL sital_mRt_Initialize (U16BIT swDevice, U32BIT dwOptions);
_EXTERN S16BIT _DECL sital_mRt_Close (U16BIT swDevice);
_EXTERN S16BIT _DECL sital_mRt_Create_BusList (U16BIT wBusList);
_EXTERN S16BIT _DECL sital_mRt_Create_BusList_Element (U16BIT wElement, U16BIT wCommand, U16BIT wOptions);
_EXTERN S16BIT _DECL sital_mRt_Create_Element_DataBlock (U16BIT wDataBlock, U16BIT wDataBlockMode, U16BIT* wBuffer, U16BIT wBufferSize);
_EXTERN S16BIT _DECL sital_mRt_Map_DataBlock_To_Element (U16BIT wElement, U16BIT wDataBlock);
_EXTERN S16BIT _DECL sital_mRt_Map_Element_To_BusList (U16BIT wBusList, U16BIT wElement);
_EXTERN S16BIT _DECL sital_mRt_Start (U16BIT swDevice, U16BIT wBusList);
_EXTERN S16BIT _DECL sital_mRt_Stop (U16BIT swDevice);
_EXTERN S16BIT _DECL sital_mRt_Element_DataBlock_Write (U16BIT wElement, U16BIT wDataBlock, U16BIT* wBuffer, U16BIT wBufferSize);
_EXTERN S16BIT _DECL sital_mRt_Element_DataBlock_Read (U16BIT wElement, U16BIT wDataBlock, U16BIT* wBuffer, U16BIT* wBufferSize); 
_EXTERN S16BIT _DECL sital_mRt_Delete_BusList (U16BIT wBusList);
_EXTERN S16BIT _DECL sital_mRt_Delete_BusList_Element (U16BIT wElement);
_EXTERN S16BIT _DECL sital_mRt_Delete_Element_DataBlock (U16BIT wDataBlock);
_EXTERN S16BIT _DECL sital_mRt_UnMap_DataBlock_From_Element (U16BIT wElement, U16BIT wDataBlock);
_EXTERN S16BIT _DECL sital_mRt_UnMap_Element_From_BusList (U16BIT wBusList, U16BIT wElement);
_EXTERN S16BIT _DECL sital_mRt_Get_DataBlock_NumberOfWordsToRead (U16BIT wElement, U16BIT wDataBlock, U16BIT* numWordsToRead);
_EXTERN S16BIT _DECL sital_mRt_Get_DataBlock_NumberOfWordsToWrite (U16BIT wElement, U16BIT wDataBlock, U16BIT* numWordsToWrite);
_EXTERN S16BIT _DECL sital_mRt_Get_Version (U16BIT swDevice, U16BIT* wVersion);
_EXTERN S16BIT _DECL sital_mRt_EnableRts (U16BIT swDevice, U32BIT wRtsVector); 
_EXTERN S16BIT _DECL sital_mRt_Get_EnabledRts (U16BIT swDevice, U32BIT* wRtsVector);
_EXTERN S16BIT _DECL sital_mRt_SetIntEnable (U16BIT swDevice, U16BIT wInterrupsEnabled); 
_EXTERN S16BIT _DECL sital_mRt_GetIntVector (U16BIT swDevice, U16BIT* wInterruptsStatuses);
_EXTERN S16BIT _DECL sital_mRt_SetTime (U16BIT swDevice, U32BIT wTime); 
_EXTERN S16BIT _DECL sital_mRt_GetTime (U16BIT swDevice, U32BIT* wTime);
_EXTERN S16BIT _DECL sital_mRt_SetTimeResolution (U16BIT swDevice, U16BIT wTimeResolution); 
_EXTERN S16BIT _DECL sital_mRt_GetTimeResolution (U16BIT swDevice, U16BIT* wTimeResolution);
_EXTERN S16BIT _DECL sital_mRt_Set_Error(U16BIT swDevice, U16BIT wErrorType, U16BIT wMessageNumber, U16BIT wWordNumber, U16BIT wInjectionParameters, S16BIT wZXDistortion);
_EXTERN S16BIT _DECL sital_mRt_Element_EnableIrq (S16BIT wBusList);
_EXTERN S16BIT _DECL sital_mRt_Element_ElementGetIrq (S16BIT wBusList, U16BIT wElement, U16BIT* wInterruptStatusRegisterValue);
// Service functions *******************************************
_EXTERN S16BIT _DECL RMem(U16BIT swDevice, U16BIT Address, U16BIT* Data);
_EXTERN S16BIT _DECL RReg(U16BIT swDevice, U16BIT Address, U16BIT* Data);
_EXTERN S16BIT _DECL MemTest(U16BIT swDevice, U16BIT startAddress, U16BIT endAddress, U16BIT* pass, U16BIT* errorAddress);
_EXTERN S16BIT _DECL RBar2(U16BIT card, U16BIT Address, U32BIT Length, U32BIT* Data);
//***********************************************************************
_EXTERN S16BIT _DECL sital_mRt_Create_Global_Tx_DataBlock (	U16BIT swDevice, U16BIT wMemorySize);
_EXTERN S16BIT _DECL sital_mRt_Create_Global_Rx_DataBlock (	U16BIT swDevice, U16BIT wMemorySize);
_EXTERN S16BIT _DECL sital_mRt_Get_Global_Tx_DataBlock_Address (U16BIT swDevice, U16BIT* wMemorySize);
_EXTERN S16BIT _DECL sital_mRt_Get_Global_Rx_DataBlock_Address (U16BIT swDevice, U16BIT* wMemorySize);
_EXTERN S16BIT _DECL sital_mRt_Get_buslist_Length (S16BIT wBusList);
_EXTERN S16BIT _DECL sital_mRt_Get_Element_DataBlock_GetSize (S16BIT wBusList, U16BIT wElement, S16BIT* wMemorySize);
_EXTERN S16BIT _DECL sital_mRt_Element_DataBlock_GetAddress (S16BIT wBusList, U16BIT wElement, S16BIT* wAddress, S16BIT* wMode);
_EXTERN S16BIT _DECL sital_mRt_Element_DataBlock_MapToMessage (S16BIT wBusList, U16BIT wElement);
_EXTERN S16BIT _DECL sital_mRt_Element_DataBlock_UnmapFromMessage (S16BIT wBusList, U16BIT wElement);
_EXTERN S16BIT _DECL sital_mRt_MessageLegality_Enable (S16BIT wBusList);
_EXTERN S16BIT _DECL sital_mRt_MessageLegality_Disable (S16BIT wBusList);
_EXTERN S16BIT _DECL sital_mRt_MessageLegality_GetStatus (S16BIT wBusList);
_EXTERN S16BIT _DECL sital_mRt_MessageBusyBit_Set (S16BIT wBusList, U16BIT wElement);
_EXTERN S16BIT _DECL sital_mRt_MessageBusyBit_Clear (S16BIT wBusList, U16BIT wElement);
_EXTERN S16BIT _DECL sital_mRt_MessageBusyBit_GetStatus (S16BIT wBusList, U16BIT wElement);
_EXTERN S16BIT _DECL sital_mRt_ResponseStatusBits_Set (S16BIT wBusList, U16BIT wElement, S16BIT wBits);
_EXTERN S16BIT _DECL sital_mRt_ResponseStatusBits_Unset (S16BIT wBusList, U16BIT wElement, S16BIT wBits);
_EXTERN S16BIT _DECL sital_mRt_GetDecodedMessage (S16BIT wBusList, U16BIT wElement);


// RT functions.
_EXTERN S16BIT _DECL sitalRt_Initialize (S16BIT swDevice, U16BIT wCommandStackSize, U32BIT dwOptions);
_EXTERN S16BIT _DECL sitalRt_AddressSource_Set (S16BIT swDevice, U16BIT wRtAddressSource);
_EXTERN S16BIT _DECL sitalRt_AddressSource_Get (S16BIT swDevice, U16BIT* wpRtAddressSource);
_EXTERN S16BIT _DECL sitalRt_Address_Relatch (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalRt_Address_Set (S16BIT swDevice, U16BIT wRtAddress);
_EXTERN S16BIT _DECL sitalRt_Address_Get (S16BIT swDevice, U16BIT* wpRtAddress);
_EXTERN S16BIT _DECL sitalRt_Start (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalRt_Stop (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalRt_DataBlock_GetSize (U16BIT wDataBlockType, U16BIT* wpSizeOfAllocatedDeviceMemory, U16BIT* wpActualSizeOfDataBlock);
_EXTERN S16BIT _DECL sitalRt_DataBlock_Create (	S16BIT swDevice,
												S16BIT swDataBlockId,
												U16BIT wDataBlockType,
												U16BIT* wapBuffer,
												U16BIT wBufferSize);
_EXTERN S16BIT _DECL sitalRt_DataBlock_GetAddress (S16BIT swDevice, S16BIT swDataBlockId, U16BIT* wpMemoryAddress);
_EXTERN S16BIT _DECL sitalRt_DataBlock_Delete ( S16BIT swDevice, S16BIT swDataBlockId);
_EXTERN S16BIT _DECL sitalRt_DataBlock_Write (	S16BIT swDevice,
												S16BIT swDataBlockId,
												U16BIT* wapBuffer,
												U16BIT wBufferSize,
												U16BIT wOffset);
_EXTERN S16BIT _DECL sitalRt_DataBlock_Read (	S16BIT swDevice,
												S16BIT swDataBlockId,
												U16BIT* wapBuffer,
												U16BIT wBufferSize,
												U16BIT wOffset);
_EXTERN S16BIT _DECL sitalRt_DataBlock_MapToSubaddress (	S16BIT swDevice,
															S16BIT swDataBlockId,
															U16BIT wSubaddress,
															U16BIT wMessageTypes,
															U16BIT wIrqOptions,
															U16BIT bIsSubaddressLegalizationRequested);
_EXTERN S16BIT _DECL sitalRt_DataBlock_UnmapFromSubaddress (	S16BIT swDevice,
																S16BIT swDataBlockId,
																U16BIT wSubaddress,
																U16BIT wMessageTypes);
_EXTERN S16BIT _DECL sitalRt_ModeCode_EnableIrq (S16BIT swDevice, U16BIT wModeCodeType, U16BIT wModeCodeIrq);
_EXTERN S16BIT _DECL sitalRt_ModeCode_DisableIrq (S16BIT swDevice, U16BIT wModeCodeType, U16BIT wModeCodeIrq);
_EXTERN S16BIT _DECL sitalRt_ModeCode_GetIrq (S16BIT swDevice, U16BIT wModeCodeType, U16BIT* wpModeCodeIrq);
_EXTERN S16BIT _DECL sitalRt_ModeCode_ReadData (S16BIT swDevice, U16BIT wDataContainingModeCode, U16BIT* wpData);
_EXTERN S16BIT _DECL sitalRt_ModeCode_WriteData (S16BIT swDevice, U16BIT wDataContainingModeCode, U16BIT wData);
_EXTERN S16BIT _DECL sitalRt_MessageLegality_Enable (	S16BIT swDevice,
														U16BIT wOwnAddressOrBroadcast,
														U16BIT wMessageDirection,
														U16BIT wSubaddress,
														U32BIT dwWordCountOrModeCodeMask);
_EXTERN S16BIT _DECL sitalRt_MessageLegality_Disable (	S16BIT swDevice,
														U16BIT wOwnAddressOrBroadcast,
														U16BIT wMessageDirection,
														U16BIT wSubaddress,
														U32BIT dwWordCountOrModeCodeMask);
_EXTERN S16BIT _DECL sitalRt_MessageLegality_GetStatus (	S16BIT swDevice,
															U16BIT wOwnAddressOrBroadcast,
															U16BIT wMessageDirection,
															U16BIT wSubaddress,
															U32BIT* dwpMessageLegality);
_EXTERN S16BIT _DECL sitalRt_MessageBusyBit_Set (	S16BIT swDevice,
													U16BIT wOwnAddressOrBroadcast,
													U16BIT wMessageDirection,
													U32BIT dwSubaddressMask);
_EXTERN S16BIT _DECL sitalRt_MessageBusyBit_Clear (	S16BIT swDevice,
													U16BIT wOwnAddressOrBroadcast,
													U16BIT wMessageDirection,
													U32BIT dwSubaddressMask);
_EXTERN S16BIT _DECL sitalRt_MessageBusyBit_GetStatus (	S16BIT swDevice,
														U16BIT wOwnAddressOrBroadcast,
														U16BIT wMessageDirection,
														U32BIT* dwpSubaddressMask);
_EXTERN S16BIT _DECL sitalRt_ResponseStatusBits_Set (S16BIT swDevice, U16BIT wStatusEnablerMask);
_EXTERN S16BIT _DECL sitalRt_ResponseStatusBits_Unset (S16BIT swDevice, U16BIT wStatusEnablerMask);
_EXTERN S16BIT _DECL sitalRt_ResponseStatusBits_Get (S16BIT swDevice, U16BIT* wpStatusEnablerMask);
_EXTERN S16BIT _DECL sitalRt_Message_GetFromStackRaw (S16BIT swDevice, U16BIT* wapBuffer, U16BIT wBufferSize);
_EXTERN S16BIT _DECL sitalRt_Message_GetFromStackDecoded (S16BIT swDevice, struct sitalDecodedMessageStructure* dmspDecodedMessage, U16BIT wMessageLocationAndRemoval);
_EXTERN S16BIT _DECL sitalRt_Message_DecodeRaw (S16BIT swDevice, U16BIT* wapBuffer, struct sitalDecodedMessageStructure* dmspDecodedMessage);
_EXTERN S16BIT _DECL sitalRt_BuiltInTestWord_Configure (S16BIT swDevice, U16BIT wWordLocation, U16BIT wPermitOrInihibitIfRtBusy);
_EXTERN S16BIT _DECL sitalRt_BuiltInTestWord_Read (S16BIT swDevice, U16BIT wWordLocation, U16BIT* wpWord);
_EXTERN S16BIT _DECL sitalRt_BuiltInTestWord_Write (S16BIT swDevice, U16BIT wWord);
_EXTERN S16BIT _DECL sitalRt_HostBuffer_Initialize (S16BIT swDevice, U32BIT dwHostBufferSize);
_EXTERN S16BIT _DECL sitalRt_HostBuffer_Free (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalRt_HostBuffer_Message_Record (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalRt_HostBuffer_Message_GetCount (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalRt_HostBuffer_Message_GetDecoded (	S16BIT swDevice,
																struct sitalDecodedMessageStructure* dmspDecodedMessage,
																U32BIT* dwpMessageCount,
																U32BIT* dwpStackLostMessageCount,
																U32BIT* dwpHostBufferLostMessageCount,
																U16BIT wMessageLocationAndRemoval);
_EXTERN S16BIT _DECL sitalRt_HostBuffer_Message_GetRaw (	S16BIT swDevice,
															U16BIT* wapBuffer,
															U16BIT wBufferSize,
															U32BIT* dwpMessageCount,
															U32BIT* dwpStackLostMessageCount,
															U32BIT* dwpHostBufferLostMessageCount);
_EXTERN S16BIT _DECL sitalRt_HostBuffer_GetOperationalStatistics (	S16BIT swDevice, struct sitalHostBufferOperationalStatisticsStructure* hbosspHostBufferOperationalStatistics,	
																	U16BIT bIsResetOfHighestRecordedPercentageRequired);
_EXTERN S16BIT _DECL sitalRt_Stack_GetOperationalStatistics (	S16BIT swDevice, 
																struct sitalStackOperationalStatisticsStructure* sosspStackOperationalStatistics, 
																U16BIT bIsResetOfHighestRecordedPercentageRequired);

// MT functions.
_EXTERN S16BIT _DECL sitalMt_Initialize (	S16BIT swDevice,
											U16BIT wStackMode,
											U16BIT wCommandStackSize,
											U16BIT wDataStackSize,
											U32BIT dwOptions);
_EXTERN S16BIT _DECL sitalMt_Stack_GetOperationalStatistics (	S16BIT swDevice,
																struct sitalStackOperationalStatisticsStructure* sosspStackOperationalStatistics,
																U16BIT wStackSelector,
																U16BIT bIsResetOfHighestRecordedPercentageRequired);
_EXTERN S16BIT _DECL sitalMt_Stack_Swap (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalMt_GetInformation (S16BIT swDevice, struct sitalMtInformationStructure* mispMtInformation);
_EXTERN S16BIT _DECL sitalMt_Start (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalMt_Stop (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalMt_Pause (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalMt_Continue (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalMt_MessageMonitoring_Enable (	S16BIT swDevice,
														U16BIT wRtAddress,
														U16BIT wMessageDirection,
														U32BIT dwRtSubaddressMask);
_EXTERN S16BIT _DECL sitalHoo9_Mt_MessageMonitoring_Enable (	S16BIT swDevice,
																U16BIT wRtAddress,
																U16BIT wMessageDirection,
																U64BIT qwRtSubaddressMask);
_EXTERN S16BIT _DECL sitalPp194_Mt_MessageMonitoring_Enable (	S16BIT swDevice,
																U16BIT wRtAddress,
																U16BIT wMessageDirection,
																U32BIT dwRtSubaddressMask);
_EXTERN S16BIT _DECL sitalMt_MessageMonitoring_Disable (	S16BIT swDevice,
															U16BIT wRtAddress,
															U16BIT wMessageDirection,
															U32BIT dwRtSubaddressMask);
_EXTERN S16BIT _DECL sitalHoo9_Mt_MessageMonitoring_Disable (	S16BIT swDevice,
																U16BIT wRtAddress,
																U16BIT wMessageDirection,
																U64BIT qwRtSubaddressMask);
_EXTERN S16BIT _DECL sitalPp194_Mt_MessageMonitoring_Disable (	S16BIT swDevice,
																U16BIT wRtAddress,
																U16BIT wMessageDirection,
																U32BIT dwRtSubaddressMask);
_EXTERN S16BIT _DECL sitalMt_MessageMonitoring_GetStatus (	S16BIT swDevice,
															U16BIT wRtAddress,
															U16BIT wMessageDirection,
															U32BIT* dwpRtSubaddressMask);
_EXTERN S16BIT _DECL sitalHoo9_Mt_MessageMonitoring_GetStatus (	S16BIT swDevice,
																U16BIT wRtAddress,
																U16BIT wMessageDirection,
																U64BIT* qwpRtSubaddressMask);
_EXTERN S16BIT _DECL sitalPp194_Mt_MessageMonitoring_GetStatus (	S16BIT swDevice,
																	U16BIT wRtAddress,
																	U16BIT wMessageDirection,
																	U32BIT* dwpRtSubaddressMask);
_EXTERN S16BIT _DECL sitalMt_Message_DecodeRaw (S16BIT swDevice, U16BIT* wapBuffer, struct sitalDecodedMessageStructure* dmspDecodedMessage);
_EXTERN S16BIT _DECL sitalHoo9_Mt_Message_DecodeRaw (S16BIT swDevice, U16BIT* wapBuffer, struct sitalDecodedMessageStructure* dmspDecodedMessage);
_EXTERN S16BIT _DECL sitalPp194_Mt_Message_DecodeRaw (S16BIT swDevice, U16BIT* wapBuffer, struct sitalDecodedMessageStructure* dmspDecodedMessage);
_EXTERN S16BIT _DECL sitalMt_Message_GetFromStackRaw (	S16BIT swDevice,
														U16BIT* wapBuffer,
														U16BIT wBufferSize,
														U16BIT wStackSelector);
_EXTERN S16BIT _DECL sitalHoo9_Mt_Message_GetFromStackRaw (	S16BIT swDevice,
															U16BIT* wapBuffer,
															U16BIT wBufferSize,
															U16BIT wStackSelector);
_EXTERN S16BIT _DECL sitalPp194_Mt_Message_GetFromStackRaw (	S16BIT swDevice,
																U16BIT* wapBuffer,
																U16BIT wBufferSize,
																U16BIT wStackSelector);
_EXTERN S16BIT _DECL sitalMt_Message_GetFromStackDecoded (	S16BIT swDevice,
															struct sitalDecodedMessageStructure* dmspDecodedMessage,
															U16BIT wMessageLocationAndRemoval,
															U16BIT wStackSelector);
_EXTERN S16BIT _DECL sitalHoo9_Mt_Message_GetFromStackDecoded (	S16BIT swDevice,
																struct sitalDecodedMessageStructure* dmspDecodedMessage,
																U16BIT wMessageLocationAndRemoval,
																U16BIT wStackSelector);
_EXTERN S16BIT _DECL sitalPp194_Mt_Message_GetFromStackDecoded (	S16BIT swDevice,
																	struct sitalDecodedMessageStructure* dmspDecodedMessage,
																	U16BIT wMessageLocationAndRemoval,
																	U16BIT wStackSelector);
_EXTERN S16BIT _DECL sitalMt_HostBuffer_Initialize (S16BIT swDevice, U32BIT dwHostBufferSize);
_EXTERN S16BIT _DECL sitalMt_HostBuffer_Free (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalMt_HostBuffer_Message_Record (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalMt_HostBuffer_Message_GetCount (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalMt_HostBuffer_Message_GetDecoded (	S16BIT swDevice,
																struct sitalDecodedMessageStructure* dmspDecodedMessage,
																U32BIT* dwpMessageCount,
																U32BIT* dwpStackLostMessageCount,
																U32BIT* dwpHostBufferLostMessageCount,
																U16BIT wMessageLocationAndRemoval);
_EXTERN S16BIT _DECL sitalHoo9_Mt_HostBuffer_Message_GetDecoded (	S16BIT swDevice,
																	struct sitalDecodedMessageStructure* dmspDecodedMessage,
																	U32BIT* dwpMessageCount,
																	U32BIT* dwpStackLostMessageCount,
																	U32BIT* dwpHostBufferLostMessageCount,
																	U16BIT wMessageLocationAndRemoval);
_EXTERN S16BIT _DECL sitalPp194_Mt_HostBuffer_Message_GetDecoded (	S16BIT swDevice,
																	struct sitalDecodedMessageStructure* dmspDecodedMessage,
																	U32BIT* dwpMessageCount,
																	U32BIT* dwpStackLostMessageCount,
																	U32BIT* dwpHostBufferLostMessageCount,
																	U16BIT wMessageLocationAndRemoval);
_EXTERN S16BIT _DECL sitalMt_HostBuffer_Message_GetRaw (	S16BIT swDevice,
															U16BIT* wapBuffer,
															U16BIT wBufferSize,
															U32BIT* dwpMessageCount,
															U32BIT* dwpStackLostMessageCount,
															U32BIT* dwpHostBufferLostMessageCount);
_EXTERN S16BIT _DECL sitalHoo9_Mt_HostBuffer_Message_GetRaw (	S16BIT swDevice,
																U16BIT* wapBuffer,
																U16BIT wBufferSize,
																U32BIT* dwpMessageCount,
																U32BIT* dwpStackLostMessageCount,
																U32BIT* dwpHostBufferLostMessageCount);
_EXTERN S16BIT _DECL sitalPp194_Mt_HostBuffer_Message_GetRaw (	S16BIT swDevice,
																U16BIT* wapBuffer,
																U16BIT wBufferSize,
																U32BIT* dwpMessageCount,
																U32BIT* dwpStackLostMessageCount,
																U32BIT* dwpHostBufferLostMessageCount);
_EXTERN S16BIT _DECL sitalMt_HostBuffer_GetOperationalStatistics (S16BIT swDevice, struct sitalHostBufferOperationalStatisticsStructure* hbosspHostBufferOperationalStatistics, U16BIT bIsResetOfHighestRecordedPercentageRequired);

// RT&MT functions.
_EXTERN S16BIT _DECL sitalRtMt_Initialize (	S16BIT swDevice,
											U16BIT wRtCommandStackSize,
											U16BIT wMtStackMode,
											U16BIT wMtCommandStackSize,
											U16BIT wMtDataStackSize,
											U32BIT dwOptions);
_EXTERN S16BIT _DECL sitalRtMt_Start (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalRtMt_Stop (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalRtMt_HostBuffer_Initialize (S16BIT swDevice, U32BIT dwHostBufferSize);
_EXTERN S16BIT _DECL sitalRtMt_HostBuffer_Free (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalRtMt_HostBuffer_Message_Record (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalRtMt_HostBuffer_Message_GetCount (S16BIT swDevice);
_EXTERN S16BIT _DECL sitalRtMt_HostBuffer_Message_GetDecoded (	S16BIT swDevice,
																struct sitalDecodedMessageStructure* dmspDecodedMessage,
																U32BIT* dwpMessageCount,
																U32BIT* dwpRtStackLostMessageCount,
																U32BIT* dwpMtStackLostMessageCount,
																U32BIT* dwpHostBufferLostMessageCount,
																U16BIT wMessageLocationAndRemoval);
_EXTERN S16BIT _DECL sitalRtMt_HostBuffer_Message_GetRaw (	S16BIT swDevice,
															U16BIT* wapBuffer,
															U16BIT wBufferSize,
															U32BIT* dwpMessageCount,
															U32BIT* dwpRtStackLostMessageCount,
															U32BIT* dwpMtStackLostMessageCount,
															U32BIT* dwpHostBufferLostMessageCount);
_EXTERN S16BIT _DECL sitalRtMt_HostBuffer_GetOperationalStatistics (S16BIT swDevice, struct sitalHostBufferOperationalStatisticsStructure* hbosspHostBufferOperationalStatistics, U16BIT bIsResetOfHighestRecordedPercentageRequired);

// DDC Message Struct
/* Global (used for all modes) Message Structure for decoded 1553 msgs */
typedef struct MSGSTRUCT
{
	U16BIT wType;				/* Contains the msg type (see above) */
	U16BIT wBlkSts;				/* Contains the block status word */
	U16BIT wTimeTag3;
	U16BIT wTimeTag2;
	U16BIT wTimeTag;			/* Time tag of message */
	U16BIT wCmdWrd1;			/* First command word */
	U16BIT wCmdWrd2;			/* Second command word (RT to RT) */
	U16BIT wCmdWrd1Flg;			/* Is command word 1 valid? */
	U16BIT wCmdWrd2Flg;			/* Is command word 2 valid? */
	U16BIT wStsWrd1;			/* First status word */
	U16BIT wStsWrd2;			/* Second status word */
	U16BIT wStsWrd1Flg;			/* Is status word 1 valid? */
	U16BIT wStsWrd2Flg;			/* Is status word 2 valid? */
	U16BIT wWordCount;			/* Number of valid data words */
	U16BIT aDataWrds[32];		/* An array of data words */

	/* The following are only applicable in BC mode */
	U16BIT wBCCtrlWrd;			/* Contains the BC control word */
	U16BIT wBCGapTime;			/* Message gap time word */
	U16BIT wBCLoopBack1;		/* First looped back word */
	U16BIT wBCLoopBack2;		/* Second looped back word */
	U16BIT wBCLoopBack1Flg;		/* Is loop back 1 valid? */
	U16BIT wBCLoopBack2Flg;		/* Is loop back 2 valid? */
	
}MSGSTRUCT;

// Unique DDC Exports 
_EXTERN U16BIT _DECL aceGetLibVersion (void);
_EXTERN S16BIT _DECL aceFree (S16BIT swDevice);
_EXTERN S16BIT _DECL aceRTGetAddress (S16BIT swDevice, U16BIT* wpRtAddress);
_EXTERN S16BIT _DECL aceInitialize (S16BIT swDevice, U16BIT wAccess, U16BIT wMode, U32BIT dwSizeOfAllocatedMemory, U32BIT dwRegistersAddress, U32BIT dwMemoryAddress);
_EXTERN S16BIT _DECL aceRTSetAddress (S16BIT swDevice, U16BIT wRtAddress);
_EXTERN S16BIT _DECL aceSetTimeTagRes (S16BIT swDevice, U16BIT wTimeTagResolution);
_EXTERN S16BIT _DECL aceMTStart (S16BIT swDevice);
_EXTERN S16BIT _DECL aceMTContinue (S16BIT swDevice);
_EXTERN S16BIT _DECL aceMTGetStkMsgDecoded (S16BIT swDevice, MSGSTRUCT* dmspDecodedMessage,	U16BIT wMessageLocationAndRemoval, U16BIT wStackLocation); 
_EXTERN S16BIT _DECL aceMTPause (S16BIT swDevice);
_EXTERN S16BIT _DECL aceMTStop (S16BIT swDevice); 
_EXTERN S16BIT _DECL aceMTEnableRTFilter (S16BIT swDevice, U16BIT wRtAddress, U16BIT wMessageDirection,	U32BIT dwSubaddressMask);
_EXTERN S16BIT _DECL aceMTDisableRTFilter (S16BIT swDevice,	U16BIT wRtAddress, U16BIT wMessageDirection, U32BIT dwSubaddressMask);
_EXTERN S16BIT _DECL aceRTDataBlkCreate (S16BIT swDevice, S16BIT swDataBlockId,	U16BIT wDataBlockType, U16BIT* wapBuffer, U16BIT wBufferSize);
_EXTERN S16BIT _DECL aceRTDataBlkMapToSA (S16BIT swDevice, S16BIT swDataBlockId, U16BIT wSubaddress, U16BIT wMessageTypes, U16BIT wIrqOptions, U16BIT bIsSubaddressLegalizationRequested);
_EXTERN S16BIT _DECL aceRTModeCodeWriteData (S16BIT swDevice, U16BIT wDataContainingModeCode, U16BIT wData);
_EXTERN S16BIT _DECL aceRTStart (S16BIT swDevice);
_EXTERN S16BIT _DECL aceRTGetStkMsgDecoded (S16BIT swDevice, MSGSTRUCT* dmspDecodedMessage, U16BIT wMessageLocationAndRemoval);
_EXTERN S16BIT _DECL aceRTModeCodeReadData (S16BIT swDevice, U16BIT wDataContainingModeCode, U16BIT* wpData); 
_EXTERN S16BIT _DECL aceRTStop (S16BIT swDevice);
_EXTERN S16BIT _DECL aceRTDataBlkUnmapFromSA (S16BIT swDevice, S16BIT swDataBlockId, U16BIT wSubaddress, U16BIT wMessageTypes);
_EXTERN S16BIT _DECL aceRTDataBlkDelete ( S16BIT swDevice, S16BIT swDataBlockId);
_EXTERN S16BIT _DECL aceSetIrqConditions (S16BIT swDevice, U16BIT bIsInterruptEnabled, U32BIT dwIrqMask, USER_ISR_FUNCTION funcpExternalIsr);
_EXTERN S16BIT _DECL aceBCDataBlkCreate (S16BIT swDevice, S16BIT swDataBlockId, U16BIT wDataBlockType, U16BIT* wapBuffer, U16BIT wBufferSize);
_EXTERN S16BIT _DECL aceBCMsgCreateBCtoRT (S16BIT swDevice,	S16BIT swMessageId,	S16BIT swDataBlockId, U16BIT wReceiverRt, U16BIT wReceiverRtSubaddress,	U16BIT wWordCount, U16BIT wGapTime,	U32BIT dwOptions);
_EXTERN S16BIT _DECL aceBCOpCodeCreate (S16BIT swDevice, S16BIT swCommandId, U16BIT wOpcode, U16BIT wCondition,	U32BIT dwParameter1, U32BIT dwParameter2, U32BIT dwReserved);
_EXTERN S16BIT _DECL aceBCFrameCreate (S16BIT swDevice,	S16BIT swFrameId, U16BIT wFrameType, S16BIT* swapCommandIds, U16BIT wCommandCount, U16BIT wFrameTime, U16BIT wFlags);
_EXTERN S16BIT _DECL aceBCGetStatus (S16BIT swDevice, U16BIT *wpCurrentState);
_EXTERN S16BIT _DECL aceBCStop (S16BIT swDevice);
_EXTERN S16BIT _DECL aceBCGetMsgFromIDDecoded (	S16BIT swDevice, S16BIT swMessageId, MSGSTRUCT* dmspDecodedMessage, U16BIT wIsPurgeRequired);
_EXTERN S16BIT _DECL aceBCFrameDelete (S16BIT swDevice, S16BIT swFrameId);
_EXTERN S16BIT _DECL aceBCOpCodeDelete (S16BIT swDevice, S16BIT swCommandId);
_EXTERN S16BIT _DECL aceBCMsgDelete (S16BIT swDevice, S16BIT swMessageId);
_EXTERN S16BIT _DECL aceBCDataBlkDelete (S16BIT swDevice, S16BIT swDataBlockId);
_EXTERN S16BIT _DECL aceBCMsgCreate (S16BIT swDevice, S16BIT swMessageId, S16BIT swDataBlockIdForMessage1, U16BIT wBcControlWordForMessage1, U16BIT wCommandWord1ForMessage1, U16BIT wCommandWord2ForMessage1, U16BIT wGapTimeForMessage1, S16BIT swDataBlockIdForMessage2,	U16BIT wBcControlWordForMessage2, U16BIT wCommandWord1ForMessage2, U16BIT wCommandWord2ForMessage2,	U16BIT wGapTimeForMessage2,	U32BIT dwOptions); 

_EXTERN S16BIT _DECL sital_RS485_Initialize (U16BIT swDevice, U32BIT dwOptions);
_EXTERN S16BIT _DECL sital_RS485_Setup (U16BIT swDevice, U16BIT uiBitsCount, U16BIT peParity, U16BIT sbeStopBits, U32BIT pciSpeed, U32BIT rs485BaudRate, U16BIT rtmeRxTxMode, U16BIT* uipOffset);
_EXTERN S16BIT _DECL sital_RS485_Put (U16BIT swDevice, U16BIT uiLength, WORD* waBuffer);
_EXTERN S16BIT _DECL sital_RS485_Get (U16BIT swDevice, U16BIT* uipOffset, U16BIT uiLength, WORD* waBuffer);
_EXTERN S16BIT _DECL sital_RS485_GetNumberOfReceivedWords (U16BIT swDevice, U16BIT uiOffset, U16BIT* uipLength);

_EXTERN S16BIT _DECL sital_GPIO_Read (U16BIT swDevice, U16BIT* wData);
_EXTERN S16BIT _DECL sital_GPIO_Write (U16BIT swDevice, U16BIT wData);
_EXTERN S16BIT _DECL sital_GPIO_Set2HiZ (U16BIT swDevice);

_EXTERN S16BIT _DECL sital_A429_GetCount(U16BIT* swCards, U16BIT* numOfChannels);
_EXTERN S16BIT _DECL sital_A429_Channel_Open(U16BIT swCard, U16BIT channel, sital_A429ChannelInfo* channelInfo);
_EXTERN S16BIT _DECL sital_A429_Channel_GetInformation(U16BIT swCard, U16BIT channel, sital_A429ChannelInfo* channelInfo);
_EXTERN S16BIT _DECL sital_A429_Channel_Close(U16BIT swCard, U16BIT channel);
_EXTERN S16BIT _DECL sital_A429_Channel_SetConfigRegister(U16BIT swCard, U16BIT channel, U32BIT chanFlags);
_EXTERN S16BIT _DECL sital_A429_Channel_GetConfigRegister(U16BIT swCard, U16BIT channel, U32BIT* chanFlags);
_EXTERN S16BIT _DECL sital_A429_Channel_GetStatusRegister(U16BIT swCard, U16BIT channel, U32BIT* chanStats);
_EXTERN S16BIT _DECL sital_A429_Receive (U16BIT swCard, U16BIT channel, U32BIT bufferSize, U32BIT* buffer, U32BIT* numberOfReceivedWords);
_EXTERN S16BIT _DECL sital_A429_Send (U16BIT swCard, U16BIT channel, U32BIT bufferSize, U32BIT* buffer, U32BIT* numberOfWrittenWords);
_EXTERN S16BIT _DECL sital_A429_GetRxWordsPending(U16BIT swCard, U16BIT channel, U32BIT* numberOfWords);
_EXTERN S16BIT _DECL sital_A429_Channel_Reset(U16BIT swCard, U16BIT channel, U32BIT chanFlags);
_EXTERN S16BIT _DECL sital_A429_Card_SetConfiguration(U16BIT swCard, U32BIT cardFlags);

_EXTERN S16BIT a429_Write(U16BIT card, U16BIT channel, U32BIT address, U32BIT len, U32BIT* buffer);
_EXTERN S16BIT a429_Read(U16BIT card, U16BIT channel, U32BIT address, U32BIT len, U32BIT* buffer);

#ifdef __cplusplus
}
#endif

#endif // stld1553_INCLUDED
